# -*- encoding: UTF-8 -*-
dic = [['(?u)(?<![-\\w–.,\xad])(assim|lhe|lhes|me|não|nos|que|te|vezes|vos) da vontade de ([a-zç]+)r(?![-\\w–\xad])', '\\1 dá vontade de \\2r', 'Faltou o acento em dá? Você quis dizer:', False],
 ['(?u)\\b([,]) da vontade de ([a-zç]+)r(?![-\\w–\xad])', ', dá vontade de \\2r', 'Faltou o acento em dá ou o "r" em dar? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])a (?P<Pdah_0>[a-zàáâãçéêíóôú]+)(?![-\\w–\xad])', '\\1á \\2\\n\\1ar \\2', 'Faltou o acento em dá? Você quis dizer:', 'm.group("Pdah_0") in plvrGdada'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue da (?P<Pdah_1>[a-zàáâãçéêíóôú]+)(?![-\\w–\xad])', '\\1ue dá \\2', 'Faltou o acento em dá? Você quis dizer:', 'not " do que da " in TEXT and not " da que da " in TEXT and m.group("Pdah_1") in plvrQdada'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])ão da (?P<Pdah_2>[a-zàáâãçéêíóôú]+)(?![-\\w–\xad])', '\\1ão dá \\2', 'Faltou o acento em dá? Você quis dizer:', 'm.group("Pdah_2") in plvrNdada'],
 ['(?u)(?<![-\\w–.,\xad])da([,.!?])(?![-\\w–\xad])', 'dá\\1', 'Faltou o acento em dá? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ara da(?![-\\w–\xad])', '\\1ara dar', 'Você quis dizer:', 'not excparadah.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ara dá(?![-\\w–\xad])', '\\1ara dar', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ra da(?![-\\w–\xad])', '\\1ra dar', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ra dá(?![-\\w–\xad])', '\\1ra dar', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])e da(?![-\\w–\xad])', '\\1e dar', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])e dá(?![-\\w–\xad])', '\\1e dar', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])ás(?![-\\w–\xad])', 'às\\nas', 'Você quis dizer:', 'not "um "+"à"+"s" in TEXT and not "uma "+"à"+"s" in TEXT and not " o "+"à"+"s" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])Ei de(?![-\\w–\xad])', 'Hei de', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])ei de(?![-\\w–\xad])', 'hei de', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])ltos ([Ff])alantes(?![-\\w–\xad])', '\\1lto-falantes', 'Termo composto? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([a-zA-Záâãçéêíóôõú]+) no entanto ([a-záâãçéêíóôõú]+)(?![-\\w–\xad])', '\\1, no entanto, \\2', 'Faltaram as pausas. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])No entanto ([a-záâãçéêíóôõú]+)(?![-\\w–\xad])', 'No entanto, \\1', 'Faltou a pausa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Acusamos o recebimento de(?![-\\w–\xad])', 'Recebemos', 'Simplifique. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Agradecemos a atenção dispensada(?![-\\w–\xad])', 'Agradecemos', 'Simplifique. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Agradecendo a atenção dispensada(?![-\\w–\xad])', 'Agradecemos', 'Simplifique. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Acima citado(?![-\\w–\xad])', 'Citado', 'Simplifique. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])acima citado(?![-\\w–\xad])', 'citado', 'Simplifique. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Acima citada(?![-\\w–\xad])', 'Citada', 'Simplifique. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])acima citada(?![-\\w–\xad])', 'citada', 'Simplifique. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Antecipadamente gratos(?![-\\w–\xad])', 'Gratos', 'Simplifique. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])antecipadamente gratos(?![-\\w–\xad])', 'gratos', 'Simplifique. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Aproveitamos o ensejo para comunicar(?![-\\w–\xad])', 'Comunicamos', 'Simplifique. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])aproveitamos o ensejo para comunicar(?![-\\w–\xad])', 'comunicamos', 'Simplifique. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])De acordo com o supracitado(?![-\\w–\xad])', 'Conforme exposto', 'Simplifique. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])de acordo com o supracitado(?![-\\w–\xad])', 'conforme exposto', 'Simplifique. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Levamos ao conhecimento de(?![-\\w–\xad])', 'Informamos', 'Simplifique. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])levamos ao conhecimento de(?![-\\w–\xad])', 'informamos', 'Simplifique. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])levar ao conhecimento de(?![-\\w–\xad])', 'informar', 'Simplifique. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])levou ao conhecimento de(?![-\\w–\xad])', 'informo', 'Simplifique. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])No que tange a(?![-\\w–\xad])', 'Em relação a\\nQuanto a\\nNo âmbito da\\nNo que se refere a\\nCom relação a', 'Expressão arcaica. Você pode substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])No que tange ao(?![-\\w–\xad])', 'Em relação ao\\nQuanto ao\\nNo âmbito do\\nNo que se refere ao\\nCom relação ao', 'Expressão arcaica. Você pode substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])no que tange a(?![-\\w–\xad])', 'em relação a\\nquanto a\\nno âmbito da\\nno que se refere a\\ncom relação a', 'Expressão arcaica. Você pode substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])no que tange ao(?![-\\w–\xad])', 'em relação ao\\nquanto ao\\nno âmbito do\\nno que se refere ao\\ncom relação ao', 'Expressão arcaica. Você pode substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) medida em que(?![-\\w–\xad])', '\\1 medida que', 'Uso inapropriado da preposição "EM". Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])ter (?P<Ptd_1>[a-zA-Zç]+)ada a(?![-\\w–\xad])', '= "ter " + m.group(1) + "ado a"', 'Você quis dizer:', 'not m.group("Ptd_1") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])ter (?P<Ptd_2>[a-zA-Zç]+)ada uma(?![-\\w–\xad])', '= "ter " + m.group(1) + "ado uma"', 'Você quis dizer:', 'not m.group("Ptd_2") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])ter (?P<Ptd_3>[a-zA-Zç]+)ida a(?![-\\w–\xad])', '= "ter " + m.group(1) + "ido a"', 'Você quis dizer:', 'not m.group("Ptd_3") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])ter (?P<Ptd_4>[a-zA-Zç]+)ida uma(?![-\\w–\xad])', '= "ter " + m.group(1) + "ido uma"', 'Você quis dizer:', 'not m.group("Ptd_4") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(Não|não|Nunca|nunca|Jamais|jamais|Nada|nada|Ninguém|ninguém) (?P<Pqn_1>[a-záâãçéêíóôõú]+) qualquer(?![-\\w–\xad])', '\\1 \\2 nenhum\\n\\1 \\2 nenhuma', 'Após negativas usa-se "nenhum" em vez de "qualquer". Você quis dizer:', 'm.group("Pqn_1") in pnqquer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]lguma|[Aa]aquela|[Dd]a|[Dd]aquela|[Dd]essa|[Nn]a|[Nn]ova|[Pp]ela|[Uu]ma|[Vv]ária)s via(?![-\\w–\xad])', '\\1s vias', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]lguma|[Aa]aquela|[Dd]a|[Dd]aquela|[Dd]essa|[Nn]a|[Nn]ova|[Pp]ela|[Uu]ma) vias(?![-\\w–\xad])', '\\1s vias', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uto nível(?![-\\w–\xad])', '\\1lto nível', 'Você quis dizer:', False],
# -*- Iniciar frase com maiuscula -*-
 ['(?u)(?<![-\\w–.,\xad])(^)(?P<low_1>[a-záâçéêíóôõúã]+)(?![-\\w–\xad])', '= m.group("low_1").capitalize()', 'Iniciar com maiúscula?', 'paralcap.search(TEXT) and not abbrev.search(TEXT) and option(LOCALE,"cap")'],
 ['(?u)((?<=[!?.] )|^)(?P<low_2>[a-záâçéêíóôõúã]+)(?![-\\w–\xad])', '= m.group("low_2").capitalize()', 'Iniciar com maiúscula?', 'not "... " + m.group("low_2") in TEXT and option(LOCALE,"cap") and not abbrev.search(TEXT) and not erroscap.search(TEXT) and not erroscapa.search(TEXT) and not erroscapb.search(TEXT) and not erroscapc.search(TEXT)'],
# -*- FIM Iniciar frase com maiuscula -*-
# -*- Palavras repetidas - duplicadas -*-
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_a>[Aa][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_a>[Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_a>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_b>[Bb][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_b>[Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_b>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_c>[Cc][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_c>[Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_c>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_d>[Dd][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_d>[Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_d>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_e>[Ee][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_e>[Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_e>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup") and not m.group(2) in "e"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_f>[Ff][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_f>[Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_f>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_g>[Gg][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_g>[Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_g>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_h>[Hh][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_h>[Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_h>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_i>[Ii][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_i>[Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_i>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_j>[Jj][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_j>[Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_j>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_k>[Kk][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_k>[Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_k>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_l>[Ll][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_l>[Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_l>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_m>[Mm][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_m>[Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_m>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_n>[Nn][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_n>[Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_n>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_o>[Oo][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_o>[Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_o>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_p>[Pp][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_p>[Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_p>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in excpLvrep and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_q>[Qq][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_q>[Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_q>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_r>[Rr][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_r>[Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_r>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_s>[Ss][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_s>[Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_s>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in "se-Se-SE-sE" and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_t>[Tt][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_t>[Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_t>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_u>[Uu][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_u>[Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_u>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_v>[Vv][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_v>[Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_v>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_w>[Ww][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_w>[Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_w>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_x>[Xx][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_x>[Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_x>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_y>[Yy][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_y>[Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_y>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_z>[Zz][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_z>[Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_z>', 'Palavras repetidas. Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and not m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_a>[Aa][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_a>[Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_b>[Bb][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_b>[Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_c>[Cc][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_c>[Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_d>[Dd][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_d>[Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_e>[Ee][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_e>[Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_f>[Ff][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_f>[Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_g>[Gg][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_g>[Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_h>[Hh][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_h>[Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_i>[Ii][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_i>[Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_j>[Jj][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_j>[Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_k>[Kk][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_k>[Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_l>[Ll][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_l>[Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_m>[Mm][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_m>[Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_n>[Nn][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_n>[Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_o>[Oo][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_o>[Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_p>[Pp][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_p>[Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_q>[Qq][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_q>[Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_r>[Rr][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_r>[Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_s>[Ss][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_s>[Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_t>[Tt][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_t>[Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_u>[Uu][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_u>[Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_v>[Vv][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_v>[Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_w>[Ww][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_w>[Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_x>[Xx][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_x>[Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_y>[Yy][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_y>[Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpc_z>[Zz][a-zA-Záâçéêíóôõúã]+) (?P<Dcp_z>[Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1\\n\\1-\\2', 'Palavras repetidas ou termo composto? Você quis dizer:', 'm.group(1).lower() == m.group(2).lower() and m.group(1) in igualTc and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ara para(?![-\\w–\xad])', '\\1ara', 'Palavra repetida. Você quis dizer:', 'not excpPara.search(TEXT) and option(LOCALE,"dup")'],
# ---*--- Dupla repeticao ---*---
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Ww][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Xx][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Yy][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Aa][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Bb][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Cc][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Dd][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Ee][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Ff][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Gg][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Hh][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Ii][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Jj][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Kk][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Ll][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Mm][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Nn][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Oo][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Pp][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Qq][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Rr][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Ss][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Tt][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Uu][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Vv][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Ww][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Xx][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Yy][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])([Zz][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+) ([Zz][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\1 \\2', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(3) and m.group(2) == m.group(4) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_1>[Áá][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_1>[Áá][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_1>', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(2) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_2>[Ââ][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_2>[Ââ][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_2>', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(2) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_3>[Éé][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_3>[Éé][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_3>', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(2) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_4>[Êê][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_4>[Êê][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_4>', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(2) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_5>[Íí][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_5>[Íí][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_5>', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(2) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_6>[Óó][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_6>[Óó][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_6>', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(2) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_7>[Ôô][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_7>[Ôô][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_7>', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(2) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dup_8>[Úú][a-zA-Záâçéêíóôõúã]+) (?P<Dpu_8>[Úú][a-zA-Záâçéêíóôõúã]+)(?![-\\w–\xad])', '\\g<Dup_8>', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(2) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Duq_1>[a-zA-Z]) (?P<Dqu_1>[a-zA-Z])(?![-\\w–\xad])', '\\g<Duq_1>', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(2) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Duq_2>[Éé]) (?P<Dqu_2>[Éé])(?![-\\w–\xad])', '\\g<Duq_2>', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(2) and option(LOCALE,"dup")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Duq_3>[Àà]) (?P<Dqu_3>[Àà])(?![-\\w–\xad])', '\\g<Duq_3>', 'Palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(2) and option(LOCALE,"dup")'],
# ---*--- FIM Dupla repeticao ---*---
# -*- FIM Palavras repetidas - duplicadas -*-
# -*- Pleonasmos -*-
 ['(?u)(?<![-\\w–.,\xad])([Hh])á (?P<Pln_1>[a-zA-Z0-9áâçéêíóôú]+) anos atrás(?![-\\w–\xad])', '\\1á \\g<Pln_1> anos', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á (?P<Pln_2>[a-zA-Z0-9áâçéêíóôú]+) meses atrás(?![-\\w–\xad])', '\\1á \\g<Pln_2> meses', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á (?P<Pln_3>[a-zA-Z0-9áâçéêíóôú]+) dias atrás(?![-\\w–\xad])', '\\1á \\g<Pln_3> dias', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á (?P<Pln_4>[a-zA-Z0-9áâçéêíóôú]+) horas atrás(?![-\\w–\xad])', '\\1á \\g<Pln_4> horas', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á (?P<Pln_45>[a-zA-Z0-9áâçéêíóôú]+) mil anos atrás(?![-\\w–\xad])', '\\1á \\g<Pln_45> mil anos', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á (?P<Pln_46>[a-zA-Z0-9áâçéêíóôú]+) mil meses atrás(?![-\\w–\xad])', '\\1á \\g<Pln_46> mil meses', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á (?P<Pln_47>[a-zA-Z0-9áâçéêíóôú]+) mil dias atrás(?![-\\w–\xad])', '\\1á \\g<Pln_47> mil dias', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á (?P<Pln_48>[a-zA-Z0-9áâçéêíóôú]+) mil horas atrás(?![-\\w–\xad])', '\\1á \\g<Pln_48> mil horas', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á cerca de (?P<Plcn_1>[a-zA-Z0-9áâçéêíóôú]+) anos atrás(?![-\\w–\xad])', '\\1á cerca de \\g<Plcn_1> anos', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á cerca de (?P<Plcn_2>[a-zA-Z0-9áâçéêíóôú]+) meses atrás(?![-\\w–\xad])', '\\1á cerca de \\g<Plcn_2> meses', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á cerca de (?P<Plcn_3>[a-zA-Z0-9áâçéêíóôú]+) dias atrás(?![-\\w–\xad])', '\\1á cerca de \\g<Plcn_3> dias', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á cerca de (?P<Plcn_4>[a-zA-Z0-9áâçéêíóôú]+) horas atrás(?![-\\w–\xad])', '\\1á cerca de \\g<Plcn_4> horas', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á cerca de (?P<Plcn_45>[a-zA-Z0-9áâçéêíóôú]+) mil anos atrás(?![-\\w–\xad])', '\\1á cerca de \\g<Plcn_45> mil anos', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á cerca de (?P<Plcn_46>[a-zA-Z0-9áâçéêíóôú]+) mil meses atrás(?![-\\w–\xad])', '\\1á cerca de \\g<Plcn_46> mil meses', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á cerca de (?P<Plcn_47>[a-zA-Z0-9áâçéêíóôú]+) mil dias atrás(?![-\\w–\xad])', '\\1á cerca de \\g<Plcn_47> mil dias', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á cerca de (?P<Plcn_48>[a-zA-Z0-9áâçéêíóôú]+) mil horas atrás(?![-\\w–\xad])', '\\1á cerca de \\g<Plcn_48> mil horas', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])A cerca de (?P<Plcx_1>[a-zA-Z0-9áâçéêíóôú]+) anos(?![-\\w–\xad])', 'Há cerca de \\g<Plcx_1> anos', 'Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])A cerca de (?P<Plcx_2>[a-zA-Z0-9áâçéêíóôú]+) meses(?![-\\w–\xad])', 'Há cerca de \\g<Plcx_2> meses', 'Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])A cerca de (?P<Plcx_3>[a-zA-Z0-9áâçéêíóôú]+) dias(?![-\\w–\xad])', 'Há cerca de \\g<Plcx_3> dias', 'Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])A cerca de (?P<Plcx_4>[a-zA-Z0-9áâçéêíóôú]+) horas(?![-\\w–\xad])', 'Há cerca de \\g<Plcx_4> horas', 'Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])A cerca de (?P<Plcx_45>[a-zA-Z0-9áâçéêíóôú]+) mil anos(?![-\\w–\xad])', 'Há cerca de \\g<Plcx_45> mil anos', 'Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])A cerca de (?P<Plcx_46>[a-zA-Z0-9áâçéêíóôú]+) mil meses(?![-\\w–\xad])', 'Há cerca de \\g<Plcx_46> mil meses', 'Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])A cerca de (?P<Plcx_47>[a-zA-Z0-9áâçéêíóôú]+) mil dias(?![-\\w–\xad])', 'Há cerca de \\g<Plcx_47> mil dias', 'Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])A cerca de (?P<Plcx_48>[a-zA-Z0-9áâçéêíóôú]+) mil horas(?![-\\w–\xad])', 'Há cerca de \\g<Plcx_48> mil horas', 'Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])a cerca de (?P<Plcy_1>[a-zA-Z0-9áâçéêíóôú]+) anos(?![-\\w–\xad])', 'há cerca de \\g<Plcy_1> anos', 'Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])a cerca de (?P<Plcy_2>[a-zA-Z0-9áâçéêíóôú]+) meses(?![-\\w–\xad])', 'há cerca de \\g<Plcy_2> meses', 'Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])a cerca de (?P<Plcy_3>[a-zA-Z0-9áâçéêíóôú]+) dias(?![-\\w–\xad])', 'há cerca de \\g<Plcy_3> dias', 'Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])a cerca de (?P<Plcy_4>[a-zA-Z0-9áâçéêíóôú]+) horas(?![-\\w–\xad])', 'há cerca de \\g<Plcy_4> horas', 'Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])a cerca de (?P<Plcy_45>[a-zA-Z0-9áâçéêíóôú]+) mil anos(?![-\\w–\xad])', 'há cerca de \\g<Plcy_45> mil anos', 'Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])a cerca de (?P<Plcy_46>[a-zA-Z0-9áâçéêíóôú]+) mil meses(?![-\\w–\xad])', 'há cerca de \\g<Plcy_46> mil meses', 'Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])a cerca de (?P<Plcy_47>[a-zA-Z0-9áâçéêíóôú]+) mil dias(?![-\\w–\xad])', 'há cerca de \\g<Plcy_47> mil dias', 'Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])a cerca de (?P<Plcy_48>[a-zA-Z0-9áâçéêíóôú]+) mil horas(?![-\\w–\xad])', 'há cerca de \\g<Plcy_48> mil horas', 'Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á milhares de anos atrás(?![-\\w–\xad])', '\\1á milhares de anos', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á ([bm])ilhões de anos atrás(?![-\\w–\xad])', '\\1á \\2ilhões de anos', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á trilhões de anos atrás(?![-\\w–\xad])', '\\1á trilhões de anos', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á anos atrás(?![-\\w–\xad])', '\\1á anos', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á meses atrás(?![-\\w–\xad])', '\\1á meses', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á dias atrás(?![-\\w–\xad])', '\\1á dias', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á horas atrás(?![-\\w–\xad])', '\\1á horas', 'Pleonasmo, há e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])aiu para fora(?![-\\w–\xad])', '\\1ai', 'Pleonasmo. Sair e fora são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])aiu pra fora(?![-\\w–\xad])', '\\1ai', 'Pleonasmo. Sair e fora são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])air fora(?![-\\w–\xad])', '\\1air', 'Pleonasmo. Sair e fora são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ntrou para dentro(?![-\\w–\xad])', '\\1ntro', 'Pleonasmo. Entrar e dentro são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ntrou pra dentro(?![-\\w–\xad])', '\\1ntro', 'Pleonasmo. Entrar e dentro são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ntrou dentro(?![-\\w–\xad])', '\\1ntro', 'Pleonasmo. Entrar e dentro são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ntrar dentro(?![-\\w–\xad])', '\\1ntrar', 'Pleonasmo. Entrar e dentro são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])ub(o|a|i|iu|ir|imos|amos|iram|ia) (p|pa)ra cima(?![-\\w–\xad])', '\\1ub\\2', 'Pleonasmo. Subir e cima são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])ob(e|em|es) (p|pa)ra cima(?![-\\w–\xad])', '\\1ob\\2', 'Pleonasmo. Subir e cima são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])esceu para baixo(?![-\\w–\xad])', '\\1esce', 'Pleonasmo. Descer e baixo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])esceu pra baixo(?![-\\w–\xad])', '\\1esce', 'Pleonasmo. Descer e baixo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riar um novo (?P<Pln_5>[a-zA-Z0-9áâçéêíóôú]+)(?![-\\w–\xad])', '\\1riar um \\g<Pln_5>', 'Pleonasmo. Criar e Novo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riar uma nova (?P<Pln_6>[a-zA-Z0-9áâçéêíóôú]+)(?![-\\w–\xad])', '\\1riar uma \\g<Pln_6>', 'Pleonasmo. Criar e Novo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riaram um novo (?P<Pln_7>[a-zA-Z0-9áâçéêíóôú]+)(?![-\\w–\xad])', '\\1riaram um \\g<Pln_7>', 'Pleonasmo. Criar e Novo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riaram uma nova (?P<Pln_8>[a-zA-Z0-9áâçéêíóôú]+)(?![-\\w–\xad])', '\\1riaram uma \\g<Pln_8>', 'Pleonasmo. Criar e Novo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riamos um novo (?P<Pln_9>[a-zA-Z0-9áâçéêíóôú]+)(?![-\\w–\xad])', '\\1riamos um \\g<Pln_9>', 'Pleonasmo. Criar e Novo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riamos uma nova (?P<Pln_10>[a-zA-Z0-9áâçéêíóôú]+)(?![-\\w–\xad])', '\\1riamos uma \\g<Pln_10>', 'Pleonasmo. Criar e Novo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riei um novo (?P<Pln_11>[a-zA-Z0-9áâçéêíóôú]+)(?![-\\w–\xad])', '\\1riei um \\g<Pln_11>', 'Pleonasmo. Criar e Novo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riei uma nova (?P<Pln_12>[a-zA-Z0-9áâçéêíóôú]+)(?![-\\w–\xad])', '\\1riei uma \\g<Pln_12>', 'Pleonasmo. Criar e Novo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riar novo (?P<Pln_13>[a-zA-Z0-9áâçéêíóôú]+)(?![-\\w–\xad])', '\\1riar \\g<Pln_13>', 'Pleonasmo. Criar e Novo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riar nova (?P<Pln_14>[a-zA-Z0-9áâçéêíóôú]+)(?![-\\w–\xad])', '\\1riar \\g<Pln_14>', 'Pleonasmo. Criar e Novo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riar novos (?P<Pln_15>[a-zA-Z0-9áâçéêíóôú]+)(?![-\\w–\xad])', '\\1riar \\g<Pln_15>', 'Pleonasmo. Criar e Novo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riar novas (?P<Pln_16>[a-zA-Z0-9áâçéêíóôú]+)(?![-\\w–\xad])', '\\1riar \\g<Pln_16>', 'Pleonasmo. Criar e Novo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])urpresa inesperada(?![-\\w–\xad])', '\\1urpresa', 'Pleonasmo. Toda surpresa é inesperada. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Inesperada surpresa(?![-\\w–\xad])', 'Surpresa', 'Pleonasmo. Toda surpresa é inesperada. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])inesperada surpresa(?![-\\w–\xad])', 'surpresa', 'Pleonasmo. Toda surpresa é inesperada. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg])rit(o|ar|ou|amos|aram|a|ei|ava|avam) alto(?![-\\w–\xad])', '\\1rit\\2', 'Pleonasmo. Gritar e alto são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg])rit(o|ar|ou|amos|aram|a|ei|ava|avam) bem alto(?![-\\w–\xad])', '\\1rit\\2', 'Pleonasmo. Gritar e alto são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg])rit(o|ar|ou|amos|aram|a|ei|ava|avam) muito alto(?![-\\w–\xad])', '\\1rit\\2', 'Pleonasmo. Gritar e alto são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])ussurr(o|ar|ou|amos|aram|a|ei|ava|avam) (baixo|baixinho)(?![-\\w–\xad])', '\\1ussurr\\2', 'Pleonasmo. Sussurrar e baixo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])ussurr(o|ar|ou|amos|aram|a|ei|ava|avam) bem (baixo|baixinho)(?![-\\w–\xad])', '\\1ussurr\\2', 'Pleonasmo. Sussurrar e baixo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])ussurr(o|ar|ou|amos|aram|a|ei|ava|avam) muito (baixo|baixinho)(?![-\\w–\xad])', '\\1ussurr\\2', 'Pleonasmo. Sussurrar e baixo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])lo de ligação(?![-\\w–\xad])', '\\1lo\\nligação', 'Pleonasmo. Elo e ligação são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg])oteira no teto(?![-\\w–\xad])', '\\1oteira', 'Pleonasmo. Toda goteira é no teto. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg])oteiras no teto(?![-\\w–\xad])', '\\1oteiras', 'Pleonasmo. Toda goteira é no teto. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg])onclusão final(?![-\\w–\xad])', '\\1onclusão', 'Pleonasmo. Conclusão e Final são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])epetir de novo(?![-\\w–\xad])', '\\1epetir', 'Pleonasmo. Repetir e de novo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])rário ([Pp])úblico(?![-\\w–\xad])', '\\1rário', 'Pleonasmo. Todo erário é público. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])erteza absoluta(?![-\\w–\xad])', '\\1erteza', 'Pleonasmo. Certeza é conhecimento exato, convicto, seguro. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Absoluta certeza(?![-\\w–\xad])', 'Certeza', 'Pleonasmo. Certeza é conhecimento exato, convicto, seguro. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])absoluta certeza(?![-\\w–\xad])', 'certeza', 'Pleonasmo. Certeza é conhecimento exato, convicto, seguro. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])lebiscito popular(?![-\\w–\xad])', '\\1lebiscito', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Acabamento final(?![-\\w–\xad])', 'Acabamento\\nFechamento\\nFinalização\\nConclusão', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])acabamento final(?![-\\w–\xad])', 'acabamento\\nfechamento\\nfinalização\\nconclusão', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])onclusão final(?![-\\w–\xad])', '\\1onclusão', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])manhecer do dia(?![-\\w–\xad])', '\\1manhecer', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])aíses do mundo(?![-\\w–\xad])', '\\1aíses', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Limite extremo(?![-\\w–\xad])', 'Limite\\nExtremo', 'Pleonasmo. Limite e extremo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])limite extremo(?![-\\w–\xad])', 'limite\\nextremo', 'Pleonasmo. Limite e extremo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Extremo limite(?![-\\w–\xad])', 'Limite\\nExtremo', 'Pleonasmo. Limite e extremo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])extremo limite(?![-\\w–\xad])', 'limite\\nextremo', 'Pleonasmo. Limite e extremo são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Abertura inaugural(?![-\\w–\xad])', 'Abertura\\nInauguração', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])abertura inaugural(?![-\\w–\xad])', 'abertura\\ninauguração', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])emorragia de sangue(?![-\\w–\xad])', '\\1emorragia', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ego dos olhos(?![-\\w–\xad])', '\\1ego', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])ultidão de pessoas(?![-\\w–\xad])', '\\1ultidão', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])juntamente com(?![-\\w–\xad])', 'com\\nacompanhado de\\nacompanhada de\\nem companhia de\\ncombinado a\\njunto a\\nunido a\\nsomado a\\nagregado a\\nem parceria com\\nassociado a', 'Pleonasmo. Com significa - junto de ou junto a. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Juntamente com(?![-\\w–\xad])', 'Com\\nAcompanhado de\\nAcompanhada de\\nEm companhia de\\nCombinado a\\nJunto a\\nUnido a\\nSomado a\\nAgregado a\\nEm parceria com\\nAssociado a', 'Pleonasmo. Com significa - junto de ou junto a. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])expressamente proibido(?![-\\w–\xad])', 'proibido', 'Pleonasmo. A proibição sempre é expressa. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])expressamente proibida(?![-\\w–\xad])', 'proibida', 'Pleonasmo. A proibição sempre é expressa. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])expressamente proibidos(?![-\\w–\xad])', 'proibidos', 'Pleonasmo. A proibição sempre é expressa. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])expressamente proibidas(?![-\\w–\xad])', 'proibidas', 'Pleonasmo. A proibição sempre é expressa. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])duas metades(?![-\\w–\xad])', 'metades\\nduas partes', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])metades iguais(?![-\\w–\xad])', 'metades\\npartes iguais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])detalhe minucioso(?![-\\w–\xad])', 'detalhe\\nminúcia', 'Pleonasmo. Detalhes são minúcias. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])detalhes minuciosos(?![-\\w–\xad])', 'detalhes\\nminúcias', 'Pleonasmo. Detalhes são minúcias. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])nexo junto(?![-\\w–\xad])', '\\1nexo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])nexar junto(?![-\\w–\xad])', '\\1nexar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])nexou junto(?![-\\w–\xad])', '\\1nexo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])nexaram junto(?![-\\w–\xad])', '\\1nexaram', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])livre escolha(?![-\\w–\xad])', 'escolha', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])pequeno detalhe(?![-\\w–\xad])', 'detalhe', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])pequenos detalhes(?![-\\w–\xad])', 'detalhes', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])encarar de frente(?![-\\w–\xad])', 'encarar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])encarou de frente(?![-\\w–\xad])', 'encaro', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])encararam de frente(?![-\\w–\xad])', 'encararam', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])encarava de frente(?![-\\w–\xad])', 'encarava', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])encarei de frente(?![-\\w–\xad])', 'encarei', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])encaramos de frente(?![-\\w–\xad])', 'encaramos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])pequeno contratempo(?![-\\w–\xad])', 'contratempo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])pequenos contratempo(?![-\\w–\xad])', 'contratempo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])fato real(?![-\\w–\xad])', 'fato', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])fatos reais(?![-\\w–\xad])', 'fatos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])empréstimo temporário(?![-\\w–\xad])', 'empréstimo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])empréstimos temporários(?![-\\w–\xad])', 'empréstimos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])escolha opcional(?![-\\w–\xad])', 'escolha\\nopção', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])planejar antecipadamente(?![-\\w–\xad])', 'planejar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])planejou antecipadamente(?![-\\w–\xad])', 'planejo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])planejaram antecipadamente(?![-\\w–\xad])', 'planejaram', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])continua a permanecer(?![-\\w–\xad])', 'permanece', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])continuar a permanecer(?![-\\w–\xad])', 'permanecer', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])continuaram a permanecer(?![-\\w–\xad])', 'permaneceram', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])continuou a permanecer(?![-\\w–\xad])', 'permanece', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])continuava a permanecer(?![-\\w–\xad])', 'permanecia', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])continuavam a permanecer(?![-\\w–\xad])', 'permaneciam', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])última versão definitiva(?![-\\w–\xad])', 'última versão', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])última e definitiva(?![-\\w–\xad])', 'última', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])possivelmente poderá (?P<Pleo_1>[a-z]+)ar(?![-\\w–\xad])', 'possivelmente \\1ará\\npoderá \\1ar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])possivelmente deverá (?P<Pleo_2>[a-z]+)ar(?![-\\w–\xad])', 'possivelmente \\1ará\\ndeverá \\1ar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])provavelmente poderá (?P<Pleo_3>[a-z]+)ar(?![-\\w–\xad])', 'provavelmente \\1ará\\npoderá \\1ar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])provavelmente deverá (?P<Pleo_4>[a-z]+)ar(?![-\\w–\xad])', 'provavelmente \\1ará\\ndeverá \\1ar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])possivelmente poderá (?P<Pleo_5>[a-z]+)er(?![-\\w–\xad])', 'possivelmente \\1erá\\npoderá \\1er', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])possivelmente deverá (?P<Pleo_6>[a-z]+)er(?![-\\w–\xad])', 'possivelmente \\1erá\\ndeverá \\1er', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])provavelmente poderá (?P<Pleo_7>[a-z]+)er(?![-\\w–\xad])', 'provavelmente \\1erá\\npoderá \\1er', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])provavelmente deverá (?P<Pleo_8>[a-z]+)er(?![-\\w–\xad])', 'provavelmente \\1erá\\ndeverá \\1er', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])possivelmente poderá (?P<Pleo_9>[a-z]+)ir(?![-\\w–\xad])', 'possivelmente \\1irá\\npoderá \\1ir', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])possivelmente deverá (?P<Pleo_0>[a-z]+)ir(?![-\\w–\xad])', 'possivelmente \\1irá\\ndeverá \\1ir', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])provavelmente poderá (?P<Pleo_a>[a-z]+)ir(?![-\\w–\xad])', 'provavelmente \\1irá\\npoderá \\1ir', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])provavelmente deverá (?P<Pleo_b>[a-z]+)ir(?![-\\w–\xad])', 'provavelmente \\1irá\\ndeverá \\1ir', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])comparecer em pessoa(?![-\\w–\xad])', 'comparecer', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])compareceu em pessoa(?![-\\w–\xad])', 'comparece', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])propriedade característica(?![-\\w–\xad])', 'propriedade\\ncaracterística', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])propriedades características(?![-\\w–\xad])', 'propriedades\\ncaracterísticas', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])a seu critério pessoal(?![-\\w–\xad])', 'a seu critério', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])onopólio exclusivo(?![-\\w–\xad])', '\\1onopólio', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])sintoma indicativo(?![-\\w–\xad])', 'sintoma', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])sintomas indicativos(?![-\\w–\xad])', 'sintomas', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ntrar para dentro(?![-\\w–\xad])', '\\1ntrar', 'Pleonasmo. Entrar e dentro são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])air para fora(?![-\\w–\xad])', '\\1air', 'Pleonasmo. Sair e fora são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ntrar pra dentro(?![-\\w–\xad])', '\\1ntrar', 'Pleonasmo. Entrar e dentro são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])air pra fora(?![-\\w–\xad])', '\\1air', 'Pleonasmo. Sair e fora são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])anorama geral(?![-\\w–\xad])', '\\1anorama', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])diar para depois(?![-\\w–\xad])', '\\1diar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])diou para depois(?![-\\w–\xad])', '\\1dio', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])diaram para depois(?![-\\w–\xad])', '\\1diararm', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ecapitar a cabeça(?![-\\w–\xad])', '\\1ecapitar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ecapitaram a cabeça(?![-\\w–\xad])', '\\1ecapitaram', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ecapitou a cabeça(?![-\\w–\xad])', '\\1ecapito', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ecapitar as cabeças(?![-\\w–\xad])', '\\1ecapitar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ecapitaram as cabeças(?![-\\w–\xad])', '\\1ecapitaram', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ecapitou as cabeças(?![-\\w–\xad])', '\\1ecapito', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])egolou o pescoço(?![-\\w–\xad])', '\\1egolo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emente mental(?![-\\w–\xad])', '\\1emente', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ementes mentais(?![-\\w–\xad])', '\\1ementes', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])efunto morto(?![-\\w–\xad])', '\\1efunto', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])efuntos mortos(?![-\\w–\xad])', '\\1efuntos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])ugir para outro lugar(?![-\\w–\xad])', '\\1ugir', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])ugir pra outro lugar(?![-\\w–\xad])', '\\1ugir', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])e jeito maneira(?![-\\w–\xad])', '\\1e jeito algum\\n\\1e maneira nenhuma\\n\\1e forma nenhuma', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])e jeito e maneira(?![-\\w–\xad])', '\\1e jeito algum\\n\\1e maneira nenhuma\\n\\1e forma nenhuma', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])ultidão de pessoa(?![-\\w–\xad])', '\\1ultidão', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])ultidão de gente(?![-\\w–\xad])', '\\1ultidão', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ardume de peixe(?![-\\w–\xad])', '\\1ardume', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ardume de peixes(?![-\\w–\xad])', '\\1ardume', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ardumes de peixes(?![-\\w–\xad])', '\\1ardumes', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])nxame de abelha(?![-\\w–\xad])', '\\1nxame', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])nxame de abelhas(?![-\\w–\xad])', '\\1nxame', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])nxames de abelhas(?![-\\w–\xad])', '\\1nxames', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])rganizar uma torcida organizada(?![-\\w–\xad])', '\\1rganizar uma torcida', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])rganizar a torcida organizada(?![-\\w–\xad])', '\\1rganizar a torcida', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])rganizar as torcidas organizadas(?![-\\w–\xad])', '\\1rganizar as torcidas', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])uicidou-se a si mesmo(?![-\\w–\xad])', '\\1uicidou-se', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])uicidar-se a si mesmo(?![-\\w–\xad])', '\\1uicidar-se', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])onsenso geral(?![-\\w–\xad])', '\\1onsenso', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])nanimidade de todos(?![-\\w–\xad])', '\\1nanimidade', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ncarar cara a cara(?![-\\w–\xad])', '\\1ncarar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ncarou cara a cara(?![-\\w–\xad])', '\\1ncaro', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ereador ([Mm])unicipal(?![-\\w–\xad])', '\\1ereador', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])nfrentou de frente(?![-\\w–\xad])', '\\1nfrento', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])nfrentar de frente(?![-\\w–\xad])', '\\1nfrentar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])xultar de alegria(?![-\\w–\xad])', '\\1xultar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])xultou de alegria(?![-\\w–\xad])', '\\1xulto', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])xultaram de alegria(?![-\\w–\xad])', '\\1xultaram', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])onviver junto(?![-\\w–\xad])', '\\1onviver', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])onviver juntos(?![-\\w–\xad])', '\\1onviver', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])onviveram juntos(?![-\\w–\xad])', '\\1onviveram', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])onvivem juntos(?![-\\w–\xad])', '\\1onvivem', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])onviveu junto(?![-\\w–\xad])', '\\1onvive', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])onvivia junto(?![-\\w–\xad])', '\\1onvivia', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])onviviam juntos(?![-\\w–\xad])', '\\1onviviam', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg])eneral do exército([.,:;])(?![-\\w–\xad])', '\\1eneral\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])rigadeiro da aeronáutica(?![-\\w–\xad])', '\\1rigadeiro', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lmirante da marinha(?![-\\w–\xad])', '\\1lmirante', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg])eneral de exército(?![-\\w–\xad])', '\\1eneral', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg])enerais do exército(?![-\\w–\xad])', '\\1enerais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])rigadeiros da aeronáutica(?![-\\w–\xad])', '\\1rigadeiros', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lmirantes da marinha(?![-\\w–\xad])', '\\1lmirantes', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])onocultura exclusiva(?![-\\w–\xad])', '\\1onocultura', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])upla de dois(?![-\\w–\xad])', '\\1upla', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])rio de três(?![-\\w–\xad])', '\\1rio', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])erdade verdadeira(?![-\\w–\xad])', '\\1erdade', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])anter o mesmo(?![-\\w–\xad])', '\\1anter o', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])anter a mesma(?![-\\w–\xad])', '\\1anter a', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])anter os mesmos(?![-\\w–\xad])', '\\1anter os', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])anter as mesmas(?![-\\w–\xad])', '\\1anter as', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])anteve o mesmo(?![-\\w–\xad])', '\\1anteve o', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])anteve a mesma(?![-\\w–\xad])', '\\1anteve a', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])anteve os mesmos(?![-\\w–\xad])', '\\1anteve os', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])anteve as mesmas(?![-\\w–\xad])', '\\1anteve as', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])anterá o mesmo(?![-\\w–\xad])', '\\1anterá o', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])anterá a mesma(?![-\\w–\xad])', '\\1anterá a', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])anterá os mesmos(?![-\\w–\xad])', '\\1anterá os', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])anterá as mesmas(?![-\\w–\xad])', '\\1anterá as', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])antiveram o mesmo(?![-\\w–\xad])', '\\1antiveram o', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])antiveram a mesma(?![-\\w–\xad])', '\\1antiveram a', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])antiveram os mesmos(?![-\\w–\xad])', '\\1antiveram os', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])antiveram as mesmas(?![-\\w–\xad])', '\\1antiveram as', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])antive o mesmo(?![-\\w–\xad])', '\\1antive o', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])antive a mesma(?![-\\w–\xad])', '\\1antive a', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])antive os mesmos(?![-\\w–\xad])', '\\1antive os', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])antive as mesmas(?![-\\w–\xad])', '\\1antive as', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riar nov([ao])(?![-\\w–\xad])', '\\1riar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riar nov([ao])s(?![-\\w–\xad])', '\\1riar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riou nov([ao])(?![-\\w–\xad])', '\\1rio', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riou nov([ao])s(?![-\\w–\xad])', '\\1rio', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])ovidade inédita(?![-\\w–\xad])', '\\1rio', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ar de graça(?![-\\w–\xad])', '\\1ar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])eu de graça(?![-\\w–\xad])', '\\1e', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])eram de graça(?![-\\w–\xad])', '\\1eram', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Pequenos detalhes(?![-\\w–\xad])', 'Detalhes', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])etalhes tão pequenos(?![-\\w–\xad])', '\\1etalhes', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])etalhes muito pequenos(?![-\\w–\xad])', '\\1etalhes', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])rotagonista principal(?![-\\w–\xad])', '\\1rotagonista', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])egra geral(?![-\\w–\xad])', '\\1egra', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])ato verídico(?![-\\w–\xad])', '\\1ato', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])atos verídicos(?![-\\w–\xad])', '\\1atos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])az (?P<Plnz_1>[a-zA-Z0-9áâçéêíóôú]+) anos atrás(?![-\\w–\xad])', '\\1á \\g<Plnz_1> anos', 'Pleonasmo, faz e atrás indicam passado. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])iúva do falecido(?![-\\w–\xad])', '\\1iúva', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])iúva do finado(?![-\\w–\xad])', '\\1iúva', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])iúvo do falecida(?![-\\w–\xad])', '\\1iúvo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])iúvo do finada(?![-\\w–\xad])', '\\1iúvo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])escer para baixo(?![-\\w–\xad])', '\\1escer', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])escer pra baixo(?![-\\w–\xad])', '\\1escer', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])esceu para baixo(?![-\\w–\xad])', '\\1esce', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])esceu pra baixo(?![-\\w–\xad])', '\\1esce', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])esceram para baixo(?![-\\w–\xad])', '\\1esceram', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])esceram pra baixo(?![-\\w–\xad])', '\\1esceram', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ncarar de frente(?![-\\w–\xad])', '\\1ncarar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ncarei de frente(?![-\\w–\xad])', '\\1ncarei', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ncaramos de frente(?![-\\w–\xad])', '\\1ncaramos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ncararemos de frente(?![-\\w–\xad])', '\\1ncararemos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ncararam de frente(?![-\\w–\xad])', '\\1ncararam', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ncararei de frente(?![-\\w–\xad])', '\\1ncararei', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])uperavit positivo(?![-\\w–\xad])', '\\1uperavit', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])eficit negativo(?![-\\w–\xad])', '\\1eficit', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])busaram demais(?![-\\w–\xad])', '\\1busaram', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])lanejada antecipadamente(?![-\\w–\xad])', '\\1lanejada', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])lanejadas antecipadamente(?![-\\w–\xad])', '\\1lanejadas', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])lanejado antecipadamente(?![-\\w–\xad])', '\\1lanejada', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])lanejados antecipadamente(?![-\\w–\xad])', '\\1lanejadas', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])lanejada com antecedência(?![-\\w–\xad])', '\\1lanejada', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])lanejadas com antecedência(?![-\\w–\xad])', '\\1lanejadas', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])lanejado com antecedência(?![-\\w–\xad])', '\\1lanejada', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])lanejados com antecedência(?![-\\w–\xad])', '\\1lanejadas', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])xultei de alegria(?![-\\w–\xad])', '\\1xultei', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])abitat natural(?![-\\w–\xad])', '\\1abitat', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])produzimos bons produtos(?![-\\w–\xad])', 'criamos bons produtos\\nfizemos bons produtos\\ngeramos bons produtos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])produziu maus produtos(?![-\\w–\xad])', 'criou maus produtos\\nfez maus produtos\\ngerou maus produtos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])produzimos maus produtos(?![-\\w–\xad])', 'criamos maus produtos\\nfizemos maus produtos\\ngeramos maus produtos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])produziu bons produtos(?![-\\w–\xad])', 'criou bons produtos\\nfez bons produtos\\ngerou bons produtos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Produzimos bons produtos(?![-\\w–\xad])', 'Criamos bons produtos\\nFizemos bons produtos\\nGeramos bons produtos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Produziu maus produtos(?![-\\w–\xad])', 'Criou maus produtos\\nFez maus produtos\\nGerou maus produtos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Produzimos maus produtos(?![-\\w–\xad])', 'Criamos maus produtos\\nFizemos maus produtos\\nGeramos maus produtos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Produziu bons produtos(?![-\\w–\xad])', 'Criou bons produtos\\nFez bons produtos\\nGerou bons produtos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])prever de antemão(?![-\\w–\xad])', 'prever', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])scolha opcional(?![-\\w–\xad])', '\\1scolha', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])scolhas opcionais(?![-\\w–\xad])', '\\1scolhas', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])razão é porque(?![-\\w–\xad])', 'razão', 'Pleonasmo - Razão e Porque são redundandes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])motivo é porque(?![-\\w–\xad])', 'motivo', 'Pleonasmo - Motivo e Porque são redundandes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lmirante da Marinha(?![-\\w–\xad])', '\\1lmirante', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])manheceu o dia(?![-\\w–\xad])', '\\1manhece', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])O dia amanheceu(?![-\\w–\xad])', 'Amanhece', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])o dia amanheceu(?![-\\w–\xad])', 'amanhece', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])o dia já amanheceu(?![-\\w–\xad])', 'já amanhece', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])O dia já amanheceu(?![-\\w–\xad])', 'Já amanhece', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ntardeceu o dia(?![-\\w–\xad])', '\\1ntardece', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])O dia entardeceu(?![-\\w–\xad])', 'Entardece', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])o dia entardeceu(?![-\\w–\xad])', 'entardece', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])o dia já entardeceu(?![-\\w–\xad])', 'já entardece', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])O dia já entardeceu(?![-\\w–\xad])', 'Já entardece', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])bilateral entre dois(?![-\\w–\xad])', 'bilateral', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])anja de galinha(?![-\\w–\xad])', '\\1anja', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Cursei um curso(?![-\\w–\xad])', 'Cursei\\nConcluí um curso\\nParticipei de um curso\\nFiz um curso', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])cursei um curso(?![-\\w–\xad])', 'cursei\\nconcluí um curso\\nparticipei de um curso\\nfiz um curso', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Cursei o curso(?![-\\w–\xad])', 'Cursei\\nConcluí o curso\\nParticipei do curso\\nFiz o curso', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])cursei o curso(?![-\\w–\xad])', 'cursei\\nconcluí o curso\\nparticipei do curso\\nfiz o curso', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg])anh(e|ou|em|aram|arão|ei|ava|aria|ariam|o|a|am) grátis(?![-\\w–\xad])', '\\1anh\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Gg])anh(e|ou|em|aram|arão|ei|ava|aria|ariam|o|a|am) inteiramente grátis(?![-\\w–\xad])', '\\1anh\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])unânime de todos(?![-\\w–\xad])', 'unânime', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])unanimidade de todos(?![-\\w–\xad])', 'unanimidade', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])minha opinião pessoal(?![-\\w–\xad])', 'minha opinião', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])individual de cada um(?![-\\w–\xad])', 'individual', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])mbos os dois(?![-\\w–\xad])', '\\1mbos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])mbas as duas(?![-\\w–\xad])', '\\1mbas', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Duas metades(?![-\\w–\xad])', 'As metades', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])duas metades(?![-\\w–\xad])', 'metades', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])produzir produtos(?![-\\w–\xad])', 'criar produtos\\nfazer produtos\\gerar produtos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])produzir um produto(?![-\\w–\xad])', 'criar um produto\\nfazer um produto\\ngerar um produto', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])produzir bons produtos(?![-\\w–\xad])', 'criar bons produtos\\nfazer bons produtos\\ngerar bons produtos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])produzir maus produtos(?![-\\w–\xad])', 'criar maus produtos\\nfazer maus produtos\\ngerar maus produtos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])produzir novos produtos(?![-\\w–\xad])', 'criar produtos\\nfazer produtos\\ngerar produtos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])produzir um novo produto(?![-\\w–\xad])', 'criar um produto\\nfazer um produto\\ngerar um produto', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])inha autobiografia(?![-\\w–\xad])', '\\1inha biografia', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])a própria autobiografia(?![-\\w–\xad])', 'a autobiografia\\na própria biografia', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])boa caligrafia(?![-\\w–\xad])', 'boa letra\\nbom estilo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])bela caligrafia(?![-\\w–\xad])', 'bela letra\\nbom estilo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])planos para o futuro(?![-\\w–\xad])', 'planos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])projetos para o futuro(?![-\\w–\xad])', 'projetos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])ganha outro inteiramente grátis(?![-\\w–\xad])', 'leva outro inteiramente grátis\\nganha outro', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])ganhou outro inteiramente grátis(?![-\\w–\xad])', 'levou outro inteiramente grátis\\nganhou outro', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])ganhar outro inteiramente grátis(?![-\\w–\xad])', 'levar outro inteiramente grátis\\nganhar outro', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])ganha outro grátis(?![-\\w–\xad])', 'leva outro grátis\\nganha outro', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])ganhou outro grátis(?![-\\w–\xad])', 'levou outro grátis\\nganhou outro', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])ganhar outro grátis(?![-\\w–\xad])', 'levar outro grátis\\nganhar outro', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])permanece ainda(?![-\\w–\xad])', 'permanece', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])ainda permanece(?![-\\w–\xad])', 'permanece', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])recordar o passado(?![-\\w–\xad])', 'recordar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])recordamos o passado(?![-\\w–\xad])', 'recordamos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])recordaram o passado(?![-\\w–\xad])', 'recordaram', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])um plus a mais(?![-\\w–\xad])', 'um plus', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])democracia popular(?![-\\w–\xad])', 'democracia', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])aparência exterior(?![-\\w–\xad])', 'aparência', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])falso pretexto(?![-\\w–\xad])', 'pretexto', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])duna de areia(?![-\\w–\xad])', 'duna', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])dunas de areia(?![-\\w–\xad])', 'dunas', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])estrelas do céu(?![-\\w–\xad])', 'estrelas', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])estrela do céu(?![-\\w–\xad])', 'estrela', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])exultava de felicidade(?![-\\w–\xad])', 'exultava', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])exultou de felicidade(?![-\\w–\xad])', 'exulto', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])exultaram de felicidade(?![-\\w–\xad])', 'exultaram', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])recuar para trás(?![-\\w–\xad])', 'recuar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])recuou para trás(?![-\\w–\xad])', 'recuo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])recuaram para trás(?![-\\w–\xad])', 'recuaram', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])retornou de novo(?![-\\w–\xad])', 'retorno', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])retornar de novo(?![-\\w–\xad])', 'retornar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])repetiu de novo(?![-\\w–\xad])', 'repeti', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])repetir de novo(?![-\\w–\xad])', 'repetir', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])refez de novo(?![-\\w–\xad])', 'refez', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])refazer de novo(?![-\\w–\xad])', 'refazer', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])retornou novamente(?![-\\w–\xad])', 'retorno', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])retornar novamente(?![-\\w–\xad])', 'retornar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])repetiu novamente(?![-\\w–\xad])', 'repeti', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])repetir novamente(?![-\\w–\xad])', 'repetir', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])refez novamente(?![-\\w–\xad])', 'refez', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])refazer novamente(?![-\\w–\xad])', 'refazer', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])roubou objeto alheio(?![-\\w–\xad])', 'roubou objeto', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])roubou o objeto alheio(?![-\\w–\xad])', 'roubou o objeto', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])roubou os objetos alheios(?![-\\w–\xad])', 'roubou os objetos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])segredo secreto(?![-\\w–\xad])', 'segredo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])segredos secretos(?![-\\w–\xad])', 'segredo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])sorriso nos lábios(?![-\\w–\xad])', 'sorriso', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])viver a vida(?![-\\w–\xad])', 'viver como\\ngozar a vida\\nlevar a vida\\npassar a vida\\nter a vida\\nviver', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Viver a vida(?![-\\w–\xad])', 'Viver como\\nGozar a vida\\nLevar a vida\\nPassar a vida\\nTer a vida\\nViver', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ncarar a vida de frente(?![-\\w–\xad])', '\\1ncarar a vida', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ncarar as coisas de frente(?![-\\w–\xad])', '\\1ncarar as coisas', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ncarar a situação de frente(?![-\\w–\xad])', '\\1ncarar a situação', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ncarar o problema de frente(?![-\\w–\xad])', '\\1ncarar o problema', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])individualidade de cada um(?![-\\w–\xad])', 'individualidade', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])individual de cada um(?![-\\w–\xad])', 'individual', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])individuais de cada um(?![-\\w–\xad])', 'individuais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])individual para cada um(?![-\\w–\xad])', 'individual', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])individuais para cada um(?![-\\w–\xad])', 'individuais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])(minha|sua) opinião individual(?![-\\w–\xad])', '\\1 opinião', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])sonhei um sonho(?![-\\w–\xad])', 'tive um sonho', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Sonhei um sonho(?![-\\w–\xad])', 'Tive um sonho', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ref([ei])r([a-záíê]+) mais(?![-\\w–\xad])', '\\1ref\\2r\\3', 'Pleonasmo. Preferir siginifica gostar mais. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ref([ei])r([a-záíê]+) muito mais(?![-\\w–\xad])', '\\1ref\\2r\\3', 'Pleonasmo. Preferir siginifica gostar mais. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])ainda continu([a-záãí]+)(?![-\\w–\xad])', 'continu\\1', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda continu([a-záãí]+)(?![-\\w–\xad])', 'Continu\\1', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontinu([a-záãí]+) ainda(?![-\\w–\xad])', '\\1ontinu\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])ecessário experiência anterior(?![-\\w–\xad])', '\\1ecessário experiência', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])mig([ao]) pessoal(?![-\\w–\xad])', '\\1mig\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])mig([ao])s pessoais(?![-\\w–\xad])', '\\1mig\\2s', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])ainda (deverá|poderá|vem|vai|irá) ([a-z]+)ar mais(?![-\\w–\xad])', 'ainda \\2ará\\n\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) a([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda a\\2ará\\nA\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) b([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda b\\2ará\\nB\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) c([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda c\\2ará\\nC\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) d([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda d\\2ará\\nD\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) e([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda e\\2ará\\nE\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) f([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda f\\2ará\\nF\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) g([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda g\\2ará\\nG\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) h([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda h\\2ará\\nH\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) i([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda i\\2ará\\nI\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) j([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda j\\2ará\\nJ\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) l([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda l\\2ará\\nL\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) m([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda m\\2ará\\nM\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) n([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda n\\2ará\\nN\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) o([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda o\\2ará\\nO\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) p([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda p\\2ará\\nP\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) q([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda q\\2ará\\nQ\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) r([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda r\\2ará\\nR\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) s([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda s\\2ará\\nS\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) t([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda t\\2ará\\nT\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) u([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda u\\2ará\\nU\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) v([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda v\\2ará\\nV\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) x([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda x\\2ará\\nX\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverá|poderá|vem|vai|irá) z([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda z\\2ará\\nG\\2ará mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])ainda (deverão|poderão|vão|irão) ([a-z]+)ar mais(?![-\\w–\xad])', 'ainda \\2arão\\n\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) a([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda a\\2arão\\nA\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) b([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda b\\2arão\\nB\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) c([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda c\\2arão\\nC\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) d([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda d\\2arão\\nD\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) e([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda e\\2arão\\nE\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) f([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda f\\2arão\\nF\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) g([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda g\\2arão\\nG\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) h([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda h\\2arão\\nH\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) i([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda i\\2arão\\nI\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) j([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda j\\2arão\\nJ\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) l([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda l\\2arão\\nL\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) m([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda m\\2arão\\nM\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) n([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda n\\2arão\\nN\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) o([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda o\\2arão\\nO\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) p([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda p\\2arão\\nP\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) q([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda q\\2arão\\nQ\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) r([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda r\\2arão\\nR\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) s([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda s\\2arão\\nS\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) t([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda t\\2arão\\nT\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) u([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda u\\2arão\\nU\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) v([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda v\\2arão\\nV\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) x([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda x\\2arão\\nX\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Ainda (deverão|poderão|vão|irão) z([a-z]+)ar mais(?![-\\w–\xad])', 'Ainda z\\2arão\\nG\\2arão mais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])vivência subjetiva(?![-\\w–\xad])', 'vivência', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])contratempo inusitado(?![-\\w–\xad])', 'contratempo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])inusitado contratempo(?![-\\w–\xad])', 'contratempo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])estemunh([a-záãí]+) in loco o fato(?![-\\w–\xad])', '\\1estemunh\\2 o fato', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])estemunh([a-záãí]+) o fato in loco(?![-\\w–\xad])', '\\1estemunh\\2 o fato', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ir([a-záãí]+) de dentro d([ao]|[ao]s)(?![-\\w–\xad])', '\\1ir\\2 d\\3', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Todas as demais(?![-\\w–\xad])', 'As demais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Todos os demais(?![-\\w–\xad])', 'Os demais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])todos ([ao])s demais(?![-\\w–\xad])', '\\1s demais', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Todo o (resto|restante)(?![-\\w–\xad])', 'O \\1', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])todo o (resto|restante)(?![-\\w–\xad])', 'o \\1', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos sem exceção(?![-\\w–\xad])', '\\1odos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos, sem exceção,(?![-\\w–\xad])', '\\1odos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos, sem exceção (?![-\\w–\xad])', '\\1odos ', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ada (segundo|minuto|hora|dia|semana|mês|ano|século|milênio|instante|momento|noite|tarde) que passa(?![-\\w–\xad])', '\\1ada \\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) cada ([a-záâãçéêíóôú]+) se ([a-záâãçéêíóôú]+) ainda mais(?![-\\w–\xad])', '\\1 cada \\2 se \\3 mais\\n\\1 cada \\2 se \\3 ainda', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])huva que cai(?![-\\w–\xad])', '\\1huva\\n\\1huva que ocorre', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])huva que caiu(?![-\\w–\xad])', '\\1huva houve\\n\\1huva que ocorre', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])huvas que caíram(?![-\\w–\xad])', '\\1huvas que ocorreram', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])À distância de ([0-9]+) metros(?![-\\w–\xad])', 'A \\1 metros', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])à distância de ([0-9]+) metros(?![-\\w–\xad])', 'a \\1 metros', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Absoluta verdade(?![-\\w–\xad])', 'Verdade', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])absoluta verdade(?![-\\w–\xad])', 'verdade', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])erdade absoluta(?![-\\w–\xad])', '\\1erdade', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])mpulhet(a|as) do tempo(?![-\\w–\xad])', '\\1mpulhet\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])eu critério pessoal(?![-\\w–\xad])', '\\1eu critério', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])bismo sem fundo(?![-\\w–\xad])', '\\1bismo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])bismo profundo(?![-\\w–\xad])', '\\1bismo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])brir a boca para dizer(?![-\\w–\xad])', 'dirá\\ndizer', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])briu a boca para dizer(?![-\\w–\xad])', 'disse', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])bro a boca para dizer(?![-\\w–\xad])', 'digo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])bra a boca para dizer(?![-\\w–\xad])', 'diga', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])briram a boca para dizer(?![-\\w–\xad])', 'disseram', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])bram a boca para dizer(?![-\\w–\xad])', 'digam', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])bsolutamente inacreditáve(l|is)(?![-\\w–\xad])', 'inacreditáve\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])bsoluto silêncio(?![-\\w–\xad])', 'silêncio', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])ilêncio absoluto(?![-\\w–\xad])', '\\1ilêncio', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])bus([aeo]|ei|ou|ava|avam|aram|am|ar|arem) demais(?![-\\w–\xad])', '\\1bus\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])contece(eu|ram) anteriormente(?![-\\w–\xad])', '\\1contece\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])contece(eu|ram) ([a-záâãçéêíóôú]+) anteriormente(?![-\\w–\xad])', '\\1contece\\2 \\3', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])cordo amigável(?![-\\w–\xad])', '\\1contece\\2 \\3', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])crescent([a-záãí]+) mais(?![-\\w–\xad])', '\\1crescent\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])di(e|ar|aram|amos|ou|ei|arão) para outro dia(?![-\\w–\xad])', '\\1di\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])di(e|ar|aram|amos|ou|ei|arão) (o|a|os|as) ([a-záâãçéêíóôú]+) para outro dia(?![-\\w–\xad])', '\\1di\\2 \\3 \\4', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])firm([a-záãí]+) com bastante precisão(?![-\\w–\xad])', '\\1firm\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])gradável e prazeros([ao])(?![-\\w–\xad])', '\\1gradável', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])grav([a-záãí]+) ainda mais(?![-\\w–\xad])', 'torn\\2 mais grave\\n\\1grav\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lastr(ar|a|ou|aram|am)-se mais(?![-\\w–\xad])', '\\1lastr\\2-se', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lerta prévio(?![-\\w–\xad])', '\\1lerta', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lterações posteriores(?![-\\w–\xad])', '\\1lterações', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])mbição pessoal(?![-\\w–\xad])', '\\1mbição', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])mbições pessoais(?![-\\w–\xad])', '\\1mbições', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])mput([a-záãí]+) totalmente(?![-\\w–\xad])', '\\1mput\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])niquilação total(?![-\\w–\xad])', '\\1niquilação', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])parência exterior(?![-\\w–\xad])', '\\1parência', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])posentadoria vitalícia(?![-\\w–\xad])', '\\1posentadoria', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])rran(car|que|quei|camos|cou|caram|cariam|co|ca|quem|caria|cam) fora(?![-\\w–\xad])', '\\1rra\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([0-9]|[1][01]|[0-9]:[0-5][0-9]|0[0-9]:[0-5][0-9]|1[01]:[0-5][0-9])h da manhã(?![-\\w–\xad])', '\\1h', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([0-9]|[1][01]|[0-9]:[0-5][0-9]|0[0-9]:[0-5][0-9]|1[01]:[0-5][0-9]) horas da manhã(?![-\\w–\xad])', '\\1 horas', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])(1[3-8]|1[3-8]:[0-5][0-9])h da tarde(?![-\\w–\xad])', '\\1h', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])(1[3-8]|1[3-8]:[0-5][0-9]) horas da tarde(?![-\\w–\xad])', '\\1 horas', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])(19|2[0-3]|19:[0-5][0-9]|2[0-3]:[0-5][0-9])h da noite(?![-\\w–\xad])', '\\1h', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])(19|2[0-3]|19:[0-5][0-9]|2[0-3]:[0-5][0-9]) horas da noite(?![-\\w–\xad])', '\\1 horas', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])ssim como ([a-záâãçéêíóôú]+) também(?![-\\w–\xad])', '\\1ssim como \\2\\ntambém \\2', 'Pleonasmo, Assim como e Também são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])ssim como ([a-záâãçéêíóôú]+) ([a-záâãçéêíóôú]+) também(?![-\\w–\xad])', '\\1ssim como \\2 \\3\\ntambém \\2 \\3', 'Pleonasmo, Assim como e Também são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])ssim como ([a-záâãçéêíóôú]+), também(?![-\\w–\xad])', '\\1ssim como \\2,\\ntambém \\2', 'Pleonasmo, Assim como e Também são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])ssim como ([a-záâãçéêíóôú]+) ([a-záâãçéêíóôú]+), também(?![-\\w–\xad])', '\\1ssim como \\2 \\3,\\ntambém \\2 \\3', 'Pleonasmo, Assim como e Também são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])té (hoje|ontem|agora|o momento) ainda se(?![-\\w–\xad])', '\\1té \\2 se', 'Pleonasmo, Até e Ainda são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])té (hoje|ontem|agora|o momento), ainda se(?![-\\w–\xad])', '\\1té \\2, se', 'Pleonasmo, Até e Ainda são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])trás na retaguarda(?![-\\w–\xad])', '\\1trás\\nna retaguarda', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])ument([a-záãí]+) ainda mais(?![-\\w–\xad])', '\\1ument\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])crescent([a-záãí]+) ainda mais(?![-\\w–\xad])', '\\1crescent\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])ura de ([a-záâãçéêíóôú]+) em (volta|torno) de(?![-\\w–\xad])', '\\1ura de \\2 em', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])utossatisfação interior(?![-\\w–\xad])', '\\1utossatisfação', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])vançar em direção ao futuro(?![-\\w–\xad])', '\\1ndar em direção ao futuro\\ncaminhar em direção ao futuro\\n\\1vançar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])vançar para a frente(?![-\\w–\xad])', '\\1ndar para a frente\\ndar um passo à frente\\n\\1vançar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])arbaramente torturad(a|o|as|os)(?![-\\w–\xad])', 'torturad\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])orturad(a|o|as|os) barbaramente(?![-\\w–\xad])', '\\1orturad\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])astante embriagad(a|o|as|os)(?![-\\w–\xad])', 'embriagad\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uito embriagad(a|o|as|os)(?![-\\w–\xad])', 'embriagad\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])atalhas sangrentas(?![-\\w–\xad])', '\\1atalhas', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])atalha sangrenta(?![-\\w–\xad])', '\\1atalha', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])ecorde histórico(?![-\\w–\xad])', '\\1ecorde', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])eco sem saída(?![-\\w–\xad])', '\\1eco', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])oato falso(?![-\\w–\xad])', '\\1oato', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])oatos falsos(?![-\\w–\xad])', '\\1oatos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])oat(o|os) de possível ([a-záâãçéêíóôú]+)(?![-\\w–\xad])', '\\1oat\\2 de \\3', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])oat(o|os) de (um|uma) possível ([a-záâãçéêíóôú]+)(?![-\\w–\xad])', '\\1oat\\2 de \\3 \\4', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])oat(o|os) que circul([a-záãí]+)(?![-\\w–\xad])', '\\1oat\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])falsos boatos(?![-\\w–\xad])', 'boatos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])rad([a-záãí]+) alto(?![-\\w–\xad])', '\\1rad\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])rad([a-záãí]+) (bem|muito|bastante) alto(?![-\\w–\xad])', '\\1rad\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])reve (alocução|instante|momento)(?![-\\w–\xad])', '\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])rigadeir(o|os) da ([Aa])eronáutica(?![-\\w–\xad])', '\\1rigadeir\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])risa (fagueira|amena|fresca|gentil|leve|ligeira|suave)(?![-\\w–\xad])', '\\1risa', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ada vez mais crescente(?![-\\w–\xad])', '\\1rescente', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ada vez mais crescendo(?![-\\w–\xad])', '\\1rescendo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])al([aeo]|ar|ei|ou|ava) a boca(?![-\\w–\xad])', '\\1al\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])al(aram|am|avam) a boca dele(?![-\\w–\xad])', '\\1al\\2-no', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])al(aram|am|avam) a boca dela(?![-\\w–\xad])', '\\1al\\2-na', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])al(o|ei|ava|ar|ara|avam|ou|am|aram) a minha boca(?![-\\w–\xad])', '\\1al\\2-me', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])al(o|ei|ava|ar|ara|avam|ou|am|aram) a sua boca(?![-\\w–\xad])', '\\1al\\2-lhe', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])grande furor(?![-\\w–\xad])', 'furor', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ercad(a|o|as|os) por todos os lados(?![-\\w–\xad])', '\\1ercad\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ham([a-záãí]+) a atenção para si mesmo(?![-\\w–\xad])', '\\1ham\\2 a atenção', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])tra([a-záãí]+) a atenção para si mesmo(?![-\\w–\xad])', '\\1tra\\2 a atenção', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])hoque brutal(?![-\\w–\xad])', '\\1oque', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])hut([a-záãí]+) com os pés(?![-\\w–\xad])', '\\1hut\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])huvinha fina(?![-\\w–\xad])', '\\1huvinha', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])l(itóris|ítoris|itóride) feminino(?![-\\w–\xad])', '\\1\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])olabor([a-záãí]+) com uma ajuda(?![-\\w–\xad])', '\\1olabor\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])olabor([a-záãí]+) com um auxílio(?![-\\w–\xad])', '\\1olabor\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])em seu respectivo lugar(?![-\\w–\xad])', 'em seu lugar', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])em seus respectivos lugares(?![-\\w–\xad])', 'em seus lugares', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])om a máxima urgência(?![-\\w–\xad])', '\\1om urgência', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])om absoluta (correção|exatidão)(?![-\\w–\xad])', '\\1om \\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])rara exceção(?![-\\w–\xad])', 'exceção', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Rara exceção(?![-\\w–\xad])', 'Exceção', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Raras exceções(?![-\\w–\xad])', 'Exceções', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])raras exceções(?![-\\w–\xad])', 'exceções', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ome(çar|çamos|çaram|çou|çava|çavam|çaria|çariam|ço|cei) a sentir um início de(?![-\\w–\xad])', '\\1ome\\2 a sentir', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo já diss(e|emos|este|estes|eram|era) (antes|anteriormente)(?![-\\w–\xad])', '\\1omo já diss\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo já foi (refei|desfei|revis|fei|vis|di)t([ao]) (antes|anteriormente)(?![-\\w–\xad])', '\\1omo já foi \\2t\\3', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo diss(e|emos|este|estes|eram|era) (antes|anteriormente)(?![-\\w–\xad])', '\\1omo diss\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo foi (refei|desfei|revis|fei|vis|di)t([ao]) (antes|anteriormente)(?![-\\w–\xad])', '\\1omo foi \\2t\\3', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo já (?P<pleo_21>[a-z]+[bcdfghjlmnprstvxzç])(ei|amos|aste|astes|aram|ara|ou) (antes|anteriormente)(?![-\\w–\xad])', '\\1omo já \\2\\3', 'Pleonasmo. Você quis dizer:', 'm.group("pleo_21") in plvrVbrar and option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo (?P<pleo_22>[a-z]+[bcdfghjlmnprstvxzç])(ei|amos|aste|astes|aram|ara|ou) (antes|anteriormente)(?![-\\w–\xad])', '\\1omo \\2\\3', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo foi ([a-z]+[aií])d([ao]) (antes|anteriormente)(?![-\\w–\xad])', '\\1omo foi \\2d\\3', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo já foi ([a-z]+[aií])d([ao]) (antes|anteriormente)(?![-\\w–\xad])', '\\1omo já foi \\2d\\3', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo se previu (antes|anteriormente)(?![-\\w–\xad])', '\\1omo se previ', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo já se previa (antes|anteriormente)(?![-\\w–\xad])', '\\1omo já se previa', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo já era previsto (antes|anteriormente)(?![-\\w–\xad])', '\\1omo já era previsto', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo todos já (sabem|sabiam|saberiam|souberam)(?![-\\w–\xad])', '\\1omo já \\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ompare([cç])([a-záãí]+) em pessoa(?![-\\w–\xad])', '\\1ompare\\2\\3', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ompartilh([a-záãí]+) conosco(?![-\\w–\xad])', '\\1ompartilh\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ompletamente (cheia|cheio|nu|nua|vazio|vazia)(?![-\\w–\xad])', '\\1ompartilh\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ompletamente ([a-z]+[aií])d([ao])(?![-\\w–\xad])', '\\2d\\3', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ompleto silêncio(?![-\\w–\xad])', 'silêncio', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omprovadamente cert([ao]|[ao]s)(?![-\\w–\xad])', '\\1ert\\2\\n\\1omprovad\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ongel([a-záãí]+) de frio(?![-\\w–\xad])', '\\1ongel\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])onsenso unânime(?![-\\w–\xad])', '\\1onsenso', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontinua a permanecer(?![-\\w–\xad])', '\\1ontinua\\npermanece', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontinuou a permanecer(?![-\\w–\xad])', '\\1ontinuou\\npermanece', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontinuaram a permanecer(?![-\\w–\xad])', '\\1ontinuaram\\npermaneceram', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontinuei a permanecer(?![-\\w–\xad])', '\\1ontinuei\\npermaneci', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontinuava a permanecer(?![-\\w–\xad])', '\\1ontinuava\\npermanecia', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontinuavam a permanecer(?![-\\w–\xad])', '\\1ontinuavam\\npermaneciam', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontinuaria a permanecer(?![-\\w–\xad])', '\\1ontinuaria\\npermaneceria', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontinuamos a permanecer(?![-\\w–\xad])', '\\1ontinuamos\\npermanecemos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontinuarão a permanecer(?![-\\w–\xad])', '\\1ontinuarão\\npermanecerão', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontinu([a-záãí]+) com a mesma ([a-záâãçéêíóôú]+)(?![-\\w–\xad])', '\\1ontinu\\2 com a \\3', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontinu([a-záãí]+) com as mesmas ([a-záâãçéêíóôú]+)(?![-\\w–\xad])', '\\1ontinu\\2 com as \\3', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontinu([a-záãí]+) com o mesmo ([a-záâãçéêíóôú]+)(?![-\\w–\xad])', '\\1ontinu\\2 com o \\3', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontinu([a-záãí]+) com os mesmos ([a-záâãçéêíóôú]+)(?![-\\w–\xad])', '\\1ontinu\\2 com os \\3', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ostume habitual(?![-\\w–\xad])', '\\1ostume\\nhábito', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riação nova(?![-\\w–\xad])', '\\1riação', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riança pequena de ([2-9]|10) anos(?![-\\w–\xad])', '\\1riança de \\2 anos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riança pequena de 1 ano(?![-\\w–\xad])', '\\1riança de 1 ano', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riança pequena de (dois|três|quatro|cinco|seis|sete|oito|nove|dez) anos(?![-\\w–\xad])', '\\1riança de \\2 anos', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riança pequena de um ano(?![-\\w–\xad])', '\\1riança de um ano', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ri(ar|ou|aremos|aram|arei|em|asse|assem|aria|ariam|ará|arão) algo novo(?![-\\w–\xad])', '\\1ri\\2 algo diferente\\n\\1ri\\2 algo inusitado\\n\\1ri\\2 algo surpreendente\\n\\1ri\\2 algo moderno\\n\\1ri\\2 algo interessante\\n\\1ri\\2 algo especial\\n\\1ri\\2 algo melhor', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ntr(e|em) já para dentro(?![-\\w–\xad])', '\\1ntr\\2 já', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ntr(e|em) já pra dentro(?![-\\w–\xad])', '\\1ntr\\2 já', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])ubindo para cima(?![-\\w–\xad])', '\\1ubindo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ompare([cç])(\\w+) pessoalmente(?![-\\w–\xad])', '\\1ompare\\2\\3', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])A um (minuto|segundo|dia|mês|ano|século|milênio) atrás(?![-\\w–\xad])', 'Há um \\1', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])A uma (semana|hora) atrás(?![-\\w–\xad])', 'Há uma \\1', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])A ([a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios) atrás(?![-\\w–\xad])', 'Há \\1 \\2', 'Pleonasmo. Você quis dizer:', 'not m.group(1) in "-001-um-uma-" and option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])foi a um (minuto|segundo|dia|mês|ano|século|milênio) atrás(?![-\\w–\xad])', 'foi há um \\1', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])foi a uma (semana|hora) atrás(?![-\\w–\xad])', 'foi há uma \\1', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+[eo]u) a um (minuto|segundo|dia|mês|ano|século|milênio) atrás(?![-\\w–\xad])', '\\1 há um \\2', 'Pleonasmo. Você quis dizer:', 'not m.group(1) in exctempo and option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+[eo]u) a uma (semana|hora) atrás(?![-\\w–\xad])', '\\1 há uma \\2', 'Pleonasmo. Você quis dizer:', 'not m.group(1) in exctempo and option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+[dt][ao]) a um (minuto|segundo|dia|mês|ano|século|milênio) atrás(?![-\\w–\xad])', '\\1 há um \\2', 'Pleonasmo. Você quis dizer:', 'not m.group(1) in exctempo and option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+[dt][ao]) a uma (semana|hora) atrás(?![-\\w–\xad])', '\\1 há uma \\2', 'Pleonasmo. Você quis dizer:', 'not m.group(1) in exctempo and option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+[dt][ao])s a um (minuto|segundo|dia|mês|ano|século|milênio) atrás(?![-\\w–\xad])', '\\1s há um \\2', 'Pleonasmo. Você quis dizer:', 'not m.group(1) in exctempo and option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+[dt][ao])s a uma (semana|hora) atrás(?![-\\w–\xad])', '\\1s há uma \\2', 'Pleonasmo. Você quis dizer:', 'not m.group(1) in exctempo and option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])foi a ([a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios) atrás(?![-\\w–\xad])', 'foi há \\1 \\2', 'Pleonasmo. Você quis dizer:', 'not m.group(1) in "-001-um-uma-" and option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Tmp_3>[a-z]+[eo]u) a (?P<Tmp_4>[a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios) atrás(?![-\\w–\xad])', '\\1 há \\2 \\3', 'Pleonasmo. Você quis dizer:', 'not m.group("Tmp_4") in "-001-um-uma-" and not m.group("Tmp_3") in exctempo and option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Tmp_7>[a-z]+[dt][ao]) a (?P<Tmp_8>[a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios) atrás(?![-\\w–\xad])', '\\1 há \\2 \\3', 'Pleonasmo. Você quis dizer:', 'not m.group("Tmp_8") in "-001-um-uma-" and not m.group("Tmp_7") in exctempo and option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Tmp_11>[a-z]+[dt][ao])s a (?P<Tmp_12>[a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios) atrás(?![-\\w–\xad])', '\\1s há \\2 \\3', 'Pleonasmo. Você quis dizer:', 'not m.group("Tmp_12") in "-001-um-uma-" and not m.group("Tmp_11") in exctempo and option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])a vári([ao])s (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios) atrás(?![-\\w–\xad])', 'há vári\\1s \\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])A mais de um (minuto|segundo|dia|mês|ano|século|milênio) atrás(?![-\\w–\xad])', 'Há mais de um \\1', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])A mais de uma (semana|hora) atrás(?![-\\w–\xad])', 'Há mais de uma \\1', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])(A|Há) mais de ([a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios) atrás(?![-\\w–\xad])', 'Há mais de \\2 \\3', 'Pleonasmo. Você quis dizer:', 'not m.group(2) in "-001-um-uma-" and option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])a mais de um (minuto|segundo|dia|mês|ano|século|milênio) atrás(?![-\\w–\xad])', 'há mais de um \\1', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])(a|há) mais de ([a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios) atrás(?![-\\w–\xad])', 'há mais de \\2 \\3', 'Pleonasmo. Você quis dizer:', 'not m.group(2) in "-001-um-uma-" and option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á (pouco|muito) tempo atrás(?![-\\w–\xad])', '\\1á \\2 tempo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Há poucos (segundos|minutos|dias|meses|anos|séculos|milênios|instantes|momentos) atrás(?![-\\w–\xad])', 'Há poucos \\1\\nPoucos \\1 atrás', 'Pleonasmo. Há e atrás são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])há (poucos|alguns) (segundos|minutos|dias|meses|anos|séculos|milênios|instantes|momentos) atrás(?![-\\w–\xad])', 'Há \\1 \\2\\n\\1 \\2 atrás', 'Pleonasmo. Há e atrás são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Há alguns (segundos|minutos|dias|meses|anos|séculos|milênios|instantes|momentos) atrás(?![-\\w–\xad])', 'Há alguns \\1\\nAlguns \\1 atrás', 'Pleonasmo. Há e atrás são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])há (segundos|minutos|dias|meses|anos|séculos|milênios|instantes|momentos|tempos) atrás(?![-\\w–\xad])', 'há \\1\\n\\1 atrás', 'Pleonasmo. Há e atrás são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Há (segundos|minutos|dias|meses|anos|séculos|milênios|instantes|momentos|tempos) atrás(?![-\\w–\xad])', '= "Há " + m.group(1) + "\\n" + m.group(1).capitalize() + " atrás"', 'Pleonasmo. Há e atrás são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á pouco tempo atrás(?![-\\w–\xad])', '\\1á pouco tempo\\nPouco tempo atrás', 'Pleonasmo. Há e atrás são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])á muito tempo atrás(?![-\\w–\xad])', '\\1á muito tempo\\nMuito tempo atrás', 'Pleonasmo. Há e atrás são redundantes. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])azem (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios)(?![-\\w–\xad])', '\\1az \\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])azem ([a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios)(?![-\\w–\xad])', '\\1az \\2 \\3', 'Pleonasmo. Você quis dizer:', 'not m.group(2) in "-001-um-uma-" and option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])izeram ([a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios)(?![-\\w–\xad])', '\\1ez \\2 \\3', 'Pleonasmo. Você quis dizer:', 'not m.group(2) in "-001-um-uma-" and option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])ariam ([a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios)(?![-\\w–\xad])', '\\1aria \\2 \\3', 'Pleonasmo. Você quis dizer:', 'not m.group(2) in "-001-um-uma-" and option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])erçol nos olhos(?![-\\w–\xad])', '\\1erçol', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])erçol no olho(?![-\\w–\xad])', '\\1erçol', 'Pleonasmo. Você quis dizer:', 'not "direito" in TEXT and not "esquerdo" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])erçol no meu olho(?![-\\w–\xad])', '\\1erçol', 'Pleonasmo. Você quis dizer:', 'not "direito" in TEXT and not "esquerdo" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])ara(ó|ós) do ([Ee])gito(?![-\\w–\xad])', '\\1ara\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])rincipal ([Pp])rotagonista(?![-\\w–\xad])', '\\1rotagonista', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])anteve-se (a|o|as|os) mesm(a|o|as|os)(?![-\\w–\xad])', '\\1anteve-se \\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])antiveram-se (a|o|as|os) mesm(a|o|as|os)(?![-\\w–\xad])', '\\1antiveram-se \\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])asc(er|imento) de uma nova(?![-\\w–\xad])', '\\1asc\\2 de uma', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])asc(e|eu|er|erá) um novo(?![-\\w–\xad])', '\\1asc\\2 um', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])asc(e|eu|er|erá) uma nova(?![-\\w–\xad])', '\\1asc\\2 uma', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])própria autobiografia(?![-\\w–\xad])', 'autobiografia', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Sua autobiografia(?![-\\w–\xad])', 'Autobiografia\\nSua biografia', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])sua autobiografia(?![-\\w–\xad])', 'autobiografia\\nsua biografia', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])outra alternativa(?![-\\w–\xad])', 'alternativa\\noutra opção', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Outra alternativa(?![-\\w–\xad])', 'Alternativa\\nOutra opção', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Se caso(?![-\\w–\xad])', 'Se\\nCaso', 'Pleonasmo. Caso e se têm a mesma função. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])se caso(?![-\\w–\xad])', 'se\\ncaso', 'Pleonasmo. Caso e se têm a mesma função. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])aixa etária de idade(?![-\\w–\xad])', '\\1aixa etária', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])stre(ar|ou|ará|aria|ava) (seu|sua|seus|suas) ([a-záâãçéêíóôõú]+) nov(a|o|as|os)(?![-\\w–\xad])', '\\1stre\\2 \\3 \\4', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])stre(ar|ou|ará|aria|ava) (seu|sua|suas|seus) nov(a|o|as|os)(?![-\\w–\xad])', '\\1stre\\2 \\3', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Todos foram unânimes(?![-\\w–\xad])', 'Por unanimidade\\nA unanimidade\\nForam unânimes', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])todos foram unânimes(?![-\\w–\xad])', 'por unanimidade\\na unanimidade\\nforam unânimes', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Inclusive até(?![-\\w–\xad])', 'Inclusive\\nAté', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])inclusive até(?![-\\w–\xad])', 'inclusive\\naté', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Até inclusive(?![-\\w–\xad])', 'Inclusive\\nAté', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])até inclusive(?![-\\w–\xad])', 'inclusive\\naté', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])oi ex-([a-záâçéêíóôú]+)(?![-\\w–\xad])', 'é ex-\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])otalmente ([a-zç]+)([aií])do(?![-\\w–\xad])', '\\2\\3do', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])esumo sucinto(?![-\\w–\xad])', '\\1esumo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])esumo sintético(?![-\\w–\xad])', '\\1esumo', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj])unin(a|as) de ([Jj])unho(?![-\\w–\xad])', '\\1unin\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])revist([ao]|[ao]s) anteriormente(?![-\\w–\xad])', '\\1revist\\2', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])Cedo madruga(?![-\\w–\xad])', 'Madruga', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])cedo madruga(?![-\\w–\xad])', 'madruga', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])demasiadamente excessiv(a|as|o|os)(?![-\\w–\xad])', 'excessiv\\1', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])demasiadamente exagerad(a|as|o|os)(?![-\\w–\xad])', 'exagerad\\1', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])excessivamente exagerad(a|as|o|os)(?![-\\w–\xad])', 'exagerad\\1', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])exageradamente excessivo(a|as|o|os)(?![-\\w–\xad])', 'excessiv\\1', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
 ['(?u)(?<![-\\w–.,\xad])futuro daqui pra frente(?![-\\w–\xad])', 'futuro', 'Pleonasmo. Você quis dizer:', 'option(LOCALE,"metric")'],
# -*- Fim Pleonasmos -*-
# -*- Crase -*-
# Igual a
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_2>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1gual à \\2', 'Faltou a crase. Você quis dizer:', 'm.group("Msgal_2").lower() in plvrFema and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_4>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '\\1gual à \\2a', 'Faltou a crase. Você quis dizer:', 'm.group("Msgal_4").lower() in plvrMfoa and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_12>[a-zA-Z]+)([aí])da(?![-\\w–\xad])', '\\1gual à \\2da', 'Faltou a crase. Você quis dizer:', 'not m.group("Msgal_12").lower() in excAdo and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_16>[a-zA-Zç]+)osa(?![-\\w–\xad])', '\\1gual à \\2osa', 'Faltou a crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_18>[a-zA-Zç]+)iva(?![-\\w–\xad])', '\\1gual à \\2iva', 'Faltou a crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_22>[a-zA-Zç]+[âêô][mn])ica(?![-\\w–\xad])', '\\1gual à \\2ica', 'Faltou a crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_24>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ica(?![-\\w–\xad])', '\\1gual à \\2ica', 'Faltou a crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_26>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica(?![-\\w–\xad])', '\\1gual à \\2ica', 'Faltou a crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_28>[a-zA-Zç]+)esca(?![-\\w–\xad])', '\\1gual à \\2esca', 'Faltou a crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_30>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida(?![-\\w–\xad])', '\\1gual à \\2ida', 'Faltou a crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_32>[a-zA-Zç]+[ó])loga(?![-\\w–\xad])', '\\1gual à \\2loga', 'Faltou a crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_34>[a-zA-Zç]+[áéíóúâêô])ria(?![-\\w–\xad])', '\\1gual à \\2ria', 'Faltou a crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_36>[a-zA-Zç]+[í])ssima(?![-\\w–\xad])', '\\1gual à \\2ssima', 'Faltou a crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_38>[a-zA-Zç]+[é])sima(?![-\\w–\xad])', '\\1gual à \\2sima', 'Faltou a crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_42>[a-zA-Zçáéíóúâêô]+[dst])ora(?![-\\w–\xad])', '\\1gual à \\2ora', 'Faltou a crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_46>[a-zA-Zçáéíóúâêô]+r)(?![-\\w–\xad])', '\\1gual à \\2', 'Faltou a crase. Você quis dizer:', 'm.group("Msgal_46") in plvrFemr and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_52>[a-zA-Zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '\\1gual à \\2ão', 'Faltou a crase. Você quis dizer:', 'not m.group("Msgal_52") in plvrMascao and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_54>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '\\1gual à \\2ão', 'Faltou a crase. Você quis dizer:', 'm.group("Msgal_54") in plvrFemao and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_60>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '\\1gual à \\2e', 'Faltou a crase. Você quis dizer:', 'm.group("Msgal_60").lower() in plvrFeme and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_72>[a-zA-Z]+)z(?![-\\w–\xad])', '\\1gual à \\2z', 'Faltou a crase. Você quis dizer:', 'm.group("Msgal_72") in plvrFemz and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])gual a (?P<Msgal_73>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '\\1gual à \\2m', 'Faltou a crase. Você quis dizer:', 'm.group("Msgal_73") in plvrFemm and option(LOCALE,"grammar")'],
#
 ['(?u)(?<![-\\w–.,\xad])([Dd]evido|[Ii]gual|[Ss]emelhante|[Gg]raças) a (?P<Dev_1>[a-z]+)dade(?![-\\w–\xad])', '\\1 à \\2dade', 'Faltou a crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd]evido|[Ii]gual|[Ss]emelhante|[Gg]raças) a (?P<Dev_2>[a-z]+)nça(?![-\\w–\xad])', '\\1 à \\2nça', 'Faltou a crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd]evido|[Ii]gual|[Ss]emelhante|[Gg]raças) a (?P<Dev_3>[a-zãêí]+)ncia(?![-\\w–\xad])', '\\1 à \\2ncia', 'Faltou a crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Rep_1>[a-zA-Záâçéêíóôú]+) [Àà] (?P<Rep_2>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Rep_1> a \\g<Rep_2>', 'Crase entre palavras repetidas. Você quis dizer:', 'm.group(1) == m.group(2) and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Abc_2>[a-záâçéêíóôú]+[a][mr])(?![-\\w–\xad])', 'a \\g<Abc_2>', 'Não se usa crase antes de verbo ou palavra masculina. Você quis dizer:', 'not m.group("Abc_2") in plvrFemr and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Abc_3>[a-záâçéêíóôú]+[bcdfglmnoprtv][e][r])(?![-\\w–\xad])', 'a \\g<Abc_3>', 'Não se usa crase antes de verbo ou palavra masculina. Você quis dizer:', 'not m.group("Abc_3") in plvrFemr and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Abc_4>[a-záâçéêíóôú]+[çbcdfghlomnprtv][aei][r][e][m])(?![-\\w–\xad])', 'a \\g<Abc_4>', 'Não se usa crase antes de verbo. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Abc_5>[a-záâçéêíóôú]+[i][ur])(?![-\\w–\xad])', 'a \\g<Abc_5>', 'Não se usa crase antes de verbo ou palavra masculina. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Abc_7>[a-zA-Záâçéêíóôú]+[bcçefghijlmnoprstuvxz][o])(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "\\n" + aacCrase[m.group(1)] + "o " + m.group(2)', 'Não se usa crase antes de verbo ou palavra masculina. Você quis dizer:', 'not m.group("Abc_7") in femeCrase and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Abc_8>[a-zA-Záâçéêíóôú]+[bcçefghijlmnoprstuvxz][o])s(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "s"', 'Não se usa crase antes de verbo ou palavra masculina. Você quis dizer:', 'not m.group("Abc_8") in femeCrase and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà])[s] (?P<Abs_1>[a-zA-Záâçéêíóôú]+[bcçefghijlmnoprstuvxz][o])(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "s"', 'Não se usa crase antes de verbo ou palavra masculina. Você quis dizer:', 'not m.group("Abs_1") in femeCrase and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà])[s] (?P<Abs_2>[a-zA-Záâçéêíóôú]+[bcçefghijlmnoprstuvxz][o])s(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "s\\n" + aacCrase[m.group(1)] + "os " + m.group(2) + "s"', 'Não se usa crase antes de verbo ou palavra masculina. Você quis dizer:', 'not m.group("Abs_2") in femeCrase and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Abs__3>[a-záâçéêíóôú]+[aeiínoru][d][o])(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2)', 'Não se usa crase antes de verbo ou palavra masculina. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Abs__4>[a-záâçéêíóôú]+[aeiínoru][d][o])s(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "s"', 'Não se usa crase antes de verbo ou palavra masculina. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Zao_1>[a-zA-Záâçéêíóôú]+[bcefghijlmnoprtuvxz][ã][o])(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "\\n" + aacCrase[m.group(1)] + "o " + m.group(2)', 'Não se usa crase antes de verbo ou palavra masculina. Você quis dizer:', 'not m.group("Zao_1") in femeCrase and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Zao_2>[a-zA-Záâçéêíóôú]+[bcefghijlmnoprtuvxz][ã][o])[s](?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "s"', 'Não se usa crase antes de verbo ou palavra masculina. Você quis dizer:', 'not m.group("Zao_2") in femeCrase and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà])[s] (?P<Zao_3>[a-zA-Záâçéêíóôú]+[bcefghijlmnoprtuvxz][ã][o])(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "s"', 'Não se usa crase antes de verbo ou palavra masculina. Você quis dizer:', 'not m.group("Zao_3") in femeCrase and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà])[s] (?P<Zao_4>[a-zA-Záâçéêíóôú]+[bcefghijlmnoprtuvxz][ã][o])[s](?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "s\\n" + aacCrase[m.group(1)] + "os " + m.group(2) + "s"', 'Não se usa crase antes de verbo ou palavra masculina. Você quis dizer:', 'not m.group("Zao_4") in femeCrase and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Cso_1>[a-zçã]+)(?![-\\w–\xad])', 'a \\g<Cso_1>', 'Crase inapropriada. Você quis dizer:', 'm.group("Cso_1").lower() in masAoCrase and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crc_2>[a-záâçéêíóôú]+[dhst]or)(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2)', 'Não se usa crase antes de verbo ou palavra masculina. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crc_3>[a-záâçéêíóôú]+[dhst]ores)(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2)', 'Crase antes de substantivo masculino:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Àà][ ](?P<Scr_1>[a-zA-Z]\\w*)(?![-\\w–\xad])', 'a \\g<Scr_1>', 'Crase inapropriada.\\n http://pt.wikipedia.org/wiki/Crase', 'm.group("Scr_1") in semCrase and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Àà][ ]([Vv])ocê(?![-\\w–\xad])', 'a \\1ocê', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Àà][ ]([Vv])ocês(?![-\\w–\xad])', 'a \\1ocês', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Àà][ ]([Aa])lguém(?![-\\w–\xad])', 'a \\1lguém', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Àà][ ]([Gg])ás(?![-\\w–\xad])', 'a \\1lás', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Àà][ ]([Cc])éu(?![-\\w–\xad])', 'a \\1lé', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Àà][ ]([Tt])ém(?![-\\w–\xad])', 'a \\1lém', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Àà][ ]índice(?![-\\w–\xad])', 'a índice', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Àà][ ]índices(?![-\\w–\xad])', 'a índices', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Àà] queima roupa(?![-\\w–\xad])', 'a queima roupa', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Aa][Nn][Tt][Ee] [Àà](?![-\\w–\xad])', 'ante a', 'Não se usa crase depois da preposição ante.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Aa][Pp][Óó][Ss] [Àà](?![-\\w–\xad])', 'após a', 'Não se usa crase depois da preposição após.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Cc][Oo][Mm] [Àà](?![-\\w–\xad])', 'com a', 'Não se usa crase depois da preposição com.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Cc][Oo][Nn][Tt][Rr][Aa] [Àà](?![-\\w–\xad])', 'contra a', 'Não se usa crase depois da preposição contra.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Cc][Oo][Nn][Ff][Oo][Rr][Mm][Ee] [Àà](?![-\\w–\xad])', 'conforme a', 'Não se usa crase depois da preposição conforme.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Dd][Ee][Ss][Dd][Ee] [Àà](?![-\\w–\xad])', 'desde a', 'Não se usa crase depois da preposição desde.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Dd][Uu][Rr][Aa][Nn][Tt][Ee] [Àà](?![-\\w–\xad])', 'durante a', 'Não se usa crase depois da preposição durante.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[En][Nn][Tt][Rr][Ee] [Àà](?![-\\w–\xad])', 'entre a', 'Não se usa crase depois da preposição entre.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Mm][Ee][Dd][Ii][Aa][Nn][Tt][Ee] [Àà](?![-\\w–\xad])', 'mediante a', 'Não se usa crase depois da preposição mediante.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Pp][Aa][Rr][Aa] [Àà](?![-\\w–\xad])', 'para a', 'Não se usa crase depois da preposição para.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Pp][Ee][Rr][Aa][Nn][Tt][Ee] [Àà](?![-\\w–\xad])', 'perante a', 'Não se usa crase depois da preposição perante.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Pp][Ee][Rr][Aa][Nn][Tt][Ee] [Àà]s(?![-\\w–\xad])', 'perante as', 'Não se usa crase depois da preposição perante.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Ss][Oo][Bb] [Àà](?![-\\w–\xad])', 'sob a', 'Não se usa crase depois da preposição sob.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Ss][Oo][Bb][Rr][Ee] [Àà](?![-\\w–\xad])', 'sobre a', 'Não se usa crase depois da preposição sobre.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])a à(?![-\\w–\xad])', 'a', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])até à(?![-\\w–\xad])', 'até a', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])de à(?![-\\w–\xad])', 'da\ndê a', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])em à(?![-\\w–\xad])', 'na', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])entre à(?![-\\w–\xad])', 'entre a', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])por (a|as|o|os)(?![-\\w–\xad])', 'pôr \\1', 'Faltou o acento? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])por à(?![-\\w–\xad])', 'pôr à', 'Faltou o acento? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])sem à(?![-\\w–\xad])', 'sem a', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])trás à(?![-\\w–\xad])', 'trás a', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])a às(?![-\\w–\xad])', 'as', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])ante às(?![-\\w–\xad])', 'ante as', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])até às(?![-\\w–\xad])', 'até as', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])após às(?![-\\w–\xad])', 'após as', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])com às(?![-\\w–\xad])', 'com as', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])de às(?![-\\w–\xad])', 'da\ndê as', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])desde às(?![-\\w–\xad])', 'desde as', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])em às(?![-\\w–\xad])', 'nas', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])entre às(?![-\\w–\xad])', 'entre as', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])para às(?![-\\w–\xad])', 'para as', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])per às(?![-\\w–\xad])', 'per as', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])por às(?![-\\w–\xad])', 'por as', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])sem às(?![-\\w–\xad])', 'sem as', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])sob às(?![-\\w–\xad])', 'sob as', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])sobre às(?![-\\w–\xad])', 'sobre as', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])trás às(?![-\\w–\xad])', 'trás as', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ccr_2>[a-zA-Z]\\w*)[ ][a][ ][d]([aeo])(?![-\\w–\xad])', '\\g<Ccr_2> à d\\2', 'Preposição -a- mais pronome demonstrativo implícito - aquele, aquela - exige crase.', 'm.group("Ccr_2") in comCrase and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ccr_3>[a-zA-Z]\\w*)[ ][a][ ][d]([ao])[s](?![-\\w–\xad])', '\\g<Ccr_3> à d\\2s', 'Preposição -a- mais pronome demonstrativo implícito - aquele, aquela - exige crase.', 'm.group("Ccr_3") in comCrase and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ccr_4>[a-zA-Z]\\w*)[ ][a][s][ ][d]([aeo])(?![-\\w–\xad])', '\\g<Ccr_4> às d\\2', 'Preposição -a- mais pronome demonstrativo implícito - aquele,aquela - exige crase.', 'm.group("Ccr_4") in comCrase and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ccr_5>[a-zA-Z]\\w*)[ ][a][s][ ][d]([ao])[s](?![-\\w–\xad])', '\\g<Ccr_5> às d\\2s', 'Preposição -a- mais pronome demonstrativo implícito - aquele, aquela - exige crase.', 'm.group("Ccr_5") in comCrase and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])idêntica a d([aeo])(?![-\\w–\xad])', 'idêntica à d\\1', 'Preposição -a- mais pronome demonstrativo implícito - aquele, aquela - exige crase.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])idêntica a d([ao])[s](?![-\\w–\xad])', 'idêntica à d\\1s', 'Preposição -a- mais pronome demontrativo - aquele,aquela - exige crase.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])idêntica as d([aeo])(?![-\\w–\xad])', 'idêntica às d\\1', 'Preposição -a- mais pronome demonstrativo implícito - aquele, aquela - exige crase.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])idêntica as d([ao])[s](?![-\\w–\xad])', 'idêntica às d\\1s', 'Preposição -a- mais pronome demonstrativo implícito - aquele,aquela - exige crase.', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])de (?P<Smn_1>[a-zA-Zçá]+) ([Àà]) (?P<Smn_2>[a-zA-Zçá]+)(?![-\\w–\xad])', 'de \\g<Smn_1> a \\g<Smn_2>', 'Crase inapropriada. Você quis dizer:', 'm.group("Smn_1").lower() in seMana and m.group("Smn_2").lower() in seMana and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])de (?P<Smn_1>[a-zA-Zçá]+) ([Àà]) (?P<Smn_2>[a-zA-Zçá]+)-feira(?![-\\w–\xad])', 'de \\g<Smn_1> a \\g<Smn_2>-feira', 'Crase inapropriada. Você quis dizer:', 'm.group("Smn_1").lower() in seMana and m.group("Smn_2").lower() in seMana and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])de (?P<Smn_1>[a-zA-Zçá]+)-feira ([Àà]) (?P<Smn_2>[a-zA-Zçá]+)-feira(?![-\\w–\xad])', 'de \\g<Smn_1>-feira a \\g<Smn_2>-feira', 'Crase inapropriada. Você quis dizer:', 'm.group("Smn_1").lower() in seMana and m.group("Smn_2").lower() in seMana and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) duras penas(?![-\\w–\xad])', 'a duras penas', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) grande distância(?![-\\w–\xad])', 'a grande distância', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) meia distância(?![-\\w–\xad])', 'a meia distância', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) pouca distância(?![-\\w–\xad])', 'a pouca distância', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])nsino à distância(?![-\\w–\xad])', '\\1nsino a distância', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])nsinos à distância(?![-\\w–\xad])', '\\1nsinos a distância', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])studo à distância(?![-\\w–\xad])', '\\1studo a distância', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])studos à distância(?![-\\w–\xad])', '\\1studos a distância', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])a distância de(?![-\\w–\xad])', 'à distância de', 'Faltou a crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])as expensas(?![-\\w–\xad])', 'às expensas', 'Termo exige uso da crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[,] a esquerda,(?![-\\w–\xad])', 'à esquerda,', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[.] A esquerda,(?![-\\w–\xad])', 'À esquerda,', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])mais a esquerda(?![-\\w–\xad])', 'mais à esquerda', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Esq_1>[a-zA-Záâçéêíóôúã]+[a][d][ao]) a esquerda(?![-\\w–\xad])', '\\g<Esq_1> à esquerda', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Esq_2>[a-zA-Záâçéêíóôúã]+[a][d][ao][s]) a esquerda(?![-\\w–\xad])', '\\g<Esq_2> à esquerda', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) direita e a esquerda(?![-\\w–\xad])', '\\1 direita e à esquerda,', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) esquerda e a direita(?![-\\w–\xad])', '\\1 esquerda e à direita,', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[,] a direita,(?![-\\w–\xad])', 'à direita,', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[.] A direita,(?![-\\w–\xad])', 'À direita,', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])mais a direita(?![-\\w–\xad])', 'mais à direita', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dir_1>[a-zA-Záâçéêíóôúã]+[a][d][ao]) a direita(?![-\\w–\xad])', '\\g<Dir_1> à direita', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dir_2>[a-zA-Záâçéêíóôúã]+[a][d][ao][s]) a direita(?![-\\w–\xad])', '\\g<Dir_2> à direita', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Frt_1>[a-zA-Záâçéêíóôúã]+) frente ([Àà])(?![-\\w–\xad])', '\\g<Frt_1> frente a\\n\\g<Frt_1> diante da', 'Crase inapropriada. Você quis dizer:', 'not m.group("Frt_1").lower() in excEmFrente and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Frt_2>[a-zA-Záâçéêíóôúã]+) frente ([Àà])s(?![-\\w–\xad])', '\\g<Frt_2> frente as\\n\\g<Frt_2> diante da', 'Crase inapropriada. Você quis dizer:', 'not m.group("Frt_2").lower() in excEmFrente and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])Frente ([Àà])(?![-\\w–\xad])', 'Frente a\\nDiante da', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])Frente ([Àà])s(?![-\\w–\xad])', 'Frente as\\nDiante das', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([,]) frente ([Àà])(?![-\\w–\xad])', '\\1 frente a\\n\\1 diante da', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([,]) frente ([Àà])s(?![-\\w–\xad])', '\\1 frente as\\n\\1 diante das', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) bel-prazer(?![-\\w–\xad])', 'a bel-prazer', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) bel prazer(?![-\\w–\xad])', 'a bel-prazer', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) boa distância de(?![-\\w–\xad])', 'a boa distância de', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) certa altura(?![-\\w–\xad])', 'a certa altura', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) certa distância(?![-\\w–\xad])', 'a certa distância', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) expensas de(?![-\\w–\xad])', 'a expensas de', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) instâncias de(?![-\\w–\xad])', 'a instâncias de', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) portas fechadas(?![-\\w–\xad])', 'a portas fechadas', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) meia altura(?![-\\w–\xad])', 'a meia altura', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) sete chaves(?![-\\w–\xad])', 'a sete chaves', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) três por dois(?![-\\w–\xad])', 'a três por dois', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])m que pese ([Àà])(?![-\\w–\xad])', '\\1m que pese a', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])fazer ([Àà])s vezes de(?![-\\w–\xad])', 'fazer as vezes de', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odas ([Àà])s vezes(?![-\\w–\xad])', '\\1odas as vezes', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Àà]) pena(?![-\\w–\xad])', '\\1ale a pena', 'Crase inapropriada. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([à]) (?P<Zaf_1>[a-záâçéêíóôú]+)dades(?![-\\w–\xad])', 'a \\g<Zaf_1>dades\\n\\1s \\g<Zaf_1>dades', 'Preposição sem o artigo - as - não admite crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([à]) (?P<ZAf_2>[a-záâçéêíóôú]+[aeiounrs][dst])oras(?![-\\w–\xad])', 'a \\g<Zaf_2>oras\\n\\1s \\g<Zaf_2>oras', 'Preposição sem o artigo - as - não admite crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([à]) (?P<Zaf_3>[a-z]+[áéóú][cr])ias(?![-\\w–\xad])', 'a \\g<Zaf_3>ias\\n\\1s \\g<Zaf_3>ias', 'Preposição sem o artigo - as - não admite crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([à]) (?P<Zaf_4>[a-z]+[áéóú])rias(?![-\\w–\xad])', 'a \\g<Zaf_4>rias\\n\\1s \\g<Zaf_4>rias', 'Preposição sem o artigo - as - não admite crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Pcr_a>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "\\n" + aacCrase[m.group(1)] + "o " + m.group(2)', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Pcr_a") in plvrMasca and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Pcr_b>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "s\\n" + aacCrase[m.group(1)] + "os " + m.group(2) + "s"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Pcr_b") in plvrMasca and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà])s (?P<Pcr_c>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "\\n" + aacCrase[m.group(1)] + "o " + m.group(2) + "s"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Pcr_c") in plvrMasca and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà])s (?P<Pcr_d>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "s\\n" + aacCrase[m.group(1)] + "os " + m.group(2) + "s"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Pcr_d") in plvrMasca and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crcu_10>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "u"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crcu_10") in plvrMascu and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crcu_11>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "us"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crcu_11") in plvrMascu and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crc_10>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "l"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crc_10") in plvrMascal and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crc_11>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "is"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crc_11") in plvrMascal and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crcel_10>[a-zA-Zçáéíóúâêô]+)el(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "el"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crcel_10") in plvrMascel and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crcel_11>[a-zA-Zçáéíóúâêô]+)éis(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "éis"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crcel_11") in plvrMascel and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crcel_12>[a-zA-Zçáéíóúâêô]+[e])l(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "l"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crcel_12") in plvrAmascel and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crcel_13>[a-zA-Zçáéíóúâêô]+[é])is(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "is"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crcel_13") in plvrAmascel and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Ptfe_33>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "e\\n" + aacCrase[m.group(1)] + "o " + m.group(2) + "e"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Ptfe_33") in plvrMasce and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Ptfe_34>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "es\\n" + aacCrase[m.group(1)] + "os " + m.group(2) + "es"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Ptfe_34") in plvrMasce and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà])s (?P<Ptfe_35>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "e\\n" + aacCrase[m.group(1)] + "o " + m.group(2) + "es"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Ptfe_35") in plvrMasce and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà])s (?P<Ptfe_36>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "es\\n" + aacCrase[m.group(1)] + "os " + m.group(2) + "es"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Ptfe_36") in plvrMasce and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crc_10>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "z"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crc_10") in plvrMascz and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crc_11>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "zes"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crc_11") in plvrMascz and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crcu_10>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "m"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crcu_10") in plvrMascm and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crcu_11>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "ns"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crcu_11") in plvrMascm and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])st(eja|ejam|arei|aremos|ar|arem|ariam|ou|ive) a vontade(?![-\\w–\xad])', '\\1st\\2 à vontade', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])st(eja|ejam|arei|aremos|ar|arem|ariam|ou|ive) a disposição(?![-\\w–\xad])', '\\1st\\2 à disposição', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])i(que|quei|carei|caremos|car|carem|cariam|cou|co|camos|caram|ca) a disposição(?![-\\w–\xad])', '\\1i\\2 à disposição', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])scolh(a|er|erei|eremos|e|erem|eriam|eu|i|ia|iam|o) a vontade(?![-\\w–\xad])', '\\1scolh\\2 à vontade', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])om(a|er|erei|eremos|e|erem|eriam|eu|i|ia|iam|o) a vontade(?![-\\w–\xad])', '\\1om\\2 à vontade', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(mais|muito|pouco|bem|sinto|sinta|sintam|[Ss]inta-se|[Ss]intam-se|[Ss]into-me|dormir|andar|beber|completamente|tão) a vontade(?![-\\w–\xad])', '\\1 à vontade', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])i(que|quem|car|cou|caram|carão|caremos|quei|camos|quemos|casse|cassem|cássemos) a vontade(?![-\\w–\xad])', '\\1i\\2 à vontade', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])al(ar|em|ou|aram|arão|aremos|ei|amos|emos|asse|assem|ássemos) a vontade(?![-\\w–\xad])', '\\1al\\2 à vontade', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])hor(ar|em|ou|aram|arão|ei) a vontade(?![-\\w–\xad])', '\\1hor\\2 à vontade', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])scolh(er|em|eu|eram|erão|erei|emos|i|eremos) a vontade(?![-\\w–\xad])', '\\1scolh\\2 à vontade', 'Ausência de crase? Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a abertura(?![-\\w–\xad])', '\\1 à abertura', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a assembleia(?![-\\w–\xad])', '\\1 à assembleia', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a biblioteca(?![-\\w–\xad])', '\\1 à biblioteca', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|saiu|sairam|sairão|irá|irei) a caça(?![-\\w–\xad])', '\\1 à caça', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a capela(?![-\\w–\xad])', '\\1 à capela', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a casa(?![-\\w–\xad])', '\\1 à casa', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|saiu|sairam|sairão|irá|irei) a cata(?![-\\w–\xad])', '\\1 à cata', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a cidade(?![-\\w–\xad])', '\\1 à cidade', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a copa(?![-\\w–\xad])', '\\1 à copa', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a cozinha(?![-\\w–\xad])', '\\1 à cozinha', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a CPI(?![-\\w–\xad])', '\\1 à CPI', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a custa(?![-\\w–\xad])', '\\1 à custa', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a escola(?![-\\w–\xad])', '\\1 à escola', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a estação(?![-\\w–\xad])', '\\1 à estação', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|levou|levaram|levaria|levariam|levar|levará|vai|vão|irão|irá|irei) a falência(?![-\\w–\xad])', '\\1 à falência', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a favela(?![-\\w–\xad])', '\\1 à favela', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a fazenda(?![-\\w–\xad])', '\\1 à fazenda', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a inauguração(?![-\\w–\xad])', '\\1 à inauguração', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a praia(?![-\\w–\xad])', '\\1 à praia', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a delegacia(?![-\\w–\xad])', '\\1 à delegacia', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a missa(?![-\\w–\xad])', '\\1 à missa', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a ([Ss])ecretaria(?![-\\w–\xad])', '\\1 à \\2ecretaria', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a ([Pp])olícia(?![-\\w–\xad])', '\\1 à \\2olícia', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a ([Ff])armácia(?![-\\w–\xad])', '\\1 à \\2armácia', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a ([Ii])greja(?![-\\w–\xad])', '\\1 à \\2greja', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a ([Ff])eira(?![-\\w–\xad])', '\\1 à \\2eira', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a ([Pp])adaria(?![-\\w–\xad])', '\\1 à \\2adaria', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a ([Rr])ua(?![-\\w–\xad])', '\\1 à \\2ua', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(vou|vai|vão|irão|irá|irei) a ([Pp])raça(?![-\\w–\xad])', '\\1 à \\2raça', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])acesso a ([Ii])nternet(?![-\\w–\xad])', 'acesso à \\1nternet', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])acesso a (?P<Acs_1>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', 'acesso à \\1', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_1") in plvrFema and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])acesso a (?P<Acs_2>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', 'acesso às \\1s', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_2") in plvrFema and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])acesso a (?P<Acs_3>[a-zA-Zç]+)([âêíôú])ncia(?![-\\w–\xad])', 'acesso à \\1\\2ncia', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])acesso a (?P<Acs_4>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', 'acesso à \\1grafia', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])acesso a (?P<Acs_5>[a-zA-Záâãçéêíóôú]+)([gl])ogia(?![-\\w–\xad])', 'acesso à \\1\\2ogia', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])acesso a (?P<Acs_6>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', 'acesso à \\1rgia', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])acesso a (?P<Acs_7>[a-zA-Zç]+)([áéíóú])lia(?![-\\w–\xad])', 'acesso à \\1\\2lia', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])acesso a (?P<Acs_8>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', 'acesso à \\1erapia', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])acesso a (?P<Acs_9>[a-zA-Zç]+)([áéíóú])ria(?![-\\w–\xad])', 'acesso à \\1\\2ria', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])acesso a (?P<Acs_10>[a-zA-Zç]+)([áéíú])sia(?![-\\w–\xad])', 'acesso à \\1\\2sia', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])acesso a (?P<Acs_11>[a-zA-Zç]+)([áéíóú])rsia(?![-\\w–\xad])', 'acesso à \\1\\2rsia', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])acesso a (?P<Acs_12>[a-zA-Zç]+)([áéíóú])ssia(?![-\\w–\xad])', 'acesso à \\1\\2ssia', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])acesso a (?P<Acs_13>[a-zA-Zç]+)([áéíóú])rnia(?![-\\w–\xad])', 'acesso à \\1\\2rnia', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])acesso a (?P<Acs_14>[a-zA-Zç]+)([âêíôú])nia(?![-\\w–\xad])', 'acesso à \\1\\2nia', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])acesso a (?P<Acs_15>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', 'acesso à \\1dade', 'Ausência de crase. Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])(?P<Acs_16>[a-záãéêí]+) acesso a (?P<Acs_17>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1\\2 acesso à \\3', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_16") in vbTer and m.group("Acs_17").lower() in plvrFema and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])(?P<Acs_18>[a-záãéêí]+) acesso a (?P<Acs_19>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '\\1\\2 acesso à \\3a', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_18") in vbTer and m.group("Acs_19").lower() in plvrMfoa and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])(?P<Acs_20>[a-záãéêí]+) acesso a (?P<Acs_21>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '\\1\\2 acesso à \\3', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_20") in vbTer and m.group("Acs_21").lower() in plvrFemr and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])(?P<Acs_22>[a-záãéêí]+) acesso a (?P<Acs_23>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '\\1\\2 acesso à \\3l', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_22") in vbTer and m.group("Acs_23").lower() in plvrFemal and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])(?P<Acs_24>[a-záãéêí]+) acesso a (?P<Acs_25>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '\\1\\2 acesso à \\3el', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_24") in vbTer and m.group("Acs_25").lower() in plvrFemel and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])(?P<Acs_26>[a-záãéêí]+) acesso a (?P<Acs_27>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '\\1\\2 acesso à \\3ão', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_26") in vbTer and not m.group("Acs_27").lower() in plvrNfemcao and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])(?P<Acs_28>[a-záãéêí]+) acesso a (?P<Acs_29>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '\\1\\2 acesso à \\3ão', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_28") in vbTer and m.group("Acs_29").lower() in plvrFemao and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])(?P<Acs_30>[a-záãéêí]+) acesso a (?P<Acs_31>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '\\1\\2 acesso à \\3e', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_30") in vbTer and m.group("Acs_31").lower() in plvrFeme and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])(?P<Acs_32>[a-záãéêí]+) acesso a (?P<Acs_33>[a-zA-Z]+)z(?![-\\w–\xad])', '\\1\\2 acesso à \\3z', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_32") in vbTer and m.group("Acs_33").lower() in plvrFemz and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])(?P<Acs_34>[a-záãéêí]+) acesso a (?P<Acs_35>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '\\1\\2 acesso à \\3m', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_34") in vbTer and m.group("Acs_35").lower() in plvrFemm and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])(?P<Acs_36>[a-záãéêí]+) acesso a (?P<Acs_37>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1\\2 acesso à \\3', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_36") in vbDar and m.group("Acs_37").lower() in plvrFema and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])(?P<Acs_38>[a-záãéêí]+) acesso a (?P<Acs_39>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '\\1\\2 acesso à \\3a', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_38") in vbDar and m.group("Acs_39").lower() in plvrMfoa and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])(?P<Acs_40>[a-záãéêí]+) acesso a (?P<Acs_41>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '\\1\\2 acesso à \\3', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_40") in vbDar and m.group("Acs_41").lower() in plvrFemr and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])(?P<Acs_42>[a-záãéêí]+) acesso a (?P<Acs_43>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '\\1\\2 acesso à \\3l', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_42") in vbDar and m.group("Acs_43").lower() in plvrFemal and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])(?P<Acs_44>[a-záãéêí]+) acesso a (?P<Acs_45>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '\\1\\2 acesso à \\3el', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_44") in vbDar and m.group("Acs_45").lower() in plvrFemel and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])(?P<Acs_46>[a-záãéêí]+) acesso a (?P<Acs_47>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '\\1\\2 acesso à \\3ão', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_46") in vbDar and not m.group("Acs_47").lower() in plvrNfemcao and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])(?P<Acs_48>[a-záãéêí]+) acesso a (?P<Acs_49>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '\\1\\2 acesso à \\3ão', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_48") in vbDar and m.group("Acs_49").lower() in plvrFemao and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])(?P<Acs_50>[a-záãéêí]+) acesso a (?P<Acs_51>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '\\1\\2 acesso à \\3e', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_50") in vbDar and m.group("Acs_51").lower() in plvrFeme and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])(?P<Acs_52>[a-záãéêí]+) acesso a (?P<Acs_53>[a-zA-Z]+)z(?![-\\w–\xad])', '\\1\\2 acesso à \\3z', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_52") in vbDar and m.group("Acs_53").lower() in plvrFemz and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])(?P<Acs_54>[a-záãéêí]+) acesso a (?P<Acs_55>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '\\1\\2 acesso à \\3m', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_54") in vbDar and m.group("Acs_55").lower() in plvrFemm and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(algum|ao|cada|com|do|e|fácil|livre|maior|melhor|menor|meu|muito|nenhum|no|o|para|pelo|pouco|sem|seu|teu|um) acesso a (?P<Acs_56>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1 acesso à \\2', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_56").lower() in plvrFema and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(algum|ao|cada|com|do|e|fácil|livre|maior|melhor|menor|meu|muito|nenhum|no|o|para|pelo|pouco|sem|seu|teu|um) acesso a (?P<Acs_57>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '\\1 acesso à \\2a', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_57").lower() in plvrMfoa and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(algum|ao|cada|com|do|e|fácil|livre|maior|melhor|menor|meu|muito|nenhum|no|o|para|pelo|pouco|sem|seu|teu|um) acesso a (?P<Acs_58>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '\\1 acesso à \\2', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_58").lower() in plvrFemr and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(algum|ao|cada|com|do|e|fácil|livre|maior|melhor|menor|meu|muito|nenhum|no|o|para|pelo|pouco|sem|seu|teu|um) acesso a (?P<Acs_59>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '\\1 acesso à \\2l', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_59").lower() in plvrFemal and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(algum|ao|cada|com|do|e|fácil|livre|maior|melhor|menor|meu|muito|nenhum|no|o|para|pelo|pouco|sem|seu|teu|um) acesso a (?P<Acs_60>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '\\1 acesso à \\2el', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_60").lower() in plvrFemel and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(algum|ao|cada|com|do|e|fácil|livre|maior|melhor|menor|meu|muito|nenhum|no|o|para|pelo|pouco|sem|seu|teu|um) acesso a (?P<Acs_61>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '\\1 acesso à \\2ão', 'Ausência de crase. Você quis dizer:', 'not m.group("Acs_61").lower() in plvrNfemcao and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(algum|ao|cada|com|do|e|fácil|livre|maior|melhor|menor|meu|muito|nenhum|no|o|para|pelo|pouco|sem|seu|teu|um) acesso a (?P<Acs_62>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '\\1 acesso à \\2ão', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_62").lower() in plvrFemao and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(algum|ao|cada|com|do|e|fácil|livre|maior|melhor|menor|meu|muito|nenhum|no|o|para|pelo|pouco|sem|seu|teu|um) acesso a (?P<Acs_63>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '\\1 acesso à \\2e', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_63").lower() in plvrFeme and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(algum|ao|cada|com|do|e|fácil|livre|maior|melhor|menor|meu|muito|nenhum|no|o|para|pelo|pouco|sem|seu|teu|um) acesso a (?P<Acs_64>[a-zA-Z]+)z(?![-\\w–\xad])', '\\1 acesso à \\2z', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_64").lower() in plvrFemz and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(algum|ao|cada|com|do|e|fácil|livre|maior|melhor|menor|meu|muito|nenhum|no|o|para|pelo|pouco|sem|seu|teu|um) acesso a (?P<Acs_65>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '\\1 acesso à \\2m', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_65").lower() in plvrFemm and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(alguns|aos|dos|fáceis|livres|maiores|melhores|menores|meus|muitos|nos|os|pelos|poucos|seus|teus|uns) acessos a (?P<Acs_66>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1 acessos à \\2', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_66").lower() in plvrFema and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(alguns|aos|dos|fáceis|livres|maiores|melhores|menores|meus|muitos|nos|os|pelos|poucos|seus|teus|uns) acessos a (?P<Acs_67>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '\\1 acessos à \\2a', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_67").lower() in plvrMfoa and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(alguns|aos|dos|fáceis|livres|maiores|melhores|menores|meus|muitos|nos|os|pelos|poucos|seus|teus|uns) acessos a (?P<Acs_68>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '\\1 acessos à \\2', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_68").lower() in plvrFemr and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(alguns|aos|dos|fáceis|livres|maiores|melhores|menores|meus|muitos|nos|os|pelos|poucos|seus|teus|uns) acessos a (?P<Acs_69>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '\\1 acessos à \\2l', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_69").lower() in plvrFemal and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(alguns|aos|dos|fáceis|livres|maiores|melhores|menores|meus|muitos|nos|os|pelos|poucos|seus|teus|uns) acessos a (?P<Acs_70>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '\\1 acessos à \\2el', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_70").lower() in plvrFemel and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(alguns|aos|dos|fáceis|livres|maiores|melhores|menores|meus|muitos|nos|os|pelos|poucos|seus|teus|uns) acessos a (?P<Acs_71>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '\\1 acessos à \\2ão', 'Ausência de crase. Você quis dizer:', 'not m.group("Acs_71").lower() in plvrNfemcao and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(alguns|aos|dos|fáceis|livres|maiores|melhores|menores|meus|muitos|nos|os|pelos|poucos|seus|teus|uns) acessos a (?P<Acs_72>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '\\1 acessos à \\2ão', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_72").lower() in plvrFemao and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(alguns|aos|dos|fáceis|livres|maiores|melhores|menores|meus|muitos|nos|os|pelos|poucos|seus|teus|uns) acessos a (?P<Acs_73>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '\\1 acessos à \\2e', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_73").lower() in plvrFeme and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(alguns|aos|dos|fáceis|livres|maiores|melhores|menores|meus|muitos|nos|os|pelos|poucos|seus|teus|uns) acessos a (?P<Acs_74>[a-zA-Z]+)z(?![-\\w–\xad])', '\\1 acessos à \\2z', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_74").lower() in plvrFemz and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])(alguns|aos|dos|fáceis|livres|maiores|melhores|menores|meus|muitos|nos|os|pelos|poucos|seus|teus|uns) acessos a (?P<Acs_75>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '\\1 acessos à \\2m', 'Ausência de crase. Você quis dizer:', 'm.group("Acs_75").lower() in plvrFemm and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])at(er|eu|ia|emos|eram|i|iam|eram-lhe|eu-lhe) na porta(?![-\\w–\xad])', '\\1at\\2 à porta', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])iv(o|a|am|em|erem|er|e|emos|ia|iam|i|erão|erá) as custas d([aeo])(?![-\\w–\xad])', '\\1iv\\2 à custa d\\3', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])iv(o|a|am|em|erem|er|e|emos|ia|iam|i|erão|erá) às custas d([aeo])(?![-\\w–\xad])', '\\1iv\\2 à custa d\\3', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Àà][ ]([MmTtSs])[e][u][s](?![-\\w–\xad])', 'a \\1eus\\naos \\1eus', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])[Àà][ ]([MmTtSs])[e][u](?![-\\w–\xad])', 'a \\1eu\\nao \\1e', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Bcs_1>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', 'às \\1s', 'Você quis dizer:', 'm.group("Bcs_1") in plvrFema and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Bcs_2>[a-zA-Zç]+)([âêíôú])ncias(?![-\\w–\xad])', 'às \\1\\2ncias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Bcs_3>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', 'às \\1grafias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Bcs_4>[a-zA-Záâãçéêíóôú]+)([gl])ogias(?![-\\w–\xad])', 'às \\1\\2ogias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Bcs_5>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', 'às \\1rgias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Bcs_6>[a-zA-Zç]+)([áéíóú])lias(?![-\\w–\xad])', 'às \\1\\2lias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Bcs_7>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', 'às \\1erapias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Bcs_8>[a-zA-Zç]+)([áéíóú])rias(?![-\\w–\xad])', 'às \\1\\2rias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Bcs_9>[a-zA-Zç]+)([áéíú])sias(?![-\\w–\xad])', 'às \\1\\2sias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Bcs_10>[a-zA-Zç]+)([áéíóú])rsias(?![-\\w–\xad])', 'às \\1\\2rsias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Bcs_11>[a-zA-Zç]+)([áéíóú])ssias(?![-\\w–\xad])', 'às \\1\\2ssias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Bcs_12>[a-zA-Zç]+)([áéíóú])rnias(?![-\\w–\xad])', 'às \\1\\2rnias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Bcs_13>[a-zA-Zç]+)([âêíôú])nias(?![-\\w–\xad])', 'às \\1\\2nias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Bcs_14>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', 'às \\1dades', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])às (?P<Bcs_15>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', 'às \\1s', 'Você quis dizer:', 'm.group("Bcs_15") in plvrFema and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])às (?P<Bcs_16>[a-zA-Zç]+)([âêíôú])ncia(?![-\\w–\xad])', 'às \\1\\2ncias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])às (?P<Bcs_17>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', 'às \\1grafias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])às (?P<Bcs_18>[a-zA-Záâãçéêíóôú]+)([gl])ogia(?![-\\w–\xad])', 'às \\1\\2ogias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])às (?P<Bcs_19>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', 'às \\1rgias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])às (?P<Bcs_20>[a-zA-Zç]+)([áéíóú])lia(?![-\\w–\xad])', 'às \\1\\2lias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])às (?P<Bcs_21>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', 'às \\1erapias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])às (?P<Bcs_22>[a-zA-Zç]+)([áéíóú])ria(?![-\\w–\xad])', 'às \\1\\2rias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])às (?P<Bcs_23>[a-zA-Zç]+)([áéíú])sia(?![-\\w–\xad])', 'às \\1\\2sias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])às (?P<Bcs_24>[a-zA-Zç]+)([áéíóú])rsia(?![-\\w–\xad])', 'às \\1\\2rsias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])às (?P<Bcs_25>[a-zA-Zç]+)([áéíóú])ssia(?![-\\w–\xad])', 'às \\1\\2ssias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])às (?P<Bcs_26>[a-zA-Zç]+)([áéíóú])rnia(?![-\\w–\xad])', 'às \\1\\2rnias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])às (?P<Bcs_27>[a-zA-Zç]+)([âêíôú])nia(?![-\\w–\xad])', 'às \\1\\2nias', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])às (?P<Bcs_28>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', 'às \\1dades', 'Você quis dizer:', 'option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Bcs_30>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', 'às \\1as', 'Você quis dizer:', 'm.group("Bcs_30") in plvrMfoa and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])às (?P<Bcs_31>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', 'às \\1as', 'Você quis dizer:', 'm.group("Bcs_31") in plvrMfoa and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Bcs_32>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', 'às \\1es', 'Você quis dizer:', 'm.group("Bcs_32") in plvrFeme and option(LOCALE,"grammar")'],
 ['(?u)(?<![-\\w–.,\xad])às (?P<Bcs_33>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', 'às \\1es', 'Você quis dizer:', 'm.group("Bcs_33") in plvrFeme and option(LOCALE,"grammar")'],
# -*- Fim Crase -*-
# -*- Gerundismo -*-
 ['(?u)(?<![-\\w–.,\xad])Vou estar (?P<Grd_1>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '= m.group("Grd_1").capitalize() + \'rei \'', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vou estar (?P<Grd_2>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Grd_2>rei', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Vou estar (?P<Grd_3>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '= m.group("Grd_3").capitalize() + \'rei \'', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vou estar (?P<Grd_4>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Grd_4>rei', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Vou estar (?P<Grd_5>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '= m.group("Grd_5").capitalize() + \'rei \'', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vou estar (?P<Grd_6>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Grd_6>rei', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Vamos estar (?P<Grs_1>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '= m.group("Grs_1").capitalize() + \'remos \'', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vamos estar (?P<Grs_2>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Grs_2>remos', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Vamos estar (?P<Grs_3>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '= m.group("Grs_3").capitalize() + \'remos \'', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vamos estar (?P<Grs_4>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Grs_4>remos', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Vamos estar (?P<Grs_5>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '= m.group("Grs_5").capitalize() + \'remos \'', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vamos estar (?P<Grs_6>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Grs_6>remos', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vai estar (?P<Gra_2>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Gra_2>rá', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vai estar (?P<Gra_4>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Gra_4>rá', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vai estar (?P<Gra_6>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Gra_6>rá', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vão estar (?P<Gro_2>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Gro_2>rão', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vão estar (?P<Gro_4>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Gro_4>rão', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vão estar (?P<Gro_6>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Gro_6>rão', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Grd_a>[a-zA-Záãç]+) estar (?P<Grd_b>[a-zç]+[aieo])[n][d][o](?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "r"', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGerundio and not m.group(2) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Grk_a>[a-zA-Záãç]+) acabar (?P<Grk_b>[a-zç]+[aieo])[n][d][o](?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "r"', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGerundio and not m.group(2) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Estaremos (?P<Grs_c>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '= m.group("Grs_c").capitalize() + \'remos \'', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estaremos (?P<Grs_d>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Grs_d>remos', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Estaremos (?P<Grs_e>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '= m.group("Grs_e").capitalize() + \'remos \'', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estaremos (?P<Grs_f>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Grs_f>remos', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Estaremos (?P<Grs_g>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '= m.group("Grs_g").capitalize() + \'remos \'', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estaremos (?P<Grs_h>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Grs_h>remos', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Estarei (?P<Grd_c>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '= m.group("Grd_c").capitalize() + \'rei \'', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estarei (?P<Grd_d>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Grd_d>rei', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Estarei (?P<Grd_e>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '= m.group("Grd_e").capitalize() + \'rei \'', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estarei (?P<Grd_f>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Grd_f>rei', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Estarei (?P<Grd_g>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '= m.group("Grd_g").capitalize() + \'rei \'', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estarei (?P<Grd_h>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Grd_h>rei', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estará (?P<Gra_a>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Gra_a>rá', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estará (?P<Gra_b>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Gra_b>rá', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estará (?P<Gra_c>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Gra_c>rá', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estarão (?P<Gro_a>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Gro_a>rão', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estarão (?P<Gro_b>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Gro_b>rão', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estarão (?P<Gro_c>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Gro_c>rão', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estaria (?P<Grb_a>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Grb_a>ria', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estaria (?P<Grb_b>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Grb_b>ria', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estaria (?P<Grb_c>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Grb_c>ria', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estariam (?P<Grc_a>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Grc_a>riam', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estariam (?P<Grc_b>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Grc_b>riam', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])estariam (?P<Grc_c>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Grc_c>riam', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Vou acabar (?P<Gkd_1>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '= m.group("Gkd_1").capitalize() + \'rei \'', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vou acabar (?P<Gkd_2>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Gkd_2>rei', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Vou acabar (?P<Gkd_3>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '= m.group("Gkd_3").capitalize() + \'rei \'', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vou acabar (?P<Gkd_4>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Gkd_4>rei', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Vou acabar (?P<Gkd_5>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '= m.group("Gkd_5").capitalize() + \'rei \'', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vou acabar (?P<Gkd_6>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Gkd_6>rei', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Vamos acabar (?P<Gks_1>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '= m.group("Gks_1").capitalize() + \'remos \'', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vamos acabar (?P<Gks_2>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Gks_2>remos', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Vamos acabar (?P<Gks_3>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '= m.group("Gks_3").capitalize() + \'remos \'', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vamos acabar (?P<Gks_4>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Gks_4>remos', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Vamos acabar (?P<Gks_5>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '= m.group("Gks_5").capitalize() + \'remos \'', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vamos acabar (?P<Gks_6>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Gks_6>remos', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vai acabar (?P<Gka_2>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Gka_2>rá', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vai acabar (?P<Gka_4>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Gka_4>rá', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vai acabar (?P<Gka_6>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Gka_6>rá', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vão acabar (?P<Gko_2>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Gko_2>rão', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vão acabar (?P<Gko_4>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Gko_4>rão', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])vão acabar (?P<Gko_6>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Gko_6>rão', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Acabaremos (?P<Gks_c>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '= m.group("Gks_c").capitalize() + \'remos \'', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabaremos (?P<Gks_d>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Gks_d>remos', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Acabaremos (?P<Gks_e>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '= m.group("Gks_e").capitalize() + \'remos \'', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabaremos (?P<Gks_f>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Gks_f>remos', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Acabaremos (?P<Gks_g>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '= m.group("Gks_g").capitalize() + \'remos \'', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabaremos (?P<Gks_h>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Gks_h>remos', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Acabarei (?P<Gkd_c>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '= m.group("Gkd_c").capitalize() + \'rei \'', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabarei (?P<Gkd_d>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Gkd_d>rei', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Acabarei (?P<Gkd_e>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '= m.group("Gkd_e").capitalize() + \'rei \'', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabarei (?P<Gkd_f>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Gkd_f>rei', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])Acabarei (?P<Gkd_g>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '= m.group("Gkd_g").capitalize() + \'rei \'', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabarei (?P<Gkd_h>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Gkd_h>rei', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabará (?P<Gka_a>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Gka_a>rá', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabará (?P<Gka_b>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Gka_b>rá', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabará (?P<Gka_c>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Gka_c>rá', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabarão (?P<Gko_a>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Gko_a>rão', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabarão (?P<Gko_b>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Gko_b>rão', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabarão (?P<Gko_c>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Gko_c>rão', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabaria (?P<Gkb_a>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Gkb_a>ria', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabaria (?P<Gkb_b>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Gkb_b>ria', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabaria (?P<Gkb_c>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Gkb_c>ria', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabariam (?P<Gkc_a>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Gkc_a>riam', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabariam (?P<Gkc_b>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Gkc_b>riam', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabariam (?P<Gkc_c>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Gkc_c>riam', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabar (?P<Gkr_a>[a-zç]+[ai])[n][d][o](?![-\\w–\xad])', '\\g<Gkr_a>r', 'Gerundismo. Você quis dizer:', 'not m.group(1) in excGquando and option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabar (?P<Gkr_b>[a-zç]+[bcdfgjlmnprstvx][e])[n][d][o](?![-\\w–\xad])', '\\g<Gkr_b>r', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
 ['(?u)(?<![-\\w–.,\xad])acabar (?P<Gkr_c>[a-zç]+)[z][e][n][d][o](?![-\\w–\xad])', '\\g<Gkr_c>r', 'Gerundismo. Você quis dizer:', 'option(LOCALE,"gerund")'],
# -*- Fim Gerundismo -*-
# -*- Paronimos -*-
# ----*--- Geral -*-
 ['(?u)(?<![-\\w–.,\xad])(?P<Act_1>[a-zA-Zç]+)(?![-\\w–\xad])', '= aacento[m.group(1)]', 'Faltou o acento? Você quis dizer:', 'm.group("Act_1") in acAcento and not "Eu " + m.group("Act_1") in TEXT and not "Ela " + m.group("Act_1") in TEXT and not "Ele " + m.group("Act_1") in TEXT and not " eu " + m.group("Act_1") in TEXT and not " ele " + m.group("Act_1") in TEXT and not " ela " + m.group("Act_1") in TEXT and option(LOCALE,"paronimo")'],
# ----*--- FIM Geral -*-
# ----*--- Analise-Análise -*-
 ['(?u)(?<![-\\w–.,\xad])([Aa])nalises(?![-\\w–\xad])', '\\1nálises', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Apr_1>[a-zA-Z]+) analise(?![-\\w–\xad])', '\\g<Apr_1> análise', 'Palavra analise, sem acento. Você quis dizer:', 'm.group("Apr_1") in preAnalise and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])nalise (?P<Apo_1>[a-z]+)(?![-\\w–\xad])', '\\1nálise \\g<Apo_1>', 'Palavra analise, sem acento. Você quis dizer:', 'm.group("Apo_1") in posAnalise and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])aç([ao]) analise(?![-\\w–\xad])', '\\1aç\\2 análise', 'Palavra analise, sem acento. Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])ará analise(?![-\\w–\xad])', '\\1ará análise', 'Palavra analise, sem acento. Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])arão analise(?![-\\w–\xad])', '\\1arão análise', 'Palavra analise, sem acento. Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])aríamos analise(?![-\\w–\xad])', '\\1aríamos análise', 'Palavra analise, sem acento. Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue analise ([ao]) (?P<Apo_3>[a-z0-9áâãçéêíóôõú]+) (f[ae]z)(?![-\\w–\xad])', '\\1ue análise \\2 \\g<Apo_3> \\4', 'Palavra analise, sem acento. Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue analise (?P<Apo_4>[a-záâãçéêíóôõú]+) (?P<Apo_5>[f][a-záâãçéêíóôõú]+)(?![-\\w–\xad])', '\\1ue análise \\g<Apo_4> \\g<Apo_5>', 'Palavra analise, sem acento. Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])à analise(?![-\\w–\xad])', 'à análise', 'Palavra analise, sem acento. Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])última analise(?![-\\w–\xad])', 'última análise', 'Palavra analise, sem acento. Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])após analise(?![-\\w–\xad])', 'após análise', 'Palavra analise, sem acento. Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])rápida analise(?![-\\w–\xad])', 'rápida análise', 'Palavra analise, sem acento. Você quis dizer:', 'option(LOCALE,"paronimo")'],
# ----*--- FIM Analise-Análise -*-
# ----*--- Esta-Está -*-estah
 ['(?u)(?<![-\\w–.,\xad])([Ee])sta (?P<Est_1>[a-záâãçéêíóôõú]+)(?![-\\w–\xad])', '\\1stá \\g<Est_1>', 'Faltou o acento na palavra está? Você quis dizer:', 'm.group("Est_1") in posEsta and option(LOCALE,"paronimo") and not excestaem.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])sta à(?![-\\w–\xad])', '\\1stá à', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])sta (?P<Est_3>[a-z]+[áí])vel(?![-\\w–\xad])', '\\1stá \\g<Est_3>vel', 'Faltou o acento na palavra está? Você quis dizer:', 'not m.group("Est_3") in excvelEsta and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])sta lá(?![-\\w–\xad])', '\\1stá lá', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])sta só(?![-\\w–\xad])', '\\1stá só', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])sta tão(?![-\\w–\xad])', '\\1stá tão', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])Esta de(?![-\\w–\xad])', 'Está de', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])que esta de(?![-\\w–\xad])', 'que está de', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([,]) esta de(?![-\\w–\xad])', '\\1 está de', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])ão esta de(?![-\\w–\xad])', '\\1ão está de', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj])á esta de(?![-\\w–\xad])', '\\1á está de', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uem esta de(?![-\\w–\xad])', '\\1uem está de', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando esta de(?![-\\w–\xad])', '\\1uando está de', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])(ele|ela|Ele|Ela|você|Você) esta(?![-\\w–\xad])', '\\1 está', 'Faltou o acento na palavra está? Você quis dizer:', 'not " a " + m.group(1) + " esta" in TEXT and not " para " + m.group(1) + " esta" in TEXT and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])mas esta de(?![-\\w–\xad])', 'mas está de', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])agora esta de(?![-\\w–\xad])', 'agora está de', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])sempre esta de(?![-\\w–\xad])', 'sempre está de', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])nunca esta de(?![-\\w–\xad])', 'nunca está de', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])tudo esta(?![-\\w–\xad])', 'tudo está', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([AaOo]) (?P<Est_5>[a-záâãçéêíóôõú]+)([ao]) esta(?![-\\w–\xad])', '\\1 \\g<Est_5>\\3 está', 'Faltou o acento na palavra está? Você quis dizer:', 'not "para a " + m.group("Est_5") in TEXT and not "para o " + m.group("Est_5") in TEXT and not m.group("Est_5") in excpreEsta and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])um esta(?![-\\w–\xad])', 'um está', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])uma esta(?![-\\w–\xad])', 'uma está', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])outr([ao]) esta(?![-\\w–\xad])', 'outr\\1 está', 'Faltou o acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])Esta (?P<Est_2>[a-záâãçéêíóôõú]+[an][d][o])(?![-\\w–\xad])', 'Está \\g<Est_2>\\nEsta, \\g<Est_2>', 'Faltou acento na palavra está? Faltou separar as frases? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([,]) esta (?P<Est_3>[a-záâãçéêíóôõú]+[an][d][ao])(?![-\\w–\xad])', '\\1 está \\g<Est_3>', 'Faltou acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Est_4>[a-záâçéêíóôõúã]+) esta (?P<Est_5>[a-záâãçéêíóôõú]+[n][d][o])(?![-\\w–\xad])', '\\g<Est_4> está \\g<Est_5>', 'Faltou o acento na palavra está? Você quis dizer:', 'm.group("Est_4") in preEsta and option(LOCALE,"paronimo") and not " para que esta " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Est_6>[A-Z][a-záâçéêíóôõúã]+) esta (?P<Est_7>[a-záâãçéêíóôõú]+[an][d][ao])(?![-\\w–\xad])', '\\g<Est_6> está \\g<Est_7>', 'Faltou o acento na palavra está? Você quis dizer:', 'not m.group("Est_7") in plvrFema and option(LOCALE,"paronimo") and not " para que esta " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Est_8>[a-zA-Záâçéêíóôõúã]+) esta (?P<Est_9>[a-zç]+)ad([ao])(?![-\\w–\xad])', '\\g<Est_8> está \\g<Est_9>ad\\3', 'Faltou o acento na palavra está? Você quis dizer:', 'm.group("Est_8") in preEsta and m.group("Est_9") in plvrVbrar and option(LOCALE,"paronimo") and not " para que esta " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])sta quase (?P<Est_11>[a-záâãçéêíóôõú]+[an][d][ao])(?![-\\w–\xad])', '\\1stá quase \\g<Est_11>', 'Faltou acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])sta quase se (?P<Est_12>[a-záâãçéêíóôõú]+[n][d][o])(?![-\\w–\xad])', '\\1stá quase se \\g<Est_12>', 'Faltou acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])sta se (?P<Est_13>[a-záâãçéêíóôõú]+[n][d][o])(?![-\\w–\xad])', '\\1stá se \\g<Est_13>', 'Faltou acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])sta quase (?P<Est_14>[a-z]+[t][ao])(?![-\\w–\xad])', '\\1stá quase \\g<Est_14>', 'Faltou acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])sta sempre (?P<Est_15>[a-záâãçéêíóôõú]+[an][d][ao])(?![-\\w–\xad])', '\\1stá quase \\g<Est_15>', 'Faltou acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])sta sempre se (?P<Est_16>[a-záâãçéêíóôõú]+[n][d][o])(?![-\\w–\xad])', '\\1stá quase se \\g<Est_16>', 'Faltou acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])sta sempre (?P<Est_17>[a-z]+[t][ao])(?![-\\w–\xad])', '\\1stá quase \\g<Est_17>', 'Faltou acento na palavra está? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])s([st])([ae]) (?P<Est_18>[a-záâãçéêíóôõú]+) esta(?![-\\w–\xad])', '\\1s\\2\\3 \\4 está', 'Faltou acento na palavra está? Você quis dizer:', 'not "ndo esta " in TEXT and option(LOCALE,"paronimo")'],
# ----*--- FIM Esta-Está -*-
# ----*--- Outros casos -*-
 ['(?u)(?<![-\\w–.,\xad])fabrica(?![-\\w–\xad])', 'fábrica', 'Faltou o acento? Você quis dizer:', 'vfabrica.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])inicio(?![-\\w–\xad])', 'início', 'Faltou o acento? Você quis dizer:', 'vinicio.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])lastima(?![-\\w–\xad])', 'lástima', 'Faltou o acento? Você quis dizer:', 'vlastima.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])magoa(?![-\\w–\xad])', 'mágoa', 'Faltou o acento? Você quis dizer:', 'vmagoa.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])mascara(?![-\\w–\xad])', 'máscara', 'Faltou o acento? Você quis dizer:', 'vmascara.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])negocio(?![-\\w–\xad])', 'negócio', 'Faltou o acento? Você quis dizer:', 'vnegocio.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])pratica(?![-\\w–\xad])', 'prática', 'Faltou o acento? Você quis dizer:', 'not "uem muito pratica" in TEXT and vpratica.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])pratico(?![-\\w–\xad])', 'prático', 'Faltou o acento? Você quis dizer:', 'vpratico.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])publica(?![-\\w–\xad])', 'pública', 'Faltou o acento? Você quis dizer:', 'vpublica.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])republica(?![-\\w–\xad])', 'república', 'Faltou o acento? Você quis dizer:', 'vrepub.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])tabula(?![-\\w–\xad])', 'tábula', 'Faltou o acento? Você quis dizer:', 'vtabula.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])tábula(?![-\\w–\xad])', 'tabula', 'Faltou o acento? Você quis dizer:', 'vtabulb.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])credito(?![-\\w–\xad])', 'crédito', 'Faltou o acento? Você quis dizer:', 'vcredito.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])debito(?![-\\w–\xad])', 'débito', 'Faltou o acento? Você quis dizer:', 'vdebito.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])à credito(?![-\\w–\xad])', 'a crédito', 'Não se usa crase antes de palavra masculina? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])exercito(?![-\\w–\xad])', 'exército', 'Faltou o acento? Você quis dizer:', 'vexercito.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])interprete(?![-\\w–\xad])', 'intérprete', 'Faltou o acento? Você quis dizer:', 'vinterprete.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])perpetua(?![-\\w–\xad])', 'perpétua', 'Faltou o acento? Você quis dizer:', 'not vperpetua.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])replica(?![-\\w–\xad])', 'réplica', 'Faltou o acento? Você quis dizer:', 'vreplica.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])tremula(?![-\\w–\xad])', 'trêmula', 'Faltou o acento? Você quis dizer:', 'not "andeira tremula" in TEXT and not "que tremula" in TEXT and not vtremula.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])auxilio(?![-\\w–\xad])', 'auxílio', 'Faltou o acento? Você quis dizer:', 'vauxilio.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Aux_1>[a-záâãçéêíóôõú]+)-(me|te|se|lha|lhas|lhe|lhes|lho|lhos|nos|o|os|a|as|la|las|lo|los|vos) auxilio(?![-\\w–\xad])', '\\1-\\2 auxílio', 'Faltou o acento em auxílio. Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])distancia(?![-\\w–\xad])', 'distância', 'Faltou o acento? Você quis dizer:', 'vdistancia.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])circulo(?![-\\w–\xad])', 'círculo', 'Faltou o acento? Você quis dizer:', 'vcirculo.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])transito(?![-\\w–\xad])', 'trânsito', 'Faltou o acento? Você quis dizer:', 'vtransito.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])tramite(?![-\\w–\xad])', 'trâmite', 'Faltou o acento? Você quis dizer:', 'vtramite.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])animo(?![-\\w–\xad])', 'ânimo', 'Faltou o acento? Você quis dizer:', 'vanimo.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])parodia(?![-\\w–\xad])', 'paródia', 'Faltou o acento? Você quis dizer:', 'vparodia.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])oncilio(?![-\\w–\xad])', '\\1oncílio', 'Faltou o acento? Você quis dizer:', 'vconcilio.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])continua(?![-\\w–\xad])', 'contínua', 'Faltou o acento? Você quis dizer:', 'vcontinua.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])continuo(?![-\\w–\xad])', 'contínuo', 'Faltou o acento? Você quis dizer:', 'vcontinuo.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])especifica(?![-\\w–\xad])', 'específica', 'Faltou o acento? Você quis dizer:', 'vspecifa.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])especifico(?![-\\w–\xad])', 'específico', 'Faltou o acento? Você quis dizer:', 'vspecifo.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])estimulo(?![-\\w–\xad])', 'estímulo', 'Faltou o acento? Você quis dizer:', 'vestimulo.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])[Ii]ndico(?![-\\w–\xad])', 'Índico', 'Faltou o acento? Você quis dizer:', '("ceano indico" in TEXT or "ceano Indico" in TEXT or " do Indico" in TEXT  or " no Indico" in TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])integra(?![-\\w–\xad])', 'íntegra', 'Faltou o acento? Você quis dizer:', 'vintegra.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])integro(?![-\\w–\xad])', 'íntegro', 'Faltou o acento? Você quis dizer:', 'vintegro.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])intimo(?![-\\w–\xad])', 'íntimo', 'Faltou o acento? Você quis dizer:', 'vintimo.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])intima(?![-\\w–\xad])', 'íntima', 'Faltou o acento? Você quis dizer:', 'vintima.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])renuncia(?![-\\w–\xad])', 'renúncia', 'Faltou o acento? Você quis dizer:', 'vrenuncia.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])denuncia(?![-\\w–\xad])', 'denúncia', 'Faltou o acento? Você quis dizer:', 'vdenuncia.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])libero(?![-\\w–\xad])', 'líbero', 'Faltou o acento? Você quis dizer:', 'vlibero.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])liquido(?![-\\w–\xad])', 'líquido', 'Faltou o acento? Você quis dizer:', 'vliquido.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])liquida(?![-\\w–\xad])', 'líquida', 'Faltou o acento? Você quis dizer:', 'vliquida.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])malicia(?![-\\w–\xad])', 'malícia', 'Faltou o acento? Você quis dizer:', 'vmalicia.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])matricula(?![-\\w–\xad])', 'matrícula', 'Faltou o acento? Você quis dizer:', 'vmatricula.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])participe(?![-\\w–\xad])', 'partícipe', 'Faltou o acento? Você quis dizer:', 'vparticipe.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])participes(?![-\\w–\xad])', 'partícipes', 'Faltou o acento? Você quis dizer:', 'vparticips.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])pericia(?![-\\w–\xad])', 'perícia', 'Faltou o acento? Você quis dizer:', 'vpericia.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])prestigio(?![-\\w–\xad])', 'prestígio', 'Faltou o acento? Você quis dizer:', 'vprestigio.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])retifica(?![-\\w–\xad])', 'retífica', 'Faltou o acento? Você quis dizer:', 'vretifica.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])solicito(?![-\\w–\xad])', 'solícito', 'Faltou o acento? Você quis dizer:', 'vsolicito.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])vicio(?![-\\w–\xad])', 'vício', 'Faltou o acento? Você quis dizer:', 'vvicio.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])vinculo(?![-\\w–\xad])', 'vínculo', 'Faltou o acento? Você quis dizer:', 'vvinculo.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])vitima(?![-\\w–\xad])', 'vítima', 'Faltou o acento? Você quis dizer:', 'vvitima.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])vo(?![-\\w–\xad])', '\\1vó\\n\\1vô', 'Faltou o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ice-([Gg])erenci(a|as)(?![-\\w–\xad])', '\\1ice-\\2erênci\\3', 'Faltou o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ice-([Pp])rmie(?![-\\w–\xad])', '\\1ice-\\2remiê', 'Faltou o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])umero(?![-\\w–\xad])', '\\1úmero', 'Faltou o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])noticia(?![-\\w–\xad])', 'notícia', 'Você quis dizer:', 'vnoticia.search(TEXT) and not excnoticia.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])agencia(?![-\\w–\xad])', 'agência', 'Faltou o acento? Você quis dizer:', 'vagencia.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])agencia(?![-\\w–\xad])', 'agência', 'Faltou o acento? Você quis dizer:', 'vagenciap.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])utentic([ao])(?![-\\w–\xad])', '\\1têntic\\2', 'Faltou o acento? Você quis dizer:', 'not excauttic.search(TEXT) and not not excauttix.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])uque(?![-\\w–\xad])', '\\1uquê', 'Faltou o acento? Você quis dizer:', 'vbuque.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Bb])uques(?![-\\w–\xad])', '\\1uquês', 'Faltou o acento? Você quis dizer:', 'vbuque.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])gerencia(?![-\\w–\xad])', 'gerência', 'Faltou o acento? Você quis dizer:', 'vgerencia.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])negligencia(?![-\\w–\xad])', 'negligência', 'Faltou o acento? Você quis dizer:', 'vnegligencia.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])providencia(?![-\\w–\xad])', 'providência', 'Faltou o acento? Você quis dizer:', 'vprovidencia.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])influencia(?![-\\w–\xad])', 'influência', 'Faltou o acento? Você quis dizer:', 'vinfluencia.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])referencia(?![-\\w–\xad])', 'referência', 'Faltou o acento? Você quis dizer:', 'vreferencia.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])reverencia(?![-\\w–\xad])', 'reverência', 'Faltou o acento? Você quis dizer:', 'vreverencia.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])sequencia(?![-\\w–\xad])', 'sequência', 'Faltou o acento? Você quis dizer:', 'vsequencia.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])vivencia(?![-\\w–\xad])', 'vivência', 'Faltou o acento? Você quis dizer:', 'vvivencia.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])anuncio(?![-\\w–\xad])', 'anúncio', 'Faltou o acento? Você quis dizer:', 'vanuncio.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])duvida(?![-\\w–\xad])', 'dúvida', 'Faltou o acento? Você quis dizer:', 'vduvida.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])duvidas(?![-\\w–\xad])', 'dúvidas', 'Faltou o acento? Você quis dizer:', 'vduvids.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])refugio(?![-\\w–\xad])', 'refúgio', 'Faltou o acento? Você quis dizer:', 'vrefugio.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])suplica(?![-\\w–\xad])', 'súplica', 'Faltou o acento? Você quis dizer:', 'vsuplica.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])copia(?![-\\w–\xad])', 'cópia', 'Faltou o acento? Você quis dizer:', 'vcopia.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])cordão(?![-\\w–\xad])', '\\1córdão', 'Faltou o acento? Você quis dizer:', 'vacordao.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])deposito(?![-\\w–\xad])', 'depósito', 'Faltou o acento? Você quis dizer:', 'vdeposito.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])divorcio(?![-\\w–\xad])', 'divórcio', 'Faltou o acento? Você quis dizer:', 'not excdivorc.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])formula(?![-\\w–\xad])', 'fórmula', 'Faltou o acento? Você quis dizer:', 'vformula.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])otograf([ao])(?![-\\w–\xad])', '\\1otógraf\\2', 'Faltou o acento? Você quis dizer:', 'not excfotogra.search(TEXT) and not not excfotogrx.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])hospede(?![-\\w–\xad])', 'hóspede', 'Faltou o acento? Você quis dizer:', 'vhospede.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])Opera(?![-\\w–\xad])', 'Ópera', 'Faltou o acento? Você quis dizer:', 'vopera.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])opera(?![-\\w–\xad])', 'ópera', 'Faltou o acento? Você quis dizer:', 'vopera.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])orbita(?![-\\w–\xad])', 'órbita', 'Faltou o acento? Você quis dizer:', 'vorbita.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])ovulo(?![-\\w–\xad])', 'óvulo', 'Faltou o acento? Você quis dizer:', 'vovulo.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])prospero(?![-\\w–\xad])', 'próspero', 'Faltou o acento? Você quis dizer:', 'vprospero.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])prospera(?![-\\w–\xad])', 'próspera', 'Faltou o acento? Você quis dizer:', 'vprospera.search(TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])revolver(?![-\\w–\xad])', 'revólver', 'Faltou o acento? Você quis dizer:', 'vrevolver.search(TEXT) and option(LOCALE,"paronimo")'],
# ----*----
 ['(?u)(?<![-\\w–.,\xad])([Ee])l([ae]) fábrica(?![-\\w–\xad])', '\\1l\\2 fabrica', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee]u|Sempre) início(?![-\\w–\xad])', '\\1 inicio', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])l([ae]) lástima(?![-\\w–\xad])', '\\1l\\2 lastima', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])l([ae]) mágoa(?![-\\w–\xad])', '\\1l\\2 magoa', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])l([ae]) máscara(?![-\\w–\xad])', '\\1l\\2 mascara', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee]u|Sempre) negócio(?![-\\w–\xad])', '\\1 negocio', 'Sem o acento? Você quis dizer:', 'not "é"+" sempre" in TEXT and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])l([ae]) prática(?![-\\w–\xad])', '\\1l\\2 pratica', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee]u|Sempre) prático(?![-\\w–\xad])', '\\1 pratico', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])l([ae]) pública(?![-\\w–\xad])', '\\1l\\2 publica', 'Sem o acento? Você quis dizer:', 'not "é"+" sempre" in TEXT and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])l([ae]) república(?![-\\w–\xad])', '\\1l\\2 republica', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])l([ae]) tábula(?![-\\w–\xad])', '\\1l\\2 tabula', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])tábula(?![-\\w–\xad])', 'tabula', 'Sem o acento? Você quis dizer:', '("bula a " in TEXT or "bula o " in TEXT or "bula as " or "bula os" in TEXT in TEXT) and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee]u|Sempre|me) crédito(?![-\\w–\xad])', '\\1 credito', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee]u|Sempre|me) exército(?![-\\w–\xad])', '\\1 exercito', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee]u|[Ee]l[ea]|[Vv]ocê|[Aa]lguém|[Nn]inguém|gente) intérprete(?![-\\w–\xad])', '\\1 interprete', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee]u|[Ee]l[ea]|[Vv]ocê|[Aa]lguém|[Nn]inguém|gente) réplica(?![-\\w–\xad])', '\\1 replica', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee]u|Sempre|me) auxílio(?![-\\w–\xad])', '\\1 auxilio', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee]u|Sempre|me) ânimo(?![-\\w–\xad])', '\\1 animo', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
# ----*---
 ['(?u)(?<![-\\w–.,\xad])([Qq]uem|[Nn]ão) fábrica(?![-\\w–\xad])', '\\1 fabrica', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uem|[Nn]ão) lástima(?![-\\w–\xad])', '\\1 lastima', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uem|[Nn]ão) mágoa(?![-\\w–\xad])', '\\1 magoa', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uem|[Nn]ão) máscara(?![-\\w–\xad])', '\\1 mascara', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uem|[Nn]ão) prática(?![-\\w–\xad])', '\\1 pratica', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uem|[Nn]ão) pública(?![-\\w–\xad])', '\\1 publica', 'Sem o acento? Você quis dizer:', 'not "é"+" sempre" in TEXT and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uem|[Nn]ão) república(?![-\\w–\xad])', '\\1 republica', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uem|[Nn]ão) tábula(?![-\\w–\xad])', '\\1 tabula', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uem|[Nn]ão) réplica(?![-\\w–\xad])', '\\1 replica', 'Sem o acento? Você quis dizer:', 'option(LOCALE,"paronimo")'],
# ----*--- Fim Outros casos -*-
 ['(?u)(?<![-\\w–.,\xad])(?P<Pay_1>[a-zA-Záâçéêíóôúã]+) pais(?![-\\w–\xad])', '\\g<Pay_1> país', 'Faltou o acento? Você quis dizer:', 'm.group("Pay_1").lower() in corPais and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])era(?![-\\w–\xad])', '\\1erá', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])eras(?![-\\w–\xad])', '\\1erás', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])arias(?![-\\w–\xad])', '\\1árias', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontrario(?![-\\w–\xad])', '\\1ontrário', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontrarias(?![-\\w–\xad])', '\\1ontrárias', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])arvore(?![-\\w–\xad])', 'árvore', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])arvores(?![-\\w–\xad])', 'árvores', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])teoria e pratica(?![-\\w–\xad])', 'teoria e prática', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])pratica e teoria(?![-\\w–\xad])', 'prática e teoria', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptk_1>[a-záâãçéêíóôõú]+[c][i][a]) pratica(?![-\\w–\xad])', '\\g<Ptk_1> prática', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])Cemente(?![-\\w–\xad])', 'Semente', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])cemente(?![-\\w–\xad])', 'semente', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])Cementes(?![-\\w–\xad])', 'Sementes', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])cementes(?![-\\w–\xad])', 'sementes', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Smt_1>[a-zA-Záâçéêíóôú]+) semente(?![-\\w–\xad])', '= aacCmf[m.group(1)] + " semente"', 'Termos precisam concordar em gênero. Você quis dizer:', 'm.group(1) in conCmf and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Smt_2>[a-zA-Záâçéêíóôú]+) semente(?![-\\w–\xad])', '= aacPfas[m.group(1)] + " sementes"', 'Termos precisam concordar em número. Você quis dizer:', 'm.group(1) in conPf and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Smt_3>[a-zA-Záâçéêíóôú]+) sementes(?![-\\w–\xad])', '= aacPfsa[m.group(1)] + " semente"', 'Termos precisam concordar em número. Você quis dizer:', 'm.group(1) in conCfm and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])emento(?![-\\w–\xad])', '\\1imento', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ementos(?![-\\w–\xad])', '\\1imentos', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ementar(?![-\\w–\xad])', '\\1imentar', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])u poço(?![-\\w–\xad])', '\\1u posso', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oço (?P<Oss_a>[a-zA-Zç]+)([ea][r])(?![-\\w–\xad])', '\\1osso \\g<Oss_a>\\3', 'Você quis dizer:', 'not m.group(2) in excPosso and option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])([Kk]|Qu|qu)il(o|os) de ([Cc])olchão(?![-\\w–\xad])', '\\1il\\2 de \\3oxão', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])kg de ([Cc])olchão(?![-\\w–\xad])', 'kg de \\3oxão', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])taxad([ao]) de(?![-\\w–\xad])', 'tachad\\1 de', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
 ['(?u)(?<![-\\w–.,\xad])taxad([ao])s de(?![-\\w–\xad])', 'tachad\\1s de', 'Você quis dizer:', 'option(LOCALE,"paronimo")'],
# ----*--- Fim Outros casos -*-
# -*- FIM Paronimos -*-
# -*- Termos Compostos -*-
 ['(?u)(?<![-\\w–.,\xad])([Aa])lto (análise|confiança|controle|estima|estimas|estrada|estradas|financiamento)(?![-\\w–\xad])', '\\1uto\\2', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lto (retrato|retratos)(?![-\\w–\xad])', '\\1utor\\2', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lto (suficiência|suficiências|suficiente|suficientes|sugestão)(?![-\\w–\xad])', '\\1utos\\2', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uto (astral|relevo)(?![-\\w–\xad])', '\\1lto-\\2', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])oto p[oô]r(?![-\\w–\xad])', '\\1oto-pôr', 'Termo composto. Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])oto post(a|as|o|os)(?![-\\w–\xad])', '\\1oto-post\\2', 'Termo composto. Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])oto (almirante|cacheiro|capitão|comitre|embaixador|embaixadora|general|mestre|patrão|piloto|soberania)(?![-\\w–\xad])', '\\1oto-\\2', 'Termo composto. Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])oto (almirantes|cacheiros|capitães|comitres|embaixadoras|embaixadores|generais|mestres|patrões|pilotos|soberanias)(?![-\\w–\xad])', '\\1oto-\\2', 'Termo composto. Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])ico leão (dourado|preto|vermelho)(?![-\\w–\xad])', '\\1ico-leão-\\2', 'Termo composto. Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])icro leão (dourado|preto|vermelho)(?![-\\w–\xad])', '\\1ico-leão-\\2', 'Termo composto. Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])ico-leão (dourado|preto|vermelho)(?![-\\w–\xad])', '\\1ico-leão-\\2', 'Termo composto. Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])icro-leão (dourado|preto|vermelho)(?![-\\w–\xad])', '\\1ico-leão-\\2', 'Termo composto. Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])ico leão-(dourado|preto|vermelho)(?![-\\w–\xad])', '\\1ico-leão-\\2', 'Termo composto. Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])icro leão-(dourado|preto|vermelho)(?![-\\w–\xad])', '\\1ico-leão-\\2', 'Termo composto. Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])icroleão (dourado|preto|vermelho)(?![-\\w–\xad])', '\\1ico-leão-\\2', 'Termo composto. Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])ico leão(?![-\\w–\xad])', '\\1ico-leão', 'Termo composto. Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_1>[Aa][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_2>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_1") + "s-" + m.group("Cpps_2") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_3>[Bb][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_4>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_3") + "s-" + m.group("Cpps_4") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_5>[Cc][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_6>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_5") + "s-" + m.group("Cpps_6") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_7>[Dd][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_8>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_7") + "s-" + m.group("Cpps_8") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_9>[Ee][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_10>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_9") + "s-" + m.group("Cpps_10") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_11>[Ff][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_12>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_11") + "s-" + m.group("Cpps_12") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_13>[Gg][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_14>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_13") + "s-" + m.group("Cpps_14") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_15>[Hh][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_16>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_15") + "s-" + m.group("Cpps_16") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_17>[Ii][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_18>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_17") + "s-" + m.group("Cpps_18") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_19>[Jj][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_20>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_19") + "s-" + m.group("Cpps_20") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_21>[Kk][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_22>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_21") + "s-" + m.group("Cpps_22") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_23>[Ll][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_24>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_23") + "s-" + m.group("Cpps_24") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_25>[Mm][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_26>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_25") + "s-" + m.group("Cpps_26") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_27>[Nn][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_28>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_27") + "s-" + m.group("Cpps_28") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_29>[Oo][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_30>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_29") + "s-" + m.group("Cpps_30") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_31>[Pp][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_32>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_31") + "s-" + m.group("Cpps_32") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_33>[Qq][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_34>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_33") + "s-" + m.group("Cpps_34") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_35>[Rr][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_36>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_35") + "s-" + m.group("Cpps_36") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_37>[Ss][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_38>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_37") + "s-" + m.group("Cpps_38") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_39>[Tt][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_40>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_39") + "s-" + m.group("Cpps_40") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_41>[Uu][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_42>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_41") + "s-" + m.group("Cpps_42") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_43>[Vv][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_44>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_43") + "s-" + m.group("Cpps_44") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_45>[Ww][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_46>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_45") + "s-" + m.group("Cpps_46") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_47>[Xx][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_48>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_47") + "s-" + m.group("Cpps_48") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_49>[Yy][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_50>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_49") + "s-" + m.group("Cpps_50") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_51>[Zz][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_52>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_51") + "s-" + m.group("Cpps_52") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_53>[Áá][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_54>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_53") + "s-" + m.group("Cpps_54") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_55>[Éé][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_56>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_55") + "s-" + m.group("Cpps_56") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_57>[Íí][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_58>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_57") + "s-" + m.group("Cpps_58") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_59>[Óó][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_60>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_59") + "s-" + m.group("Cpps_60") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpps_61>[Úú][a-zA-Záâãçéêíóôúõ]+)s (?P<Cpps_62>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "s-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpps_61") + "s-" + m.group("Cpps_62") in tCompostops and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_1>[Aa][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_2>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_1") + "-" + m.group("Cpsto_2") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_3>[Bb][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_4>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_3") + "-" + m.group("Cpsto_4") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_5>[Cc][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_6>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_5") + "-" + m.group("Cpsto_6") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_7>[Dd][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_8>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_7") + "-" + m.group("Cpsto_8") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_9>[Ee][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_10>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_9") + "-" + m.group("Cpsto_10") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_11>[Ff][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_12>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_11") + "-" + m.group("Cpsto_12") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_13>[Gg][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_14>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_13") + "-" + m.group("Cpsto_14") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_15>[Hh][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_16>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_15") + "-" + m.group("Cpsto_16") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_17>[Ii][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_18>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_17") + "-" + m.group("Cpsto_18") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_19>[Jj][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_20>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_19") + "-" + m.group("Cpsto_20") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_21>[Kk][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_22>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_21") + "-" + m.group("Cpsto_22") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_23>[Ll][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_24>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_23") + "-" + m.group("Cpsto_24") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_25>[Mm][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_26>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_25") + "-" + m.group("Cpsto_26") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_27>[Nn][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_28>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_27") + "-" + m.group("Cpsto_28") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_29>[Oo][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_30>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_29") + "-" + m.group("Cpsto_30") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_31>[Pp][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_32>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_31") + "-" + m.group("Cpsto_32") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_33>[Qq][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_34>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_33") + "-" + m.group("Cpsto_34") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_35>[Rr][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_36>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_35") + "-" + m.group("Cpsto_36") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_37>[Ss][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_38>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_37") + "-" + m.group("Cpsto_38") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_39>[Tt][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_40>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_39") + "-" + m.group("Cpsto_40") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_41>[Uu][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_42>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_41") + "-" + m.group("Cpsto_42") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_43>[Vv][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_44>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_43") + "-" + m.group("Cpsto_44") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_45>[Ww][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_46>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_45") + "-" + m.group("Cpsto_46") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_47>[Xx][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_48>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_47") + "-" + m.group("Cpsto_48") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_49>[Yy][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_50>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_49") + "-" + m.group("Cpsto_50") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_51>[Zz][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_52>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_51") + "-" + m.group("Cpsto_52") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_53>[Áá][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_54>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_53") + "-" + m.group("Cpsto_54") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_55>[Éé][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_56>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_55") + "-" + m.group("Cpsto_56") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_57>[Íí][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_58>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_57") + "-" + m.group("Cpsto_58") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_59>[Óó][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_60>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_59") + "-" + m.group("Cpsto_60") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cpsto_61>[Úú][a-zA-Záâãçéêíóôúõ]+) (?P<Cpsto_62>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Cpsto_61") + "-" + m.group("Cpsto_62") in tcmpsto and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_1>[Aa][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_2>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_1") + "-" + m.group("Dpsto_2") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_3>[Bb][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_4>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_3") + "-" + m.group("Dpsto_4") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_5>[Cc][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_6>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_5") + "-" + m.group("Dpsto_6") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_7>[Dd][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_8>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_7") + "-" + m.group("Dpsto_8") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_9>[Ee][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_10>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_9") + "-" + m.group("Dpsto_10") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_11>[Ff][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_12>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_11") + "-" + m.group("Dpsto_12") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_13>[Gg][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_14>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_13") + "-" + m.group("Dpsto_14") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_15>[Hh][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_16>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_15") + "-" + m.group("Dpsto_16") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_17>[Ii][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_18>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_17") + "-" + m.group("Dpsto_18") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_19>[Jj][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_20>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_19") + "-" + m.group("Dpsto_20") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_21>[Kk][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_22>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_21") + "-" + m.group("Dpsto_22") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_23>[Ll][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_24>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_23") + "-" + m.group("Dpsto_24") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_25>[Mm][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_26>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_25") + "-" + m.group("Dpsto_26") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_27>[Nn][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_28>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_27") + "-" + m.group("Dpsto_28") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_29>[Oo][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_30>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_29") + "-" + m.group("Dpsto_30") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_31>[Pp][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_32>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_31") + "-" + m.group("Dpsto_32") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_33>[Qq][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_34>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_33") + "-" + m.group("Dpsto_34") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_35>[Rr][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_36>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_35") + "-" + m.group("Dpsto_36") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_37>[Ss][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_38>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_37") + "-" + m.group("Dpsto_38") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_39>[Tt][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_40>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_39") + "-" + m.group("Dpsto_40") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_41>[Uu][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_42>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_41") + "-" + m.group("Dpsto_42") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_43>[Vv][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_44>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_43") + "-" + m.group("Dpsto_44") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_45>[Ww][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_46>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_45") + "-" + m.group("Dpsto_46") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_47>[Xx][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_48>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_47") + "-" + m.group("Dpsto_48") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_49>[Yy][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_50>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_49") + "-" + m.group("Dpsto_50") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_51>[Zz][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_52>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_51") + "-" + m.group("Dpsto_52") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_53>[Áá][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_54>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_53") + "-" + m.group("Dpsto_54") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_55>[Éé][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_56>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_55") + "-" + m.group("Dpsto_56") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_57>[Íí][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_58>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_57") + "-" + m.group("Dpsto_58") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_59>[Óó][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_60>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_59") + "-" + m.group("Dpsto_60") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Dpsto_61>[Úú][a-zA-Záâãçéêíóôúõ]+) de (?P<Dpsto_62>[a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '= m.group(1) + "-de-" + m.group(2)', 'Termo composto? Você quis dizer:', 'm.group("Dpsto_61") + "-" + m.group("Dpsto_62") in tcptoMde and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])(i|í)deo (?P<Vdo_1>[a-zA-Záâçéêíóôúã]+)(?![-\\w–\xad])', '= m.group(1) + "ideo" + m.group(3).lower()', 'Termo composto? Você quis dizer:', 'm.group("Vdo_1").lower() in tcptoVideo and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])(i|í)deo (?P<Vdo_2>[a-zA-Záâçéêíóôúã]+)s(?![-\\w–\xad])', '= m.group(1) + "ideo" + m.group(3).lower() + "s"', 'Termo composto? Você quis dizer:', 'm.group("Vdo_2").lower() in tcptoVideo and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])(i|í)deos (?P<Vdo_3>[a-zA-Záâçéêíóôúã]+)(?![-\\w–\xad])', '= m.group(1) + "ideo" + m.group(3).lower()', 'Termo composto? Você quis dizer:', 'm.group("Vdo_3").lower() in tcptoVideo and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])(i|í)deos (?P<Vdo_4>[a-zA-Záâçéêíóôúã]+)s(?![-\\w–\xad])', '= m.group(1) + "ideo" + m.group(3).lower() + "s"', 'Termo composto? Você quis dizer:', 'm.group("Vdo_4").lower() in tcptoVideo and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])(i|í)de(o|os) ([Rr])eportage(m|ns)(?![-\\w–\xad])', '\\1ideorreportage\\5', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])(i|í)de(o|os) ([Gg])gravado(r|res|ra|ras)(?![-\\w–\xad])', '\\1ideogravado\\5', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])(i|í)de(o|os) ([Jj])orna(l|is|lismo|lista|listas)(?![-\\w–\xad])', '\\1ideojorna\\5', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])(i|í)de(o|os) ([Pp])ôquer(?![-\\w–\xad])', '\\1ideopôquer', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele (?P<Tle_1>[a-zA-Záâçéêíóôúã]+)(?![-\\w–\xad])', '= m.group(1) + "ele" + m.group(2).lower()', 'Termo composto? Você quis dizer:', 'm.group("Tle_1").lower() in tcptoTele and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele (?P<Tle_2>[a-zA-Záâçéêíóôúã]+)s(?![-\\w–\xad])', '= m.group(1) + "ele" + m.group(2).lower() + "s"', 'Termo composto? Você quis dizer:', 'm.group("Tle_2").lower() in tcptoTele and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])eles (?P<Tle_3>[a-zA-Záâçéêíóôúã]+)(?![-\\w–\xad])', '= m.group(1) + "ele" + m.group(2).lower()', 'Termo composto? Você quis dizer:', 'm.group("Tle_3").lower() in tcptoTele and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])eles (?P<Tle_3>[a-zA-Záâçéêíóôúã]+)s(?![-\\w–\xad])', '= m.group(1) + "ele" + m.group(2).lower() + "s"', 'Termo composto? Você quis dizer:', 'm.group("Tle_3").lower() in tcptoTele and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele (advinha|comunica|condu|detec|dire|grafa|medi)ção(?![-\\w–\xad])', '\\1ele\\2ção', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele (Advinha|Comunica|Condu|Detec|Dire|Grafa|Medi)ção(?![-\\w–\xad])', '= m.group(1) + "ele" + m.group(2).lower() + "ção"', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele (advinha|comunica|condu|detec|dire|grafa|medi)ções(?![-\\w–\xad])', '\\1ele\\2ções', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele (Advinha|Comunica|Condu|Detec|Dire|Grafa|Medi)ções(?![-\\w–\xad])', '= m.group(1) + "ele" + m.group(2).lower() + "ções"', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele (difus|impress|transmiss|vis)ão(?![-\\w–\xad])', '\\1ele\\2ão', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele (Difus|Impress|Transmiss|vis)ão(?![-\\w–\xad])', '= m.group(1) + "ele" + m.group(2).lower() + "ão"', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele (difus|impress|transmiss)ões(?![-\\w–\xad])', '\\1ele\\2ões', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele (Difus|Impress|Transmiss)ões(?![-\\w–\xad])', '= m.group(1) + "ele" + m.group(2).lower() + "ões"', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele ([Rr])(adiografa|egula|eprodu)ção(?![-\\w–\xad])', '\\1elerr\\3ção', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele ([Rr])(adiografa|egula|eprodu)ções(?![-\\w–\xad])', '\\1elerr\\3ções', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele ([Ss])(inaliza)ção(?![-\\w–\xad])', '\\1eless\\3ção', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele ([Ss])(inaliza)ções(?![-\\w–\xad])', '\\1eless\\3ções', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele (jorna|móve|presencia|posta|grafoposta|teatra|visua|visiona|comunicáve|detectáve)l(?![-\\w–\xad])', '\\1ele\\2l', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele (Jorna|Móve|Presencia|Posta|Grafoposta|Teatra|Visua|Visiona|Comunicáve|Detectáve)l(?![-\\w–\xad])', '= m.group(1) + "ele" + m.group(2).lower() + "l"', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele (jorna|móve|presencia|posta|grafoposta|teatra|visua|visiona|comunicáve|detectáve)is(?![-\\w–\xad])', '\\1ele\\2is', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ele (Jorna|Móve|Presencia|Posta|Grafoposta|Teatra|Visua|Visiona|Comunicáve|Detectáve)is(?![-\\w–\xad])', '= m.group(1) + "ele" + m.group(2).lower() + "is"', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])udio ([Vv])(isual|isuais)(?![-\\w–\xad])', '\\1udiov\\3', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Á])udio ([Vv])(isual|isuais)(?![-\\w–\xad])', 'Audiov\\3', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([á])udio ([Vv])(isual|isuais)(?![-\\w–\xad])', 'audiov\\3', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])etro (?P<Rto_1>[a-zA-Záâçéêíóôúã]+)(?![-\\w–\xad])', '= m.group(1) + "etro" + m.group(2).lower()', 'Termo composto? Você quis dizer:', 'm.group("Rto_1").lower() in tcptoRetro and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])etro (?P<Rto_2>[a-zA-Záâçéêíóôúã]+)s(?![-\\w–\xad])', '= m.group(1) + "etro" + m.group(2).lower() + "s"', 'Termo composto? Você quis dizer:', 'm.group("Rto_2").lower() in tcptoRetro and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])etro (alimenta|cogni|infec|inje|posi|proje|tra|vacina|vendi)ção(?![-\\w–\xad])', '\\1etro\\2ção', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])etro (Alimenta|Cogni|Infec|Inje|Posi|Proje|Tra|Vacina|Vendi)ção(?![-\\w–\xad])', '= m.group(1) + "etro" + m.group(2).lower() + "ção"', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])etro (alimenta|cogni|infec|inje|posi|proje|tra|vacina|vendi)ções(?![-\\w–\xad])', '\\1etro\\2ções', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])etro (Alimenta|Cogni|Infec|Inje|Posi|Proje|Tra|Vacina|Vendi)ções(?![-\\w–\xad])', '= m.group(1) + "etro" + m.group(2).lower() + "ções"', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])etro (cess|difus|dispers|propuls|puls|vers|flex)ão(?![-\\w–\xad])', '\\1etro\\2ão', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])etro (Cess|Difus|Dispers|Propuls|Puls|Vers|Flex)ão(?![-\\w–\xad])', '= m.group(1) + "etro" + m.group(2).lower() + "ão"', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])etro (cess|difus|dispers|propuls|puls|vers|flex)ões(?![-\\w–\xad])', '\\1etro\\2ões', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])etro (Cess|Difus|Dispers|Propuls|Puls|Vers|Flex)ões(?![-\\w–\xad])', '= m.group(1) + "etro" + m.group(2).lower() + "ões"', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])etro (alimentar|injetor|projetor|visor|maxilar)(?![-\\w–\xad])', '\\1etro\\2', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])etro (Injetor|Projetor|Visor|Maxilar)(?![-\\w–\xad])', '= m.group(1) + "etro" + m.group(2).lower()', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])etro (injetor|projetor|visor|maxilar)es(?![-\\w–\xad])', '\\1etro\\2es', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])etro (Injetor|Projetor|Visor|Maxilar)es(?![-\\w–\xad])', '= m.group(1) + "etro" + m.group(2).lower() + "es"', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])etro ([Vv])írus(?![-\\w–\xad])', '\\1etrovírus', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])etro ([Cc])(eder|edo|eda|ede|edemos|edem|edi|edeste|edeu|ederam|ederei|ederemos)(?![-\\w–\xad])', '\\1etroc\\3', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])([oó])cio (?P<Soc_1>[a-zA-Záâçéêíóôúã]+)(?![-\\w–\xad])', '= m.group(1) + "ocio" + m.group(3).lower()', 'Termo composto? Você quis dizer:', 'm.group("Soc_1").lower() in tcptoSocio and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])([oó])cio (?P<Soc_2>[a-zA-Záâçéêíóôúã]+)s(?![-\\w–\xad])', '= m.group(1) + "ocio" + m.group(3).lower() + "s"', 'Termo composto? Você quis dizer:', 'm.group("Soc_2").lower() in tcptoSocio and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])([oó])cios (?P<Soc_3>[a-zA-Záâçéêíóôúã]+)(?![-\\w–\xad])', '= m.group(1) + "ocio" + m.group(3).lower()', 'Termo composto? Você quis dizer:', 'm.group("Soc_3").lower() in tcptoSocio and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])([oó])cios (?P<Soc_3>[a-zA-Záâçéêíóôúã]+)s(?![-\\w–\xad])', '= m.group(1) + "ocio" + m.group(3).lower() + "s"', 'Termo composto? Você quis dizer:', 'm.group("Soc_3").lower() in tcptoSocio and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])([oó])cio (ambient|assistenci|cultur|dialet|digit|empresari|espaci|funcion|institucion|internacion|let|nacion|profission)(al|ais)(?![-\\w–\xad])', '\\1ocio\\3\\4', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])([oó])cio (culturalização|culturalizações|culturalizar|familiar|familiares)(?![-\\w–\xad])', '\\1ocio\\3', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])([oó])cios (ambient|assistenci|cultur|dialet|digit|empresari|espaci|funcion|institucion|internacion|let|nacion|profission)(al|ais)(?![-\\w–\xad])', '\\1ocio\\3\\4', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])([oó])cios (culturalização|culturalizações|culturalizar|familiar|familiares)(?![-\\w–\xad])', '\\1ocio\\3', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])([oó])cio (Ambient|Assistenci|Cultur|Dialet|Digit|Empresari|Espaci|Funcion|Institucion|Internacion|Let|Nacion|Profission)(al|ais)(?![-\\w–\xad])', '= m.group(1) + "ocio" + m.group(3).lower() + m.group(4)', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])letro (?P<Eltr_1>[a-zA-Záâçéêíóôúã]+)(?![-\\w–\xad])', '= m.group(1) + "letro" + m.group(2).lower()', 'Termo composto? Você quis dizer:', 'm.group("Eltr_1").lower() in tcptoEletro and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])letro imã(?![-\\w–\xad])', '\\1letroímã', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])letro imãs(?![-\\w–\xad])', '\\1letroímãs', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])letro hidráulic(o|a|os|as)(?![-\\w–\xad])', '\\1letro-hidráulic\\2', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])letro óptic(o|a|os|as)(?![-\\w–\xad])', '\\1letro-óptic\\2', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])letro ótic(o|a|os|as)(?![-\\w–\xad])', '\\1letro-ótic\\2', 'Termo composto? Você quis dizer:', 'option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ermo (?P<Trm_1>[ohOH][a-záâãçéêíóôõú]+)(?![-\\w–\xad])', '= m.group(1) + "ermo-" + m.group(2).lower()', 'Termo composto? Você quis dizer:', 'm.group("Trm_1") in tcptoTermo and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ermo (?P<Trm_2>[rR][a-záâãçéêíóôõú]+)(?![-\\w–\xad])', '= m.group(1) + "ermor" + m.group(2).lower()', 'Termo composto? Você quis dizer:', 'm.group("Trm_2") in tcptoTermo and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ermo (?P<Trm_3>[sS][a-záâãçéêíóôõú]+)(?![-\\w–\xad])', '= m.group(1) + "ermos" + m.group(2).lower()', 'Termo composto? Você quis dizer:', 'm.group("Trm_3") in tcptoTermo and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ermo (?P<Trm_4>[^oOhHrRsS][a-záâãçéêíóôõú]+)(?![-\\w–\xad])', '= m.group(1) + "ermo" + m.group(2).lower()', 'Termo composto? Você quis dizer:', 'm.group("Trm_4") in tcptoTermo and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll])onga metragem(?![-\\w–\xad])', '\\1onga-metragem', 'Termo composto? Você quis dizer:', 'not "de longa" in TEXT and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll])onga metragens(?![-\\w–\xad])', '\\1ongas-metragens', 'Termo composto? Você quis dizer:', 'not "de longa" in TEXT and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll])ongas metragens(?![-\\w–\xad])', '\\1ongas-metragens', 'Termo composto? Você quis dizer:', 'not "de longa" in TEXT and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Ll])ongas metragem(?![-\\w–\xad])', '\\1ongas-metragens', 'Termo composto? Você quis dizer:', 'not "de longa" in TEXT and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])urta metragem(?![-\\w–\xad])', '\\1onga-metragem', 'Termo composto? Você quis dizer:', 'not "de curta" in TEXT and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])urta metragens(?![-\\w–\xad])', '\\1ongas-metragens', 'Termo composto? Você quis dizer:', 'not "de curta" in TEXT and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])urtas metragens(?![-\\w–\xad])', '\\1ongas-metragens', 'Termo composto? Você quis dizer:', 'not "de curta" in TEXT and option(LOCALE,"composto")'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])urtas metragem(?![-\\w–\xad])', '\\1ongas-metragens', 'Termo composto? Você quis dizer:', 'not "de curta" in TEXT and option(LOCALE,"composto")'],
# -*- FIM Termos Compostos -*-
# -*- Uso de Mal e Mau -*-
 ['(?u)(?<![-\\w–.,\xad])fala([a-zA-Záâãõçéêíóôú]+) mau(?![-\\w–\xad])', 'fala\\1 mal', 'Você quis dizer:', 'option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])ma[ul] (?P<Mlu_1>[a-záâçéêíóôú]+)([ao])(?![-\\w–\xad])', 'mal\\g<Mlu_1>\\2', 'Você quis dizer:', 'm.group("Mlu_1") in mauMal and option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])ma[ul] (?P<Mlu_2>[a-záâçéêíóôú]+)([ao][s])(?![-\\w–\xad])', 'mal\\g<Mlu_2>\\2', 'Você quis dizer:', 'm.group("Mlu_2") in mauMal and option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])má (?P<Mlu_3>[a-záâçéêíóôú]+)([a])(?![-\\w–\xad])', 'mal\\g<Mlu_3>\\2', 'Você quis dizer:', 'm.group("Mlu_3") in mauMal and option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])más (?P<Mlu_4>[a-záâçéêíóôú]+)([a][s])(?![-\\w–\xad])', 'mal\\g<Mlu_4>\\2', 'Você quis dizer:', 'm.group("Mlu_4") in mauMal and option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])maus (?P<Mlu_5>[a-záâçéêíóôú]+)([ao][s])(?![-\\w–\xad])', 'mal\\g<Mlu_5>\\2', 'Você quis dizer:', 'm.group("Mlu_5") in mauMal and option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])[a][lu][ ](?P<Mlh_1>[a-zA-Z]\\w*)(?![-\\w–\xad])', '\\1al-\\g<Mlh_1>', 'Você quis dizer:', 'm.group("Mlh_1") in malHifen and option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])[a][l][ ](?P<Mlm_1>[a-zA-Z]\\w*)(?![-\\w–\xad])', '\\1au \\g<Mlm_1>', 'Você quis dizer:', 'm.group("Mlm_1") in malMau and option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])al (?P<Mau_1>[a-záâçéêíóôú]+[stdmh][o][r])(?![-\\w–\xad])', '\\1au \\g<Mau_1>', 'Você quis dizer:', 'option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])al (?P<Mau_2>[a-záâçéêíóôú]+[tdmh][o][r][e][s])(?![-\\w–\xad])', '\\1aus \\g<Mau_2>', 'Você quis dizer:', 'option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])a[lu] caráter(?![-\\w–\xad])', '\\1au-caráter', 'Você quis dizer:', 'option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])a[lu] caratismo(?![-\\w–\xad])', '\\1au-caratismo', 'Você quis dizer:', 'option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])a[lu] grado(?![-\\w–\xad])', '\\1au-grado', 'Você quis dizer:', 'option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])a([lu]) olhado(?![-\\w–\xad])', '\\1a\\2-olhado', 'Você quis dizer:', 'option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])a[lu] trato(?![-\\w–\xad])', '\\1aus-tratos', 'Você quis dizer:', 'option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])aus tratos(?![-\\w–\xad])', '\\1aus-tratos', 'Você quis dizer:', 'option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])al gênio(?![-\\w–\xad])', '\\1au gênio', 'Você quis dizer:', 'option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])al negócio(?![-\\w–\xad])', '\\1au negócio', 'Você quis dizer:', 'option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])al hálito(?![-\\w–\xad])', '\\1au hálito', 'Você quis dizer:', 'option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])au (?P<Mlu_20>[a-záâçéêíóôú]+)(ada|adas|ado|ados)(?![-\\w–\xad])', '\\1al \\2\\3', 'Você quis dizer:', 'not m.group(2).lower() + m.group(3).lower() in malHifen and not m.group(2).lower() + m.group(3).lower() in malMau and option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])a[lu] criações(?![-\\w–\xad])', '\\1alcriações', 'Você quis dizer:', 'option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])a[lu] criação(?![-\\w–\xad])', '\\1alcriação', 'Você quis dizer:', 'option(LOCALE,"malmau")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])o mal sentido(?![-\\w–\xad])', '\\1o mau sentido', 'Você quis dizer:', 'option(LOCALE,"malmau")'],
# -*- FIM Uso de Mal e Mau -*-
# -*- Uso de Ha e a -*-
 ['(?u)(?<![-\\w–.,\xad])([Hh])a(?![-\\w–\xad])', '\\1á', 'Faltou o acento? Você quis dizer:', 'not excha.search(TEXT) and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])ão a(?![-\\w–\xad])', '\\1ão há', 'Você quis dizer:', 'vnaoHa.search(TEXT) and not vdisNaoa.search(TEXT) and not vMaisNaoa.search(TEXT) and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])aqui há um (minuto|segundo|dia|mês|ano|século|milênio)(?![-\\w–\xad])', '\\1aqui a um \\2', 'Você quis dizer:', 'option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])aqui há uma (semana|hora)(?![-\\w–\xad])', '\\1aqui a uma \\2', 'Você quis dizer:', 'option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])aqui há ([a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios)(?![-\\w–\xad])', '\\1aqui a \\2 \\3', 'Você quis dizer:', 'not m.group(2) in "-001-um-uma-" and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])aqui há (um|algum|muito) tempo(?![-\\w–\xad])', '\\1aqui a \\2 tempo', 'Você quis dizer:', 'option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])aqui há pouco(?![-\\w–\xad])', '\\1aqui a pouco', 'Você quis dizer:', 'option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])e (hoje|amanhã|ontem) há ([a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios)(?![-\\w–\xad])', '\\1e \\2 a \\3 \\4', 'Você quis dizer:', 'not m.group(3) in "-001-um-uma-" and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])A um (minuto|segundo|dia|mês|ano|século|milênio)(?![-\\w–\xad])', 'Há um \\1', 'Você quis dizer:', 'not m.group(1) + " de " in TEXT and not m.group(1) + " da " in TEXT and not m.group(1) + " das " in TEXT and not m.group(1) + " do " in TEXT and not m.group(1) + " dos " in TEXT and not m.group(1) + " para " in TEXT and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])A uma (semana|hora)(?![-\\w–\xad])', 'Há uma \\1', 'Você quis dizer:', 'not m.group(1) + " de " in TEXT and not m.group(1) + " da " in TEXT and not m.group(1) + " das " in TEXT and not m.group(1) + " do " in TEXT and not m.group(1) + " dos " in TEXT and not m.group(1) + " para " in TEXT and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])A ([a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios)(?![-\\w–\xad])', 'Há \\1 \\2', 'Você quis dizer:', 'not m.group(2) + " de " in TEXT and not m.group(2) + " da " in TEXT and not m.group(2) + " das " in TEXT and not m.group(2) + " do " in TEXT and not m.group(2) + " dos " in TEXT and not m.group(2) + " para " in TEXT and not m.group(1) in "-001-um-uma-" and not m.group(2) + " d" in TEXT and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])foi a um (minuto|segundo|dia|mês|ano|século|milênio)(?![-\\w–\xad])', 'foi há um \\1', 'Você quis dizer:', 'option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])foi a uma (semana|hora)(?![-\\w–\xad])', 'foi há uma \\1', 'Você quis dizer:', 'option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+[eo]u) a um (minuto|segundo|dia|mês|ano|século|milênio)(?![-\\w–\xad])', '\\1 há um \\2', 'Você quis dizer:', 'not m.group(1) in exctempo and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+[eo]u) a uma (semana|hora)(?![-\\w–\xad])', '\\1 há uma \\2', 'Você quis dizer:', 'not m.group(1) in exctempo and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+[dt][ao]) a um (minuto|dia|mês|ano|século|milênio)(?![-\\w–\xad])', '\\1 há um \\2', 'Você quis dizer:', 'not m.group(1) in exctempo and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+[dt][ao]) a uma (semana|hora)(?![-\\w–\xad])', '\\1 há uma \\2', 'Você quis dizer:', 'not " a uma " + m.group(1) + " de " in TEXT and not m.group(2) in exctempo and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+[dt][ao])s a um (minuto|dia|mês|ano|século|milênio)(?![-\\w–\xad])', '\\1s há um \\2', 'Você quis dizer:', 'not m.group(1) in exctempo and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+[dt][ao])s a uma (semana|hora)(?![-\\w–\xad])', '\\1s há uma \\2', 'Você quis dizer:', 'not m.group(1) in exctempo and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])foi a ([a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios)(?![-\\w–\xad])', 'foi há \\1 \\2', 'Você quis dizer:', 'not m.group(1) in "-001-um-uma-" and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Tmp_1>[a-z]+[eo]u) a (?P<Tmp_2>[a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios)(?![-\\w–\xad])', '\\1 há \\2 \\3', 'Você quis dizer:', 'not m.group("Tmp_2") in "-001-um-uma-" and not m.group("Tmp_1") in exctempo and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Tmp_5>[a-z]+[dt][ao]) a (?P<Tmp_6>[a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios)(?![-\\w–\xad])', '\\1 há \\2 \\3', 'Você quis dizer:', 'not m.group("Tmp_6") in "-001-um-uma-" and not m.group("Tmp_5") in exctempo and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Tmp_9>[a-z]+[dt][ao])s a (?P<Tmp_10>[a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios)(?![-\\w–\xad])', '\\1s há \\2 \\3', 'Você quis dizer:', 'not m.group("Tmp_10") in "-001-um-uma-" and not m.group("Tmp_9") in exctempo and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])a vári([ao])s (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios)(?![-\\w–\xad])', 'há vári\\1s \\2', 'Você quis dizer:', 'option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])A vári([ao])s(?![-\\w–\xad])', 'Há vári\\1s', 'Você quis dizer:', 'option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])A mais de um (minuto|segundo|dia|mês|ano|século|milênio)(?![-\\w–\xad])', 'Há mais de um \\1', 'Você quis dizer:', 'option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])A mais de uma (semana|hora)(?![-\\w–\xad])', 'Há mais de uma \\1', 'Você quis dizer:', 'option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([a-zA-Záâçéêíóôúã]+) a mais de ([a-z0-9]+) (semanas|horas|minutos|segundos|dias|meses|anos|séculos|milênios)(?![-\\w–\xad])', '\\1 há mais de \\2 \\3', 'Você quis dizer:', 'not m.group(1) in "-001-um-uma-" and not m.group(1) in exctempo and not "hegue a mais de" in TEXT and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([a-zA-Záâçéêíóôúã]+) a mais de um (minuto|segundo|dia|mês|ano|século|milênio)(?![-\\w–\xad])', '\\1 há mais de um \\2', 'Você quis dizer:', 'not m.group(1) in exctempo and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([a-zA-Záâçéêíóôúã]+) a mais de uma (semana|hora)(?![-\\w–\xad])', '\\1 há mais de uma \\2', 'Você quis dizer:', 'not m.group(1) in exctempo and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])A pouco(?![-\\w–\xad])', 'Há pouco', 'Você quis dizer:', 'not exceapouco.search(TEXT) and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd]isse|[Dd]izia|[Ss]ó|[Ff]alei|[Mm]orreram|[Cc]hegaram|[Cc]heguei|[Ee]steve|[Ee]stive|[Tt]ive) a pouco(?![-\\w–\xad])', '\\1 há pouco', 'Você quis dizer:', 'option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([A-Za-z]+ou) a pouco(?![-\\w–\xad])', '\\1 há pouco', 'Você quis dizer:', 'option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([A-Za-z]+[aeio]ram) a pouco(?![-\\w–\xad])', '\\1 há pouco', 'Você quis dizer:', 'option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])A poucos (segundos|minutos|dias|meses|anos|séculos|milênios|instantes|momentos)(?![-\\w–\xad])', 'Há poucos \\1', 'Você quis dizer:', 'not m.group(1) + " de " in TEXT and not m.group(1) + " da " in TEXT and not m.group(1) + " das " in TEXT and not m.group(1) + " do " in TEXT and not m.group(1) + " dos " in TEXT and option(LOCALE,"aha")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])inda a pouco(?![-\\w–\xad])', '\\1inda há pouco', 'Você quis dizer:', 'option(LOCALE,"aha")'],
# -*- FIM Uso de Ha e a -*-
# -*- Uso de meia e meio -*-
 ['(?u)(?<![-\\w–.,\xad])meio-dia e meio(?![-\\w–\xad])', 'meio-dia e meia', 'Você quis dizer:', 'option(LOCALE,"meiameio")'],
 ['(?u)(?<![-\\w–.,\xad])meia tonta(?![-\\w–\xad])', 'meio tonta', 'Você quis dizer:', 'option(LOCALE,"meiameio")'],
 ['(?u)(?<![-\\w–.,\xad])meia fora(?![-\\w–\xad])', 'meio fora', 'Você quis dizer:', 'option(LOCALE,"meiameio")'],
 ['(?u)(?<![-\\w–.,\xad])meia mole(?![-\\w–\xad])', 'meio mole', 'Você quis dizer:', 'option(LOCALE,"meiameio")'],
 ['(?u)(?<![-\\w–.,\xad])meia aberta(?![-\\w–\xad])', 'meio aberta', 'Você quis dizer:', 'option(LOCALE,"meiameio")'],
 ['(?u)(?<![-\\w–.,\xad])meia (?P<Mei_1>[a-zA-Záâçéêíóôú]+[aouni][dh][a])(?![-\\w–\xad])', 'meio \\g<Mei_1>', 'Você quis dizer:', 'not m.group("Mei_1").lower() in excDa and option(LOCALE,"meiameio")'],
 ['(?u)(?<![-\\w–.,\xad])meia (?P<Mei_2>[a-zA-Záâçéêíóôú]+[rni][t][a])(?![-\\w–\xad])', 'meio \\g<Mei_2>', 'Você quis dizer:', 'not m.group("Mei_2").lower() in excDa and option(LOCALE,"meiameio")'],
# -*- FIM Uso de meia e meio -*-
# -*- Concordancia Verbal -*-
 ['(?u)(?<![-\\w–.,\xad])(?P<nalf_1>[a-zA-Zç]+)á(?![-\\w–\xad])', '\\1ar', 'Você quis dizer:', 'm.group("nalf_1").lower() in plvrVbrar and not m.group("nalf_1").lower() in excvbah and not m.group("nalf_1") in excvbah and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<nalf_2>[a-zA-Zç]+)ê(?![-\\w–\xad])', '\\1er', 'Você quis dizer:', 'm.group("nalf_2").lower() in plvrVbrxer and not m.group("nalf_2").lower() in excvbeh and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<nalf_3>[a-zA-Zç]+)cê(?![-\\w–\xad])', '\\1cer', 'Você quis dizer:', 'm.group("nalf_3").lower() in plvrVbrcer and not m.group("nalf_3").lower() in excvbceh and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<nalf_4>[a-zA-Zç]+)gê(?![-\\w–\xad])', '\\1ger', 'Você quis dizer:', 'm.group("nalf_4").lower() in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<nalf_5>[a-zA-Zç]+)uê(?![-\\w–\xad])', '\\1uer', 'Você quis dizer:', 'm.group("nalf_5").lower() in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Se (?P<Vbss_1>[a-zç]+)-se(?![-\\w–\xad])', '= m.group("Vbss_1").capitalize() + "-se\\nSe " + m.group("Vbss_1") +"\\nSe se " + m.group("Vbss_1")', 'Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])se (?P<Vbss_2>[a-zç]+)-se(?![-\\w–\xad])', '= m.group("Vbss_2") + "-se\\nse " + m.group("Vbss_2") +"\\nse se " + m.group("Vbss_2")', 'Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])(?P<Abun_1>[a-záâçéêíóôõúã]+) (?P<Abun_2>[a-z]+)([ao])(?![-\\w–\xad])', '= m.group(1) + vbESTARsing[m.group(2)] + " " + aavbSEF[m.group(3)] + m.group(4)', '= "Usa-se " + aavbSEF[m.group(3).lower()] + m.group(4) + " com os verbos ser, estar e ficar. Você quis dizer:"', 'm.group(2) in vbEstar and m.group(3) in acvbSEF and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])(?P<Abun_3>[a-záâçéêíóôõúã]+) (?P<Abun_4>[a-z]+)([ao])(?![-\\w–\xad])', '= m.group(1) + vbFICARsing[m.group(2)] + " " + aavbSEF[m.group(3)] + m.group(4)', '= "Usa-se " + aavbSEF[m.group(3).lower()] + m.group(4) + " com os verbos ser, estar e ficar. Você quis dizer:"', 'm.group(2) in vbFicar and m.group(3) in acvbSEF and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])(?P<Abun_5>[a-záâçéêíóôõúã]+) (?P<Abun_6>[a-z]+)(as|os)(?![-\\w–\xad])', '= m.group(1) + vbESTARplur[m.group(2)] + " " + aavbSEF[m.group(3)] + m.group(4)', '= "Usa-se " + aavbSEF[m.group(3).lower()] + m.group(4) + " com os verbos ser, estar e ficar. Você quis dizer:"', 'm.group(2) in vbEstar and m.group(3) in acvbSEF and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])(?P<Abun_7>[a-záâçéêíóôõúã]+) (?P<Abun_8>[a-z]+)(as|os)(?![-\\w–\xad])', '= m.group(1) + vbFICARplur[m.group(2)] + " " + aavbSEF[m.group(3)] + m.group(4)', '= "Usa-se " + aavbSEF[m.group(3).lower()] + m.group(4) + " com os verbos ser, estar e ficar. Você quis dizer:"', 'm.group(2) in vbFicar and m.group(3) in acvbSEF and option(LOCALE,"verbo")'],
# Retirados
# ['(?u)(?<![-\\w–.,\xad])([Tt])(?P<Abun_9>[a-záâçéêíóôõúã]+) (?P<Abun_10>[a-z]+)(a|as|o|os)(?![-\\w–\xad])', '= m.group(1) + m.group(2) +" " + aavbTH[m.group(3)] + "o"', '= "Usa-se " + aavbTH[m.group(3).lower()] + "o com os verbos ter e haver. Você quis dizer:"', 'm.group(2) in vbTer and m.group(3) in acvbTH and option(LOCALE,"verbo")'],
# ['(?u)(?<![-\\w–.,\xad])([Hh])(?P<Abun_11>[a-záâçéêíóôõúã]+) (?P<Abun_12>[a-z]+)(a|as|o|os)(?![-\\w–\xad])', '= m.group(1) + m.group(2) +" " + aavbTH[m.group(3)] + "o"', '= "Usa-se " + aavbTH[m.group(3).lower()] + "o com os verbos ter e haver. Você quis dizer:"', 'm.group(2) in vbHaver and m.group(3) in acvbTH and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Abun_13>[a-záâçéêíóôõúã]+) (?P<Abun_14>[a-z]+)([ao])(?![-\\w–\xad])', '= vbSERsing[m.group("Abun_13")] + " " + aavbSEF[m.group("Abun_14")] + m.group(3)', '= "Usa-se " + aavbSEF[m.group("Abun_14").lower()] + m.group(3) + " com os verbos ser, estar e ficar. Você quis dizer:"', 'm.group("Abun_13") in vbSer and m.group("Abun_14") in acvbSEF and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Abun_15>[a-záâçéêíóôõúã]+) (?P<Abun_16>[a-z]+)(as|os)(?![-\\w–\xad])', '= vbSERplur[m.group("Abun_15")] + " " + aavbSEF[m.group("Abun_16")] + m.group(3)', '= "Usa-se " + aavbSEF[m.group("Abun_16").lower()] + m.group(3) + " com os verbos ser, estar e ficar. Você quis dizer:"', 'm.group("Abun_15") in vbSer and m.group("Abun_16") in acvbSEF and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])(?P<Abun_17>[a-záâçéêíóôõúã]+) entregad([ao])(?![-\\w–\xad])', '= m.group(1) + vbESTARsing[m.group(2)] + " entregue"', '= "Usa-se entregue com os verbos ser, estar e ficar. Você quis dizer:"', 'm.group(2) in vbEstar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])(?P<Abun_18>[a-záâçéêíóôõúã]+) entregad([ao])(?![-\\w–\xad])', '= m.group(1) + vbFICARsing[m.group(2)] + " entregue"', '= "Usa-se entregue com os verbos ser, estar e ficar. Você quis dizer:"', 'm.group(2) in vbFicar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])(?P<Abun_19>[a-záâçéêíóôõúã]+) entregad(as|os)(?![-\\w–\xad])', '= m.group(1) + vbESTARplur[m.group(2)] + " entregues"', '= "Usa-se entregue com os verbos ser, estar e ficar. Você quis dizer:"', 'm.group(2) in vbEstar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])(?P<Abun_20>[a-záâçéêíóôõúã]+) entregad(as|os)(?![-\\w–\xad])', '= m.group(1) + vbFICARplur[m.group(2)] + " entregues"', '= "Usa-se entregue com os verbos ser, estar e ficar. Você quis dizer:"', 'm.group(2) in vbFicar and option(LOCALE,"verbo")'],
# Retirados
# ['(?u)(?<![-\\w–.,\xad])([Tt])(?P<Abun_21>[a-záâçéêíóôõúã]+) entregue(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " entregado"', 'Usa-se entregado com os verbos ter e haver. Você quis dizer:', 'm.group(2) in vbTer and option(LOCALE,"verbo")'],
# ['(?u)(?<![-\\w–.,\xad])([Hh])(?P<Abun_22>[a-záâçéêíóôõúã]+) entregue(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " entregado"', 'Usa-se entregado com os verbos ter e haver. Você quis dizer:', 'm.group(2) in vbHaver and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Abun_23>[a-záâçéêíóôõúã]+) entregad([ao])(?![-\\w–\xad])', '= vbSERsing[m.group("Abun_23")] + " entregue"', 'Usa-se entregue com os verbos ser, estar e ficar. Você quis dizer:', 'm.group("Abun_23") in vbSer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Abun_24>[a-záâçéêíóôõúã]+) entregad(as|os)(?![-\\w–\xad])', '= vbSERplur[m.group("Abun_24")] + " entregues"', 'Usa-se entregue com os verbos ser, estar e ficar. Você quis dizer:', 'm.group("Abun_24") in vbSer and option(LOCALE,"verbo")'],
# VERBOS REGULARES TERMINADOS EM AR - com pronomes EU, TU, ELE, NOS ...
# PRESENTE DO INDICATIVO
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbar_11>[a-z]+[bcdfghjlmnprstvxzç])(as|a|amos|ais|am)(?![-\\w–\xad])', 'Eu \\1o', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_11") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbar_12>[a-z]+[bcdfghjlmnprstvxzç])(o|a|amos|ais|am)(?![-\\w–\xad])', 'Tu \\1as', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_12") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbar_13>[a-z]+[bcdfghjlmnprstvxzç])(o|as|amos|ais|am)(?![-\\w–\xad])', 'Ele \\1a', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_13") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbar_14>[a-z]+[bcdfghjlmnprstvxzç])(o|as|amos|ais|am)(?![-\\w–\xad])', 'Ela \\1a', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_14") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbar_15>[a-z]+[bcdfghjlmnprstvxzç])(o|as|amos|ais|am)(?![-\\w–\xad])', 'Você \\1a', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_15") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbar_16>[a-z]+[bcdfghjlmnprstvxzç])(o|as|a|ais|am)(?![-\\w–\xad])', 'Nós \\1amos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_16") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbar_17>[a-z]+[bcdfghjlmnprstvxzç])(o|as|a|amos|am)(?![-\\w–\xad])', 'Vós \\1ais', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_17") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbar_18>[a-z]+[bcdfghjlmnprstvxzç])(o|as|amos|ais|a)(?![-\\w–\xad])', 'Eles \\1am', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_18") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbar_19>[a-z]+[bcdfghjlmnprstvxzç])(o|as|amos|ais|a)(?![-\\w–\xad])', 'Elas \\1am', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_19") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbar_10>[a-z]+[bcdfghjlmnprstvxzç])(o|as|amos|ais|a)(?![-\\w–\xad])', 'Vocês \\1am', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_10") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbar_1a>[a-z]+[bcdfghjlmnprstvxzç])(o|as|amos|ais|am)(?![-\\w–\xad])', 'A gente \\1a', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_1a") in plvrVbrar and option(LOCALE,"verbo")'],
# PRETERITO IMPERFEITO
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbar_21>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', 'Eu \\1ava', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_21") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbar_22>[a-z]+[bcdfghjlmnprstvxzç])(ava|ávamos|áveis|avam)(?![-\\w–\xad])', 'Tu \\1avas', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_22") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbar_23>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', 'Ele \\1ava', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_23") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbar_24>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', 'Ela \\1ava', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_24") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbar_25>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', 'Você \\1ava', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_25") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbar_26>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|áveis|avam)(?![-\\w–\xad])', 'Nós \\1ávamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_26") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbar_27>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|avam)(?![-\\w–\xad])', 'Vós \\1áveis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_27") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbar_28>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', 'Eles \\1avam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_28") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbar_29>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', 'Elas \\1avam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_29") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbar_20>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', 'Vocês \\1avam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_20") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbar_2a>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', 'A gente \\1ava', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_2a") in plvrVbrar and option(LOCALE,"verbo")'],
# PRETERITO PERFEITO todos
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbar_31>[a-z]+[bdfhjlmnprstvxz])(aste|ou|amos|astes|aram)(?![-\\w–\xad])', 'Eu \\1ei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_31") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbar_32>[a-z]+[bdfhjlmnprstvxz])(ei|ou|amos|astes|aram)(?![-\\w–\xad])', 'Tu \\1aste', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_32") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbar_33>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', 'Ele \\1o', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_33") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbar_34>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', 'Ela \\1o', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_34") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbar_35>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', 'Você \\1o', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_35") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbar_36>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|astes|aram)(?![-\\w–\xad])', 'Nós \\1amos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_36") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbar_37>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|aram)(?![-\\w–\xad])', 'Vós \\1astes', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_37") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbar_38>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', 'Eles \\1aram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_38") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbar_39>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', 'Elas \\1aram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_39") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbar_30>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', 'Vocês \\1aram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_30") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbar_3a>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', 'A gente \\1o', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_3a") in plvrVbrar and option(LOCALE,"verbo")'],
# PRETERITO PERFEITO terminados em c cedilha ar
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbar_41>[a-z]+)(çaste|çou|çamos|çastes|çaram)(?![-\\w–\xad])', 'Eu \\1cei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_41") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbar_42>[a-z]+)(cei|çou|çamos|çastes|çaram)(?![-\\w–\xad])', 'Tu \\1çaste', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_42") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbar_43>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', 'Ele \\1ço', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_43") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbar_44>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', 'Ela \\1ço', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_44") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbar_45>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', 'Você \\1ço', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_45") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbar_46>[a-z]+)(cei|çaste|çou|çastes|çaram)(?![-\\w–\xad])', 'Nós \\1\çamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_46") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbar_47>[a-z]+)(cei|çaste|çou|çamos|çaram)(?![-\\w–\xad])', 'Vós \\1\çastes', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_47") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbar_48>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', 'Eles \\1çaram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_48") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbar_49>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', 'Elas \\1çaram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_49") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbar_40>[a-z]+)(cei|çaste|çou|çamos|açstes)(?![-\\w–\xad])', 'Vocês \\1çaram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_40") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbar_4a>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', 'A gente \\1ço', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_4a") in plvrCVbrar and option(LOCALE,"verbo")'],
# PRETERITO PERFEITO terminados em car
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbar_51>[a-z]+)(caste|cou|camos|castes|caram)(?![-\\w–\xad])', 'Eu \\1quei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_51") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbar_52>[a-z]+)(quei|cou|camos|castes|caram)(?![-\\w–\xad])', 'Tu \\1caste', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_52") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbar_53>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', 'Ele \\1co', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_53") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbar_54>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', 'Ela \\1co', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_54") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbar_55>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', 'Você \\1co', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_55") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbar_56>[a-z]+)(quei|caste|cou|castes|caram)(?![-\\w–\xad])', 'Nós \\1camos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_56") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbar_57>[a-z]+)(quei|caste|cou|camos|caram)(?![-\\w–\xad])', 'Vós \\1castes', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_57") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbar_58>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', 'Eles \\1caram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_58") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbar_59>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', 'Elas \\1caram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_59") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbar_50>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', 'Vocês \\1caram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_50") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbar_5a>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', 'A gente \\1co', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_5a") in plvrCVbrar and option(LOCALE,"verbo")'],
# PRETERITO PERFEITO terminados em gar
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbar_61>[a-z]+)(gaste|gou|gamos|gastes|garam)(?![-\\w–\xad])', 'Eu \\1guei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_61") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbar_62>[a-z]+)(guei|gou|gamos|gastes|garam)(?![-\\w–\xad])', 'Tu \\1gaste', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_62") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbar_63>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', 'Ele \\1go', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_63") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbar_64>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', 'Ela \\1go', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_64") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbar_65>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', 'Você \\1go', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_65") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbar_66>[a-z]+)(guei|gaste|gou|gastes|garam)(?![-\\w–\xad])', 'Nós \\1gamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_66") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbar_67>[a-z]+)(guei|gaste|gou|gamos|garam)(?![-\\w–\xad])', 'Vós \\1gastes', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_67") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbar_68>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', 'Eles \\1garam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_68") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbar_69>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', 'Elas \\1garam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_69") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbar_60>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', 'Vocês \\1garam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_60") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbar_6a>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', 'A gente \\1go', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_6a") in plvrCVbrar and option(LOCALE,"verbo")'],
# FUTURO DO PRESENTE
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbar_71>[a-z]+[bcdfghjlmnprstvxzç])(arás|ará|aremos|areis|arão)(?![-\\w–\xad])', 'Eu \\1arei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_71") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbar_72>[a-z]+[bcdfghjlmnprstvxzç])(arei|ará|aremos|areis|arão)(?![-\\w–\xad])', 'Tu \\1arás', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_72") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbar_73>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', 'Ele \\1ará', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_73") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbar_74>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', 'Ela \\1ará', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_74") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbar_75>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', 'Você \\1ará', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_75") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbar_76>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|areis|arão)(?![-\\w–\xad])', 'Nós \\1aremos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_76") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbar_77>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|arão)(?![-\\w–\xad])', 'Vós \\1areis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_77") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbar_78>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', 'Eles \\1arão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_78") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbar_79>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis|ar)(?![-\\w–\xad])', 'Elas \\1arão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_79") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbar_70>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', 'Vocês \\1arão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_70") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbar_7a>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', 'A gente \\1ará', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_7a") in plvrVbrar and option(LOCALE,"verbo")'],
# FUTURO DO PRETERITO
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbar_81>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', 'Eu \\1aria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_81") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbar_82>[a-z]+[bcdfghjlmnprstvxzç])(aria|aríamos|aríeis|ariam)(?![-\\w–\xad])', 'Tu \\1arias', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_82") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbar_83>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', 'Ele \\1aria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_83") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbar_84>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', 'Ela \\1aria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_84") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbar_85>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', 'Você \\1aria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_85") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbar_86>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríeis|ariam)(?![-\\w–\xad])', 'Nós \\1aríamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_86") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbar_87>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|ariam)(?![-\\w–\xad])', 'Vós \\1aríeis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_87") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbar_88>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', 'Eles \\1ariam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_88") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbar_89>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', 'Elas \\1ariam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_89") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbar_80>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', 'Vocês \\1ariam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_80") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbar_8a>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', 'A gente \\1aria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_8a") in plvrVbrar and option(LOCALE,"verbo")'],
# PRETERITO IMPERFEITO DO SUBJUNTIVO
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e eu (?P<vbar_91>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1e eu \\2asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_91") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e tu (?P<vbar_92>[a-z]+[bcdfghjlmnprstvxzç])(asse|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1e tu \\2asses', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_92") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e ele (?P<vbar_93>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1e ele \\2asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_93") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e ela (?P<vbar_94>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1e ela \\2asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_94") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e você (?P<vbar_95>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1e você \\2asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_95") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e nós (?P<vbar_96>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ásseis|assem)(?![-\\w–\xad])', '\\1e nós \\2ássemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_96") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e vós (?P<vbar_97>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ássemos|assem)(?![-\\w–\xad])', '\\1e vós \\2ásseis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_97") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e eles (?P<vbar_98>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ássemos|ásseis)(?![-\\w–\xad])', '\\1e eles \\2assem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_98") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e elas (?P<vbar_99>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ássemos|ásseis)(?![-\\w–\xad])', '\\1e elas \\2assem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_99") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e vocês (?P<vbar_90>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ássemos|ásseis)(?![-\\w–\xad])', '\\1e vocês \\2assem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_90") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e a gente (?P<vbar_9a>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1e a gente \\2asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_9a") in plvrVbrar and option(LOCALE,"verbo")'],
#
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando eu (?P<vbar_a1>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1uando eu \\2asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_a1") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando tu (?P<vbar_a2>[a-z]+[bcdfghjlmnprstvxzç])(asse|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1uando tu \\2asses', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_a2") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando ele (?P<vbar_a3>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1uando ele \\2asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_a3") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando ela (?P<vbar_a4>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1uando ela \\2asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_a4") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando você (?P<vbar_a5>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1uando você \\2asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_a5") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando nós (?P<vbar_a6>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ásseis|assem)(?![-\\w–\xad])', '\\1uando nós \\2ássemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_a6") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando vós (?P<vbar_a7>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ássemos|assem)(?![-\\w–\xad])', '\\1uando vós \\2ásseis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_a7") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando eles (?P<vbar_a8>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ássemos|ásseis)(?![-\\w–\xad])', '\\1uando eles \\2assem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_a8") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando elas (?P<vbar_a9>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ássemos|ásseis)(?![-\\w–\xad])', '\\1uando elas \\2assem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_a9") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando vocês (?P<vbar_a0>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ássemos|ásseis)(?![-\\w–\xad])', '\\1uando vocês \\2assem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_a0") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a gente (?P<vbar_aa>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1uando a gente \\2asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_aa") in plvrVbrar and option(LOCALE,"verbo")'],
#
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e eu (?P<vbar_b1>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1e eu \\2ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_b1") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e tu (?P<vbar_b2>[a-z]+[bcdfghjlmnprstvxzç])(ar|armos|ardes|arem)(?![-\\w–\xad])', '\\1e tu \\2ares', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_b2") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e ele (?P<vbar_b3>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1e ele \\2ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_b3") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e ela (?P<vbar_b4>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1e ela \\2ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_b4") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e você (?P<vbar_b5>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1e você \\2ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_b5") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e nós (?P<vbar_b6>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|ardes|arem)(?![-\\w–\xad])', '\\1e nós \\2armos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_b6") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e vós (?P<vbar_b7>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|armos|arem)(?![-\\w–\xad])', '\\1e vós \\2ardes', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_b7") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e eles (?P<vbar_b8>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|armos|ardes)(?![-\\w–\xad])', '\\1e eles \\2arem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_b8") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e elas (?P<vbar_b9>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|armos|ardes)(?![-\\w–\xad])', '\\1e elas \\2arem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_b9") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e vocês (?P<vbar_b0>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|armos|ardes)(?![-\\w–\xad])', '\\1e vocês \\2arem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_b0") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e a gente (?P<vbar_ba>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1e a gente \\2ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_ba") in plvrVbrar and option(LOCALE,"verbo")'],
#
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando eu (?P<vbar_c1>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1uando eu \\2ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_c1") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando tu (?P<vbar_c2>[a-z]+[bcdfghjlmnprstvxzç])(ar|armos|ardes|arem)(?![-\\w–\xad])', '\\1uando tu \\2ares', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_c2") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando ele (?P<vbar_c3>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1uando ele \\2ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_c3") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando ela (?P<vbar_c4>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1uando ela \\2ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_c4") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando você (?P<vbar_c5>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1uando você \\2ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_c5") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando nós (?P<vbar_c6>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|ardes|arem)(?![-\\w–\xad])', '\\1uando nós \\2armos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_c6") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando vós (?P<vbar_c7>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|armos|arem)(?![-\\w–\xad])', '\\1uando vós \\2ardes', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_c7") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando eles (?P<vbar_c8>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|armos|ardes)(?![-\\w–\xad])', '\\1uando eles \\2arem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_c8") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando elas (?P<vbar_c9>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|armos|ardes)(?![-\\w–\xad])', '\\1uando elas \\2arem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_c9") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando vocês (?P<vbar_c0>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|armos|ardes)(?![-\\w–\xad])', '\\1uando vocês \\2arem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_c0") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a gente (?P<vbar_ca>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1uando a gente \\2ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbar_ca") in plvrVbrar and option(LOCALE,"verbo")'],
# VERBOS REGULARES TERMINADOS EM AR COM PRONOMES ME TE SE LHE LHES ...
 ['(?u)(?<![-\\w–.,\xad])Eu (me|te|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_11>[a-z]+[bcdfghjlmnprstvxzç])(as|a|amos|ais|am)(?![-\\w–\xad])', 'Eu \\1 \\2o', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_11") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu se (?P<vbarp_11a>[a-z]+[bcdfghjlmnprstvxzç])(o|as|a|amos|ais|am)(?![-\\w–\xad])', 'Eu me \\1o', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_11a") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_12>[a-z]+[bcdfghjlmnprstvxzç])(o|a|amos|ais|am)(?![-\\w–\xad])', 'Tu \\1 \\2as', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_12") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_13>[a-z]+[bcdfghjlmnprstvxzç])(o|as|amos|ais|am)(?![-\\w–\xad])', 'Ele \\1 \\2a', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_13") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_14>[a-z]+[bcdfghjlmnprstvxzç])(o|as|amos|ais|am)(?![-\\w–\xad])', 'Ela \\1 \\2a', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_14") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_15>[a-z]+[bcdfghjlmnprstvxzç])(o|as|amos|ais|am)(?![-\\w–\xad])', 'Você \\1 \\2a', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_15") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_16>[a-z]+[bcdfghjlmnprstvxzç])(o|as|a|ais|am)(?![-\\w–\xad])', 'Nós \\1 \\2amos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_16") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_17>[a-z]+[bcdfghjlmnprstvxzç])(o|as|a|amos|am)(?![-\\w–\xad])', 'Vós \\1 \\2ais', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_17") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_18>[a-z]+[bcdfghjlmnprstvxzç])(o|as|amos|ais|a)(?![-\\w–\xad])', 'Eles \\1 \\2am', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_18") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_19>[a-z]+[bcdfghjlmnprstvxzç])(o|as|amos|ais|a)(?![-\\w–\xad])', 'Elas \\1 \\2am', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_19") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_10>[a-z]+[bcdfghjlmnprstvxzç])(o|as|amos|ais|a)(?![-\\w–\xad])', 'Vocês \\1 \\2am', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_10") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_1a>[a-z]+[bcdfghjlmnprstvxzç])(o|as|amos|ais|am)(?![-\\w–\xad])', 'A gente \\1 \\2a', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_1a") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (me|te|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_21>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', 'Eu \\1 \\2ava', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_21") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu se (?P<vbarp_21a>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis|avam)(?![-\\w–\xad])', 'Eu me \\1ava', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_21a") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_22>[a-z]+[bcdfghjlmnprstvxzç])(ava|ávamos|áveis|avam)(?![-\\w–\xad])', 'Tu \\1 \\2avas', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_22") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_23>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', 'Ele \\1 \\2ava', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_23") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_24>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', 'Ela \\1 \\2ava', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_24") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_25>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', 'Você \\1 \\2ava', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_25") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_26>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|áveis|avam)(?![-\\w–\xad])', 'Nós \\1 \\2ávamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_26") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_27>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|avam)(?![-\\w–\xad])', 'Vós \\1 \\2áveis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_27") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_28>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', 'Eles \\1 \\2avam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_28") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_29>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', 'Elas \\1 \\2avam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_29") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_20>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', 'Vocês \\1 \\2avam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_20") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_2a>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', 'A gente \\1 \\2ava', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_2a") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (me|te|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_31>[a-z]+[bdfhjlmnprstvxz])(aste|ou|amos|astes|aram)(?![-\\w–\xad])', 'Eu \\1 \\2ei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_31") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu se (?P<vbarp_31a>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes|aram)(?![-\\w–\xad])', 'Eu me \\1ei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_31a") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_32>[a-z]+[bdfhjlmnprstvxz])(ei|ou|amos|astes|aram)(?![-\\w–\xad])', 'Tu \\1 \\2aste', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_32") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_33>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', 'Ele \\1 \\2o', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_33") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_34>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', 'Ela \\1 \\2o', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_34") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_35>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', 'Você \\1 \\2o', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_35") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_36>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|astes|aram)(?![-\\w–\xad])', 'Nós \\1 \\2amos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_36") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_37>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|aram)(?![-\\w–\xad])', 'Vós \\1 \\2astes', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_37") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_38>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', 'Eles \\1 \\2aram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_38") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_39>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', 'Elas \\1 \\2aram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_39") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_30>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', 'Vocês \\1 \\2aram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_30") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_3a>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', 'A gente \\1 \\2o', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_3a") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (me|te|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_41>[a-z]+)(çaste|çou|çamos|çastes|çaram)(?![-\\w–\xad])', 'Eu \\1 \\2cei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_41") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu se (?P<vbarp_41>[a-z]+)(cei|çaste|çou|çamos|çastes|çaram)(?![-\\w–\xad])', 'Eu me \\1cei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_41a") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_42>[a-z]+)(cei|çou|çamos|çastes|çaram)(?![-\\w–\xad])', 'Tu \\1 \\2çaste', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_42") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_43>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', 'Ele \\1 \\2ço', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_43") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_44>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', 'Ela \\1 \\2ço', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_44") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_45>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', 'Você \\1 \\2ço', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_45") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_46>[a-z]+)(cei|çaste|çou|çastes|çaram)(?![-\\w–\xad])', 'Nós \\1 \\2\çamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_46") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_47>[a-z]+)(cei|çaste|çou|çamos|çaram)(?![-\\w–\xad])', 'Vós \\1 \\2\çastes', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_47") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_48>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', 'Eles \\1 \\2çaram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_48") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_49>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', 'Elas \\1 \\2çaram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_49") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_40>[a-z]+)(cei|çaste|çou|çamos|açstes)(?![-\\w–\xad])', 'Vocês \\1 \\2çaram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_40") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_4a>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', 'A gente \\1 \\2ço', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_4a") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (me|te|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_51>[a-z]+)(caste|cou|camos|castes|caram)(?![-\\w–\xad])', 'Eu \\1 \\2quei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_51") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu se (?P<vbarp_51a>[a-z]+)(quei|caste|cou|camos|castes|caram)(?![-\\w–\xad])', 'Eu me \\1quei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_51a") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_52>[a-z]+)(quei|cou|camos|castes|caram)(?![-\\w–\xad])', 'Tu \\1 \\2caste', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_52") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_53>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', 'Ele \\1 \\2co', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_53") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_54>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', 'Ela \\1 \\2co', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_54") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_55>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', 'Você \\1 \\2co', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_55") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_56>[a-z]+)(quei|caste|cou|castes|caram)(?![-\\w–\xad])', 'Nós \\1 \\2camos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_56") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_57>[a-z]+)(quei|caste|cou|camos|caram)(?![-\\w–\xad])', 'Vós \\1 \\2castes', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_57") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_58>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', 'Eles \\1 \\2caram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_58") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_59>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', 'Elas \\1 \\2caram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_59") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_50>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', 'Vocês \\1 \\2caram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_50") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_5a>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', 'A gente \\1 \\2co', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_5a") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (me|te|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_61>[a-z]+)(gaste|gou|gamos|gastes|garam)(?![-\\w–\xad])', 'Eu \\1 \\2guei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_61") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu se (?P<vbarp_61a>[a-z]+)(guei|gaste|gou|gamos|gastes|garam)(?![-\\w–\xad])', 'Eu me \\1guei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_61a") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_62>[a-z]+)(guei|gou|gamos|gastes|garam)(?![-\\w–\xad])', 'Tu \\1 \\2gaste', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_62") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_63>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', 'Ele \\1 \\2go', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_63") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_64>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', 'Ela \\1 \\2go', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_64") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_65>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', 'Você \\1 \\2go', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_65") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_66>[a-z]+)(guei|gaste|gou|gastes|garam)(?![-\\w–\xad])', 'Nós \\1 \\2gamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_66") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_67>[a-z]+)(guei|gaste|gou|gamos|garam)(?![-\\w–\xad])', 'Vós \\1 \\2gastes', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_67") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_68>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', 'Eles \\1 \\2garam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_68") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_69>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', 'Elas \\1 \\2garam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_69") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_60>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', 'Vocês \\1 \\2garam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_60") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_6a>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', 'A gente \\1 \\2go', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_6a") in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (me|te|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_71>[a-z]+[bcdfghjlmnprstvxzç])(arás|ará|aremos|areis|arão)(?![-\\w–\xad])', 'Eu \\1 \\2arei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_71") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu se (?P<vbarp_71a>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis|arão)(?![-\\w–\xad])', 'Eu me \\1arei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_71a") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_72>[a-z]+[bcdfghjlmnprstvxzç])(arei|ará|aremos|areis|arão)(?![-\\w–\xad])', 'Tu \\1 \\2arás', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_72") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_73>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', 'Ele \\1 \\2ará', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_73") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_74>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', 'Ela \\1 \\2ará', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_74") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_75>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', 'Você \\1 \\2ará', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_75") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_76>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|areis|arão)(?![-\\w–\xad])', 'Nós \\1 \\2aremos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_76") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_77>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|arão)(?![-\\w–\xad])', 'Vós \\1 \\2areis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_77") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_78>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', 'Eles \\1 \\2arão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_78") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_79>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis|ar)(?![-\\w–\xad])', 'Elas \\1 \\2arão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_79") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_70>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', 'Vocês \\1 \\2arão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_70") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_7a>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', 'A gente \\1 \\2ará', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_7a") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (me|te|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_81>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', 'Eu \\1 \\2aria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_81") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu se (?P<vbarp_81a>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', 'Eu me \\1aria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_81a") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_82>[a-z]+[bcdfghjlmnprstvxzç])(aria|aríamos|aríeis|ariam)(?![-\\w–\xad])', 'Tu \\1 \\2arias', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_82") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_83>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', 'Ele \\1 \\2aria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_83") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_84>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', 'Ela \\1 \\2aria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_84") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_85>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', 'Você \\1 \\2aria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_85") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_86>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríeis|ariam)(?![-\\w–\xad])', 'Nós \\1 \\2aríamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_86") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_87>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|ariam)(?![-\\w–\xad])', 'Vós \\1 \\2aríeis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_87") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_88>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', 'Eles \\1 \\2ariam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_88") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_89>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', 'Elas \\1 \\2ariam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_89") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_80>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', 'Vocês \\1 \\2ariam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_80") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_8a>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', 'A gente \\1 \\2aria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_8a") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e eu (me|te|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_91>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1e eu \\2 \\3asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_91") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e tu (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_92>[a-z]+[bcdfghjlmnprstvxzç])(asse|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1e tu \\2 \\3asses', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_92") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e ele (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_93>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1e ele \\2 \\3asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_93") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e ela (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_94>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1e ela \\2 \\3asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_94") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e você (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_95>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1e você \\2 \\3asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_95") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e nós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_96>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ásseis|assem)(?![-\\w–\xad])', '\\1e nós \\2 \\3ássemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_96") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e vós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_97>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ássemos|assem)(?![-\\w–\xad])', '\\1e vós \\2 \\3ásseis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_97") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e eles (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_98>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ássemos|ásseis)(?![-\\w–\xad])', '\\1e eles \\2 \\3assem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_98") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e elas (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_99>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ássemos|ásseis)(?![-\\w–\xad])', '\\1e elas \\2 \\3assem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_99") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e vocês (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_90>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ássemos|ásseis)(?![-\\w–\xad])', '\\1e vocês \\2 \\3assem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_90") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e a gente (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_9a>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1e a gente \\2 \\3asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_9a") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando eu (me|te|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_a1>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1uando eu \\2 \\3asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_a1") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando tu (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_a2>[a-z]+[bcdfghjlmnprstvxzç])(asse|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1uando tu \\2 \\3asses', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_a2") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando ele (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_a3>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1uando ele \\2 \\3asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_a3") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando ela (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_a4>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1uando ela \\2 \\3asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_a4") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando você (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_a5>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1uando você \\2 \\3asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_a5") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando nós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_a6>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ásseis|assem)(?![-\\w–\xad])', '\\1uando nós \\2 \\3ássemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_a6") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando vós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_a7>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ássemos|assem)(?![-\\w–\xad])', '\\1uando vós \\2 \\3ásseis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_a7") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando eles (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_a8>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ássemos|ásseis)(?![-\\w–\xad])', '\\1uando eles \\2 \\3assem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_a8") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando elas (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_a9>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ássemos|ásseis)(?![-\\w–\xad])', '\\1uando elas \\2 \\3assem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_a9") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando vocês (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_a0>[a-z]+[bcdfghjlmnprstvxzç])(asse|asses|ássemos|ásseis)(?![-\\w–\xad])', '\\1uando vocês \\2 \\3assem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_a0") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a gente (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_aa>[a-z]+[bcdfghjlmnprstvxzç])(asses|ássemos|ásseis|assem)(?![-\\w–\xad])', '\\1uando a gente \\2 \\3asse', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_aa") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e eu (me|te|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_b1>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1e eu \\2 \\3ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_b1") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e tu (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_b2>[a-z]+[bcdfghjlmnprstvxzç])(ar|armos|ardes|arem)(?![-\\w–\xad])', '\\1e tu \\2 \\3ares', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_b2") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e ele (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_b3>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1e ele \\2 \\3ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_b3") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e ela (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_b4>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1e ela \\2 \\3ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_b4") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e você (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_b5>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1e você \\2 \\3ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_b5") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e nós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_b6>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|ardes|arem)(?![-\\w–\xad])', '\\1e nós \\2 \\3armos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_b6") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e vós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_b7>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|armos|arem)(?![-\\w–\xad])', '\\1e vós \\2 \\3ardes', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_b7") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e eles (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_b8>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|armos|ardes)(?![-\\w–\xad])', '\\1e eles \\2 \\3arem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_b8") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e elas (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_b9>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|armos|ardes)(?![-\\w–\xad])', '\\1e elas \\2 \\3arem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_b9") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e vocês (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_b0>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|armos|ardes)(?![-\\w–\xad])', '\\1e vocês \\2 \\3arem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_b0") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e a gente (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_ba>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1e a gente \\2 \\3ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_ba") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando eu (me|te|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_c1>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1uando eu \\2 \\3ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_c1") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando tu (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_c2>[a-z]+[bcdfghjlmnprstvxzç])(ar|armos|ardes|arem)(?![-\\w–\xad])', '\\1uando tu \\2 \\3ares', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_c2") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando ele (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_c3>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1uando ele \\2 \\3ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_c3") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando ela (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_c4>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1uando ela \\2 \\3ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_c4") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando você (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_c5>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1uando você \\2 \\3ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_c5") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando nós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_c6>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|ardes|arem)(?![-\\w–\xad])', '\\1uando nós \\2 \\3armos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_c6") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando vós (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_c7>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|armos|arem)(?![-\\w–\xad])', '\\1uando vós \\2 \\3ardes', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_c7") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando eles (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_c8>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|armos|ardes)(?![-\\w–\xad])', '\\1uando eles \\2 \\3arem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_c8") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando elas (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_c9>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|armos|ardes)(?![-\\w–\xad])', '\\1uando elas \\2 \\3arem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_c9") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando vocês (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_c0>[a-z]+[bcdfghjlmnprstvxzç])(ar|ares|armos|ardes)(?![-\\w–\xad])', '\\1uando vocês \\2 \\3arem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_c0") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a gente (me|te|se|lhe|lhes|nos|vos|o|os|a|as) (?P<vbarp_ca>[a-z]+[bcdfghjlmnprstvxzç])(ares|armos|ardes|arem)(?![-\\w–\xad])', '\\1uando a gente \\2 \\3ar', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbarp_ca") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbxer_11>[a-z]+[bdhilmnoprstuvxz])(es|e|emos|eis|em)(?![-\\w–\xad])', 'Eu \\1o', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_11") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbxer_12>[a-z]+[bdhilmnoprstuvxz])(o|e|emos|eis|em)(?![-\\w–\xad])', 'Tu \\1es', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_12") in plvrVbrxer and not m.group("vbxer_12")+m.group(2) in exvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbxer_13>[a-z]+[bdhilmnoprstuvxz])(o|es|emos|eis|em)(?![-\\w–\xad])', 'Ele \\1e', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_13") in plvrVbrxer and not m.group("vbxer_13")+m.group(2) in exvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbxer_14>[a-z]+[bdhilmnoprstuvxz])(o|es|emos|eis|em)(?![-\\w–\xad])', 'Ela \\1e', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_14") in plvrVbrxer and not m.group("vbxer_14")+m.group(2) in exvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbxer_15>[a-z]+[bdhilmnoprstuvxz])(o|es|emos|eis|em)(?![-\\w–\xad])', 'Você \\1e', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_15") in plvrVbrxer and not m.group("vbxer_15")+m.group(2) in exvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbxer_16>[a-z]+[bdhilmnoprstuvxz])(o|es|e|eis|em)(?![-\\w–\xad])', 'Nós \\1emos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_16") in plvrVbrxer and not m.group("vbxer_16")+m.group(2) in exvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbxer_17>[a-z]+[bdhilmnoprstuvxz])(o|es|e|emos|em)(?![-\\w–\xad])', 'Vós \\1eis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_17") in plvrVbrxer and not m.group("vbxer_17")+m.group(2) in exvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbxer_18>[a-z]+[bdhilmnoprstuvxz])(o|es|e|emos|eis)(?![-\\w–\xad])', 'Eles \\1em', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_18") in plvrVbrxer and not m.group("vbxer_18")+m.group(2) in exvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbxer_19>[a-z]+[bdhilmnoprstuvxz])(o|es|e|emos|eis)(?![-\\w–\xad])', 'Elas \\1em', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_19") in plvrVbrxer and not m.group("vbxer_19")+m.group(2) in exvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbxer_10>[a-z]+[bdhilmnoprstuvxz])(o|es|e|emos|eis)(?![-\\w–\xad])', 'Vocês \\1em', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_10") in plvrVbrxer and not m.group("vbxer_10")+m.group(2) in exvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbxer_1>[a-z]+[bdhilmnoprstuvxz])(o|es|emos|eis|em)(?![-\\w–\xad])', 'A gente \\1e', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_1") in plvrVbrxer and not m.group("vbxer_1")+m.group(2) in exvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbxer_a>[a-z]+[bdhilmnoprstuvxz])(o|es|emos|eis|em)(?![-\\w–\xad])', '\\1 \\2e', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_a") in plvrVbrxer and not m.group("vbxer_a")+m.group(3) in exvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbxer_b>[a-z]+[bdhilmnoprstuvxz])(o|es|e|eis)(?![-\\w–\xad])', '\\1 \\2em\\n\\1 \\2emos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_b") in plvrVbrxer and not m.group("vbxer_b")+m.group(3) in exvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbcer_11>[a-z]+)(ces|ce|cemos|ceis|cem)(?![-\\w–\xad])', 'Eu \\1ço', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_11") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbcer_12>[a-z]+)(ço|ce|cemos|ceis|cem)(?![-\\w–\xad])', 'Tu \\1ces', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_12") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbcer_13>[a-z]+)(ço|ces|cemos|ceis|cem)(?![-\\w–\xad])', 'Ele \\1ce', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_13") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbcer_14>[a-z]+)(ço|ces|cemos|ceis|cem)(?![-\\w–\xad])', 'Ela \\1ce', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_14") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbcer_15>[a-z]+)(ço|ces|cemos|ceis|cem)(?![-\\w–\xad])', 'Você \\1ce', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_15") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbcer_16>[a-z]+)(ço|ces|ce|ceis|cem)(?![-\\w–\xad])', 'Nós \\1cemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_16") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbcer_17>[a-z]+)(ço|ces|ce|cemos|cem)(?![-\\w–\xad])', 'Vós \\1ceis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_17") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbcer_18>[a-z]+)(ço|ces|ce|cemos|ceis)(?![-\\w–\xad])', 'Eles \\1cem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_18") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbcer_19>[a-z]+)(ço|ces|ce|cemos|ceis)(?![-\\w–\xad])', 'Elas \\1cem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_19") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbcer_10>[a-z]+)(ço|ces|ce|cemos|ceis)(?![-\\w–\xad])', 'Vocês \\1cem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_10") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbcer_1>[a-z]+)(ço|ces|cemos|ceis|cem)(?![-\\w–\xad])', 'A gente \\1ce', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_1") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbcer_a>[a-z]+[bdhilmnoprstuvxz])(ço|ces|cemos|ceis|cem)(?![-\\w–\xad])', '\\1 \\2ce', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_a") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbcer_b>[a-z]+[bdhilmnoprstuvxz])(ço|ces|ce|ceis)(?![-\\w–\xad])', '\\1 \\2cem\\n\\1 \\2cemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_b") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbger_11>[a-z]+)(ges|ge|gemos|geis|gem)(?![-\\w–\xad])', 'Eu \\1jo', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_11") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbger_12>[a-z]+)(jo|ge|gemos|geis|gem)(?![-\\w–\xad])', 'Tu \\1ges', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_12") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbger_13>[a-z]+)(jo|ges|gemos|geis|gem)(?![-\\w–\xad])', 'Ele \\1ge', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_13") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbger_14>[a-z]+)(jo|ges|gemos|geis|gem)(?![-\\w–\xad])', 'Ela \\1ge', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_14") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbger_15>[a-z]+)(jo|ges|gemos|geis|gem)(?![-\\w–\xad])', 'Você \\1ge', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_15") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbger_16>[a-z]+)(jo|ges|ge|geis|gem)(?![-\\w–\xad])', 'Nós \\1gemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_16") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbger_17>[a-z]+)(jo|ges|ge|gemos|gem)(?![-\\w–\xad])', 'Vós \\1geis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_17") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbger_18>[a-z]+)(jo|ges|ge|gemos|geis)(?![-\\w–\xad])', 'Eles \\1gem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_18") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbger_19>[a-z]+)(jo|ges|ge|gemos|geis)(?![-\\w–\xad])', 'Elas \\1gem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_19") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbger_10>[a-z]+)(jo|ges|ge|gemos|geis)(?![-\\w–\xad])', 'Vocês \\1gem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_10") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbger_1>[a-z]+)(jo|ges|gemos|geis|gem)(?![-\\w–\xad])', 'A gente \\1ge', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_1") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbger_a>[a-z]+)(jo|ges|gemos|geis|gem)(?![-\\w–\xad])', '\\1 \\2ge', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_a") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbger_b>[a-z]+)(jo|ges|gemos|geis|gem)(?![-\\w–\xad])', '\\1 \\2gem\\n\\1 \\2gemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_b") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbuer_11>[a-z]+[g])(ues|ue|uemos|ueis|uem)(?![-\\w–\xad])', 'Eu \\1o', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_11") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbuer_12>[a-z]+[g])(o|ue|uemos|ueis|uem)(?![-\\w–\xad])', 'Tu \\1ues', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_12") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbuer_13>[a-z]+[g])(o|ues|uemos|ueis|uem)(?![-\\w–\xad])', 'Ele \\1ue', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_13") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbuer_14>[a-z]+[g])(o|ues|uemos|ueis|uem)(?![-\\w–\xad])', 'Ela \\1ue', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_14") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbuer_15>[a-z]+[g])(o|ues|uemos|ueis|uem)(?![-\\w–\xad])', 'Você \\1ue', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_15") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbuer_16>[a-z]+[g])(o|ues|ue|ueis|uem)(?![-\\w–\xad])', 'Nós \\1uemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_16") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbuer_17>[a-z]+[g])(o|ues|ue|uemos|uem)(?![-\\w–\xad])', 'Vós \\1ueis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_17") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbuer_18>[a-z]+[g])(o|ues|ue|uemos|ueis)(?![-\\w–\xad])', 'Eles \\1uem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_18") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbuer_19>[a-z]+[g])(o|ues|ue|uemos|ueis)(?![-\\w–\xad])', 'Elas \\1uem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_19") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbuer_10>[a-z]+[g])(o|ues|ue|uemos|ueis)(?![-\\w–\xad])', 'Vocês \\1uem', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_10") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbuer_1>[a-z]+[g])(o|ues|uemos|ueis|uem)(?![-\\w–\xad])', 'A gente \\1ue', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_1") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbuer_a>[a-z]+[g])(o|ues|uemos|ueis|uem)(?![-\\w–\xad])', '\\1 \\2ue', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_a") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbuer_b>[a-z]+[g])(o|ues|ue|ueis)(?![-\\w–\xad])', '\\1 \\2uem\\n\\1 \\2uemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_b") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbxer_21>[a-z]+[bdhilmnoprstuvxz])(este|eu|emos|estes|eram)(?![-\\w–\xad])', 'Eu \\1i', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_21") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbxer_22>[a-z]+[bdhilmnoprstuvxz])(i|eu|emos|estes|eram)(?![-\\w–\xad])', 'Tu \\1este', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_22") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbxer_23>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eram)(?![-\\w–\xad])', 'Ele \\1e', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_23") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbxer_24>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eram)(?![-\\w–\xad])', 'Ela \\1e', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_24") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbxer_25>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eram)(?![-\\w–\xad])', 'Você \\1e', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_25") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbxer_26>[a-z]+[bdhilmnoprstuvxz])(i|este|eu|estes|eram)(?![-\\w–\xad])', 'Nós \\1emos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_26") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbxer_27>[a-z]+[bdhilmnoprstuvxz])(i|este|eu|emos|eram)(?![-\\w–\xad])', 'Vós \\1estes', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_27") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbxer_28>[a-z]+[bdhilmnoprstuvxz])(i|este|eu|emos|estes)(?![-\\w–\xad])', 'Eles \\1eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_28") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbxer_29>[a-z]+[bdhilmnoprstuvxz])(i|este|eu|emos|estes)(?![-\\w–\xad])', 'Elas \\1eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_29") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbxer_20>[a-z]+[bdhilmnoprstuvxz])(i|este|eu|emos|estes)(?![-\\w–\xad])', 'Vocês \\1eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_20") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbxer_2>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eram)(?![-\\w–\xad])', 'A gente \\1e', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_2") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbxer_c>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eram)(?![-\\w–\xad])', '\\1 \\2e', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_c") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbxer_d>[a-z]+[bdhilmnoprstuvxz])(i|este|eu|estes)(?![-\\w–\xad])', '\\1 \\2eram\\n\\1 \\2emos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_d") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbcer_21>[a-z]+)(ceste|ceu|cemos|cestes|ceram)(?![-\\w–\xad])', 'Eu \\1ci', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_21") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbcer_22>[a-z]+)(ci|ceu|cemos|cestes|ceram)(?![-\\w–\xad])', 'Tu \\1ceste', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_22") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbcer_23>[a-z]+)(ci|ceste|cemos|cestes|ceram)(?![-\\w–\xad])', 'Ele \\1ce', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_23") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbcer_24>[a-z]+)(ci|ceste|cemos|cestes|ceram)(?![-\\w–\xad])', 'Ela \\1ce', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_24") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbcer_25>[a-z]+)(ci|ceste|cemos|cestes|ceram)(?![-\\w–\xad])', 'Você \\1ce', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_25") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbcer_26>[a-z]+)(ci|ceste|ceu|cestes|ceram)(?![-\\w–\xad])', 'Nós \\1cemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_26") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbcer_27>[a-z]+)(ci|ceste|ceu|cemos|ceram)(?![-\\w–\xad])', 'Vós \\1cestes', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_27") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbcer_28>[a-z]+)(ci|ceste|ceu|cemos|cestes)(?![-\\w–\xad])', 'Eles \\1ceram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_28") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbcer_29>[a-z]+)(ci|ceste|ceu|cemos|cestes)(?![-\\w–\xad])', 'Elas \\1ceram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_29") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbcer_20>[a-z]+)(ci|ceste|ceu|cemos|cestes)(?![-\\w–\xad])', 'Vocês \\1ceram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_20") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbcer_2>[a-z]+)(ci|ceste|cemos|cestes|ceram)(?![-\\w–\xad])', 'A gente \\1ce', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_2") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbcer_c>[a-z]+)(ci|ceste|cemos|cestes|ceram)(?![-\\w–\xad])', '\\1 \\2ce', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_c") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbcer_d>[a-z]+)(ci|ceste|ceu|cestes)(?![-\\w–\xad])', '\\1 \\2ceram\\n\\1 \\2cemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_d") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbger_21>[a-z]+)(geste|geu|gemos|gestes|geram)(?![-\\w–\xad])', 'Eu \\1gi', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_21") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbger_22>[a-z]+)(gi|geu|gemos|gestes|geram)(?![-\\w–\xad])', 'Tu \\1geste', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_22") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbger_23>[a-z]+)(gi|geste|gemos|gestes|geram)(?![-\\w–\xad])', 'Ele \\1ge', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_23") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbger_24>[a-z]+)(gi|geste|gemos|gestes|geram)(?![-\\w–\xad])', 'Ela \\1ge', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_24") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbger_25>[a-z]+)(gi|geste|gemos|gestes|geram)(?![-\\w–\xad])', 'Você \\1ge', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_25") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbger_26>[a-z]+)(gi|geste|geu|gestes|geram)(?![-\\w–\xad])', 'Nós \\1gemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_26") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbger_27>[a-z]+)(gi|geste|geu|gemos|geram)(?![-\\w–\xad])', 'Vós \\1gestes', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_27") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbger_28>[a-z]+)(gi|geste|geu|gemos|gestes)(?![-\\w–\xad])', 'Eles \\1geram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_28") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbger_29>[a-z]+)(gi|geste|geu|gemos|gestes)(?![-\\w–\xad])', 'Elas \\1geram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_29") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbger_20>[a-z]+)(gi|geste|geu|gemos|gestes)(?![-\\w–\xad])', 'Vocês \\1geram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_20") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbger_2>[a-z]+)(gi|geste|gemos|gestes|geram)(?![-\\w–\xad])', 'A gente \\1ge', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_2") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbger_c>[a-z]+)(gi|geste|gemos|gestes|geram)(?![-\\w–\xad])', '\\1 \\2ge', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_c") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbger_d>[a-z]+)(gi|geste|geu|gestes)(?![-\\w–\xad])', '\\1 \\2geram\\n\\1 \\2gemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_d") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbuer_21>[a-z]+[g])(ueste|ueu|uemos|uestes|ueram)(?![-\\w–\xad])', 'Eu \\1ui', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_21") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbuer_22>[a-z]+[g])(ui|ueu|uemos|uestes|ueram)(?![-\\w–\xad])', 'Tu \\1ueste', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_22") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbuer_23>[a-z]+[g])(ui|ueste|uemos|uestes|ueram)(?![-\\w–\xad])', 'Ele \\1ue', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_23") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbuer_24>[a-z]+[g])(ui|ueste|uemos|uestes|ueram)(?![-\\w–\xad])', 'Ela \\1ue', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_24") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbuer_25>[a-z]+[g])(ui|ueste|uemos|uestes|ueram)(?![-\\w–\xad])', 'Você \\1ue', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_25") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbuer_26>[a-z]+[g])(ui|ueste|ueu|uestes|ueram)(?![-\\w–\xad])', 'Nós \\1uemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_26") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbuer_27>[a-z]+[g])(ui|ueste|ueu|uemos|ueram)(?![-\\w–\xad])', 'Vós \\1uestes', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_27") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbuer_28>[a-z]+[g])(ui|ueste|ueu|uemos|uestes)(?![-\\w–\xad])', 'Eles \\1ueram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_28") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbuer_29>[a-z]+[g])(ui|ueste|ueu|uemos|uestes)(?![-\\w–\xad])', 'Elas \\1ueram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_29") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbuer_20>[a-z]+[g])(ui|ueste|ueu|uemos|uestes)(?![-\\w–\xad])', 'Vocês \\1ueram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_20") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbuer_2>[a-z]+[g])(ui|ueste|uemos|uestes|ueram)(?![-\\w–\xad])', 'A gente \\1ue', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_2") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbuer_c>[a-z]+[g])(ui|ueste|uemos|uestes|ueram)(?![-\\w–\xad])', '\\1 \\2ue', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_c") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbuer_d>[a-z]+[g])(ui|ueste|ueu|uemos|uestes)(?![-\\w–\xad])', '\\1 \\2ueram\\n\\1 \\2uemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_d") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbxer_31>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', 'Eu \\1ia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_31") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbxer_32>[a-z]+[bdhilmnoprstuvxz])(ia|íamos|íeis|iam)(?![-\\w–\xad])', 'Tu \\1ias', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_32") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbxer_33>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', 'Ele \\1ia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_33") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbxer_34>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', 'Ela \\1ia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_34") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbxer_35>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', 'Você \\1ia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_35") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbxer_36>[a-z]+[bdhilmnoprstuvxz])(ias|ia|íeis|iam)(?![-\\w–\xad])', 'Nós \\1íamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_36") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbxer_37>[a-z]+[bdhilmnoprstuvxz])(ias|ia|íamos|iam)(?![-\\w–\xad])', 'Vós \\1íeis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_37") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbxer_38>[a-z]+[bdhilmnoprstuvxz])(ias|ia|íamos|íeis)(?![-\\w–\xad])', 'Eles \\1iam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_38") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbxer_39>[a-z]+[bdhilmnoprstuvxz])(ias|ia|íamos|íeis)(?![-\\w–\xad])', 'Elas \\1iam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_39") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbxer_30>[a-z]+[bdhilmnoprstuvxz])(ias|ia|íamos|íeis)(?![-\\w–\xad])', 'Vocês \\1iam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_30") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbxer_3>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', 'A gente \\1ia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_3") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbxer_e>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', '\\1 \\2ia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_e") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbxer_f>[a-z]+[bdhilmnoprstuvxz])(ias|ia|íeis)(?![-\\w–\xad])', '\\1 \\2iam\\n\\1 \\2íamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_f") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbcer_31>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', 'Eu \\1cia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_31") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbcer_32>[a-z]+)(cia|cíamos|cíeis|ciam)(?![-\\w–\xad])', 'Tu \\1cias', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_32") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbcer_33>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', 'Ele \\1cia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_33") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbcer_34>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', 'Ela \\1cia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_34") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbcer_35>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', 'Você \\1cia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_35") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbcer_36>[a-z]+)(cia|cias|cíeis|ciam)(?![-\\w–\xad])', 'Nós \\1cíamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_36") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbcer_37>[a-z]+)(cia|cias|cíamos|ciam)(?![-\\w–\xad])', 'Vós \\1cíeis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_37") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbcer_38>[a-z]+)(cia|cias|cíamos|cíeis)(?![-\\w–\xad])', 'Eles \\1ciam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_38") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbcer_39>[a-z]+)(cia|cias|cíamos|cíeis)(?![-\\w–\xad])', 'Elas \\1ciam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_39") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbcer_30>[a-z]+)(cia|cias|cíamos|cíeis)(?![-\\w–\xad])', 'Vocês \\1ciam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_30") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbcer_3>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', 'A gente \\1cia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_3") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbcer_e>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', '\\1 \\2cia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_e") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbcer_f>[a-z]+)(cia|cias|cíeis)(?![-\\w–\xad])', '\\1 \\2ciam\\n\\1 \\2cíamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_f") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbger_31>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', 'Eu \\1gia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_31") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbger_32>[a-z]+)(gia|gíamos|gíeis|giam)(?![-\\w–\xad])', 'Tu \\1gias', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_32") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbger_33>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', 'Ele \\1gia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_33") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbger_34>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', 'Ela \\1gia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_34") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbger_35>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', 'Você \\1gia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_35") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbger_36>[a-z]+)(gia|gias|gíeis|giam)(?![-\\w–\xad])', 'Nós \\1gíamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_36") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbger_37>[a-z]+)(gia|gias|gíamos|giam)(?![-\\w–\xad])', 'Vós \\1gíeis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_37") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbger_38>[a-z]+)(gia|gias|gíamos|gíeis)(?![-\\w–\xad])', 'Eles \\1giam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_38") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbger_39>[a-z]+)(gia|gias|gíamos|gíeis)(?![-\\w–\xad])', 'Elas \\1giam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_39") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbger_30>[a-z]+)(gia|gias|gíamos|gíeis)(?![-\\w–\xad])', 'Vocês \\1giam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_30") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbger_3>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', 'A gente \\1gia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_3") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbger_e>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', '\\1 \\2gia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_e") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbger_f>[a-z]+)(gia|gias|gíeis)(?![-\\w–\xad])', '\\1 \\2giam\\n\\1 \\2gíamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_f") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbuer_31>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', 'Eu \\1uia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_31") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbuer_32>[a-z]+[g])(uia|uíamos|uíeis|uiam)(?![-\\w–\xad])', 'Tu \\1uias', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_32") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbuer_33>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', 'Ele \\1uia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_33") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbuer_34>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', 'Ela \\1uia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_34") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbuer_35>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', 'Você \\1uia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_35") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbuer_36>[a-z]+[g])(uia|uias|uíeis|uiam)(?![-\\w–\xad])', 'Nós \\1uíamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_36") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbuer_37>[a-z]+[g])(uia|uias|uíamos|uiam)(?![-\\w–\xad])', 'Vós \\1uíeis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_37") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbuer_38>[a-z]+[g])(uia|uias|uíamos|uíeis)(?![-\\w–\xad])', 'Eles \\1uiam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_38") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbuer_39>[a-z]+[g])(uia|uias|uíamos|uíeis)(?![-\\w–\xad])', 'Elas \\1uiam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_39") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbuer_30>[a-z]+[g])(uia|uias|uíamos|uíeis)(?![-\\w–\xad])', 'Vocês \\1uiam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_30") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbuer_3>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', 'A gente \\1uia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_3") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbuer_e>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', '\\1 \\2uia', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_e") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbuer_f>[a-z]+[g])(uia|uias|uíeis)(?![-\\w–\xad])', '\\1 \\2uiam\\n\\1 \\2uíamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_f") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbxer_41>[a-z]+[bdhilmnoprstuvxz])(eras|êramos|êreis|eram)(?![-\\w–\xad])', 'Eu \\1era', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_41") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbxer_42>[a-z]+[bdhilmnoprstuvxz])(era|êramos|êreis|eram)(?![-\\w–\xad])', 'Tu \\1eras', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_42") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbxer_43>[a-z]+[bdhilmnoprstuvxz])(eras|êramos|êreis|eram)(?![-\\w–\xad])', 'Ele \\1era', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_43") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbxer_44>[a-z]+[bdhilmnoprstuvxz])(eras|êramos|êreis|eram)(?![-\\w–\xad])', 'Ela \\1era', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_44") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbxer_45>[a-z]+[bdhilmnoprstuvxz])(eras|êramos|êreis|eram)(?![-\\w–\xad])', 'Você \\1era', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_45") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbxer_46>[a-z]+[bdhilmnoprstuvxz])(era|eras|êreis|eram)(?![-\\w–\xad])', 'Nós \\1êramos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_46") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbxer_47>[a-z]+[bdhilmnoprstuvxz])(era|eras|êramos|eram)(?![-\\w–\xad])', 'Vós \\1êreis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_47") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbxer_48>[a-z]+[bdhilmnoprstuvxz])(era|eras|êramos|êreis)(?![-\\w–\xad])', 'Eles \\1eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_48") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbxer_49>[a-z]+[bdhilmnoprstuvxz])(era|eras|êramos|êreis)(?![-\\w–\xad])', 'Elas \\1eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_49") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbxer_40>[a-z]+[bdhilmnoprstuvxz])(era|eras|êramos|êreis)(?![-\\w–\xad])', 'Vocês \\1eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_40") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbxer_4>[a-z]+[bdhilmnoprstuvxz])(eras|êramos|êreis|eram)(?![-\\w–\xad])', 'A gente \\1era', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_4") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbxer_g>[a-z]+[bdhilmnoprstuvxz])(eras|êramos|êreis|eram)(?![-\\w–\xad])', '\\1 \\2era', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_g") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbxer_h>[a-z]+[bdhilmnoprstuvxz])(era|eras|êreis)(?![-\\w–\xad])', '\\1 \\2eram\\n\\1 \\2êramos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_h") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbcer_41>[a-z]+)(ceras|cêramos|cêreis|ceram)(?![-\\w–\xad])', 'Eu \\1cera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_41") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbcer_42>[a-z]+)(cera|cêramos|cêreis|ceram)(?![-\\w–\xad])', 'Tu \\1ceras', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_42") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbcer_43>[a-z]+)(ceras|cêramos|cêreis|ceram)(?![-\\w–\xad])', 'Ele \\1cera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_43") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbcer_44>[a-z]+)(ceras|cêramos|cêreis|ceram)(?![-\\w–\xad])', 'Ela \\1cera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_44") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbcer_45>[a-z]+)(ceras|cêramos|cêreis|ceram)(?![-\\w–\xad])', 'Você \\1cera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_45") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbcer_46>[a-z]+)(cera|ceras|cêreis|ceram)(?![-\\w–\xad])', 'Nós \\1cêramos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_46") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbcer_47>[a-z]+)(cera|ceras|cêramos|ceram)(?![-\\w–\xad])', 'Vós \\1cêreis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_47") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbcer_48>[a-z]+)(cera|ceras|cêramos|cêreis)(?![-\\w–\xad])', 'Eles \\1ceram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_48") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbcer_49>[a-z]+)(cera|ceras|cêramos|cêreis)(?![-\\w–\xad])', 'Elas \\1ceram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_49") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbcer_40>[a-z]+)(cera|ceras|cêramos|cêreis)(?![-\\w–\xad])', 'Vocês \\1ceram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_40") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbcer_4>[a-z]+)(ceras|cêramos|cêreis|ceram)(?![-\\w–\xad])', 'A gente \\1cera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_4") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbcer_g>[a-z]+)(ceras|cêramos|cêreis|ceram)(?![-\\w–\xad])', '\\1 \\2cera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_g") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbcer_h>[a-z]+)(cera|ceras|cêreis)(?![-\\w–\xad])', '\\1 \\2ceram\\n\\1 \\2cêramos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_h") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbger_41>[a-z]+)(geras|gêramos|gêreis|geram)(?![-\\w–\xad])', 'Eu \\1gera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_41") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbger_42>[a-z]+)(gera|gêramos|gêreis|geram)(?![-\\w–\xad])', 'Tu \\1geras', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_42") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbger_43>[a-z]+)(geras|gêramos|gêreis|geram)(?![-\\w–\xad])', 'Ele \\1gera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_43") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbger_44>[a-z]+)(geras|gêramos|gêreis|geram)(?![-\\w–\xad])', 'Ela \\1gera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_44") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbger_45>[a-z]+)(geras|gêramos|gêreis|geram)(?![-\\w–\xad])', 'Você \\1gera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_45") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbger_46>[a-z]+)(gera|geras|gêreis|geram)(?![-\\w–\xad])', 'Nós \\1gêramos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_46") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbger_47>[a-z]+)(gera|geras|gêramos|geram)(?![-\\w–\xad])', 'Vós \\1gêreis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_47") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbger_48>[a-z]+)(gera|geras|gêramos|gêreis)(?![-\\w–\xad])', 'Eles \\1geram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_48") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbger_49>[a-z]+)(gera|geras|gêramos|gêreis)(?![-\\w–\xad])', 'Elas \\1geram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_49") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbger_40>[a-z]+)(gera|geras|gêramos|gêreis)(?![-\\w–\xad])', 'Vocês \\1geram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_40") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbger_4>[a-z]+)(geras|gêramos|gêreis|geram)(?![-\\w–\xad])', 'A gente \\1gera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_4") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbger_g>[a-z]+)(geras|gêramos|gêreis|geram)(?![-\\w–\xad])', '\\1 \\2gera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_g") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbger_h>[a-z]+)(gera|geras|gêreis)(?![-\\w–\xad])', '\\1 \\2geram\\n\\1 \\2gêramos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_h") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbuer_41>[a-z]+[g])(ueras|uêramos|uêreis|ueram)(?![-\\w–\xad])', 'Eu \\1uera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_41") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbuer_42>[a-z]+[g])(uera|uêramos|uêreis|ueram)(?![-\\w–\xad])', 'Tu \\1ueras', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_42") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbuer_43>[a-z]+[g])(ueras|uêramos|uêreis|ueram)(?![-\\w–\xad])', 'Ele \\1uera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_43") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbuer_44>[a-z]+[g])(ueras|uêramos|uêreis|ueram)(?![-\\w–\xad])', 'Ela \\1uera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_44") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbuer_45>[a-z]+[g])(ueras|uêramos|uêreis|ueram)(?![-\\w–\xad])', 'Você \\1uera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_45") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbuer_46>[a-z]+[g])(uera|ueras|uêreis|ueram)(?![-\\w–\xad])', 'Nós \\1uêramos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_46") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbuer_47>[a-z]+[g])(uera|ueras|uêramos|ueram)(?![-\\w–\xad])', 'Vós \\1uêreis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_47") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbuer_48>[a-z]+[g])(uera|ueras|uêramos|uêreis)(?![-\\w–\xad])', 'Eles \\1ueram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_48") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbuer_49>[a-z]+[g])(uera|ueras|uêramos|uêreis)(?![-\\w–\xad])', 'Elas \\1ueram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_49") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbuer_40>[a-z]+[g])(uera|ueras|uêramos|uêreis)(?![-\\w–\xad])', 'Vocês \\1ueram', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_40") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbuer_4>[a-z]+[g])(ueras|uêramos|uêreis|ueram)(?![-\\w–\xad])', 'A gente \\1uera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_4") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbuer_g>[a-z]+[g])(ueras|uêramos|uêreis|ueram)(?![-\\w–\xad])', '\\1 \\2uera', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_g") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbuer_h>[a-z]+[g])(uera|ueras|uêreis)(?![-\\w–\xad])', '\\1 \\2ueram\\n\\1 \\2uêramos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_h") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbxer_51>[a-z]+[bdhilmnoprstuvxz])(erás|erá|eremos|ereis|erão)(?![-\\w–\xad])', 'Eu \\1erei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_51") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbxer_52>[a-z]+[bdhilmnoprstuvxz])(erei|erá|eremos|ereis|erão)(?![-\\w–\xad])', 'Tu \\1erás', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_52") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbxer_53>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erão)(?![-\\w–\xad])', 'Ele \\1erá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_53") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbxer_54>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erão)(?![-\\w–\xad])', 'Ela \\1erá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_54") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbxer_55>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erão)(?![-\\w–\xad])', 'Você \\1erá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_55") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbxer_56>[a-z]+[bdhilmnoprstuvxz])(erei|erás|erá|ereis|erão)(?![-\\w–\xad])', 'Nós \\1eremos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_56") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbxer_57>[a-z]+[bdhilmnoprstuvxz])(erei|erás|erá|eremos|erão)(?![-\\w–\xad])', 'Vós \\1ereis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_57") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbxer_58>[a-z]+[bdhilmnoprstuvxz])(erei|erás|erá|eremos|ereis)(?![-\\w–\xad])', 'Eles \\1erão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_58") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbxer_59>[a-z]+[bdhilmnoprstuvxz])(erei|erás|erá|eremos|ereis)(?![-\\w–\xad])', 'Elas \\1erão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_59") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbxer_50>[a-z]+[bdhilmnoprstuvxz])(erei|erás|erá|eremos|ereis)(?![-\\w–\xad])', 'Vocês \\1erão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_50") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbxer_5>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erão)(?![-\\w–\xad])', 'A gente \\1erá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_5") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbxer_i>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erão)(?![-\\w–\xad])', '\\1 \\2erá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_i") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbxer_j>[a-z]+[bdhilmnoprstuvxz])(erei|erás|erá|ereis)(?![-\\w–\xad])', '\\1 \\2erão\\n\\1 \\2eremos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_j") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbcer_51>[a-z]+)(cerás|cerá|ceremos|cereis|cerão)(?![-\\w–\xad])', 'Eu \\1cerei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_51") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbcer_52>[a-z]+)(cerei|cerá|ceremos|cereis|cerão)(?![-\\w–\xad])', 'Tu \\1cerás', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_52") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbcer_53>[a-z]+)(cerei|cerás|ceremos|cereis|cerão)(?![-\\w–\xad])', 'Ele \\1cerá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_53") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbcer_54>[a-z]+)(cerei|cerás|ceremos|cereis|cerão)(?![-\\w–\xad])', 'Ela \\1cerá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_54") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbcer_55>[a-z]+)(cerei|cerás|ceremos|cereis|cerão)(?![-\\w–\xad])', 'Você \\1cerá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_55") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbcer_56>[a-z]+)(cerei|cerás|cerá|cereis|cerão)(?![-\\w–\xad])', 'Nós \\1ceremos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_56") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbcer_57>[a-z]+)(cerei|cerás|cerá|ceremos|cerão)(?![-\\w–\xad])', 'Vós \\1cereis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_57") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbcer_58>[a-z]+)(cerei|cerás|cerá|ceremos|cereis)(?![-\\w–\xad])', 'Eles \\1cerão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_58") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbcer_59>[a-z]+)(cerei|cerás|cerá|ceremos|cereis)(?![-\\w–\xad])', 'Elas \\1cerão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_59") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbcer_50>[a-z]+)(cerei|cerás|cerá|ceremos|cereis)(?![-\\w–\xad])', 'Vocês \\1cerão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_50") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbcer_5>[a-z]+)(cerei|cerás|ceremos|cereis|cerão)(?![-\\w–\xad])', 'A gente \\1cerá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_5") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbcer_i>[a-z]+)(cerei|cerás|ceremos|cereis|cerão)(?![-\\w–\xad])', '\\1 \\2cerá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_i") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbcer_j>[a-z]+)(cerei|cerás|cerá|cereis)(?![-\\w–\xad])', '\\1 \\2cerão\\n\\1 \\2ceremos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_j") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbger_51>[a-z]+)(gerás|gerá|geremos|gereis|gerão)(?![-\\w–\xad])', 'Eu \\1gerei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_51") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbger_52>[a-z]+)(gerei|gerá|geremos|gereis|gerão)(?![-\\w–\xad])', 'Tu \\1gerás', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_52") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbger_53>[a-z]+)(gerei|gerás|geremos|gereis|gerão)(?![-\\w–\xad])', 'Ele \\1gerá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_53") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbger_54>[a-z]+)(gerei|gerás|geremos|gereis|gerão)(?![-\\w–\xad])', 'Ela \\1gerá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_54") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbger_55>[a-z]+)(gerei|gerás|geremos|gereis|gerão)(?![-\\w–\xad])', 'Você \\1gerá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_55") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbger_56>[a-z]+)(gerei|gerás|gerá|gereis|gerão)(?![-\\w–\xad])', 'Nós \\1geremos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_56") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbger_57>[a-z]+)(gerei|gerás|gerá|geremos|gerão)(?![-\\w–\xad])', 'Vós \\1gereis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_57") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbger_58>[a-z]+)(gerei|gerás|gerá|geremos|gereis)(?![-\\w–\xad])', 'Eles \\1gerão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_58") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbger_59>[a-z]+)(gerei|gerás|gerá|geremos|gereis)(?![-\\w–\xad])', 'Elas \\1gerão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_59") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbger_50>[a-z]+)(gerei|gerás|gerá|geremos|gereis)(?![-\\w–\xad])', 'Vocês \\1gerão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_50") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbger_5>[a-z]+)(gerei|gerás|geremos|gereis|gerão)(?![-\\w–\xad])', 'A gente \\1gerá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_5") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbger_i>[a-z]+)(gerei|gerás|geremos|gereis|gerão)(?![-\\w–\xad])', '\\1 \\2gerá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_i") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbger_j>[a-z]+)(gerei|gerás|gerá|gereis)(?![-\\w–\xad])', '\\1 \\2gerão\\n\\1 \\2geremos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_j") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbuer_51>[a-z]+[g])(uerás|uerá|ueremos|uereis|uerão)(?![-\\w–\xad])', 'Eu \\1uerei', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_51") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbuer_52>[a-z]+[g])(uerei|uerá|ueremos|uereis|uerão)(?![-\\w–\xad])', 'Tu \\1uerás', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_52") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbuer_53>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerão)(?![-\\w–\xad])', 'Ele \\1uerá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_53") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbuer_54>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerão)(?![-\\w–\xad])', 'Ela \\1uerá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_54") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbuer_55>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerão)(?![-\\w–\xad])', 'Você \\1uerá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_55") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbuer_56>[a-z]+[g])(uerei|uerás|uerá|uereis|uerão)(?![-\\w–\xad])', 'Nós \\1ueremos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_56") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbuer_57>[a-z]+[g])(uerei|uerás|uerá|ueremos|uerão)(?![-\\w–\xad])', 'Vós \\1uereis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_57") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbuer_58>[a-z]+[g])(uerei|uerás|uerá|ueremos|uereis)(?![-\\w–\xad])', 'Eles \\1uerão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_58") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbuer_59>[a-z]+[g])(uerei|uerás|uerá|ueremos|uereis)(?![-\\w–\xad])', 'Elas \\1uerão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_59") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbuer_50>[a-z]+[g])(uerei|uerás|uerá|ueremos|uereis)(?![-\\w–\xad])', 'Vocês \\1uerão', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_50") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbuer_5>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerão)(?![-\\w–\xad])', 'A gente \\1uerá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_5") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbuer_i>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerão)(?![-\\w–\xad])', '\\1 \\2uerá', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_i") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbuer_j>[a-z]+[g])(uerei|uerás|uerá|uereis)(?![-\\w–\xad])', '\\1 \\2uerão\\n\\1 \\2ueremos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_j") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbxer_61>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', 'Eu \\1eria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_61") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbxer_62>[a-z]+[bdhilmnoprstuvxz])(eria|eríamos|eríeis|eriam)(?![-\\w–\xad])', 'Tu \\1erias', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_62") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbxer_63>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', 'Ele \\1eria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_63") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbxer_64>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', 'Ela \\1eria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_64") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbxer_65>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', 'Você \\1eria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_65") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbxer_66>[a-z]+[bdhilmnoprstuvxz])(eria|erias|eríeis|eriam)(?![-\\w–\xad])', 'Nós \\1eríamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_66") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbxer_67>[a-z]+[bdhilmnoprstuvxz])(eria|erias|eríamos|eriam)(?![-\\w–\xad])', 'Vós \\1eríeis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_67") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbxer_68>[a-z]+[bdhilmnoprstuvxz])(eria|erias|eríamos|eríeis)(?![-\\w–\xad])', 'Eles \\1eriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_68") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbxer_69>[a-z]+[bdhilmnoprstuvxz])(eria|erias|eríamos|eríeis)(?![-\\w–\xad])', 'Elas \\1eriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_69") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbxer_60>[a-z]+[bdhilmnoprstuvxz])(eria|erias|eríamos|eríeis)(?![-\\w–\xad])', 'Vocês \\1eriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_60") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbxer_6>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', 'A gente \\1eria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_6") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbxer_k>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', '\\1 \\2eria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_k") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbxer_l>[a-z]+[bdhilmnoprstuvxz])(eria|erias|eríeis)(?![-\\w–\xad])', '\\1 \\2eriam\\n\\1 \\2eríamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbxer_l") in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbcer_61>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', 'Eu \\1ceria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_61") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbcer_62>[a-z]+)(ceria|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', 'Tu \\1cerias', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_62") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbcer_63>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', 'Ele \\1ceria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_63") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbcer_64>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', 'Ela \\1ceria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_64") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbcer_65>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', 'Você \\1ceria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_65") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbcer_66>[a-z]+)(ceria|cerias|ceríeis|ceriam)(?![-\\w–\xad])', 'Nós \\1ceríamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_66") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbcer_67>[a-z]+)(ceria|cerias|ceríamos|ceriam)(?![-\\w–\xad])', 'Vós \\1ceríeis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_67") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbcer_68>[a-z]+)(ceria|cerias|ceríamos|ceríeis)(?![-\\w–\xad])', 'Eles \\1ceriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_68") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbcer_69>[a-z]+)(ceria|cerias|ceríamos|ceríeis)(?![-\\w–\xad])', 'Elas \\1ceriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_69") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbcer_60>[a-z]+)(ceria|cerias|ceríamos|ceríeis)(?![-\\w–\xad])', 'Vocês \\1ceriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_60") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbcer_6>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', 'A gente \\1ceria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_6") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbcer_k>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', '\\1 \\2ceria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_k") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbcer_l>[a-z]+)(ceria|cerias|ceríeis)(?![-\\w–\xad])', '\\1 \\2ceriam\\n\\1 \\2ceríamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbcer_l") in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbger_61>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', 'Eu \\1geria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_61") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbger_62>[a-z]+)(geria|geríamos|geríeis|geriam)(?![-\\w–\xad])', 'Tu \\1gerias', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_62") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbger_63>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', 'Ele \\1geria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_63") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbger_64>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', 'Ela \\1geria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_64") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbger_65>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', 'Você \\1geria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_65") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbger_66>[a-z]+)(geria|gerias|geríeis|geriam)(?![-\\w–\xad])', 'Nós \\1geríamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_66") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbger_67>[a-z]+)(geria|gerias|geríamos|geriam)(?![-\\w–\xad])', 'Vós \\1geríeis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_67") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbger_68>[a-z]+)(geria|gerias|geríamos|geríeis)(?![-\\w–\xad])', 'Eles \\1geriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_68") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbger_69>[a-z]+)(geria|gerias|geríamos|geríeis)(?![-\\w–\xad])', 'Elas \\1geriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_69") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbger_60>[a-z]+)(geria|gerias|geríamos|geríeis)(?![-\\w–\xad])', 'Vocês \\1geriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_60") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbger_6>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', 'A gente \\1geria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_6") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbger_k>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', '\\1 \\2geria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_k") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbger_l>[a-z]+)(geria|gerias|geríeis)(?![-\\w–\xad])', '\\1 \\2geriam\\n\\1 \\2geríamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbger_l") in plvrVbrger and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (?P<vbuer_61>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', 'Eu \\1ueria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_61") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (?P<vbuer_62>[a-z]+[g])(ueria|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', 'Tu \\1uerias', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_62") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (?P<vbuer_63>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', 'Ele \\1ueria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_63") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (?P<vbuer_64>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', 'Ela \\1ueria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_64") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (?P<vbuer_65>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', 'Você \\1ueria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_65") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<vbuer_66>[a-z]+[g])(ueria|uerias|ueríeis|ueriam)(?![-\\w–\xad])', 'Nós \\1ueríamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_66") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (?P<vbuer_67>[a-z]+[g])(ueria|uerias|ueríamos|ueriam)(?![-\\w–\xad])', 'Vós \\1ueríeis', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_67") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (?P<vbuer_68>[a-z]+[g])(ueria|uerias|ueríamos|ueríeis)(?![-\\w–\xad])', 'Eles \\1ueriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_68") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (?P<vbuer_69>[a-z]+[g])(ueria|uerias|ueríamos|ueríeis)(?![-\\w–\xad])', 'Elas \\1ueriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_69") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (?P<vbuer_60>[a-z]+[g])(ueria|uerias|ueríamos|ueríeis)(?![-\\w–\xad])', 'Vocês \\1ueriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_60") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (?P<vbuer_6>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', 'A gente \\1ueria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_6") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Alguém|Ninguém|Todo mundo|Qualquer um) (?P<vbuer_k>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', '\\1 \\2ueria', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_k") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Todos|Todas) (?P<vbuer_l>[a-z]+[g])(ueria|uerias|ueríeis)(?![-\\w–\xad])', '\\1 \\2ueriam\\n\\1 \\2ueríamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("vbuer_l") in plvrVbruer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Quando|quando|se|Se|Quem|quem) (você|ela|ele|eu|lhe|me|alguém|ninguém) (?P<Cvbs_1>[a-z]+[eoô]r)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + ccvbFsvo[m.group(3)]', 'Você quis dizer:', 'm.group("Cvbs_1").lower() in aavbFsvo and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Quando|quando|se|Se|Quem|quem) (vocês|elas|eles|lhes) (?P<Cvbs_2>[a-z]+[eoô]r)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + ccvbFsvo[m.group(3)] + "em"', 'Você quis dizer:', 'm.group("Cvbs_2").lower() in aavbFsvo and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Quando|quando|se|Se|Quem|quem) nós (?P<Cvbs_3>[a-z]+[eoô]r)(?![-\\w–\xad])', '= m.group(1) + " nós " + ccvbFsvo[m.group(2)] + "mos"', 'Você quis dizer:', 'm.group("Cvbs_3").lower() in aavbFsvo and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Quando|quando|se|Se|Quem|quem) nós (?P<Cvbs_4>[a-z]+[eoô]r)mos(?![-\\w–\xad])', '= m.group(1) + " nós " + ccvbFsvo[m.group(2)] + "mos"', 'Você quis dizer:', 'm.group("Cvbs_4").lower() in aavbFsvo and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Quando|quando|se|Se|Quem|quem) a gente (?P<Cvbs_5>[a-z]+[eoô]r)(?![-\\w–\xad])', '= m.group(1) + " a gente " + ccvbFsvo[m.group(2)]', 'Você quis dizer:', 'm.group("Cvbs_5").lower() in aavbFsvo and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Quem|quem) (?P<Cvbs_6>[a-z]+[eoô]r)(?![-\\w–\xad])', '= m.group(1) + " " + ccvbFsvo[m.group(2)]', 'Você quis dizer:', 'm.group("Cvbs_6").lower() in aavbFsvo and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Quando|quando|se|Se|Quem|quem) (o|a) (?P<Cvbs_7>[a-zA-Záâçéêíóôúã]+) (?P<Cvbs_8>[a-z]+[eoô]r)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + " " + ccvbFsvo[m.group(4)]', 'Você quis dizer:', 'm.group("Cvbs_8").lower() in aavbFsvo and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Quando|quando|se|Se|Quem|quem) (?P<Cvbs_9>[A-Z][a-záâçéêíóôúã]+) (?P<Cvbs_10>[a-z]+[eoô]r)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + ccvbFsvo[m.group(3)]', 'Você quis dizer:', 'm.group("Cvbs_10").lower() in aavbFsvo and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Quando|quando|se|Se|Quem|quem) (você|ela|ele|eu|lhe|me|alguém|ninguém) (não|já|ainda) (?P<Cvbs_11>[a-z]+[eoô]r)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + " " + ccvbFsvo[m.group(4)]', 'Você quis dizer:', 'm.group("Cvbs_11").lower() in aavbFsvo and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmart_0>[A-Za-z]+)s (?P<Msvb_1>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msvb_2>[a-zA-Záâãçéêíóôú]+) (?P<Msvb_3>[a-zA-Zçáéíóúâêô]+)[ao]s(?![-\\w–\xad])', '= varGenero[m.group(1)] +"s " + m.group(2) + "s " + aaVblgtpp[m.group(3)] + " " + m.group(4) + "os"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvb_1").lower() in plvrMasco and m.group("Msvb_3").lower() in plvrMfoa and m.group("Msvb_2").lower() in ccVblgstpp and m.group("Pmart_0") in ahSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmart_1>[A-Za-z]+) (?P<Msvb_4>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msvb_5>[a-zA-Záâãçéêíóôú]+) (?P<Msvb_6>[a-zA-Zçáéíóúâêô]+)[ao](?![-\\w–\xad])', '= varGenero[m.group(1)] +" " + m.group(2) + " " + aaVblgtps[m.group(3)] + " " + m.group(4) + "o"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvb_4").lower() in plvrMasco and m.group("Msvb_6").lower() in plvrMfoa and m.group("Msvb_5").lower() in ccVblgstps and m.group("Pmart_1") in ahSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmart_2>[A-Za-z]+) (?P<Msvb_7>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msvb_8>[a-zA-Záâãçéêíóôú]+) (?P<Msvb_9>[a-zA-Záâãçéêíóôú]+)os(?![-\\w–\xad])', '= varGenero[m.group(1)] +" " + m.group(2) + " " + aaVblgtps[m.group(3)] + " " + m.group(4) + "o"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvb_7").lower() in plvrMasco and m.group("Msvb_9").lower() in plvrMfoa and m.group("Msvb_8").lower() in ccVblgcpt and m.group("Pmart_2") in ahSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmart_3>[A-Za-z]+)s (?P<Msvb_10>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msvb_11>[a-zA-Záâãçéêíóôú]+) (?P<Msvb_12>[a-zA-Záâãçéêíóôú]+)o(?![-\\w–\xad])', '= varGenero[m.group(1)] +"s " + m.group(2) + "s " + aaVblgtpp[m.group(3)] + " " + m.group(4) + "os"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvb_10").lower() in plvrMasco and m.group("Msvb_12").lower() in plvrMfoa and m.group("Msvb_11").lower() in ccVblgcpt and m.group("Pmart_3") in ahSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmart_4>[a-z]+)s (?P<Msvb_15>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msvb_16>[a-zA-Záâãçéêíóôú]+) (?P<Msvb_17>[a-zA-Zçáéíóúâêô]+)[ao]s(?![-\\w–\xad])', '= ", "+ varGenero[m.group(1)] +"s " + m.group(2) + "s " + aaVblgtpp[m.group(3)] + " " + m.group(4) + "os"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvb_15").lower() in plvrMasco and m.group("Msvb_17").lower() in plvrMfoa and m.group("Msvb_16").lower() in ccVblgstpp and m.group("Pmart_4") in abSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmart_5>[a-z]+) (?P<Msvb_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msvb_19>[a-zA-Záâãçéêíóôú]+) (?P<Msvb_20>[a-zA-Zçáéíóúâêô]+)[ao](?![-\\w–\xad])', '= ", " + varGenero[m.group(1)] +" " + m.group(2) + " " + aaVblgtps[m.group(3)] + " " + m.group(4) + "o"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvb_18").lower() in plvrMasco and m.group("Msvb_20").lower() in plvrMfoa and m.group("Msvb_19").lower() in ccVblgstps and m.group("Pmart_5") in abSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmart_6>[a-z]+) (?P<Msvb_21>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msvb_22>[a-zA-Záâãçéêíóôú]+) (?P<Msvb_23>[a-zA-Záâãçéêíóôú]+)[ao]s(?![-\\w–\xad])', '= ", " + varGenero[m.group(1)] +" " + m.group(2) + " " + aaVblgtps[m.group(3)] + " " + m.group(4) + "o"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvb_21").lower() in plvrMasco and m.group("Msvb_23").lower() in plvrMfoa and m.group("Msvb_22").lower() in ccVblgcpt and m.group("Pmart_6") in abSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmart_7>[a-z]+)s (?P<Msvb_24>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msvb_25>[a-zA-Záâãçéêíóôú]+) (?P<Msvb_26>[a-zA-Záâãçéêíóôú]+)o(?![-\\w–\xad])', '= ", " + varGenero[m.group(1)] +"s " + m.group(2) + "s " + aaVblgtpp[m.group(3)] + " " + m.group(4) + "os"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvb_24").lower() in plvrMasco and m.group("Msvb_26").lower() in plvrMfoa and m.group("Msvb_25").lower() in ccVblgcpt and m.group("Pmart_7") in abSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmort_1>[A-Za-z]+) (?P<Mavb_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mavb_2>[a-zA-Záâãçéêíóôú]+) (?P<Mavb_3>[a-zA-Záâãçéêíóôú]+)a(?![-\\w–\xad])', '= varGenero[m.group(1)] +" " + m.group(2) + " " + aaVblgtps[m.group(3)] + " " + m.group(4) + "o"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mavb_1").lower() in plvrMasco and m.group("Mavb_3").lower() in plvrMfoa and m.group("Mavb_2").lower() in ccVblgcpt and m.group("Pmort_1") in ahSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmort_2>[a-z]+) (?P<Mavb_4>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mavb_5>[a-zA-Záâãçéêíóôú]+) (?P<Mavb_6>[a-zA-Záâãçéêíóôú]+)a(?![-\\w–\xad])', '= ", " + varGenero[m.group(1)] +" " + m.group(2) + " " + aaVblgtps[m.group(3)] + " " + m.group(4) + "o"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mavb_4").lower() in plvrMasco and m.group("Mavb_6").lower() in plvrMfoa and m.group("Mavb_5").lower() in ccVblgcpt and m.group("Pmort_2") in abSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmart_8>[A-Za-z]+)s (?P<Msvb_30>[a-zA-Zçáéíóúâêô]+)os (?P<Msvb_31>[a-zA-Záâãçéêíóôú]+) (?P<Msvb_32>[a-zA-Zçáéíóúâêô]+)[ao]s(?![-\\w–\xad])', '= varGenero[m.group(1)] +"s " + m.group(2) + "os " + aaVblgtpp[m.group(3)] + " " + m.group(4) + "os"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvb_30").lower() in plvrMfoa and m.group("Msvb_32").lower() in plvrMfoa and m.group("Msvb_31").lower() in ccVblgstpp and m.group("Pmart_8") in ahSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmart_9>[A-Za-z]+) (?P<Msvb_33>[a-zA-Zçáéíóúâêô]+)o (?P<Msvb_34>[a-zA-Záâãçéêíóôú]+) (?P<Msvb_35>[a-zA-Zçáéíóúâêô]+)[ao](?![-\\w–\xad])', '= varGenero[m.group(1)] +" " + m.group(2) + "o " + aaVblgtps[m.group(3)] + " " + m.group(4) + "o"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvb_33").lower() in plvrMfoa and m.group("Msvb_35").lower() in plvrMfoa and m.group("Msvb_34").lower() in ccVblgstps and m.group("Pmart_9") in ahSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmart_10>[A-Za-z]+) (?P<Msvb_36>[a-zA-Zçáéíóúâêô]+)o (?P<Msvb_37>[a-zA-Záâãçéêíóôú]+) (?P<Msvb_38>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= varGenero[m.group(1)] +" " + m.group(2) + "o " + aaVblgtps[m.group(3)] + " " + m.group(4) + "o"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvb_36").lower() in plvrMfoa and m.group("Msvb_38").lower() in plvrMfoa and m.group("Msvb_37").lower() in ccVblgcpt and m.group("Pmart_10") in ahSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmart_11>[A-Za-z]+)s (?P<Msvb_39>[a-zA-Zçáéíóúâêô]+)os (?P<Msvb_40>[a-zA-Záâãçéêíóôú]+) (?P<Msvb_41>[a-zA-Záâãçéêíóôú]+)o(?![-\\w–\xad])', '= varGenero[m.group(1)] +"s " + m.group(2) + "os " + aaVblgtpp[m.group(3)] + " " + m.group(4) + "os"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvb_39").lower() in plvrMfoa and m.group("Msvb_41").lower() in plvrMfoa and m.group("Msvb_40").lower() in ccVblgcpt and m.group("Pmart_11") in ahSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msvb_42>[a-zA-Zçáéíóúâêô]+)o (?P<Msvb_43>[a-záâãçéêíóôú]+)os(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvb_42").lower() in plvrMfoa and m.group("Msvb_43").lower() in plvrMfoa and not " e o " + m.group("Msvb_42") in TEXT and not " e " + m.group("Msvb_42") in TEXT and not " de " + m.group("Msvb_42") in TEXT and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmart_13>[a-z]+)s (?P<Msvb_44>[a-zA-Zçáéíóúâêô]+)os (?P<Msvb_45>[a-zA-Záâãçéêíóôú]+) (?P<Msvb_46>[a-zA-Zçáéíóúâêô]+)[ao]s(?![-\\w–\xad])', '= ", "+ varGenero[m.group(1)] +"s " + m.group(2) + "os " + aaVblgtpp[m.group(3)] + " " + m.group(4) + "os"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvb_44").lower() in plvrMfoa and m.group("Msvb_46").lower() in plvrMfoa and m.group("Msvb_45").lower() in ccVblgstpp and m.group("Pmart_13") in abSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmart_14>[a-z]+) (?P<Msvb_47>[a-zA-Zçáéíóúâêô]+)o (?P<Msvb_48>[a-zA-Záâãçéêíóôú]+) (?P<Msvb_49>[a-zA-Zçáéíóúâêô]+)[ao](?![-\\w–\xad])', '= ", " + varGenero[m.group(1)] +" " + m.group(2) + "o " + aaVblgtps[m.group(3)] + " " + m.group(4) + "o"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvb_47").lower() in plvrMfoa and m.group("Msvb_49").lower() in plvrMfoa and m.group("Msvb_48").lower() in ccVblgstps and m.group("Pmart_14") in abSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmart_15>[a-z]+) (?P<Msvb_50>[a-zA-Zçáéíóúâêô]+)o (?P<Msvb_51>[a-zA-Záâãçéêíóôú]+) (?P<Msvb_52>[a-zA-Záâãçéêíóôú]+)[ao]s(?![-\\w–\xad])', '= ", " + varGenero[m.group(1)] +" " + m.group(2) + "o " + aaVblgtps[m.group(3)] + " " + m.group(4) + "o"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvb_50").lower() in plvrMfoa and m.group("Msvb_52").lower() in plvrMfoa and m.group("Msvb_51").lower() in ccVblgcpt and m.group("Pmart_15") in abSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmart_16>[a-z]+)s (?P<Msvb_53>[a-zA-Zçáéíóúâêô]+)os (?P<Msvb_54>[a-zA-Záâãçéêíóôú]+) (?P<Msvb_55>[a-zA-Záâãçéêíóôú]+)o(?![-\\w–\xad])', '= ", "+ varGenero[m.group(1)] +"s " + m.group(2) + "os " + aaVblgtpp[m.group(3)] + " " + m.group(4) + "os"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvb_53").lower() in plvrMfoa and m.group("Msvb_55").lower() in plvrMfoa and m.group("Msvb_54").lower() in ccVblgcpt and m.group("Pmart_16") in abSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmort_1>[A-Za-z]+) (?P<Mavb_10>[a-zA-Zçáéíóúâêô]+)o (?P<Mavb_11>[a-zA-Záâãçéêíóôú]+) (?P<Mavb_12>[a-zA-Záâãçéêíóôú]+)a(?![-\\w–\xad])', '= varGenero[m.group(1)] +" " + m.group(2) + "o " + aaVblgtps[m.group(3)] + " " + m.group(4) + "o"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mavb_10").lower() in plvrMfoa and m.group("Mavb_12").lower() in plvrMfoa and m.group("Mavb_11").lower() in ccVblgcpt and m.group("Pmort_1") in ahSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmort_2>[a-z]+) (?P<Mavb_13>[a-zA-Zçáéíóúâêô]+)o (?P<Mavb_14>[a-zA-Záâãçéêíóôú]+) (?P<Mavb_15>[a-zA-Záâãçéêíóôú]+)a(?![-\\w–\xad])', '= ", " + varGenero[m.group(1)] +" " + m.group(2) + "o " + aaVblgtps[m.group(3)] + " " + m.group(4) + "o"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mavb_13").lower() in plvrMfoa and m.group("Mavb_15").lower() in plvrMfoa and m.group("Mavb_14").lower() in ccVblgcpt and m.group("Pmort_2") in abSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmolt_1>[A-Za-z]+) (?P<Mavb_1>[a-zA-Záâãçéêíóôú]+[a]) (?P<Mavb_2>[a-zA-Záâãçéêíóôú]+) (?P<Mavb_3>[a-zA-Záâãçéêíóôú]+)o(?![-\\w–\xad])', '= m.group(1) +" " + m.group(2) + " " + aaVblgtps[m.group(3)] + " " + m.group(4) + "a"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mavb_1").lower() in plvrFema and m.group("Mavb_3").lower() in plvrMfoa and m.group("Mavb_2").lower() in ccVblgcpt and m.group("Pmolt_1") in ajSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmolt_2>[a-z]+) (?P<Mavb_4>[a-zA-Záâãçéêíóôú]+[a]) (?P<Mavb_5>[a-zA-Záâãçéêíóôú]+) (?P<Mavb_6>[a-zA-Záâãçéêíóôú]+)o(?![-\\w–\xad])', '= ", " + m.group(1) +" " + m.group(2) + " " + aaVblgtps[m.group(3)] + " " + m.group(4) + "a"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mavb_4").lower() in plvrFema and m.group("Mavb_6").lower() in plvrMfoa and m.group("Mavb_5").lower() in ccVblgcpt and m.group("Pmolt_2") in acSingular and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])carret(\\w+) em(?![-\\w–\xad])', '\\1carret\\2', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])mplic(\\w+) em(?![-\\w–\xad])', '\\1mplic\\2', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])mpliq(\\w+) em(?![-\\w–\xad])', '\\1mpliq\\2', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])carret(\\w+) n(a|as|o|os)(?![-\\w–\xad])', '\\1carret\\2 \\3', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])mplic(\\w+) n(a|as|o|os)(?![-\\w–\xad])', '\\1mplic\\2 \\3', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'not "implica"+"ç"+"õ"+ "es n" in TEXT and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])mpliq(\\w+) n(a|as|o|os)(?![-\\w–\xad])', '\\1mpliq\\2 \\3', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])carret(\\w+) também em(?![-\\w–\xad])', '\\1carret\\2 também', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])mplic(\\w+) também em(?![-\\w–\xad])', '\\1mplic\\2 também', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])mpliq(\\w+) também em(?![-\\w–\xad])', '\\1mpliq\\2 também', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])carret(\\w+) também n(a|as|o|os)(?![-\\w–\xad])', '\\1carret\\2 também \\3', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])mplic(\\w+) também n(a|as|o|os)(?![-\\w–\xad])', '\\1mplic\\2 também \\3', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'not "implica"+"ç"+"õ"+ "es n" in TEXT and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])mpliq(\\w+) também n(a|as|o|os)(?![-\\w–\xad])', '\\1mpliq\\2 também \\3', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])carret(\\w+), também, em(?![-\\w–\xad])', '\\1carret\\2, também,', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])mplic(\\w+), também, em(?![-\\w–\xad])', '\\1mplic\\2, também,', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])mpliq(\\w+), também, em(?![-\\w–\xad])', '\\1mpliq\\2, também,', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])carret(\\w+), também, n(a|as|o|os)(?![-\\w–\xad])', '\\1carret\\2, também, \\3', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])mplic(\\w+), também, n(a|as|o|os)(?![-\\w–\xad])', '\\1mplic\\2, também, \\3', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'not "implica"+"ç"+"õ"+ "es n" in TEXT and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Ii])mpliq(\\w+), também, n(a|as|o|os)(?![-\\w–\xad])', '\\1mpliq\\2, também, \\3', 'Uso inapropriado da preposição "EM". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])bede([cç])(\\w+) o(?![-\\w–\xad])', '\\1bede\\2\\3 ao', 'Obedecer é um verbo transitivo indireto e necessita do uso da preposição "A". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])bede([cç])(\\w+) os(?![-\\w–\xad])', '\\1bede\\2\\3 aos', 'Obedecer é um verbo transitivo indireto e necessita do uso da preposição "A". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])esobede([cç])(\\w+) o(?![-\\w–\xad])', '\\1esobede\\2\\3 ao', 'Desobedecer é um verbo transitivo indireto e necessita do uso da preposição "A". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])esobede([cç])(\\w+) os(?![-\\w–\xad])', '\\1esobede\\2\\3 aos', 'Desobedecer é um verbo transitivo indireto e necessita do uso da preposição "A". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])bede([cç])(\\w+) a(?![-\\w–\xad])', '\\1bede\\2\\3 à', 'Obedecer é um verbo transitivo indireto e necessita do uso da preposição "A". Você quis dizer:', 'not excobdc.search(TEXT) and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])bede([cç])(\\w+) as(?![-\\w–\xad])', '\\1bede\\2\\3 às', 'Obedecer é um verbo transitivo indireto e necessita do uso da preposição "A". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])esobede([cç])(\\w+) a(?![-\\w–\xad])', '\\1esobede\\2\\3 à', 'Desobedecer é um verbo transitivo indireto e necessita do uso da preposição "A". Você quis dizer:', 'not excobdc.search(TEXT) and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])esobede([cç])(\\w+) as(?![-\\w–\xad])', '\\1esobede\\2\\3 às', 'Desobedecer é um verbo transitivo indireto e necessita do uso da preposição "A". Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])epet([aieo]|[a-zéãíá]+) de ano(?![-\\w–\xad])', '\\1epet\\2 o ano', 'O verbo repetir é transitivo direto e dispensa a preposição de. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uando|[Qq]ue|[Ss]e) tu veres(?![-\\w–\xad])', '\\1 tu vires', '= "O verbo ver, quando usado no futuro do subjuntivo, precedido de -" + aaVer[m.group(1)] + "-, assume a forma vir. Você quis dizer:"', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uando|[Qq]ue|[Ss]e) tu ([ao]) veres(?![-\\w–\xad])', '\\1uando tu \\2 vires', '= "O verbo ver, quando usado no futuro do subjuntivo, precedido de -" + aaVer[m.group(1)] + "-, assume a forma vir. Você quis dizer:"', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uando|[Qq]ue|[Ss]e) tu ([ao])s veres(?![-\\w–\xad])', '\\1uando tu \\2s vires', '= "O verbo ver, quando usado no futuro do subjuntivo, precedido de -" + aaVer[m.group(1)] + "-, assume a forma vir. Você quis dizer:"', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uando|[Qq]ue|[Ss]e) (eu|ele|ela|você|alguém|ninguém) ver(?![-\\w–\xad])', '\\1 \\2 vir', '= "O verbo ver, quando usado no futuro do subjuntivo, precedido de -" + aaVer[m.group(1)] + "-, assume a forma vir. Você quis dizer:"', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uando|[Qq]ue|[Ss]e) (eu|ele|ela|você|alguém|ninguém) ([ao]) ver(?![-\\w–\xad])', '\\1 \\2 \\3 vir', '= "O verbo ver, quando usado no futuro do subjuntivo, precedido de -" + aaVer[m.group(1)] + "-, assume a forma vir. Você quis dizer:"', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uando|[Qq]ue|[Ss]e) (eu|ele|ela|você|alguém|ninguém) ([ao])s ver(?![-\\w–\xad])', '\\1 \\2 \\3s vir', '= "O verbo ver, quando usado no futuro do subjuntivo, precedido de -" + aaVer[m.group(1)] + "-, assume a forma vir. Você quis dizer:"', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uando|[Qq]ue|[Ss]e) ([ao]) (?P<wir_1>[a-záâçéêíóôú]+) ver(?![-\\w–\xad])', '\\1 \\2 \\3 vir', '= "O verbo ver, quando usado no futuro do subjuntivo, precedido de -" + aaVer[m.group(1)] + "-, assume a forma vir. Você quis dizer:"', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uando|[Qq]ue|[Ss]e) (?P<wir_2>[A-Z][a-záâçéêíóôú]+) ver(?![-\\w–\xad])', '\\1 \\2 vir', '= "O verbo ver, quando usado no futuro do subjuntivo, precedido de -" + aaVer[m.group(1)] + "-, assume a forma vir. Você quis dizer:"', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uando|[Qq]ue|[Ss]e) nós vermos(?![-\\w–\xad])', '\\1 eu virmos', '= "O verbo ver, quando usado no futuro do subjuntivo, precedido de -" + aaVer[m.group(1)] + "-, assume a forma vir. Você quis dizer:"', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uando|[Qq]ue|[Ss]e) nós ([ao]) vermos(?![-\\w–\xad])', '\\1 eu \\2 virmos', '= "O verbo ver, quando usado no futuro do subjuntivo, precedido de -" + aaVer[m.group(1)] + "-, assume a forma vir. Você quis dizer:"', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uando|[Qq]ue|[Ss]e) nós ([ao])s vermos(?![-\\w–\xad])', '\\1 eu \\2s virmos', '= "O verbo ver, quando usado no futuro do subjuntivo, precedido de -" + aaVer[m.group(1)] + "-, assume a forma vir. Você quis dizer:"', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uando|[Qq]ue|[Ss]e) (eles|elas|vocês|todas|todos) verem(?![-\\w–\xad])', '\\1 \\2 virem', '= "O verbo ver, quando usado no futuro do subjuntivo, precedido de -" + aaVer[m.group(1)] + "-, assume a forma vir. Você quis dizer:"', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uando|[Qq]ue|[Ss]e) (eles|elas|vocês|todas|todos) ([ao]) verem(?![-\\w–\xad])', '\\1 \\2 \\3 virem', '= "O verbo ver, quando usado no futuro do subjuntivo, precedido de -" + aaVer[m.group(1)] + "-, assume a forma vir. Você quis dizer:"', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uando|[Qq]ue|[Ss]e) (eles|elas|vocês|todas|todos) ([ao])s verem(?![-\\w–\xad])', '\\1 \\2 \\3s virem', '= "O verbo ver, quando usado no futuro do subjuntivo, precedido de -" + aaVer[m.group(1)] + "-, assume a forma vir. Você quis dizer:"', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uando|[Qq]ue|[Ss]e) ([ao]) (?P<wir_1>[a-záâçéêíóôú]+) verem(?![-\\w–\xad])', '\\1 \\2 \\3 virem', '= "O verbo ver, quando usado no futuro do subjuntivo, precedido de -" + aaVer[m.group(1)] + "-, assume a forma vir. Você quis dizer:"', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq]uando|[Qq]ue|[Ss]e) (?P<wir_2>[A-Z][a-záâçéêíóôú]+) verem(?![-\\w–\xad])', '\\1 \\2 virem', '= "O verbo ver, quando usado no futuro do subjuntivo, precedido de -" + aaVer[m.group(1)] + "-, assume a forma vir. Você quis dizer:"', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(^)([n])ós (?P<pnos_0>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= "Nós " + aacpNos[m.group(3)] + "\\n" + aacpNos[m.group("pnos_0")].capitalize() + "\\nA gente " + m.group(3) + "\\nEla " + m.group(3) + "\\nEle " + m.group(3)', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_0") in concNos and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (?P<pnos_1>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= "Nós " + aacpNos[m.group(1)] + "\\n" + aacpNos[m.group("pnos_1")].capitalize() + "\\nA gente " + m.group(1) + "\\nEla " + m.group(1) + "\\nEle " + m.group(1)', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_1") in concNos and option(LOCALE,"verbo")'],
 ['(?u)\\b([,]) nós (?P<pnos_2>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= ", nós " + aacpNos[m.group("pnos_2")] + "\\n, " + aacpNos[m.group("pnos_2")]', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_2") in concNos and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(^)([n])ós não (?P<pnos_3>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= "Nós n\ão " + aacpNos[m.group(3)] + "\\nN\ão " + aacpNos[m.group("pnos_3")] + "\\nA gente n\ão " + m.group(3) + "\\nEla n\ão " + m.group(3) + "\\nEle n\ão " + m.group(3)', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_3") in concNos and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós não (?P<pnos_4>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= "Nós n\ão " + aacpNos[m.group(1)] + "\\nN\ão " + aacpNos[m.group("pnos_4")] + "\\nA gente n\ão " + m.group(1) + "\\nEla n\ão " + m.group(1) + "\\nEle n\ão " + m.group(1)', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_4") in concNos and option(LOCALE,"verbo")'],
 ['(?u)\\b([,]) nós não (?P<pnos_5>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= ", nós n\ão " + aacpNos[m.group("pnos_5")] + "\\n, n\ão " + aacpNos[m.group("pnos_5")]', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_5") in concNos and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(^)([n])ós já (?P<pnos_6>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= "Nós j\á " + aacpNos[m.group(3)] + "\\nJ\á " + aacpNos[m.group("pnos_6")] + "\\nA gente j\á " + m.group(3) + "\\nEla j\á " + m.group(3) + "\\nEle j\á " + m.group(3)', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_6") in concNos and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós já (?P<pnos_7>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= "Nós j\á " + aacpNos[m.group(1)] + "\\nJ\á " + aacpNos[m.group("pnos_7")] + "\\nA gente j\á " + m.group(1) + "\\nEla j\á " + m.group(1) + "\\nEle j\á " + m.group(1)', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_7") in concNos and option(LOCALE,"verbo")'],
 ['(?u)\\b([,]) nós já (?P<pnos_8>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= ", nós j\á " + aacpNos[m.group("pnos_8")] + "\\n, j\á " + aacpNos[m.group("pnos_8")]', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_8") in concNos and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(^)([n])ós nunca (?P<pnos_9>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= "Nós nunca " + aacpNos[m.group(3)] + "\\nNunca " + aacpNos[m.group("pnos_9")] + "\\nA gente nunca " + m.group(3) + "\\nEla nunca " + m.group(3) + "\\nEle nunca " + m.group(3)', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_9") in concNos and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós nunca (?P<pnos_10>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= "Nós nunca " + aacpNos[m.group(1)] + "\\nNunca " + aacpNos[m.group("pnos_10")] + "\\nA gente nunca " + m.group(1) + "\\nEla nunca " + m.group(1) + "\\nEle nunca " + m.group(1)', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_10") in concNos and option(LOCALE,"verbo")'],
 ['(?u)\\b([,]) nós nunca (?P<pnos_11>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= ", nós nunca " + aacpNos[m.group("pnos_11")] + "\\n, nunca " + aacpNos[m.group("pnos_11")]', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_11") in concNos and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(^)([n])ós ainda (?P<pnos_12>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= "Nós ainda " + aacpNos[m.group(3)] + "\\nAinda " + aacpNos[m.group("pnos_12")] + "\\nA gente ainda " + m.group(3) + "\\nEla ainda " + m.group(3) + "\\nEle ainda " + m.group(3)', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_12") in concNos and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós ainda (?P<pnos_13>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= "Nós ainda" + aacpNos[m.group(1)] + "\\nAinda " + aacpNos[m.group("pnos_13")] + "\\nA gente ainda " + m.group(1) + "\\nEla ainda " + m.group(1) + "\\nEle ainda " + m.group(1)', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_13") in concNos and option(LOCALE,"verbo")'],
 ['(?u)\\b([,]) nós ainda (?P<pnos_14>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= ", nós ainda " + aacpNos[m.group("pnos_14")] + "\\n, ainda " + aacpNos[m.group("pnos_14")]', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_14") in concNos and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Quand|quand)o ([n])ós (?P<pnos_15>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "o nós " + aacpNos[m.group(3)]', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_15") in concNos and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|qu)e ([n])ós (?P<pnos_16>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "e nós " + aacpNos[m.group(3)]', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_16") in concNos and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(^)([n])ós ainda não (?P<pnos_17>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= "Nós ainda n\ão " + aacpNos[m.group(3)] + "\\nAinda n\ão " + aacpNos[m.group("pnos_17")] + "\\n A gente ainda n\ão " + m.group(3) + "\\n Ela ainda n\ão " + m.group(3) + "\\n Ele ainda n\ão " + m.group(3)', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_17") in concNos and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós ainda não (?P<pnos_18>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= "Nós ainda n\ão " + aacpNos[m.group(1)] + "\\nAinda n\ão " + aacpNos[m.group("pnos_18")] + "\\nA gente ainda n\ão " + m.group(1) + "\\nEla ainda n\ão " + m.group(1) + "\\nEle ainda n\ão " + m.group(1)', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_18") in concNos and option(LOCALE,"verbo")'],
 ['(?u)\\b([,]) nós ainda não (?P<pnos_19>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= ", ainda nós n\ão " + aacpNos[m.group("pnos_19")] + "\\n, ainda n\ão " + aacpNos[m.group("pnos_19")]', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_19") in concNos and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(^)([n])ós jamais (?P<pnos_20>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= "Nós jamais " + aacpNos[m.group(3)] + "\\nJamais " + aacpNos[m.group("pnos_20")] + "\\n A gente jamais " + m.group(3) + "\\n Ela jamais " + m.group(3) + "\\n Ele jamais " + m.group(3)', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_20") in concNos and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós jamais (?P<pnos_21>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= "Nós jamais " + aacpNos[m.group(1)] + "\\nJamais " + aacpNos[m.group("pnos_21")] + "\\nA gente jamais " + m.group(1) + "\\nEla jamais " + m.group(1) + "\\nEle jamais " + m.group(1)', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_21") in concNos and option(LOCALE,"verbo")'],
 ['(?u)\\b([,]) nós jamais (?P<pnos_22>[a-záâçéêíóôú]+)(?![-\\w–\xad])', '= ", nós jamais " + aacpNos[m.group("pnos_22")] + "\\n, jamais " + aacpNos[m.group("pnos_22")]', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnos_22") in concNos and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Nenhum|nenhum|Qual|qual|Um|um|Quem|quem) de nós (?P<pnle_1>[a-záâçéêíóôú]+s)(?![-\\w–\xad])', '= m.group(1) + " de nós " + aacpEle[m.group(2)]', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnle_1") in concEle and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Nenhum|nenhum|Qual|qual|Um|um|Quem|quem) de nós nunca (?P<pnle_2>[a-záâçéêíóôú]+s)(?![-\\w–\xad])', '= m.group(1) + " de nós nunca " + aacpEle[m.group(2)]', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnle_2") in concEle and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Nenhum|nenhum|Qual|qual|Um|um|Quem|quem) de nós jamais (?P<pnle_3>[a-záâçéêíóôú]+s)(?![-\\w–\xad])', '= m.group(1) + " de nós jamais " + aacpEle[m.group(2)]', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnle_3") in concEle and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Nenhum|nenhum|Qual|qual|Um|um|Quem|quem) de nós sequer (?P<pnle_4>[a-záâçéêíóôú]+s)(?![-\\w–\xad])', '= m.group(1) + " de nós sequer " + aacpEle[m.group(2)]', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnle_4") in concEle and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Nenhum|nenhum|Qual|qual|Um|um|Quem|quem) de nós se (?P<pnle_5>[a-záâçéêíóôú]+s)(?![-\\w–\xad])', '= m.group(1) + " de nós sequer " + aacpEle[m.group(2)]', 'Pronome não concorda com o verbo. Você quis dizer:', 'm.group("pnle_5") in concEle and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (vais|vai|vamos|ides|vão)(?![-\\w–\xad])', 'Eu vo', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (vou|vai|vamos|ides|vão)(?![-\\w–\xad])', 'Tu vais', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', 'Ele vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', 'Ela vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', 'Você vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Isso (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', 'Isso vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (vou|vais|vai|ides|vão)(?![-\\w–\xad])', 'Nós vamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (vou|vais|vai|vamos|vão)(?![-\\w–\xad])', 'Vós ides', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (vou|vais|vai|vamos|ides)(?![-\\w–\xad])', 'Eles vão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (vou|vais|vai|vamos|ides)(?![-\\w–\xad])', 'Elas vão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (vou|vais|vai|vamos|ides)(?![-\\w–\xad])', 'Vocês vão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', 'A gente vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (és|é|somos|sois|são)(?![-\\w–\xad])', 'Eu so', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (sou|é|somos|sois|são)(?![-\\w–\xad])', 'Tu és', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (sou|és|somos|sois|são)(?![-\\w–\xad])', 'Ele é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (sou|és|somos|sois|são)(?![-\\w–\xad])', 'Ela é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (sou|és|somos|sois|são)(?![-\\w–\xad])', 'Você é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Isso (sou|és|somos|sois|são)(?![-\\w–\xad])', 'Isso é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (sou|és|é|sois|são)(?![-\\w–\xad])', 'Nós somos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (sou|és|é|somos|são)(?![-\\w–\xad])', 'Vós sois', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (sou|és|é|somos|sois)(?![-\\w–\xad])', 'Eles são', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (sou|és|é|somos|sois)(?![-\\w–\xad])', 'Elas são', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (sou|és|é|somos|sois)(?![-\\w–\xad])', 'Vocês são', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (sou|és|somos|sois|são)(?![-\\w–\xad])', 'A gente é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (eras|éramos|éreis|eram)(?![-\\w–\xad])', 'Eu era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (era|éramos|éreis|eram)(?![-\\w–\xad])', 'Tu eras', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (eras|éramos|éreis|eram)(?![-\\w–\xad])', 'Ele era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (eras|éramos|éreis|eram)(?![-\\w–\xad])', 'Ela era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (eras|éramos|éreis|eram)(?![-\\w–\xad])', 'Você era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Isso (eras|éramos|éreis|eram)(?![-\\w–\xad])', 'Isso era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (eras|era|éreis|eram)(?![-\\w–\xad])', 'Nós éramos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (eras|era|éramos|eram)(?![-\\w–\xad])', 'Vós éreis', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (eras|era|éramos|éreis)(?![-\\w–\xad])', 'Eles eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (eras|era|éramos|éreis)(?![-\\w–\xad])', 'Elas eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (eras|era|éramos|éreis)(?![-\\w–\xad])', 'Vocês eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (eras|éramos|éreis|eram)(?![-\\w–\xad])', 'A gente era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (foste|foi|fomos|fostes|foram)(?![-\\w–\xad])', 'Eu fui', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (fui|foi|fomos|fostes|foram)(?![-\\w–\xad])', 'Tu foste', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', 'Ele foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', 'Ela foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', 'Você foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Isso (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', 'Isso foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (fui|foste|foi|fostes|foram)(?![-\\w–\xad])', 'Nós fomos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (fui|foste|foi|fomos|foram)(?![-\\w–\xad])', 'Vós fostes', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (fui|foste|foi|fomos|fostes)(?![-\\w–\xad])', 'Eles foram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (fui|foste|foi|fomos|fostes)(?![-\\w–\xad])', 'Elas foram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (fui|foste|foi|fomos|fostes)(?![-\\w–\xad])', 'Vocês foram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', 'A gente foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (serás|será|seremos|sereis|serão)(?![-\\w–\xad])', 'Eu serei', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (serei|será|seremos|sereis|serão)(?![-\\w–\xad])', 'Tu serás', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', 'Ele será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', 'Ela será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', 'Você será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Isso (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', 'Isso será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (serei|serás|será|sereis|serão)(?![-\\w–\xad])', 'Nós seremos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (serei|serás|será|seremos|serão)(?![-\\w–\xad])', 'Vós sereis', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (serei|serás|será|seremos|sereis)(?![-\\w–\xad])', 'Eles serão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (serei|serás|será|seremos|sereis)(?![-\\w–\xad])', 'Elas serão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (serei|serás|será|seremos|sereis)(?![-\\w–\xad])', 'Vocês serão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', 'A gente será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', 'Eu seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (seria|seríamos|seríeis|seriam)(?![-\\w–\xad])', 'Tu serias', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', 'Ele seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', 'Ela seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', 'Você seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Isso (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', 'Isso seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (serias|seria|seríeis|seriam)(?![-\\w–\xad])', 'Nós seríamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (serias|seria|seríamos|seriam)(?![-\\w–\xad])', 'Vós seríeis', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (serias|seria|seríamos|seríeis)(?![-\\w–\xad])', 'Eles seriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (serias|seria|seríamos|seríeis)(?![-\\w–\xad])', 'Elas seriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (serias|seria|seríamos|seríeis)(?![-\\w–\xad])', 'Vocês seriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', 'A gente seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
# mais particulas - (nao|ja|ainda|nunca|jamais|talvez)
 ['(?u)(?<![-\\w–.,\xad])Eu (não|já|ainda|nunca|jamais|talvez) (vais|vai|vamos|ides|vão)(?![-\\w–\xad])', 'Eu \\1 vo', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (não|já|ainda|nunca|jamais|talvez) (vou|vai|vamos|ides|vão)(?![-\\w–\xad])', 'Tu \\1 vais', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (não|já|ainda|nunca|jamais|talvez) (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', 'Ele \\1 vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (não|já|ainda|nunca|jamais|talvez) (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', 'Ela \\1 vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (não|já|ainda|nunca|jamais|talvez) (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', 'Você \\1 vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Isso (não|já|ainda|nunca|jamais|talvez) (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', 'Isso \\1 vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (não|já|ainda|nunca|jamais|talvez) (vou|vais|vai|ides|vão)(?![-\\w–\xad])', 'Nós \\1 vamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (não|já|ainda|nunca|jamais|talvez) (vou|vais|vai|vamos|vão)(?![-\\w–\xad])', 'Vós \\1 ides', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (não|já|ainda|nunca|jamais|talvez) (vou|vais|vai|vamos|ides)(?![-\\w–\xad])', 'Eles \\1 vão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (não|já|ainda|nunca|jamais|talvez) (vou|vais|vai|vamos|ides)(?![-\\w–\xad])', 'Elas \\1 vão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (não|já|ainda|nunca|jamais|talvez) (vou|vais|vai|vamos|ides)(?![-\\w–\xad])', 'Vocês \\1 vão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (não|já|ainda|nunca|jamais|talvez) (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', 'A gente \\1 vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (não|já|ainda|nunca|jamais|talvez) (és|é|somos|sois|são)(?![-\\w–\xad])', 'Eu \\1 so', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (não|já|ainda|nunca|jamais|talvez) (sou|é|somos|sois|são)(?![-\\w–\xad])', 'Tu \\1 és', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (não|já|ainda|nunca|jamais|talvez) (sou|és|somos|sois|são)(?![-\\w–\xad])', 'Ele \\1 é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (não|já|ainda|nunca|jamais|talvez) (sou|és|somos|sois|são)(?![-\\w–\xad])', 'Ela \\1 é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (não|já|ainda|nunca|jamais|talvez) (sou|és|somos|sois|são)(?![-\\w–\xad])', 'Você \\1 é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Isso (não|já|ainda|nunca|jamais|talvez) (sou|és|somos|sois|são)(?![-\\w–\xad])', 'Isso \\1 é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (não|já|ainda|nunca|jamais|talvez) (sou|és|é|sois|são)(?![-\\w–\xad])', 'Nós \\1 somos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (não|já|ainda|nunca|jamais|talvez) (sou|és|é|somos|são)(?![-\\w–\xad])', 'Vós \\1 sois', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (não|já|ainda|nunca|jamais|talvez) (sou|és|é|somos|sois)(?![-\\w–\xad])', 'Eles \\1 são', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (não|já|ainda|nunca|jamais|talvez) (sou|és|é|somos|sois)(?![-\\w–\xad])', 'Elas \\1 são', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (não|já|ainda|nunca|jamais|talvez) (sou|és|é|somos|sois)(?![-\\w–\xad])', 'Vocês \\1 são', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (não|já|ainda|nunca|jamais|talvez) (sou|és|somos|sois|são)(?![-\\w–\xad])', 'A gente \\1 é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (não|já|ainda|nunca|jamais|talvez) (eras|éramos|éreis|eram)(?![-\\w–\xad])', 'Eu \\1 era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (não|já|ainda|nunca|jamais|talvez) (era|éramos|éreis|eram)(?![-\\w–\xad])', 'Tu \\1 eras', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (não|já|ainda|nunca|jamais|talvez) (eras|éramos|éreis|eram)(?![-\\w–\xad])', 'Ele \\1 era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (não|já|ainda|nunca|jamais|talvez) (eras|éramos|éreis|eram)(?![-\\w–\xad])', 'Ela \\1 era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (não|já|ainda|nunca|jamais|talvez) (eras|éramos|éreis|eram)(?![-\\w–\xad])', 'Você \\1 era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Isso (não|já|ainda|nunca|jamais|talvez) (eras|éramos|éreis|eram)(?![-\\w–\xad])', 'Isso \\1 era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (não|já|ainda|nunca|jamais|talvez) (eras|era|éreis|eram)(?![-\\w–\xad])', 'Nós \\1 éramos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (não|já|ainda|nunca|jamais|talvez) (eras|era|éramos|eram)(?![-\\w–\xad])', 'Vós \\1 éreis', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (não|já|ainda|nunca|jamais|talvez) (eras|era|éramos|éreis)(?![-\\w–\xad])', 'Eles \\1 eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (não|já|ainda|nunca|jamais|talvez) (eras|era|éramos|éreis)(?![-\\w–\xad])', 'Elas \\1 eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (não|já|ainda|nunca|jamais|talvez) (eras|era|éramos|éreis)(?![-\\w–\xad])', 'Vocês \\1 eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (não|já|ainda|nunca|jamais|talvez) (eras|éramos|éreis|eram)(?![-\\w–\xad])', 'A gente \\1 era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (não|já|ainda|nunca|jamais|talvez) (foste|foi|fomos|fostes|foram)(?![-\\w–\xad])', 'Eu \\1 fui', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (não|já|ainda|nunca|jamais|talvez) (fui|foi|fomos|fostes|foram)(?![-\\w–\xad])', 'Tu \\1 foste', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (não|já|ainda|nunca|jamais|talvez) (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', 'Ele \\1 foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (não|já|ainda|nunca|jamais|talvez) (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', 'Ela \\1 foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (não|já|ainda|nunca|jamais|talvez) (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', 'Você \\1 foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Isso (não|já|ainda|nunca|jamais|talvez) (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', 'Isso \\1 foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (não|já|ainda|nunca|jamais|talvez) (fui|foste|foi|fostes|foram)(?![-\\w–\xad])', 'Nós \\1 fomos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (não|já|ainda|nunca|jamais|talvez) (fui|foste|foi|fomos|foram)(?![-\\w–\xad])', 'Vós \\1 fostes', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (não|já|ainda|nunca|jamais|talvez) (fui|foste|foi|fomos|fostes)(?![-\\w–\xad])', 'Eles \\1 foram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (não|já|ainda|nunca|jamais|talvez) (fui|foste|foi|fomos|fostes)(?![-\\w–\xad])', 'Elas \\1 foram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (não|já|ainda|nunca|jamais|talvez) (fui|foste|foi|fomos|fostes)(?![-\\w–\xad])', 'Vocês \\1 foram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (não|já|ainda|nunca|jamais|talvez) (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', 'A gente \\1 foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (não|já|ainda|nunca|jamais|talvez) (serás|será|seremos|sereis|serão)(?![-\\w–\xad])', 'Eu \\1 serei', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (não|já|ainda|nunca|jamais|talvez) (serei|será|seremos|sereis|serão)(?![-\\w–\xad])', 'Tu \\1 serás', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (não|já|ainda|nunca|jamais|talvez) (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', 'Ele \\1 será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (não|já|ainda|nunca|jamais|talvez) (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', 'Ela \\1 será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (não|já|ainda|nunca|jamais|talvez) (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', 'Você \\1 será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Isso (não|já|ainda|nunca|jamais|talvez) (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', 'Isso \\1 será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (não|já|ainda|nunca|jamais|talvez) (serei|serás|será|sereis|serão)(?![-\\w–\xad])', 'Nós \\1 seremos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (não|já|ainda|nunca|jamais|talvez) (serei|serás|será|seremos|serão)(?![-\\w–\xad])', 'Vós \\1 sereis', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (não|já|ainda|nunca|jamais|talvez) (serei|serás|será|seremos|sereis)(?![-\\w–\xad])', 'Eles \\1 serão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (não|já|ainda|nunca|jamais|talvez) (serei|serás|será|seremos|sereis)(?![-\\w–\xad])', 'Elas \\1 serão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (não|já|ainda|nunca|jamais|talvez) (serei|serás|será|seremos|sereis)(?![-\\w–\xad])', 'Vocês \\1 serão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (não|já|ainda|nunca|jamais|talvez) (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', 'A gente \\1 será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eu (não|já|ainda|nunca|jamais|talvez) (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', 'Eu \\1 seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Tu (não|já|ainda|nunca|jamais|talvez) (seria|seríamos|seríeis|seriam)(?![-\\w–\xad])', 'Tu \\1 serias', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ele (não|já|ainda|nunca|jamais|talvez) (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', 'Ele \\1 seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Ela (não|já|ainda|nunca|jamais|talvez) (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', 'Ela \\1 seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Você (não|já|ainda|nunca|jamais|talvez) (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', 'Você \\1 seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Isso (não|já|ainda|nunca|jamais|talvez) (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', 'Isso \\1 seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Nós (não|já|ainda|nunca|jamais|talvez) (serias|seria|seríeis|seriam)(?![-\\w–\xad])', 'Nós \\1 seríamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vós (não|já|ainda|nunca|jamais|talvez) (serias|seria|seríamos|seriam)(?![-\\w–\xad])', 'Vós \\1 seríeis', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Eles (não|já|ainda|nunca|jamais|talvez) (serias|seria|seríamos|seríeis)(?![-\\w–\xad])', 'Eles \\1 seriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Elas (não|já|ainda|nunca|jamais|talvez) (serias|seria|seríamos|seríeis)(?![-\\w–\xad])', 'Elas \\1 seriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])Vocês (não|já|ainda|nunca|jamais|talvez) (serias|seria|seríamos|seríeis)(?![-\\w–\xad])', 'Vocês \\1 seriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])A gente (não|já|ainda|nunca|jamais|talvez) (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', 'A gente \\1 seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
# fim particulas - (nao|ja|ainda|nunca|jamais|talvez)
# preposicao MAS - mais pronomes pessoais e demonstrativos
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eu (vais|vai|vamos|ides|vão)(?![-\\w–\xad])', '\\1as eu vo', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as tu (vou|vai|vamos|ides|vão)(?![-\\w–\xad])', '\\1as tu vais', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ele (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', '\\1as ele vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ela (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', '\\1as ela vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as você (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', '\\1as você vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as isso (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', '\\1as isso vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as nós (vou|vais|vai|ides|vão)(?![-\\w–\xad])', '\\1as nós vamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vós (vou|vais|vai|vamos|vão)(?![-\\w–\xad])', '\\1as vós ides', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eles (vou|vais|vai|vamos|ides)(?![-\\w–\xad])', '\\1as eles vão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as elas (vou|vais|vai|vamos|ides)(?![-\\w–\xad])', '\\1as elas vão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vocês (vou|vais|vai|vamos|ides)(?![-\\w–\xad])', '\\1as vocês vão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as a gente (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', '\\1as a gente vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eu (és|é|somos|sois|são)(?![-\\w–\xad])', '\\1as eu so', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as tu (sou|é|somos|sois|são)(?![-\\w–\xad])', '\\1as tu és', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ele (sou|és|somos|sois|são)(?![-\\w–\xad])', '\\1as ele é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ela (sou|és|somos|sois|são)(?![-\\w–\xad])', '\\1as ela é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as você (sou|és|somos|sois|são)(?![-\\w–\xad])', '\\1as você é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as isso (sou|és|somos|sois|são)(?![-\\w–\xad])', '\\1as isso é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as nós (sou|és|é|sois|são)(?![-\\w–\xad])', '\\1as nós somos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vós (sou|és|é|somos|são)(?![-\\w–\xad])', '\\1as vós sois', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eles (sou|és|é|somos|sois)(?![-\\w–\xad])', '\\1as eles são', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as elas (sou|és|é|somos|sois)(?![-\\w–\xad])', '\\1as elas são', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vocês (sou|és|é|somos|sois)(?![-\\w–\xad])', '\\1as vocês são', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as a gente (sou|és|somos|sois|são)(?![-\\w–\xad])', '\\1as a gente é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eu (eras|éramos|éreis|eram)(?![-\\w–\xad])', '\\1as eu era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as tu (era|éramos|éreis|eram)(?![-\\w–\xad])', '\\1as tu eras', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ele (eras|éramos|éreis|eram)(?![-\\w–\xad])', '\\1as ele era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ela (eras|éramos|éreis|eram)(?![-\\w–\xad])', '\\1as ela era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as você (eras|éramos|éreis|eram)(?![-\\w–\xad])', '\\1as você era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as isso (eras|éramos|éreis|eram)(?![-\\w–\xad])', '\\1as isso era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as nós (eras|era|éreis|eram)(?![-\\w–\xad])', '\\1as nós éramos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vós (eras|era|éramos|eram)(?![-\\w–\xad])', '\\1as vós éreis', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eles (eras|era|éramos|éreis)(?![-\\w–\xad])', '\\1as eles eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as elas (eras|era|éramos|éreis)(?![-\\w–\xad])', '\\1as elas eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vocês (eras|era|éramos|éreis)(?![-\\w–\xad])', '\\1as vocês eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as a gente (eras|éramos|éreis|eram)(?![-\\w–\xad])', '\\1as a gente era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eu (foste|foi|fomos|fostes|foram)(?![-\\w–\xad])', '\\1as eu fui', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as tu (fui|foi|fomos|fostes|foram)(?![-\\w–\xad])', '\\1as tu foste', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ele (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', '\\1as ele foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ela (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', '\\1as ela foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as você (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', '\\1as você foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as isso (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', '\\1as isso foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as nós (fui|foste|foi|fostes|foram)(?![-\\w–\xad])', '\\1as nós fomos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vós (fui|foste|foi|fomos|foram)(?![-\\w–\xad])', '\\1as vós fostes', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eles (fui|foste|foi|fomos|fostes)(?![-\\w–\xad])', '\\1as eles foram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as elas (fui|foste|foi|fomos|fostes)(?![-\\w–\xad])', '\\1as elas foram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vocês (fui|foste|foi|fomos|fostes)(?![-\\w–\xad])', '\\1as vocês foram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as a gente (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', '\\1as a gente foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eu (serás|será|seremos|sereis|serão)(?![-\\w–\xad])', '\\1as eu serei', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as tu (serei|será|seremos|sereis|serão)(?![-\\w–\xad])', '\\1as tu serás', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ele (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', '\\1as ele será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ela (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', '\\1as ela será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as você (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', '\\1as você será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as isso (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', '\\1as isso será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as nós (serei|serás|será|sereis|serão)(?![-\\w–\xad])', '\\1as nós seremos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vós (serei|serás|será|seremos|serão)(?![-\\w–\xad])', '\\1as vós sereis', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eles (serei|serás|será|seremos|sereis)(?![-\\w–\xad])', '\\1as eles serão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as elas (serei|serás|será|seremos|sereis)(?![-\\w–\xad])', '\\1as elas serão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vocês (serei|serás|será|seremos|sereis)(?![-\\w–\xad])', '\\1as vocês serão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as a gente (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', '\\1as a gente será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eu (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', '\\1as eu seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as tu (seria|seríamos|seríeis|seriam)(?![-\\w–\xad])', '\\1as tu serias', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ele (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', '\\1as ele seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ela (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', '\\1as ela seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as você (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', '\\1as você seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as isso (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', '\\1as isso seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as nós (serias|seria|seríeis|seriam)(?![-\\w–\xad])', '\\1as nós seríamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vós (serias|seria|seríamos|seriam)(?![-\\w–\xad])', '\\1as vós seríeis', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eles (serias|seria|seríamos|seríeis)(?![-\\w–\xad])', '\\1as eles seriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as elas (serias|seria|seríamos|seríeis)(?![-\\w–\xad])', '\\1as elas seriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vocês (serias|seria|seríamos|seríeis)(?![-\\w–\xad])', '\\1as vocês seriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as a gente (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', '\\1as a gente seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
# preposicao MAS - mais particulas - (nao|ja|ainda|nunca|jamais|talvez)
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eu (não|já|ainda|nunca|jamais|talvez) (vais|vai|vamos|ides|vão)(?![-\\w–\xad])', '\\1as eu \\2 vo', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as tu (não|já|ainda|nunca|jamais|talvez) (vou|vai|vamos|ides|vão)(?![-\\w–\xad])', '\\1as tu \\2 vais', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ele (não|já|ainda|nunca|jamais|talvez) (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', '\\1as ele \\2 vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ela (não|já|ainda|nunca|jamais|talvez) (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', '\\1as ela \\2 vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as você (não|já|ainda|nunca|jamais|talvez) (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', '\\1as você \\2 vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as isso (não|já|ainda|nunca|jamais|talvez) (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', '\\1as isso \\2 vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as nós (não|já|ainda|nunca|jamais|talvez) (vou|vais|vai|ides|vão)(?![-\\w–\xad])', '\\1as nós \\2 vamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vós (não|já|ainda|nunca|jamais|talvez) (vou|vais|vai|vamos|vão)(?![-\\w–\xad])', '\\1as vós \\2 ides', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eles (não|já|ainda|nunca|jamais|talvez) (vou|vais|vai|vamos|ides)(?![-\\w–\xad])', '\\1as eles \\2 vão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as elas (não|já|ainda|nunca|jamais|talvez) (vou|vais|vai|vamos|ides)(?![-\\w–\xad])', '\\1as elas \\2 vão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vocês (não|já|ainda|nunca|jamais|talvez) (vou|vais|vai|vamos|ides)(?![-\\w–\xad])', '\\1as vocês \\2 vão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as a gente (não|já|ainda|nunca|jamais|talvez) (vou|vais|vamos|ides|vão)(?![-\\w–\xad])', '\\1as a gente \\2 vai', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eu (não|já|ainda|nunca|jamais|talvez) (és|é|somos|sois|são)(?![-\\w–\xad])', '\\1as eu \\2 so', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as tu (não|já|ainda|nunca|jamais|talvez) (sou|é|somos|sois|são)(?![-\\w–\xad])', '\\1as tu \\2 és', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ele (não|já|ainda|nunca|jamais|talvez) (sou|és|somos|sois|são)(?![-\\w–\xad])', '\\1as ele \\2 é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ela (não|já|ainda|nunca|jamais|talvez) (sou|és|somos|sois|são)(?![-\\w–\xad])', '\\1as ela \\2 é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as você (não|já|ainda|nunca|jamais|talvez) (sou|és|somos|sois|são)(?![-\\w–\xad])', '\\1as você \\2 é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as isso (não|já|ainda|nunca|jamais|talvez) (sou|és|somos|sois|são)(?![-\\w–\xad])', '\\1as isso \\2 é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as nós (não|já|ainda|nunca|jamais|talvez) (sou|és|é|sois|são)(?![-\\w–\xad])', '\\1as nós \\2 somos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vós (não|já|ainda|nunca|jamais|talvez) (sou|és|é|somos|são)(?![-\\w–\xad])', '\\1as vós \\2 sois', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eles (não|já|ainda|nunca|jamais|talvez) (sou|és|é|somos|sois)(?![-\\w–\xad])', '\\1as eles \\2 são', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as elas (não|já|ainda|nunca|jamais|talvez) (sou|és|é|somos|sois)(?![-\\w–\xad])', '\\1as elas \\2 são', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vocês (não|já|ainda|nunca|jamais|talvez) (sou|és|é|somos|sois)(?![-\\w–\xad])', '\\1as vocês \\2 são', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as a gente (não|já|ainda|nunca|jamais|talvez) (sou|és|somos|sois|são)(?![-\\w–\xad])', '\\1as a gente \\2 é', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eu (não|já|ainda|nunca|jamais|talvez) (eras|éramos|éreis|eram)(?![-\\w–\xad])', '\\1as eu \\2 era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as tu (não|já|ainda|nunca|jamais|talvez) (era|éramos|éreis|eram)(?![-\\w–\xad])', '\\1as tu \\2 eras', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ele (não|já|ainda|nunca|jamais|talvez) (eras|éramos|éreis|eram)(?![-\\w–\xad])', '\\1as ele \\2 era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ela (não|já|ainda|nunca|jamais|talvez) (eras|éramos|éreis|eram)(?![-\\w–\xad])', '\\1as ela \\2 era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as você (não|já|ainda|nunca|jamais|talvez) (eras|éramos|éreis|eram)(?![-\\w–\xad])', '\\1as você \\2 era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as isso (não|já|ainda|nunca|jamais|talvez) (eras|éramos|éreis|eram)(?![-\\w–\xad])', '\\1as isso \\2 era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as nós (não|já|ainda|nunca|jamais|talvez) (eras|era|éreis|eram)(?![-\\w–\xad])', '\\1as nós \\2 éramos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vós (não|já|ainda|nunca|jamais|talvez) (eras|era|éramos|eram)(?![-\\w–\xad])', '\\1as vós \\2 éreis', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eles (não|já|ainda|nunca|jamais|talvez) (eras|era|éramos|éreis)(?![-\\w–\xad])', '\\1as eles \\2 eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as elas (não|já|ainda|nunca|jamais|talvez) (eras|era|éramos|éreis)(?![-\\w–\xad])', '\\1as elas \\2 eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vocês (não|já|ainda|nunca|jamais|talvez) (eras|era|éramos|éreis)(?![-\\w–\xad])', '\\1as vocês \\2 eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as a gente (não|já|ainda|nunca|jamais|talvez) (eras|éramos|éreis|eram)(?![-\\w–\xad])', '\\1as a gente \\2 era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eu (não|já|ainda|nunca|jamais|talvez) (foste|foi|fomos|fostes|foram)(?![-\\w–\xad])', '\\1as eu \\2 fui', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as tu (não|já|ainda|nunca|jamais|talvez) (fui|foi|fomos|fostes|foram)(?![-\\w–\xad])', '\\1as tu \\2 foste', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ele (não|já|ainda|nunca|jamais|talvez) (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', '\\1as ele \\2 foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ela (não|já|ainda|nunca|jamais|talvez) (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', '\\1as ela \\2 foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as você (não|já|ainda|nunca|jamais|talvez) (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', '\\1as você \\2 foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as isso (não|já|ainda|nunca|jamais|talvez) (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', '\\1as isso \\2 foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as nós (não|já|ainda|nunca|jamais|talvez) (fui|foste|foi|fostes|foram)(?![-\\w–\xad])', '\\1as nós \\2 fomos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vós (não|já|ainda|nunca|jamais|talvez) (fui|foste|foi|fomos|foram)(?![-\\w–\xad])', '\\1as vós \\2 fostes', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eles (não|já|ainda|nunca|jamais|talvez) (fui|foste|foi|fomos|fostes)(?![-\\w–\xad])', '\\1as eles \\2 foram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as elas (não|já|ainda|nunca|jamais|talvez) (fui|foste|foi|fomos|fostes)(?![-\\w–\xad])', '\\1as elas \\2 foram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vocês (não|já|ainda|nunca|jamais|talvez) (fui|foste|foi|fomos|fostes)(?![-\\w–\xad])', '\\1as vocês \\2 foram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as a gente (não|já|ainda|nunca|jamais|talvez) (fui|foste|fomos|fostes|foram)(?![-\\w–\xad])', '\\1as a gente \\2 foi', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eu (não|já|ainda|nunca|jamais|talvez) (serás|será|seremos|sereis|serão)(?![-\\w–\xad])', '\\1as eu \\2 serei', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as tu (não|já|ainda|nunca|jamais|talvez) (serei|será|seremos|sereis|serão)(?![-\\w–\xad])', '\\1as tu \\2 serás', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ele (não|já|ainda|nunca|jamais|talvez) (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', '\\1as ele \\2 será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ela (não|já|ainda|nunca|jamais|talvez) (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', '\\1as ela \\2 será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as você (não|já|ainda|nunca|jamais|talvez) (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', '\\1as você \\2 será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as isso (não|já|ainda|nunca|jamais|talvez) (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', '\\1as isso \\2 será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as nós (não|já|ainda|nunca|jamais|talvez) (serei|serás|será|sereis|serão)(?![-\\w–\xad])', '\\1as nós \\2 seremos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vós (não|já|ainda|nunca|jamais|talvez) (serei|serás|será|seremos|serão)(?![-\\w–\xad])', '\\1as vós \\2 sereis', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eles (não|já|ainda|nunca|jamais|talvez) (serei|serás|será|seremos|sereis)(?![-\\w–\xad])', '\\1as eles \\2 serão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as elas (não|já|ainda|nunca|jamais|talvez) (serei|serás|será|seremos|sereis)(?![-\\w–\xad])', '\\1as elas \\2 serão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vocês (não|já|ainda|nunca|jamais|talvez) (serei|serás|será|seremos|sereis)(?![-\\w–\xad])', '\\1as vocês \\2 serão', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as a gente (não|já|ainda|nunca|jamais|talvez) (serei|serás|seremos|sereis|serão)(?![-\\w–\xad])', '\\1as a gente \\2 será', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eu (não|já|ainda|nunca|jamais|talvez) (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', '\\1as eu \\2 seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as tu (não|já|ainda|nunca|jamais|talvez) (seria|seríamos|seríeis|seriam)(?![-\\w–\xad])', '\\1as tu \\2 serias', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ele (não|já|ainda|nunca|jamais|talvez) (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', '\\1as ele \\2 seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as ela (não|já|ainda|nunca|jamais|talvez) (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', '\\1as ela \\2 seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as você (não|já|ainda|nunca|jamais|talvez) (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', '\\1as você \\2 seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as isso (não|já|ainda|nunca|jamais|talvez) (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', '\\1as isso \\2 seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as nós (não|já|ainda|nunca|jamais|talvez) (serias|seria|seríeis|seriam)(?![-\\w–\xad])', '\\1as nós \\2 seríamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vós (não|já|ainda|nunca|jamais|talvez) (serias|seria|seríamos|seriam)(?![-\\w–\xad])', '\\1as vós \\2 seríeis', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as eles (não|já|ainda|nunca|jamais|talvez) (serias|seria|seríamos|seríeis)(?![-\\w–\xad])', '\\1as eles \\2 seriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as elas (não|já|ainda|nunca|jamais|talvez) (serias|seria|seríamos|seríeis)(?![-\\w–\xad])', '\\1as elas \\2 seriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as vocês (não|já|ainda|nunca|jamais|talvez) (serias|seria|seríamos|seríeis)(?![-\\w–\xad])', '\\1as vocês \\2 seriam', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])as a gente (não|já|ainda|nunca|jamais|talvez) (serias|seríamos|seríeis|seriam)(?![-\\w–\xad])', '\\1as a gente \\2 seria', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
# fim preposicao MAS - particulas - (nao|ja|ainda|nunca|jamais|talvez)
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e eu (fosses|fôssemos|fôsseis|fossem)(?![-\\w–\xad])', '\\1e eu fosse', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e tu (fosse|fôssemos|fôsseis|fossem)(?![-\\w–\xad])', '\\1e tu fosses', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e ele (fosses|fôssemos|fôsseis|fossem)(?![-\\w–\xad])', '\\1e ele fosse', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e ela (fosses|fôssemos|fôsseis|fossem)(?![-\\w–\xad])', '\\1e ela fosse', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e você (fosses|fôssemos|fôsseis|fossem)(?![-\\w–\xad])', '\\1e você fosse', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e nós (fosse|fosses|fôsseis|fossem)(?![-\\w–\xad])', '\\1e nós fôssemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e vós (fosse|fosses|fôssemos|fossem)(?![-\\w–\xad])', '\\1e vós fôsseis', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e eles (fosse|fosses|fôssemos|fôsseis)(?![-\\w–\xad])', '\\1e eles fossem', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e elas (fosse|fosses|fôssemos|fôsseis)(?![-\\w–\xad])', '\\1e elas \\2assem', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e vocês (fosse|fosses|fôssemos|fôsseis)(?![-\\w–\xad])', '\\1e vocês fossem', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(S|s|Qu|qu)e a gente (fosses|fôssemos|fôsseis|fossem)(?![-\\w–\xad])', '\\1e a gente fosse', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando eu (fosses|fôssemos|fôsseis|fossem)(?![-\\w–\xad])', '\\1uando eu fosse', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando tu (fosse|fôssemos|fôsseis|fossem)(?![-\\w–\xad])', '\\1uando tu fosses', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando ele (fosses|fôssemos|fôsseis|fossem)(?![-\\w–\xad])', '\\1uando ele fosse', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando ela (fosses|fôssemos|fôsseis|fossem)(?![-\\w–\xad])', '\\1uando ela fosse', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando você (fosses|fôssemos|fôsseis|fossem)(?![-\\w–\xad])', '\\1uando você fosse', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando nós (fosse|fosses|fôsseis|fossem)(?![-\\w–\xad])', '\\1uando nós fôssemos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando vós (fosse|fosses|fôssemos|fossem)(?![-\\w–\xad])', '\\1uando vós fôsseis', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando eles (fosse|fosses|fôssemos|fôsseis)(?![-\\w–\xad])', '\\1uando eles fossem', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando elas (fosse|fosses|fôssemos|fôsseis)(?![-\\w–\xad])', '\\1uando elas \\2assem', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando vocês (fosse|fosses|fôssemos|fôsseis)(?![-\\w–\xad])', '\\1uando vocês fossem', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a gente (fosses|fôssemos|fôsseis|fossem)(?![-\\w–\xad])', '\\1uando a gente fosse', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Se|se|Quando|quando|que) eu (fores|formos|fordes|forem)(?![-\\w–\xad])', '\\1 eu for', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Se|se|Quando|quando|que) tu (for|formos|fordes|forem)(?![-\\w–\xad])', '\\1 tu fores', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Se|se|Quando|quando|que) ele (fores|formos|fordes|forem)(?![-\\w–\xad])', '\\1 ele for', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Se|se|Quando|quando|que) ela (fores|formos|fordes|forem)(?![-\\w–\xad])', '\\1 ela for', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Se|se|Quando|quando|que) você (fores|formos|fordes|forem)(?![-\\w–\xad])', '\\1 você for', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Se|se|Quando|quando|que) nós (for|fores|fordes|forem)(?![-\\w–\xad])', '\\1 nós formos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Se|se|Quando|quando|que) vós (for|fores|formos|forem)(?![-\\w–\xad])', '\\1 vós fordes', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Se|se|Quando|quando|que) eles (for|fores|formos|fordes)(?![-\\w–\xad])', '\\1 eles forem', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Se|se|Quando|quando|que) elas (for|fores|formos|fordes)(?![-\\w–\xad])', '\\1 elas forem', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Se|se|Quando|quando|que) vocês (for|fores|formos|fordes)(?![-\\w–\xad])', '\\1 vocês forem', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(Se|se|Quando|quando|que) a gente (fores|formos|fordes|forem)(?![-\\w–\xad])', '\\1 a gente for', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue eu (sejas|sejamos|sejais|sejam)(?![-\\w–\xad])', '\\1ue eu seja', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue tu (seja|sejamos|sejais|sejam)(?![-\\w–\xad])', '\\1ue tu sejas', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue ele (sejas|sejamos|sejais|sejam)(?![-\\w–\xad])', '\\1ue ele seja', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue ela (sejas|sejamos|sejais|sejam)(?![-\\w–\xad])', '\\1ue ela seja', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue você (sejas|sejamos|sejais|sejam)(?![-\\w–\xad])', '\\1ue você seja', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue nós (seja|sejas|sejais|sejam)(?![-\\w–\xad])', '\\1ue nós sejamos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue vós (seja|sejas|sejamos|sejam)(?![-\\w–\xad])', '\\1ue vós sejais', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue eles (seja|sejas|sejamos|sejais)(?![-\\w–\xad])', '\\1ue eles sejam', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue elas (seja|sejas|sejamos|sejais)(?![-\\w–\xad])', '\\1ue elas sejam', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue vocês (seja|sejas|sejamos|sejais)(?![-\\w–\xad])', '\\1ue vocês sejam', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a gente (sejas|sejamos|sejais|sejam)(?![-\\w–\xad])', '\\1ue a gente seja', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando eu (eras|éramos|éreis|eram)(?![-\\w–\xad])', '\\1uando eu era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando tu (era|éramos|éreis|eram)(?![-\\w–\xad])', '\\1uando tu eras', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando ele (eras|éramos|éreis|eram)(?![-\\w–\xad])', '\\1uando ele era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando ela (eras|éramos|éreis|eram)(?![-\\w–\xad])', '\\1uando ela era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando você (eras|éramos|éreis|eram)(?![-\\w–\xad])', '\\1uando você era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando nós (eras|era|éreis|eram)(?![-\\w–\xad])', '\\1uando nós éramos', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando vós (eras|era|éramos|eram)(?![-\\w–\xad])', '\\1uando vós éreis', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando eles (eras|era|éramos|éreis)(?![-\\w–\xad])', '\\1uando eles eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando elas (eras|era|éramos|éreis)(?![-\\w–\xad])', '\\1uando elas eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando vocês (eras|era|éramos|éreis)(?![-\\w–\xad])', '\\1uando vocês eram', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a gente (eras|éramos|éreis|eram)(?![-\\w–\xad])', '\\1uando a gente era', 'Pronome não concorda com o verbo. Você quis dizer:', 'option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Lvar_1>[a-z]+[bdfhjlmnoprstvxz])(am|ariam|arão|em) a ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1\\2 a \\3er \\4', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group("Lvar_1") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Lvar_2>[a-z]+[bdfhjlmnoprstvxz])aram a ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1aram a \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group("Lvar_2") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Lvar_3>[a-z]+[bdfhjlmnoprstvxz])arem a ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1arem a \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group("Lvar_3") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Lvar_4>[a-z]+[bdfhjlmnoprstvxz])assem a ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1assem a \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group("Lvar_4") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Lvar_5>[a-z]+[bdfhjlmnoprstvxz])avam a ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1avam a \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group("Lvar_5") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-zç]+)(cam|quem|caram|carem|cavam|cariam|carão|cassem) a ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1\\2 a \\3er \\4', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-zç]+)(gam|guem|garam|garem|gavam|gariam|garão|gassem) a ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1\\2 a \\3er \\4', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+)(çam|cem|çaram|çarem|çavam|çariam|çarão|çassem) a ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1\\2 a \\3er \\4', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+)(am|em|erão) a ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1\\2 a \\3er \\4', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+)eram a ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1eram a \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+)erem a ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1erem a \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+)iam a ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1iam a \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+)eriam a ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1eriam a \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+)essem a ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1essem a \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+)(çam|cem|ceram|cerem|ciam|ceriam|cerão|cessem) a ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1\\2 a \\3er \\4', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrVbrcer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Lvar_6>[a-z]+[bdfhjlmnoprstvxz])(am|ariam|arão|em) para ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1\\2 para \\3er \\4', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group("Lvar_6") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Lvar_7>[a-z]+[bdfhjlmnoprstvxz])aram para ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1aram para \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group("Lvar_7") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Lvar_8>[a-z]+[bdfhjlmnoprstvxz])arem para ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1arem para \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group("Lvar_8") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Lvar_9>[a-z]+[bdfhjlmnoprstvxz])assem para ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1assem para \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group("Lvar_9") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Lvar_10>[a-z]+[bdfhjlmnoprstvxz])avam para ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1avam para \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group("Lvar_10") in plvrVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-zç]+)(cam|quem|caram|carem|cavam|cariam|carão|cassem) para ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1\\2 para \\3er \\4', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-zç]+)(gam|guem|garam|garem|gavam|gariam|garão|gassem) para ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1\\2 para \\3er \\4', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+)(çam|cem|çaram|çarem|çavam|çariam|çarão|çassem) para ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1\\2 para \\3er \\4', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrCVbrar and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+)(am|em|erão) para ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1\\2 para \\3er \\4', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+)eram para ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1eram para \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+)erem para ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1erem para \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+)iam para ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1iam para \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+)eriam para ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1eriam para \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+)essem para ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1essem para \\2er \\3', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrVbrxer and option(LOCALE,"verbo")'],
 ['(?u)(?<![-\\w–.,\xad])([a-z]+)(çam|cem|ceram|cerem|ciam|ceriam|cerão|cessem) para ([lstv])erem ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1\\2 para \\3er \\4', 'O adequado é usar o segundo verbo no infinitivo não flexionado. Você quis dizer:', 'm.group(1) in plvrVbrcer and option(LOCALE,"verbo")'],
# -*- FIM Concordancia Verbal -*-
# -*- Colocacao Pronominal -*-
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue (?P<Osq_1>[a-zA-Záâçéêíóôúã]+)-([mst])e(?![-\\w–\xad])', '\\1ue \\3e \\g<Osq_1>', 'Oração subordinada exige antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue (?P<Osq_2>[a-zA-Záâçéêíóôúã]+)-lhe(?![-\\w–\xad])', '\\1ue lhe \\g<Osq_2>', 'Oração subordinada exige antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue (?P<Osq_6>[a-zA-Záâçéêíóôúã]+[bcefghijlmnoprstuvxz])([aeou])-([ao])(?![-\\w–\xad])', '\\1ue \\4 \\g<Osq_6>\\3', 'Oração subordinada exige antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue (?P<Osq_7>[a-zA-Záâçéêíóôúã]+)-nos(?![-\\w–\xad])', '\\1ue nos \\g<Osq_7>', 'Oração subordinada exige antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue (?P<Oqq_1>[a-zA-Záâçéêíóôúã]+) (?P<Osx_1>[a-zA-Záâçéêíóôúã]+)-([mst])e(?![-\\w–\xad])', '\\1ue \\g<Oqq_1> \\4e \\g<Osx_1>', 'Oração subordinada exige antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue (?P<Oqq_2>[a-zA-Záâçéêíóôúã]+) (?P<Osx_2>[a-zA-Záâçéêíóôúã]+)-lhe(?![-\\w–\xad])', '\\1ue \\g<Oqq_2> lhe \\g<Osx_2>', 'Oração subordinada exige antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue (?P<Oqq_6>[a-zA-Záâçéêíóôúã]+) (?P<Osx_6>[a-zA-Záâçéêíóôúã]+[aeou])-([ao])(?![-\\w–\xad])', '\\1ue \\g<Oqq_6> \\4 \\g<Osx_6>', 'Oração subordinada exige antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue (?P<Oqq_7>[a-zA-Záâçéêíóôúã]+) (?P<Osx_7>[a-zA-Záâçéêíóôúã]+)-nos(?![-\\w–\xad])', '\\1ue \\g<Oqq_7> nos \\g<Osx_7>', 'Oração subordinada exige antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue (?P<Osq_10>[a-zA-Záâçéêíóôúã]+) (?P<Osq_11>[a-zA-Záâçéêíóôúã]+) (?P<Osq_12>[a-zA-Záâçéêíóôúã]+)-([mst])e(?![-\\w–\xad])', '\\1ue \\2 \\3 \\5e \\4', 'Oração subordinada exige antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue (?P<Osq_13>[a-zA-Záâçéêíóôúã]+) (?P<Osq_14>[a-zA-Záâçéêíóôúã]+) (?P<Osq_15>[a-zA-Záâçéêíóôúã]+)-lhe(?![-\\w–\xad])', '\\1ue \\2 \\3 lhe \\4', 'Oração subordinada exige antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue (?P<Osq_16>[a-zA-Záâçéêíóôúã]+) (?P<Osq_17>[a-zA-Záâçéêíóôúã]+) (?P<Osq_18>[a-zA-Záâçéêíóôúã]+[bcefghijlmnoprstuvxz][aeou])-([ao])(?![-\\w–\xad])', '\\1ue \\2 \\3 \\5 \\4', 'Oração subordinada exige antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue (?P<Osq_19>[a-zA-Záâçéêíóôúã]+) (?P<Osq_20>[a-zA-Záâçéêíóôúã]+) (?P<Osq_21>[a-zA-Záâçéêíóôúã]+)-nos(?![-\\w–\xad])', '\\1ue \\2 \\3 nos \\4>', 'Oração subordinada exige antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj])á (?P<Avj_1>[a-zA-Záâçéêíóôúã]+)-([mst])e(?![-\\w–\xad])', '\\1á \\3e \\g<Avj_1>', 'Advérbio -já- exige antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj])á (?P<Avj_2>[a-zA-Záâçéêíóôúã]+)-lhe(?![-\\w–\xad])', '\\1á lhe \\g<Avj_2>', 'Advérbio -já- exige antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj])á (?P<Avj_6>[a-zA-Záâçéêíóôúã]+[aeou])-([ao])(?![-\\w–\xad])', '\\1á \\3 \\g<Avj_6>', 'Advérbio -já- exige antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])([Jj])á (?P<Avj_7>[a-zA-Záâçéêíóôúã]+)-nos(?![-\\w–\xad])', '\\1á nos \\g<Avj_7>', 'Advérbio -já- exige antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_1>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_2>[a-zA-Záâçéêíóôõúã]+)-([mst])e(?![-\\w–\xad])', '\\1 \\3e \\2', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_1").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_3>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_4>[a-zA-Záâçéêíóôõúã]+)-lhe(?![-\\w–\xad])', '\\1 lhe \\2', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_3").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])u (?P<Puxa_5>[a-zA-Záâçéêíóôõúã]+)-([mst])e(?![-\\w–\xad])', '\\1u \\3e \\2', '- Ou - requer antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])u (?P<Puxa_6>[a-zA-Záâçéêíóôõúã]+)-lhe(?![-\\w–\xad])', '\\1u lhe \\2', '- Ou - requer antecipação do pronome ao verbo. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_11>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_12>[a-zA-Záâçéêíóôúã]+[bcefghijlmnoprstuvxz][aeou])-([ao])(?![-\\w–\xad])', '\\1 \\3 \\2', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_11").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_15>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_16>[a-zA-Záâçéêíóôúã]+[^o])-nos(?![-\\w–\xad])', '\\1 nos \\2', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_15").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_17>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_18>[a-zA-Záâçéêíóôúã]+[^m][o])-nos(?![-\\w–\xad])', '\\1 nos \\2', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_17").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_19>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_20>[a-zA-Záâçéêíóôúã]+[m][o])-nos(?![-\\w–\xad])', '\\1 nos \\2s', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_19").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_21>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_22>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_23>[a-zA-Záâçéêíóôúã]+)-([mst])e(?![-\\w–\xad])', '\\1 \\2 \\4e \\3', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_21").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_24>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_25>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_26>[a-zA-Záâçéêíóôúã]+)-lhe(?![-\\w–\xad])', '\\1 \\2 lhe \\3', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_24").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_27>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_28>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_29>[a-zA-Záâçéêíóôúã]+[bcefghijlmnoprstuvxz][aeou])-([ao])(?![-\\w–\xad])', '\\1 \\2 \\4 \\3', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_27").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_30>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_31>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_32>[a-zA-Záâçéêíóôúã]+[^o])-nos(?![-\\w–\xad])', '\\1 \\2 nos \\3', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_30").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_33>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_34>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_35>[a-zA-Záâçéêíóôúã]+[^m][o])-nos(?![-\\w–\xad])', '\\1 \\2 nos \\3', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_33").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_36>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_37>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_38>[a-zA-Záâçéêíóôúã]+[m][o])-nos(?![-\\w–\xad])', '\\1 \\2 nos \\3s', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_36").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_37>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_38>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_39>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_40>[a-zA-Záâçéêíóôúã]+)-([mst])e(?![-\\w–\xad])', '\\1 \\2 \\3 \\5e \\4', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_37").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_41>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_42>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_43>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_44>[a-zA-Záâçéêíóôúã]+)-lhe(?![-\\w–\xad])', '\\1 \\2 \\3 lhe \\4', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_41").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_45>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_46>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_47>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_48>[a-zA-Záâçéêíóôúã]+[bcefghijlmnoprstuvxz][aeou])-([ao])(?![-\\w–\xad])', '\\1 \\2 \\3 \\5 \\4', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_45").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_49>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_50>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_51>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_52>[a-zA-Záâçéêíóôúã]+[^o])-nos(?![-\\w–\xad])', '\\1 \\2 \\3 nos \\4', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_49").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_53>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_54>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_55>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_56>[a-zA-Záâçéêíóôúã]+[^m][o])-nos(?![-\\w–\xad])', '\\1 \\2 \\3 nos \\4', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_53").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_57>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_58>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_59>[a-zA-Záâçéêíóôúã]+) (?P<Puxa_60>[a-zA-Záâçéêíóôúã]+[m][o])-nos(?![-\\w–\xad])', '\\1 \\2 \\3 nos \\4s', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'm.group("Puxa_57").lower() in aProclise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Puxa_58>[a-zA-Záâçéêíóôúã]+) (compõe|compõem|compuser|compuzeram|compuzerem|contrapõe|contrapõem|contrapuser|contrapuzeram|contrapuzerem|depõe|depõem|depuser|depuzeram|depuzerem|dispõe|dispõem|dispuser|dispuzeram|dispuzerem|põe|põem|puser|puzeram|puzerem|repõe|repõem|repuser|repuzeram|repuzerem)-([mst])e(?![-\\w–\xad])', '\\1 \\3e \\2', '= "- " + mProclise[m.group(1).lower()] + " - requer antecipação do pronome ao verbo. Você quis dizer:"', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(Nunca|nunca|Nem|nem|Jamais|jamais|Não|não|Nada|nada|Ninguém|ninguém) (?P<Nec_1>[a-zA-Záâçéêíóôúã]+)-([mst])e(?![-\\w–\xad])', '\\1 \\3e \\g<Nec_1>', 'A partícula negativa atrai o pronome. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(Nunca|nunca|Nem|nem|Jamais|jamais|Não|não|Nada|nada|Ninguém|ninguém) (?P<Nec_2>[a-zA-Záâçéêíóôúã]+)-lhe(?![-\\w–\xad])', '\\1 lhe \\g<Nec_2>', 'A partícula negativa atrai o pronome. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(Nunca|nunca|Nem|nem|Jamais|jamais|Não|não|Nada|nada|Ninguém|ninguém) (?P<Nec_6>[a-zA-Záâçéêíóôúã]+[aeou])-([ao])(?![-\\w–\xad])', '\\1 \\3 \\g<Nec_6>', 'A partícula negativa atrai o pronome. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(Nunca|nunca|Nem|nem|Jamais|jamais|Não|não|Nada|nada|Ninguém|ninguém) (?P<Nec_7>[a-zA-Záâçéêíóôúã]+)-nos(?![-\\w–\xad])', '\\1 nos \\g<Nec_7>', 'A partícula negativa atrai o pronome. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(Nunca|nunca|Nem|nem|Jamais|jamais|Não|não|Nada|nada|Ninguém|ninguém) (?P<Nec_8>[a-zA-Záâçéêíóôúã]+) (?P<Nec_9>[a-zA-Záâçéêíóôúã]+)-([mst])e(?![-\\w–\xad])', '\\1 \\2 \\4e \\3', 'A partícula negativa atrai o pronome. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(Nunca|nunca|Nem|nem|Jamais|jamais|Não|não|Nada|nada|Ninguém|ninguém) (?P<Nec_10>[a-zA-Záâçéêíóôúã]+) (?P<Nec_11>[a-zA-Záâçéêíóôúã]+)-lhe(?![-\\w–\xad])', '\\1 \\2 lhe \\3', 'A partícula negativa atrai o pronome. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(Nunca|nunca|Nem|nem|Jamais|jamais|Não|não|Nada|nada|Ninguém|ninguém) (?P<Nec_18>[a-zA-Záâçéêíóôúã]+) (?P<Nec_19>[a-zA-Záâçéêíóôúã]+[aeou])-([ao])(?![-\\w–\xad])', '\\1 \\2 \\4 \\3', 'A partícula negativa atrai o pronome. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(Nunca|nunca|Nem|nem|Jamais|jamais|Não|não|Nada|nada|Ninguém|ninguém) (?P<Nec_20>[a-zA-Záâçéêíóôúã]+) (?P<Nec_21>[a-zA-Záâçéêíóôúã]+)-nos(?![-\\w–\xad])', '\\1 \\2 nos \\3', 'A partícula negativa atrai o pronome. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(Nunca|nunca|Nem|nem|Jamais|jamais|Não|não|Nada|nada|Ninguém|ninguém) (?P<Nec_22>[a-zA-Záâçéêíóôúã]+) (?P<Nec_23>[a-zA-Záâçéêíóôúã]+) (?P<Nec_24>[a-zA-Záâçéêíóôúã]+)-([mst])e(?![-\\w–\xad])', '\\1 \\2 \\3 \\5e \\4', 'A partícula negativa atrai o pronome. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(Nunca|nunca|Nem|nem|Jamais|jamais|Não|não|Nada|nada|Ninguém|ninguém) (?P<Nec_25>[a-zA-Záâçéêíóôúã]+) (?P<Nec_26>[a-zA-Záâçéêíóôúã]+) (?P<Nec_27>[a-zA-Záâçéêíóôúã]+)-lhe(?![-\\w–\xad])', '\\1 \\2 \\3 lhe \\4', 'A partícula negativa atrai o pronome. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(Nunca|nunca|Nem|nem|Jamais|jamais|Não|não|Nada|nada|Ninguém|ninguém) (?P<Nec_37>[a-zA-Záâçéêíóôúã]+) (?P<Nec_38>[a-zA-Záâçéêíóôúã]+) (?P<Nec_39>[a-zA-Záâçéêíóôúã]+)[aeou]-([ao])(?![-\\w–\xad])', '\\1 \\2 \\3 \\5 \\4', 'A partícula negativa atrai o pronome. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(Nunca|nunca|Nem|nem|Jamais|jamais|Não|não|Nada|nada|Ninguém|ninguém) (?P<Nec_40>[a-zA-Záâçéêíóôúã]+) (?P<Nec_41>[a-zA-Záâçéêíóôúã]+) (?P<Nec_42>[a-zA-Záâçéêíóôúã]+)-nos(?![-\\w–\xad])', '\\1 \\2 \\3 nos \\4', 'A partícula negativa atrai o pronome. Você quis dizer:', 'option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(^)([MT])e (?P<Pns_1>[a-záâãçéêíóôõú]+[aeioumr])(?![-\\w–\xad])', '= m.group("Pns_1").capitalize() + \'-\' + m.group(2).lower() + \'e \'', 'Não se usa próclise no início do período', 'not m.group("Pns_1") in proClise and option(LOCALE,"pronominal")'],
 ['(?u)(?<![-\\w–.,\xad])(^)Lhe (?P<Pns_2>[a-záâãçéêíóôõú]+[aeioumr])(?![-\\w–\xad])', '= m.group("Pns_2").capitalize() + \'-lhe \'', 'Não se usa próclise no início do período', 'not m.group("Pns_2") in proClise and option(LOCALE,"pronominal")'],
 ['(?u)((?<=[!?.] )|^)([MT])e (?P<Pns_3>[a-záâãçéêíóôõú]+[aeioumr])(?![-\\w–\xad])', '= m.group("Pns_3").capitalize() + \'-\' + m.group(2).lower() + \'e \'', 'Não se usa próclise no início do período', 'not m.group("Pns_3") in proClise and option(LOCALE,"pronominal")'],
 ['(?u)((?<=[!?.] )|^)Lhe (?P<Pns_4>[a-záâãçéêíóôõú]+[aeioumr])(?![-\\w–\xad])', '= m.group("Pns_4").capitalize() + \'-lhe \'', 'Não se usa próclise no início do período', 'not m.group("Pns_4") in proClise and option(LOCALE,"pronominal")'],
# -*- FIM Colocacao Pronominal -*-
# -*- Uso de pronome -*-
 ['(?u)(?<![-\\w–.,\xad])([Oo])[s] ([MmSsTt])[e][u](?![-\\w–\xad])', '\\1s \\2eus\\n\\1 \\2e', 'Artigo precisa concordar em número com o pronome. Você quis dizer:', 'option(LOCALE,"pronome")'],
 ['(?u)(?<![-\\w–.,\xad])([Oo]) ([MmSsTt])[e][u][s](?![-\\w–\xad])', '\\1s \\2eus\\n\\1 \\2e', 'Artigo precisa concordar em número com o pronome. Você quis dizer:', 'option(LOCALE,"pronome")'],
 ['(?u)(?<![-\\w–.,\xad])([MmTtSs])[e][u][s][ ](?P<Ngs_2>[1][,][0-9]+) ([bm])ilhões(?![-\\w–\xad])', '\\1eu \\g<Ngs_2> \\3ilhão', 'Pronome precisa concordar em gênero com numeral. Você quis dizer:', 'option(LOCALE,"pronome")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s minha(?![-\\w–\xad])', '\\1s minhas\\n\\1 minha', 'Artigo precisa concordar em número com o pronome. Você quis dizer:', 'option(LOCALE,"pronome")'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s ([ts])ua(?![-\\w–\xad])', '\\1s \\2uas\\n\\1 \\2ua', 'Artigo precisa concordar em número com o pronome. Você quis dizer:', 'option(LOCALE,"pronome")'],
 ['(?u)(?<![-\\w–.,\xad])([AaOo])s ([nv])oss([oa])(?![-\\w–\xad])', '\\1s \\2oss\\3s\\n\\1 \\2oss\\3', 'Artigo precisa concordar em número com o pronome. Você quis dizer:', 'option(LOCALE,"pronome")'],
 ['(?u)(?<![-\\w–.,\xad])entre nos e(?![-\\w–\xad])', 'entre nós e\\nentre nós é', 'Você quis dizer:', 'option(LOCALE,"pronome")'],
 ['(?u)(?<![-\\w–.,\xad])entre nos([.?!,;])(?![-\\w–\xad])', 'entre nós\\1', 'Você quis dizer:', 'option(LOCALE,"pronome")'],
 ['(?u)(?<![-\\w–.,\xad])entre eu e(?![-\\w–\xad])', 'entre mim e', 'Você quis dizer:', 'option(LOCALE,"pronome")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ara eu([.?!,;])(?![-\\w–\xad])', '\\1ara mim\\2', 'Você quis dizer:', 'option(LOCALE,"pronome")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ara mim (?P<Pmim_1>[a-zç]+[r])(?![-\\w–\xad])', '\\1ara eu \\g<Pmim_1>', 'Você quis dizer:', 'not m.group("Pmim_1") in "-por-" and option(LOCALE,"pronome")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ara eu (?P<Pmim_2>[a-záâçéêíóôú]+[aoems])(?![-\\w–\xad])', '\\1ara mim \\g<Pmim_2>', 'Você quis dizer:', 'option(LOCALE,"pronome")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ra eu([.?!,;])(?![-\\w–\xad])', '\\1ra mim\\2', 'Você quis dizer:', 'option(LOCALE,"pronome")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ra mim (?P<Pmim_3>[a-zç]+[Rr])(?![-\\w–\xad])', '\\1ra eu \\g<Pmim_3>', 'Você quis dizer:', 'option(LOCALE,"pronome")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ra eu (?P<Pmim_4>[a-záâçéêíóôú]+[aoems])(?![-\\w–\xad])', '\\1ra mim \\g<Pmim_4>', 'Você quis dizer:', 'option(LOCALE,"pronome")'],
 ['(?u)(?<![-\\w–.,\xad])[AaÀà][ ][e][u](?![-\\w–\xad])', 'a mim', 'Você quis dizer:', 'option(LOCALE,"pronome")'],
 ['(?u)(?<![-\\w–.,\xad])[AaÀà][ ][t][u](?![-\\w–\xad])', 'a ti', 'Você quis dizer:', 'option(LOCALE,"pronome")'],
# -*- FIM Uso de pronome -*-
# -*- Cacofonia -*-
# ['(?u)(?<![-\\w–.,\xad])([Pp])or cada(?![-\\w–\xad])', '\\1or', 'Cacofonia. Você quis dizer:', 'not "or cada um" in TEXT and option(LOCALE,"nonmetric")'],
# -*- FIM Cacofonia -*-
# -*- Emprego do porque, por que -*-
 ['(?u)(?<![-\\w–.,\xad])([Pp])or que([.?!;])(?![-\\w–\xad])', '\\1or quê\\2', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque([.?!;])(?![-\\w–\xad])', '\\1or quê\\2', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque (?P<Prq_1>[a-zA-Z0-9áâãçéêíóôõú]+)[?](?![-\\w–\xad])', '\\1or que \\g<Prq_1>?', 'Quando a palavra razão estiver clara ou implícita, usa-se por que. Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque (?P<Prq_2>[a-zA-Z0-9áâãçéêíóôõú]+) (?P<Prq_3>[a-zA-Z0-9áâãçéêíóôõú]+)[?](?![-\\w–\xad])', '\\1or que \\g<Prq_2> \\g<Prq_3>?', 'Quando a palavra razão estiver clara ou implícita, usa-se por que. Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque (?P<Prq_4>[a-zA-Z0-9áâãçéêíóôõú]+) (?P<Prq_5>[a-zA-Z0-9áâãçéêíóôõú]+) (?P<Prq_6>[a-zA-Z0-9áâãçéêíóôõú]+)[?](?![-\\w–\xad])', '\\1or que \\g<Prq_4> \\g<Prq_5> \\g<Prq_6>?', 'Quando a palavra razão estiver clara ou implícita, usa-se por que. Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque de(?![-\\w–\xad])', 'o porquê de', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque da(?![-\\w–\xad])', 'o porquê da', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque.(?![-\\w–\xad])', 'o porquê.', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque e(?![-\\w–\xad])', 'o porquê e', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque do(?![-\\w–\xad])', 'o porquê do', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque das(?![-\\w–\xad])', 'o porquê das', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque,(?![-\\w–\xad])', 'o porquê,', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque disso(?![-\\w–\xad])', 'o porquê disso', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque deste(?![-\\w–\xad])', 'o porquê deste', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque destes(?![-\\w–\xad])', 'o porquê destes', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque dos(?![-\\w–\xad])', 'o porquê dos', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque disto(?![-\\w–\xad])', 'o porquê disto', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque desta(?![-\\w–\xad])', 'o porquê desta', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque desse(?![-\\w–\xad])', 'o porquê desse', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque desses(?![-\\w–\xad])', 'o porquê desses', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque dessas(?![-\\w–\xad])', 'o porquê dessas', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque daquilo(?![-\\w–\xad])', 'o porquê daquilo', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque daquele(?![-\\w–\xad])', 'o porquê daquele', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque daqueles(?![-\\w–\xad])', 'o porquê daqueles', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque daquela(?![-\\w–\xad])', 'o porquê daquela', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o porque daquelas(?![-\\w–\xad])', 'o porquê daquelas', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o por que (da|das|de|do|dos|e|disso|deste|destes|desta|destas|desse|desses|disto|daquilo|daquela|daquelas|daquele|daqueles)(?![-\\w–\xad])', 'o porquê \\1', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])o por quê (da|das|de|do|dos|e|disso|deste|destes|desta|destas|desse|desses|disto|daquilo|daquela|daquelas|daquele|daqueles)(?![-\\w–\xad])', 'o porquê \\1', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])até por que,(?![-\\w–\xad])', 'até porque,', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])até por que (a|as|o|os)(?![-\\w–\xad])', 'até porque \\1', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])é por que (a|as|o|os|eu|não|nós|ela|elas|ele|eles)(?![-\\w–\xad])', 'é porque \\1', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])mas por que (a|as|o|os|eu|não|nós|ela|elas|ele|eles)(?![-\\w–\xad])', 'mas porque \\1', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])ou por que (a|as|o|os|eu|não|nós|ela|elas|ele|eles)(?![-\\w–\xad])', 'ou porque \\1', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])só por que (a|as|o|os|eu|não|nós|ela|elas|ele|eles)(?![-\\w–\xad])', 'só porque \\1', 'Você quis dizer:', 'option(LOCALE,"porque")'],
 ['(?u)(?<![-\\w–.,\xad])Por que(?![-\\w–\xad])', 'Porque', 'Frase interrogativa? Falta a interrogação. Ou você quis dizer:', 'not "?" in TEXT and option(LOCALE,"porque")'],
# -*- FIM Emprego do porque, por que -*-
# Verbos ser e ficar
 ['(?u)(?<![-\\w–.,\xad])([Ee]ram|[Ff]icam|[Ff]icaram|[Ff]icavam|[Ff]icarão|[Ff]icariam|[Ff]oram|[Ff]ossem|[Ss]ão|[Ss]eriam|[Ss]erão|[Ss]ejam) (?P<Mvser_0>[a-zç]+)([aií])d(a|o)(?![-\\w–\xad])', '\\1 \\2\\3d\\4s', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]ra|[Ff]ica|[Ff]icou|[Ff]icava|[Ff]icará|[Ff]icaria|[Ff]oi|[Ff]osse|é|[Ss]eria|[Ss]erá) (?P<Mvser_1>[a-zç]+)([aií])d(a|o)s(?![-\\w–\xad])', '\\1 \\2\\3d\\4', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]ram|[Ff]icam|[Ff]icaram|[Ff]icavam|[Ff]icarão|[Ff]icariam|[Ff]oram|[Ff]ossem|[Ss]ão|[Ss]eriam|[Ss]erão|[Ss]ejam) (?P<Mvser_2>[a-z]+)mente (?P<Mvser_3>[a-zç]+)([aií])d(a|o)(?![-\\w–\xad])', '\\1 \\2mente \\3\\4d\\5s', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]ra|[Ff]ica|[Ff]icou|[Ff]icava|[Ff]icará|[Ff]icaria|[Ff]oi|[Ff]osse|é|[Ss]eria|[Ss]erá) (?P<Mvser_4>[a-z]+)mente (?P<Mvser_5>[a-zç]+)([aií])d(a|o)s(?![-\\w–\xad])', '\\1 \\2mente \\3\\4d\\5', 'Você quis dizer:', False],
#
 ['(?u)(?<![-\\w–.,\xad])([Ee]ram|[Ff]icam|[Ff]icaram|[Ff]icavam|[Ff]icarão|[Ff]icariam|[Ff]oram|[Ff]ossem|[Ss]ão|[Ss]eriam|[Ss]erão|[Ss]ejam) (?P<Mvser_6>[a-zç]+)os(a|o)(?![-\\w–\xad])', '\\1 \\2os\\3s', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]ra|[Ff]ica|[Ff]icou|[Ff]icava|[Ff]icará|[Ff]icaria|[Ff]oi|[Ff]osse|é|[Ss]eria|[Ss]erá) (?P<Mvser_7>[a-zç]+)os(a|o)s(?![-\\w–\xad])', '\\1 \\2os\\3', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]ram|[Ff]icam|[Ff]icaram|[Ff]icavam|[Ff]icarão|[Ff]icariam|[Ff]oram|[Ff]ossem|[Ss]ão|[Ss]eriam|[Ss]erão|[Ss]ejam) (?P<Mvser_8>[a-z]+)mente (?P<Mvser_9>[a-zç]+)os(a|o)(?![-\\w–\xad])', '\\1 \\2mente \\3os\\4s', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]ra|[Ff]ica|[Ff]icou|[Ff]icava|[Ff]icará|[Ff]icaria|[Ff]oi|[Ff]osse|é|[Ss]eria|[Ss]erá) (?P<Mvser_10>[a-z]+)mente (?P<Mvser_11>[a-zç]+)os(a|o)s(?![-\\w–\xad])', '\\1 \\2mente \\3os\\4', 'Você quis dizer:', False],
#
 ['(?u)(?<![-\\w–.,\xad])([Ee]ram|[Ff]icam|[Ff]icaram|[Ff]icavam|[Ff]icarão|[Ff]icariam|[Ff]oram|[Ff]ossem|[Ss]ão|[Ss]eriam|[Ss]erão|[Ss]ejam) (?P<Mvser_12>[a-zç]+)dade(?![-\\w–\xad])', '\\1 \\2dades', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]ra|[Ff]ica|[Ff]icou|[Ff]icava|[Ff]icará|[Ff]icaria|[Ff]oi|[Ff]osse|é|[Ss]eria|[Ss]erá) (?P<Mvser_13>[a-zç]+)dades(?![-\\w–\xad])', '\\1 \\2dade', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]ram|[Ff]icam|[Ff]icaram|[Ff]icavam|[Ff]icarão|[Ff]icariam|[Ff]oram|[Ff]ossem|[Ss]ão|[Ss]eriam|[Ss]erão|[Ss]ejam) (?P<Mvser_14>[a-z]+)mente (?P<Mvser_15>[a-zç]+)dade(?![-\\w–\xad])', '\\1 \\2mente \\3dades', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]ra|[Ff]ica|[Ff]icou|[Ff]icava|[Ff]icará|[Ff]icaria|[Ff]oi|[Ff]osse|é|[Ss]eria|[Ss]erá) (?P<Mvser_16>[a-z]+)mente (?P<Mvser_17>[a-zç]+)dades(?![-\\w–\xad])', '\\1 \\2mente \\3dade', 'Você quis dizer:', False],
#
 ['(?u)(?<![-\\w–.,\xad])([Ee]ram|[Ff]icam|[Ff]icaram|[Ff]icavam|[Ff]icarão|[Ff]icariam|[Ff]oram|[Ff]ossem|[Ss]ão|[Ss]eriam|[Ss]erão|[Ss]ejam) (?P<Mvser_18>[a-zç]+)iv(a|o)(?![-\\w–\xad])', '\\1 \\2iv\\3s', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]ra|[Ff]ica|[Ff]icou|[Ff]icava|[Ff]icará|[Ff]icaria|[Ff]oi|[Ff]osse|é|[Ss]eria|[Ss]erá) (?P<Mvser_19>[a-zç]+)iv(a|o)s(?![-\\w–\xad])', '\\1 \\2iv\\3', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]ram|[Ff]icam|[Ff]icaram|[Ff]icavam|[Ff]icarão|[Ff]icariam|[Ff]oram|[Ff]ossem|[Ss]ão|[Ss]eriam|[Ss]erão|[Ss]ejam) (?P<Mvser_20>[a-z]+)mente (?P<Mvser_21>[a-zç]+)iv(a|o)(?![-\\w–\xad])', '\\1 \\2mente \\3iv\\4s', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]ra|[Ff]ica|[Ff]icou|[Ff]icava|[Ff]icará|[Ff]icaria|[Ff]oi|[Ff]osse|é|[Ss]eria|[Ss]erá) (?P<Mvser_22>[a-z]+)mente (?P<Mvser_23>[a-zç]+)iv(a|o)s(?![-\\w–\xad])', '\\1 \\2mente \\3iv\\4', 'Você quis dizer:', False],
#
 ['(?u)(?<![-\\w–.,\xad])([Ee]ram|[Ff]icam|[Ff]icaram|[Ff]icavam|[Ff]icarão|[Ff]icariam|[Ff]oram|[Ff]ossem|[Ss]ão|[Ss]eriam|[Ss]erão|[Ss]ejam) (ainda|antes|apenas|até|assim|bastante|bem|depois|então|já|logo|mais|mal|melhor|menos|mesmo|muito|pouco|quase|primeiro|sempre|tão|também) (?P<Avser_0>[a-zç]+)([aií])d(a|o)(?![-\\w–\xad])', '\\1 \\2 \\3\\4d\\5s', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]ra|[Ff]ica|[Ff]icou|[Ff]icava|[Ff]icará|[Ff]icaria|[Ff]oi|[Ff]osse|é|[Ss]eria|[Ss]erá) (ainda|antes|apenas|até|assim|bastante|bem|depois|então|já|logo|mais|mal|melhor|menos|mesmo|muito|pouco|quase|primeiro|sempre|tão|também) (?P<Avser_1>[a-zç]+)([aií])d(a|o)s(?![-\\w–\xad])', '\\1 \\2 \\3\\4d\\5', 'Você quis dizer:', False],
#
 ['(?u)(?<![-\\w–.,\xad])([Ee]ram|[Ff]icam|[Ff]icaram|[Ff]icavam|[Ff]icarão|[Ff]icariam|[Ff]oram|[Ff]ossem|[Ss]ão|[Ss]eriam|[Ss]erão|[Ss]ejam) (ainda|antes|apenas|até|assim|bastante|bem|depois|então|já|logo|mais|mal|melhor|menos|mesmo|muito|pouco|quase|primeiro|sempre|tão|também) (?P<Avser_2>[a-zç]+)os(a|o)(?![-\\w–\xad])', '\\1 \\2 \\3os\\4s', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]ra|[Ff]ica|[Ff]icou|[Ff]icava|[Ff]icará|[Ff]icaria|[Ff]oi|[Ff]osse|é|[Ss]eria|[Ss]erá) (ainda|antes|apenas|até|assim|bastante|bem|depois|então|já|logo|mais|mal|melhor|menos|mesmo|muito|pouco|quase|primeiro|sempre|tão|também) (?P<Avser_3>[a-zç]+)os(a|o)s(?![-\\w–\xad])', '\\1 \\2 \\3os\\4', 'Você quis dizer:', False],
#
 ['(?u)(?<![-\\w–.,\xad])([Ee]ram|[Ff]icam|[Ff]icaram|[Ff]icavam|[Ff]icarão|[Ff]icariam|[Ff]oram|[Ff]ossem|[Ss]ão|[Ss]eriam|[Ss]erão|[Ss]ejam) (ainda|antes|apenas|até|assim|bastante|bem|depois|então|já|logo|mais|mal|melhor|menos|mesmo|muito|pouco|quase|primeiro|sempre|tão|também) (?P<Avser_4>[a-zç]+)os(a|o)(?![-\\w–\xad])', '\\1 \\2 \\3iv\\4s', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]ra|[Ff]ica|[Ff]icou|[Ff]icava|[Ff]icará|[Ff]icaria|[Ff]oi|[Ff]osse|é|[Ss]eria|[Ss]erá) (ainda|antes|apenas|até|assim|bastante|bem|depois|então|já|logo|mais|mal|melhor|menos|mesmo|muito|pouco|quase|primeiro|sempre|tão|também) (?P<Avser_5>[a-zç]+)os(a|o)s(?![-\\w–\xad])', '\\1 \\2 \\3iv\\4', 'Você quis dizer:', False],
#
 ['(?u)(?<![-\\w–.,\xad])([Ee]ram|[Ff]icam|[Ff]icaram|[Ff]icavam|[Ff]icarão|[Ff]icariam|[Ff]oram|[Ff]ossem|[Ss]ão|[Ss]eriam|[Ss]erão|[Ss]ejam) (ainda|antes|apenas|até|assim|bastante|bem|depois|então|já|logo|mais|mal|melhor|menos|mesmo|muito|pouco|quase|primeiro|sempre|tão|também) (?P<Avser_6>[a-zç]+)dade(?![-\\w–\xad])', '\\1 \\2 \\3dades', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]ra|[Ff]ica|[Ff]icou|[Ff]icava|[Ff]icará|[Ff]icaria|[Ff]oi|[Ff]osse|é|[Ss]eria|[Ss]erá) (ainda|antes|apenas|até|assim|bastante|bem|depois|então|já|logo|mais|mal|melhor|menos|mesmo|muito|pouco|quase|primeiro|sempre|tão|também) (?P<Avser_7>[a-zç]+)dades(?![-\\w–\xad])', '\\1 \\2 \\3dade', 'Você quis dizer:', False],
# fim Verbos ser e ficar
 ['(?u)(?<![-\\w–.,\xad])([Tt])odas a(?![-\\w–\xad])', '\\1odas as', 'Você quis dizer:', 'not excTodas.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])mbas a(?![-\\w–\xad])', '\\1mbas as', 'Você quis dizer:', 'not excAmbas.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])Haja visto(?![-\\w–\xad])', 'Haja vista', 'Haja vista é invariável. Você quis dizer:', False],
 ['(?u)(,) haja visto(?![-\\w–\xad])', ', haja vista', 'Haja vista é invariável. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])tipo(?![-\\w–\xad])', 'tipos', 'Você quis dizer:', 'vtipos.search(TEXT)'],
# Concordancia artigo a mais plural feminino
# Virgula as
 ['(?u)\\b([,]) a (?P<Msvrg_2>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1 as \\2s\\n\\1 há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_2").lower() in plvrFema and not ", a suas expensas" in TEXT'],
 ['(?u)\\b([,]) a (?P<Msvrg_4>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '\\1 as \\2as\\n\\1 há \\2as', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_4").lower() in plvrMfoa '],
 ['(?u)\\b([,]) a (?P<Msvrg_8>[a-zA-Z]+ista)s(?![-\\w–\xad])', '\\1 as \\2s\\n\\1 há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msvrg_8").lower() in excIsta'],
 ['(?u)\\b([,]) a (?P<Msvrg_10>[a-zA-Z]+a)s(?![-\\w–\xad])', '\\1 as \\2s\\n\\1 há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_10").lower() in plvrInva'],
 ['(?u)\\b([,]) a (?P<Msvrg_12>[a-zA-Z]+)([aí])das(?![-\\w–\xad])', '\\1 as \\2das\\n\\1 há \\2das', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msvrg_12").lower() in excAdo'],
 ['(?u)\\b([,]) a (?P<Msvrg_16>[a-zA-Zç]+)osas(?![-\\w–\xad])', '\\1 as \\2osas\\n\\1 há \\2osas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) a (?P<Msvrg_18>[a-zA-Zç]+)ivas(?![-\\w–\xad])', '\\1 as \\2ivas\\n\\1 há \\2ivas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) a (?P<Msvrg_22>[a-zA-Zç]+[âêô][mn])icas(?![-\\w–\xad])', '\\1 as \\2icas\\n\\1 há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) a (?P<Msvrg_24>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '\\1 as \\2icas\\n\\1 há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) a (?P<Msvrg_26>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '\\1 as \\2icas\\n\\1 há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) a (?P<Msvrg_28>[a-zA-Zç]+)escas(?![-\\w–\xad])', '\\1 as \\2escas\\n\\1 há \\2escas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) a (?P<Msvrg_30>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '\\1 as \\2idas\\n\\1 há \\2idas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) a (?P<Msvrg_32>[a-zA-Zç]+[ó])logas(?![-\\w–\xad])', '\\1 as \\2logas\\n\\1 há \\2logas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) a (?P<Msvrg_34>[a-zA-Zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '\\1 as \\2rias\\n\\1 há \\2rias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) a (?P<Msvrg_36>[a-zA-Zç]+[í])ssimas(?![-\\w–\xad])', '\\1 as \\2ssimas\\n\\1 há \\2ssimas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) a (?P<Msvrg_38>[a-zA-Zç]+[é])simas(?![-\\w–\xad])', '\\1 as \\2simas\\n\\1 há \\2simas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) a (?P<Msvrg_42>[a-zA-Zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '\\1 as \\2oras\\n\\1 há \\2oras', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) a (?P<Msvrg_44>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '\\1 as \\2es\\n\\1 há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_44") in plvrMfr'],
 ['(?u)\\b([,]) a (?P<Msvrg_46>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '\\1 as \\2es\\n\\1 há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_46") in plvrFemr'],
 ['(?u)\\b([,]) a (?P<Msvrg_48>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '\\1 as \\2is\\n\\1 há \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_48") in plvrMfal'],
 ['(?u)\\b([,]) a (?P<Msvrg_50>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1 as \\2ões\\n\\1 há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_50") in plvrMfcao'],
 ['(?u)\\b([,]) a (?P<Msvrg_52>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1 as \\2ões\\n\\1 há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msvrg_52") in plvrMascao'],
 ['(?u)\\b([,]) a (?P<Msvrg_54>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '\\1 as \\2ões\\n\\1 há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_54") in plvrFemao'],
 ['(?u)\\b([,]) a (?P<Msvrg_56>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '\\1 as \\2veis\\n\\1 há \\2veis', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) a (?P<Msvrg_58>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1 as \\2es\\n\\1 há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_58").lower() in plvrMfe'],
 ['(?u)\\b([,]) a (?P<Msvrg_60>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1 as \\2es\\n\\1 há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_60").lower() in plvrFeme'],
 ['(?u)\\b([,]) a (?P<Msvrg_62>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1 as \\2éis\\n\\1 há \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_62") in plvrMfel'],
 ['(?u)\\b([,]) a (?P<Msvrg_64>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1 as \\2éis\\n\\1 há \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_64") in plvrFemel'],
 ['(?u)\\b([,]) a (?P<Msvrg_66>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1 as \\2us\\n\\1 há \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_66") in plvrMfe'],
 ['(?u)\\b([,]) a (?P<Msvrg_68>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1 as \\2us\\n\\1 há \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_68") in plvrFem'],
 ['(?u)\\b([,]) a (?P<Msvrg_70>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1 as \\2zes\\n\\1 há \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_70") in plvrInvaz'],
 ['(?u)\\b([,]) a (?P<Msvrg_72>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1 as \\2zes\\n\\1 há \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_72") in plvrFemz'],
 ['(?u)\\b([,]) a (?P<Msvrg_73>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '\\1 as \\2ns\\n\\1 há \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_73") in plvrFemm'],
 ['(?u)\\b([,]) a (?P<Msvrg_74>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '\\1 as \\2ns\\n\\1 há \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvrg_74") in plvrMFm'],
# Como as
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_2>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1omo as \\2s\\n\\1omo há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_2").lower() in plvrFema and not " bem como a " in TEXT and not " como a suas expensas " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_4>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '\\1omo as \\2as\\n\\1omo há \\2as', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_4").lower() in plvrMfoa and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_8>[a-zA-Z]+ista)s(?![-\\w–\xad])', '\\1omo as \\2s\\n\\1omo há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscmo_8").lower() in excIsta and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_10>[a-zA-Z]+a)s(?![-\\w–\xad])', '\\1omo as \\2s\\n\\1omo há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_10").lower() in plvrInva and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_12>[a-zA-Z]+)([aí])das(?![-\\w–\xad])', '\\1omo as \\2das\\n\\1omo há \\2das', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscmo_12").lower() in excAdo and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_16>[a-zA-Zç]+)osas(?![-\\w–\xad])', '\\1omo as \\2osas\\n\\1omo há \\2osas', 'Não há concordância entre as palavras. Você quis dizer:', 'not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_18>[a-zA-Zç]+)ivas(?![-\\w–\xad])', '\\1omo as \\2ivas\\n\\1omo há \\2ivas', 'Não há concordância entre as palavras. Você quis dizer:', 'not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_22>[a-zA-Zç]+[âêô][mn])icas(?![-\\w–\xad])', '\\1omo as \\2icas\\n\\1omo há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', 'not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_24>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '\\1omo as \\2icas\\n\\1omo há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', 'not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_26>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '\\1omo as \\2icas\\n\\1omo há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', 'not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_28>[a-zA-Zç]+)escas(?![-\\w–\xad])', '\\1omo as \\2escas\\n\\1omo há \\2escas', 'Não há concordância entre as palavras. Você quis dizer:', 'not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_30>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '\\1omo as \\2idas\\n\\1omo há \\2idas', 'Não há concordância entre as palavras. Você quis dizer:', 'not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_32>[a-zA-Zç]+[ó])logas(?![-\\w–\xad])', '\\1omo as \\2logas\\n\\1omo há \\2logas', 'Não há concordância entre as palavras. Você quis dizer:', 'not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_34>[a-zA-Zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '\\1omo as \\2rias\\n\\1omo há \\2rias', 'Não há concordância entre as palavras. Você quis dizer:', 'not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_36>[a-zA-Zç]+[í])ssimas(?![-\\w–\xad])', '\\1omo as \\2ssimas\\n\\1omo há \\2ssimas', 'Não há concordância entre as palavras. Você quis dizer:', 'not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_38>[a-zA-Zç]+[é])simas(?![-\\w–\xad])', '\\1omo as \\2simas\\n\\1omo há \\2simas', 'Não há concordância entre as palavras. Você quis dizer:', 'not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_42>[a-zA-Zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '\\1omo as \\2oras\\n\\1omo há \\2oras', 'Não há concordância entre as palavras. Você quis dizer:', 'not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_44>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '\\1omo as \\2es\\n\\1omo há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_44") in plvrMfr and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_46>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '\\1omo as \\2es\\n\\1omo há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_46") in plvrFemr and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_48>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '\\1omo as \\2is\\n\\1omo há \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_48") in plvrMfal and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_50>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1omo as \\2ões\\n\\1omo há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_50") in plvrMfcao and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_52>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1omo as \\2ões\\n\\1omo há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscmo_52") in plvrMascao and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_54>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '\\1omo as \\2ões\\n\\1omo há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_54") in plvrFemao and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_56>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '\\1omo as \\2veis\\n\\1omo há \\2veis', 'Não há concordância entre as palavras. Você quis dizer:', 'not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_58>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1omo as \\2es\\n\\1omo há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_58").lower() in plvrMfe and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_60>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1omo as \\2es\\n\\1omo há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_60").lower() in plvrFeme and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_62>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1omo as \\2éis\\n\\1omo há \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_62") in plvrMfel and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_64>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1omo as \\2éis\\n\\1omo há \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_64") in plvrFemel and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_66>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1omo as \\2us\\n\\1omo há \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_66") in plvrMfeu and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_68>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1omo as \\2us\\n\\1omo há \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_68") in plvrFemu and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_70>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1omo as \\2zes\\n\\1omo há \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_70") in plvrInvaz and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_72>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1omo as \\2zes\\n\\1omo há \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_72") in plvrFemz and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_73>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '\\1omo as \\2ns\\n\\1omo há \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_73") in plvrFemm and not " bem como a " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omo a (?P<Mscmo_74>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '\\1omo as \\2ns\\n\\1omo há \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscmo_74") in plvrMFm and not " bem como a " in TEXT'],
# onde as
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_2>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1nde as \\2s\\n\\1nde há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_2").lower() in plvrFema and not " onde a suas expensas " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_4>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '\\1nde as \\2as\\n\\1nde há \\2as', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_4").lower() in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_8>[a-zA-Z]+ista)s(?![-\\w–\xad])', '\\1nde as \\2s\\n\\1nde há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msond_8").lower() in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_10>[a-zA-Z]+a)s(?![-\\w–\xad])', '\\1nde as \\2s\\n\\1nde há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_10").lower() in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_12>[a-zA-Z]+)([aí])das(?![-\\w–\xad])', '\\1nde as \\2das\\n\\1nde há \\2das', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msond_12").lower() in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_16>[a-zA-Zç]+)osas(?![-\\w–\xad])', '\\1nde as \\2osas\\n\\1nde há \\2osas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_18>[a-zA-Zç]+)ivas(?![-\\w–\xad])', '\\1nde as \\2ivas\\n\\1nde há \\2ivas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_22>[a-zA-Zç]+[âêô][mn])icas(?![-\\w–\xad])', '\\1nde as \\2icas\\n\\1nde há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_24>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '\\1nde as \\2icas\\n\\1nde há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_26>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '\\1nde as \\2icas\\n\\1nde há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_28>[a-zA-Zç]+)escas(?![-\\w–\xad])', '\\1nde as \\2escas\\n\\1nde há \\2escas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_30>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '\\1nde as \\2idas\\n\\1nde há \\2idas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_32>[a-zA-Zç]+[ó])logas(?![-\\w–\xad])', '\\1nde as \\2logas\\n\\1nde há \\2logas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_34>[a-zA-Zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '\\1nde as \\2rias\\n\\1nde há \\2rias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_36>[a-zA-Zç]+[í])ssimas(?![-\\w–\xad])', '\\1nde as \\2ssimas\\n\\1nde há \\2ssimas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_38>[a-zA-Zç]+[é])simas(?![-\\w–\xad])', '\\1nde as \\2simas\\n\\1nde há \\2simas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_42>[a-zA-Zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '\\1nde as \\2oras\\n\\1nde há \\2oras', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_44>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '\\1nde as \\2es\\n\\1nde há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_44") in plvrMfr'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_46>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '\\1nde as \\2es\\n\\1nde há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_46") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_48>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '\\1nde as \\2is\\n\\1nde há \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_48") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_50>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1nde as \\2ões\\n\\1nde há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_50") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_52>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1nde as \\2ões\\n\\1nde há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msond_52") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_54>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '\\1nde as \\2ões\\n\\1nde há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_54") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_56>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '\\1nde as \\2veis\\n\\1nde há \\2veis', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_58>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1nde as \\2es\\n\\1nde há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_58").lower() in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_60>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1nde as \\2es\\n\\1nde há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_60").lower() in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_62>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1nde as \\2éis\\n\\1nde há \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_62") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_64>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1nde as \\2éis\\n\\1nde há \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_64") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_66>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1nde as \\2us\\n\\1nde há \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_66") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_68>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1nde as \\2us\\n\\1nde há \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_68") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_70>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1nde as \\2zes\\n\\1nde há \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_70") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_72>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1nde as \\2zes\\n\\1nde há \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_72") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_73>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '\\1nde as \\2ns\\n\\1nde há \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_73") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])nde a (?P<Msond_74>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '\\1nde as \\2ns\\n\\1nde há \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msond_74") in plvrMFm'],
# Porque as
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_2>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1orque as \\2s\\n\\1orque há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_2").lower() in plvrFema and not " porque a suas expensas " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_4>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '\\1orque as \\2as\\n\\1orque há \\2as', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_4").lower() in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_8>[a-zA-Z]+ista)s(?![-\\w–\xad])', '\\1orque as \\2s\\n\\1orque há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msprq_8").lower() in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_10>[a-zA-Z]+a)s(?![-\\w–\xad])', '\\1orque as \\2s\\n\\1orque há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_10").lower() in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_12>[a-zA-Z]+)([aí])das(?![-\\w–\xad])', '\\1orque as \\2das\\n\\1orque há \\2das', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msprq_12").lower() in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_16>[a-zA-Zç]+)osas(?![-\\w–\xad])', '\\1orque as \\2osas\\n\\1orque há \\2osas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_18>[a-zA-Zç]+)ivas(?![-\\w–\xad])', '\\1orque as \\2ivas\\n\\1orque há \\2ivas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_22>[a-zA-Zç]+[âêô][mn])icas(?![-\\w–\xad])', '\\1orque as \\2icas\\n\\1orque há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_24>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '\\1orque as \\2icas\\n\\1orque há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_26>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '\\1orque as \\2icas\\n\\1orque há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_28>[a-zA-Zç]+)escas(?![-\\w–\xad])', '\\1orque as \\2escas\\n\\1orque há \\2escas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_30>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '\\1orque as \\2idas\\n\\1orque há \\2idas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_32>[a-zA-Zç]+[ó])logas(?![-\\w–\xad])', '\\1orque as \\2logas\\n\\1orque há \\2logas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_34>[a-zA-Zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '\\1orque as \\2rias\\n\\1orque há \\2rias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_36>[a-zA-Zç]+[í])ssimas(?![-\\w–\xad])', '\\1orque as \\2ssimas\\n\\1orque há \\2ssimas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_38>[a-zA-Zç]+[é])simas(?![-\\w–\xad])', '\\1orque as \\2simas\\n\\1orque há \\2simas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_42>[a-zA-Zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '\\1orque as \\2oras\\n\\1orque há \\2oras', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_44>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '\\1orque as \\2es\\n\\1orque há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_44") in plvrMfr'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_46>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '\\1orque as \\2es\\n\\1orque há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_46") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_48>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '\\1orque as \\2is\\n\\1orque há \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_48") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_50>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1orque as \\2ões\\n\\1orque há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_50") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_52>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1orque as \\2ões\\n\\1orque há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msprq_52") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_54>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '\\1orque as \\2ões\\n\\1orque há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_54") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_56>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '\\1orque as \\2veis\\n\\1orque há \\2veis', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_58>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1orque as \\2es\\n\\1orque há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_58").lower() in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_60>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1orque as \\2es\\n\\1orque há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_60").lower() in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_62>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1orque as \\2éis\\n\\1orque há \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_62") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_64>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1orque as \\2éis\\n\\1orque há \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_64") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_66>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1orque as \\2us\\n\\1orque há \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_66") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_68>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1orque as \\2us\\n\\1orque há \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_68") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_70>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1orque as \\2zes\\n\\1orque há \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_70") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_72>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1orque as \\2zes\\n\\1orque há \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_72") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_73>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '\\1orque as \\2ns\\n\\1orque há \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_73") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orque a (?P<Msprq_74>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '\\1orque as \\2ns\\n\\1orque há \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msprq_74") in plvrMFm'],
# Quando as
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_2>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1uando as \\2s\\n\\1uando há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_2").lower() in plvrFema and not " quando a suas expensas " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_4>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '\\1uando as \\2as\\n\\1uando há \\2as', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_4").lower() in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_8>[a-zA-Z]+ista)s(?![-\\w–\xad])', '\\1uando as \\2s\\n\\1uando há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msqdo_8").lower() in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_10>[a-zA-Z]+a)s(?![-\\w–\xad])', '\\1uando as \\2s\\n\\1uando há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_10").lower() in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_12>[a-zA-Z]+)([aí])das(?![-\\w–\xad])', '\\1uando as \\2das\\n\\1uando há \\2das', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msqdo_12").lower() in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_16>[a-zA-Zç]+)osas(?![-\\w–\xad])', '\\1uando as \\2osas\\n\\1uando há \\2osas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_18>[a-zA-Zç]+)ivas(?![-\\w–\xad])', '\\1uando as \\2ivas\\n\\1uando há \\2ivas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_22>[a-zA-Zç]+[âêô][mn])icas(?![-\\w–\xad])', '\\1uando as \\2icas\\n\\1uando há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_24>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '\\1uando as \\2icas\\n\\1uando há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_26>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '\\1uando as \\2icas\\n\\1uando há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_28>[a-zA-Zç]+)escas(?![-\\w–\xad])', '\\1uando as \\2escas\\n\\1uando há \\2escas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_30>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '\\1uando as \\2idas\\n\\1uando há \\2idas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_32>[a-zA-Zç]+[ó])logas(?![-\\w–\xad])', '\\1uando as \\2logas\\n\\1uando há \\2logas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_34>[a-zA-Zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '\\1uando as \\2rias\\n\\1uando há \\2rias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_36>[a-zA-Zç]+[í])ssimas(?![-\\w–\xad])', '\\1uando as \\2ssimas\\n\\1uando há \\2ssimas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_38>[a-zA-Zç]+[é])simas(?![-\\w–\xad])', '\\1uando as \\2simas\\n\\1uando há \\2simas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_42>[a-zA-Zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '\\1uando as \\2oras\\n\\1uando há \\2oras', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_44>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '\\1uando as \\2es\\n\\1uando há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_44") in plvrMfr'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_46>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '\\1uando as \\2es\\n\\1uando há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_46") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_48>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '\\1uando as \\2is\\n\\1uando há \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_48") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_50>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1uando as \\2ões\\n\\1uando há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_50") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_52>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1uando as \\2ões\\n\\1uando há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msqdo_52") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_54>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '\\1uando as \\2ões\\n\\1uando há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_54") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_56>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '\\1uando as \\2veis\\n\\1uando há \\2veis', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_58>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1uando as \\2es\\n\\1uando há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_58").lower() in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_60>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1uando as \\2es\\n\\1uando há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_60").lower() in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_62>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1uando as \\2éis\\n\\1uando há \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_62") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_64>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1uando as \\2éis\\n\\1uando há \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_64") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_66>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1uando as \\2us\\n\\1uando há \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_66") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_68>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1uando as \\2us\\n\\1uando há \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_68") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_70>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1uando as \\2zes\\n\\1uando há \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_70") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_72>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1uando as \\2zes\\n\\1uando há \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_72") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_73>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '\\1uando as \\2ns\\n\\1uando há \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_73") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uando a (?P<Msqdo_74>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '\\1uando as \\2ns\\n\\1uando há \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msqdo_74") in plvrMFm'],
# Que as
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_2>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1ue as \\2s\\n\\1ue há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_2").lower() in plvrFema and not " que a suas expensas " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_4>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '\\1ue as \\2as\\n\\1ue há \\2as', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_4").lower() in plvrMfoa and not m.group("Msque_4") in "-dur-" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_8>[a-zA-Z]+ista)s(?![-\\w–\xad])', '\\1ue as \\2s\\n\\1ue há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msque_8").lower() in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_10>[a-zA-Z]+a)s(?![-\\w–\xad])', '\\1ue as \\2s\\n\\1ue há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_10").lower() in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_12>[a-zA-Z]+)([aí])das(?![-\\w–\xad])', '\\1ue as \\2das\\n\\1ue há \\2das', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msque_12").lower() in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_16>[a-zA-Zç]+)osas(?![-\\w–\xad])', '\\1ue as \\2osas\\n\\1ue há \\2osas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_18>[a-zA-Zç]+)ivas(?![-\\w–\xad])', '\\1ue as \\2ivas\\n\\1ue há \\2ivas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_22>[a-zA-Zç]+[âêô][mn])icas(?![-\\w–\xad])', '\\1ue as \\2icas\\n\\1ue há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_24>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '\\1ue as \\2icas\\n\\1ue há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_26>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '\\1ue as \\2icas\\n\\1ue há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_28>[a-zA-Zç]+)escas(?![-\\w–\xad])', '\\1ue as \\2escas\\n\\1ue há \\2escas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_30>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '\\1ue as \\2idas\\n\\1ue há \\2idas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_32>[a-zA-Zç]+[ó])logas(?![-\\w–\xad])', '\\1ue as \\2logas\\n\\1ue há \\2logas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_34>[a-zA-Zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '\\1ue as \\2rias\\n\\1ue há \\2rias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_36>[a-zA-Zç]+[í])ssimas(?![-\\w–\xad])', '\\1ue as \\2ssimas\\n\\1ue há \\2ssimas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_38>[a-zA-Zç]+[é])simas(?![-\\w–\xad])', '\\1ue as \\2simas\\n\\1ue há \\2simas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_42>[a-zA-Zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '\\1ue as \\2oras\\n\\1ue há \\2oras', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_44>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '\\1ue as \\2es\\n\\1ue há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_44") in plvrMfr'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_46>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '\\1ue as \\2es\\n\\1ue há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_46") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_48>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '\\1ue as \\2is\\n\\1ue há \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_48") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_50>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1ue as \\2ões\\n\\1ue há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_50") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_52>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1ue as \\2ões\\n\\1ue há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msque_52") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_54>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '\\1ue as \\2ões\\n\\1ue há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_54") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_56>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '\\1ue as \\2veis\\n\\1ue há \\2veis', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_58>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1ue as \\2es\\n\\1ue há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_58").lower() in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_60>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1ue as \\2es\\n\\1ue há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_60").lower() in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_62>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1ue as \\2éis\\n\\1ue há \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_62") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_64>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1ue as \\2éis\\n\\1ue há \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_64") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_66>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1ue as \\2us\\n\\1ue há \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_66") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_68>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1ue as \\2us\\n\\1ue há \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_68") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_70>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1ue as \\2zes\\n\\1ue há \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_70") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_72>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1ue as \\2zes\\n\\1ue há \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_72") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_73>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '\\1ue as \\2ns\\n\\1ue há \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_73") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ue a (?P<Msque_74>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '\\1ue as \\2ns\\n\\1ue há \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msque_74") in plvrMFm'],
# Se as
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_2>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1e as \\2s\\n\\1e há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_2").lower() in plvrFema and not " se a suas expensas " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_4>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '\\1e as \\2as\\n\\1e há \\2as', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_4").lower() in plvrMfoa and not m.group("Mssee_4") in "-dur-" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_8>[a-zA-Z]+ista)s(?![-\\w–\xad])', '\\1e as \\2s\\n\\1e há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssee_8").lower() in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_10>[a-zA-Z]+a)s(?![-\\w–\xad])', '\\1e as \\2s\\n\\1e há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_10").lower() in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_12>[a-zA-Z]+)([aí])das(?![-\\w–\xad])', '\\1e as \\2das\\n\\1e há \\2das', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssee_12").lower() in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_16>[a-zA-Zç]+)osas(?![-\\w–\xad])', '\\1e as \\2osas\\n\\1e há \\2osas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_18>[a-zA-Zç]+)ivas(?![-\\w–\xad])', '\\1e as \\2ivas\\n\\1e há \\2ivas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_22>[a-zA-Zç]+[âêô][mn])icas(?![-\\w–\xad])', '\\1e as \\2icas\\n\\1e há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_24>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '\\1e as \\2icas\\n\\1e há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_26>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '\\1e as \\2icas\\n\\1e há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_28>[a-zA-Zç]+)escas(?![-\\w–\xad])', '\\1e as \\2escas\\n\\1e há \\2escas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_30>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '\\1e as \\2idas\\n\\1e há \\2idas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_32>[a-zA-Zç]+[ó])logas(?![-\\w–\xad])', '\\1e as \\2logas\\n\\1e há \\2logas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_34>[a-zA-Zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '\\1e as \\2rias\\n\\1e há \\2rias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_36>[a-zA-Zç]+[í])ssimas(?![-\\w–\xad])', '\\1e as \\2ssimas\\n\\1e há \\2ssimas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_38>[a-zA-Zç]+[é])simas(?![-\\w–\xad])', '\\1e as \\2simas\\n\\1e há \\2simas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_42>[a-zA-Zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '\\1e as \\2oras\\n\\1e há \\2oras', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_44>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '\\1e as \\2es\\n\\1e há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_44") in plvrMfr'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_46>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '\\1e as \\2es\\n\\1e há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_46") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_48>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '\\1e as \\2is\\n\\1e há \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_48") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_50>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1e as \\2ões\\n\\1e há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_50") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_52>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1e as \\2ões\\n\\1e há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssee_52") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_54>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '\\1e as \\2ões\\n\\1e há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_54") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_56>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '\\1e as \\2veis\\n\\1e há \\2veis', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_58>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1e as \\2es\\n\\1e há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_58").lower() in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_60>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1e as \\2es\\n\\1e há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_60").lower() in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_62>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1e as \\2éis\\n\\1e há \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_62") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_64>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1e as \\2éis\\n\\1e há \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_64") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_66>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1e as \\2us\\n\\1e há \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_66") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_68>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1e as \\2us\\n\\1e há \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_68") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_70>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1e as \\2zes\\n\\1e há \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_70") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_72>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1e as \\2zes\\n\\1e há \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_72") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_73>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '\\1e as \\2ns\\n\\1e há \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_73") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])e a (?P<Mssee_74>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '\\1e as \\2ns\\n\\1e há \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssee_74") in plvrMFm'],
# DIVERSOS as
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_2>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1 as \\2s\\n\\1 há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_2").lower() in plvrFema and not m.group(1) + " a suas expensas " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_4>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '\\1 as \\2as\\n\\1 há \\2as', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_4").lower() in plvrMfoa and not m.group("Mstud_4") in "-dur-" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_8>[a-zA-Z]+ista)s(?![-\\w–\xad])', '\\1 as \\2s\\n\\1 há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mstud_8").lower() in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_10>[a-zA-Z]+a)s(?![-\\w–\xad])', '\\1 as \\2s\\n\\1 há \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_10").lower() in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_12>[a-zA-Z]+)([aí])das(?![-\\w–\xad])', '\\1 as \\2das\\n\\1 há \\2das', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mstud_12").lower() in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_16>[a-zA-Zç]+)osas(?![-\\w–\xad])', '\\1 as \\2osas\\n\\1 há \\2osas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_18>[a-zA-Zç]+)ivas(?![-\\w–\xad])', '\\1 as \\2ivas\\n\\1 há \\2ivas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_22>[a-zA-Zç]+[âêô][mn])icas(?![-\\w–\xad])', '\\1 as \\2icas\\n\\1 há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_24>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '\\1 as \\2icas\\n\\1 há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_26>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '\\1 as \\2icas\\n\\1 há \\2icas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_28>[a-zA-Zç]+)escas(?![-\\w–\xad])', '\\1 as \\2escas\\n\\1 há \\2escas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_30>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '\\1 as \\2idas\\n\\1 há \\2idas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_32>[a-zA-Zç]+[ó])logas(?![-\\w–\xad])', '\\1 as \\2logas\\n\\1 há \\2logas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_34>[a-zA-Zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '\\1 as \\2rias\\n\\1 há \\2rias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_36>[a-zA-Zç]+[í])ssimas(?![-\\w–\xad])', '\\1 as \\2ssimas\\n\\1 há \\2ssimas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_38>[a-zA-Zç]+[é])simas(?![-\\w–\xad])', '\\1 as \\2simas\\n\\1 há \\2simas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_42>[a-zA-Zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '\\1 as \\2oras\\n\\1 há \\2oras', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_44>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '\\1 as \\2es\\n\\1 há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_44") in plvrMfr'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_46>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '\\1 as \\2es\\n\\1 há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_46") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_48>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '\\1 as \\2is\\n\\1 há \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_48") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_50>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1 as \\2ões\\n\\1 há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_50") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_52>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1 as \\2ões\\n\\1 há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mstud_52") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_54>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '\\1 as \\2ões\\n\\1 há \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_54") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_56>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '\\1 as \\2veis\\n\\1 há \\2veis', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_58>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1 as \\2es\\n\\1 há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_58").lower() in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_60>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1 as \\2es\\n\\1 há \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_60").lower() in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_62>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1 as \\2éis\\n\\1 há \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_62") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_64>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1 as \\2éis\\n\\1 há \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_64") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_66>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1 as \\2us\\n\\1 há \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_66") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_68>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1 as \\2us\\n\\1 há \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_68") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_70>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1 as \\2zes\\n\\1 há \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_70") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_72>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1 as \\2zes\\n\\1 há \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_72") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_73>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '\\1 as \\2ns\\n\\1 há \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_73") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]mbas|[Aa]pós|[Cc]om|[Cc]ontra|[Dd]e|[Dd]entre|[Dd]esde|[Dd]urante|[Ee]m|[Ee]ntre|[Ff]eitas|[Pp]ara|[Pp]ôs|[Ss]ão|[Ss]egundo|[Ss]ob|[Ss]obre|[Tt]êm|[Tt]inha) a (?P<Mstud_74>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '\\1 as \\2ns\\n\\1 há \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstud_74") in plvrMFm'],
# FIM Concordancia artigo a mais plural feminino
# Entre virgulas
 ['(?u)(?<![-\\w–.,\xad])([Ss]ão|[Ee]ram|é|[Ff]oram|[Ff]oi|[Ee]ra) na verdade ([a-záâãçéêíóôõú]+)(?![-\\w–\xad])', '\\1, na verdade, \\2', 'Faltou pausar a frase. Você quis dizer:', 'not m.group(2) in "-ou-que-como-das-dos-de-aos-"'],
 ['(?u)(?<![-\\w–.,\xad])([a-záâãçéêíóôõú]+) por exemplo ([a-záâãçéêíóôõú]+)(?![-\\w–\xad])', '\\1, por exemplo, \\2', 'Faltou pausar a frase. Você quis dizer:', 'not m.group(2) in "-ou-que-como-das-dos-de-aos-"'],
 ['(?u)(?<![-\\w–.,\xad])([a-záâãçéêíóôõú]+) por fim ([a-záâãçéêíóôõú]+)(?![-\\w–\xad])', '\\1, por fim, \\2', 'Faltou pausar a frase. Você quis dizer:', 'not m.group(2) in "-ou-que-como-das-dos-de-aos-"'],
 ['(?u)(?<![-\\w–.,\xad])([Oo]u|[Qq]ue|de|[Ee]u|e|é|[Cc]om|[Mm]as|para|[Hh]á|[Dd]urante|[Pp]or|ter|[Ss]e|em|[Ee]ssa|[Aa]gora|[Aa]o|tem|têm|teria|tinha|tinham|queria|[Uu]m|[Uu]ma|saber|pessoas|consiga|contém|contêm|fossem|[Ee]xistem|[Ee]xistiam|[Ee]xistiram|[Hh]avia|[Ff]azer|[Gg]ostaria|fosse) pelo menos ([a-záâãçéêíóôõú]+)(?![-\\w–\xad])', '\\1, pelo menos, \\2', 'Faltou pausar a frase. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]la|[Ee]las|[Ee]le|[Ee]les|[Vv]ocê|[Vv]ocês|conseguir|conseguiram|conseguirem|conseguia|conseguiu|demora|demore|demorou|demoraria|demorariam|demoraram|demorava|demoravam|demorasse|demorassem|demoro|demorei|conquista|conquistou|conquistaram|conquistam|[Ll]evar|[Ll]evei|[Ll]evarei|[Ll]evaram|[Ll]evará|[Ll]evarão|[Ll]evaria|[Ll]evariam|[Ll]evava|[Ll]evavam|[Ll]evo|[Gg]astou|[Gg]astam|[Gg]astaram|[Gg]astei|[Gg]astava|[Gg]astavam|[Gg]astaria|[Gg]astariam|[Gg]asto|[Gg]aranto|[Gg]arantia|[Gg]aranti|[Gg]aranta|[Gg]arantam|[Gg]arantiu|[Gg]arantiram|[Gg]arantirão|[Gg]arantirá) pelo menos ([a-záâãçéêíóôõú]+)(?![-\\w–\xad])', '\\1, pelo menos, \\2', 'Faltou pausar a frase. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([a-záâãçéêíóôõú]+) sem dúvida ([a-záâãçéêíóôõú]+)(?![-\\w–\xad])', '\\1, sem dúvida, \\2', 'Faltou pausar a frase. Você quis dizer:', 'not m.group(2) in "-alguma-nenhuma-"'],
 ['(?u)(?<![-\\w–.,\xad])([a-záâãçéêíóôõú]+) com certeza ([a-záâãçéêíóôõú]+)(?![-\\w–\xad])', '\\1, com certeza, \\2', 'Faltou pausar a frase. Você quis dizer:', 'not m.group(2) in "-absoluta-alguma-nenhuma-no-em-na"'],
# Deh e de
 ['(?u)(?<![-\\w–.,\xad])(me|te|lhe|vos|você|gente|ela|ele|eu) de (a|o|à|às|as|os|ao|aos|isto|isso|essa|essas|esse|essa|essas|este|estes|esta|estas|aquilo|aquele|aqueles|aquela|aquelas|daquilo|daquele|daqueles|daquela|daquelas|sua|suas|minha|minhas|um|uma|uns|umas|dois|três|quatro|cinco|seis|sete|oito|nove|dez|vinte)(?![-\\w–\xad])', '\\1 dê \\2', 'Faltou o acento em "de"? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])e cá (a|o|as|os|isto|isso|um|uma)(?![-\\w–\xad])', '\\1ê cá \\2', 'Faltou o acento em "de"? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])e graças (a|ao|as|aos|à|às)(?![-\\w–\xad])', '\\1ê graças \\2', 'Faltou o acento em "de"? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])e (o|no) que der(?![-\\w–\xad])', '\\1ê \\2 que der', 'Faltou o acento em "de"? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(tudo|plano|país|ideia|namoro|casamento|caso|isso) de certo(?![-\\w–\xad])', '\\1 dê certo', 'Faltou o acento em "de"? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])e um abraço (em|na|nas|no|nas)(?![-\\w–\xad])', '\\1ê um abraço \\2', 'Faltou o acento em "de"? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])e um jeito.(?![-\\w–\xad])', '\\1ê um jeito.', 'Faltou o acento em "de"? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(você|gente|ela|ele|eu) de um jeito(?![-\\w–\xad])', '\\1 dê um jeito', 'Faltou o acento em "de"? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])e conta (de|da|do|das|dos)(?![-\\w–\xad])', '\\1ê conta \\2', 'Faltou o acento em "de"? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])e o fora(?![-\\w–\xad])', '\\1ê o fora', 'Faltou o acento em "de"? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])e trela(?![-\\w–\xad])', '\\1ê trela', 'Faltou o acento em "de"? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(lhe|te) de (bom|bons|boa|boas)(?![-\\w–\xad])', '\\1 dê \\2', 'Faltou o acento em "de"? Você quis dizer:', False],
# Especial - Milhao de - Bilhao de - trilhao de - milhares de
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_1>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_1").lower() in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_3>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_3").lower() in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_5>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_5").lower() in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_2>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_2").lower() in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_4>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_4").lower() in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_6>[a-zA-Z]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + m.group(4) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mbtq_6").lower() in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_8>[a-zA-Z]+ista)(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mbtq_8").lower() in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_10>[a-zA-Z]+a)(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_10").lower() in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_12>[a-zA-Z]+)([aií])da(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + m.group(4) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mbtq_12").lower() in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_13>[a-zA-Z]+)([aií])do(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + m.group(4) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mbtq_13").lower() in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_14>[a-zA-Zç]+)oso(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_16>[a-zA-Zç]+)osa(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_18>[a-zA-Zç]+)iva(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_20>[a-zA-Zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_22>[a-zA-Zç]+[âêô][mn])ica(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_23>[a-zA-Zç]+[âêô][mn])ico(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_24>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_25>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_26>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_27>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_28>[a-zA-Zç]+)esca(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_29>[a-zA-Zç]+)esco(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_30>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_32>[a-zA-Zç]+[ó])loga(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_34>[a-zA-Zç]+[áéíóúâêô])ria(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_36>[a-zA-Zç]+[í])ssima(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_38>[a-zA-Zç]+[é])sima(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_42>[a-zA-Zçáéíóúâêô]+[dst])ora(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_43>[a-zA-Zçáéíóúâêô]+[dst])or(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_44>[a-zA-Zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_44") in plvrMfr'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_46>[a-zA-Zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_46") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_47>[a-zA-Zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_47") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_48>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_48") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_50>[a-zA-Zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_50") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_52>[a-zA-Zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mbtq_52") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_53>[a-zA-Zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_53") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_54>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_54") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_55>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_55") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_56>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_58>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_58").lower() in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_60>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_60").lower() in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_61>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_61").lower() in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_62>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_62") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_64>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_64") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_65>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_65") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_66>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_66") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_68>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_68") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_69>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_69") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_70>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_70") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_72>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_72") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_73>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_73") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_74>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_73") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Bb]|[Mm]|[Tt]r|[Qq]uatr|[Qq]uint)ilh(ares|ão|ões) de (?P<Mbtq_75>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "ilh" + m.group(2) + " de " + m.group(3) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbtq_75") in plvrMascm'],
# Especial - dezena de - dezenas de - centena de - centenas de
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_1>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_1").lower() in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_3>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_3").lower() in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_5>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_5").lower() in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_2>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_2").lower() in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_4>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_4").lower() in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_6>[a-zA-Z]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + m.group(4) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mbdc_6").lower() in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_8>[a-zA-Z]+ista)(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mbdc_8").lower() in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_10>[a-zA-Z]+a)(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_10").lower() in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_12>[a-zA-Z]+)([aií])da(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + m.group(4) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mbdc_12").lower() in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_13>[a-zA-Z]+)([aií])do(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + m.group(4) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mbdc_13").lower() in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_14>[a-zA-Zç]+)oso(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_16>[a-zA-Zç]+)osa(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_18>[a-zA-Zç]+)iva(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_20>[a-zA-Zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_22>[a-zA-Zç]+[âêô][mn])ica(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_23>[a-zA-Zç]+[âêô][mn])ico(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_24>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_25>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_26>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_27>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_28>[a-zA-Zç]+)esca(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_29>[a-zA-Zç]+)esco(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_30>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_32>[a-zA-Zç]+[ó])loga(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_34>[a-zA-Zç]+[áéíóúâêô])ria(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_36>[a-zA-Zç]+[í])ssima(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_38>[a-zA-Zç]+[é])sima(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_42>[a-zA-Zçáéíóúâêô]+[dst])ora(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_43>[a-zA-Zçáéíóúâêô]+[dst])or(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_44>[a-zA-Zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_44") in plvrMfr'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_46>[a-zA-Zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_46") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_47>[a-zA-Zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_47") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_48>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_48") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_50>[a-zA-Zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_50") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_52>[a-zA-Zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mbdc_52") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_53>[a-zA-Zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_53") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_54>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_54") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_55>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_55") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_56>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_58>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_58").lower() in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_60>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_60").lower() in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_61>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_61").lower() in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_62>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_62") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_64>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_64") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_65>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_65") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_66>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_66") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_68>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_68") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_69>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_69") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_70>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_70") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_72>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_72") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_73>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_73") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_74>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_73") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Cc]ent|[Dd]ez)en(a|as) de (?P<Mbdc_75>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "en" + m.group(2) + " de " + m.group(3) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbdc_75") in plvrMascm'],
# CONCORDANCIA VERBAL
 ['(?u)(?<![-\\w–.,\xad])(?P<Mtem_1>[a-zA-Záâãçéêíóôõú]+[s]) (?P<Mtem_2>[a-záâãçéêíóôõú]+[s]) tem(?![-\\w–\xad])', '\\1 \\2 têm', 'Não há concordância verbal. Você quis dizer:', 'not exctema.search(TEXT) and not exctemb.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mscvba_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvba_2>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|am)(?![-\\w–\xad])', '\\1 \\2 \\3a', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvba_1").lower() in plvrMasco and m.group("Mscvba_2") in plvrVbrar and not m.group("Mscvba_2") + m.group(4) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mscvba_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvba_4>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|a)(?![-\\w–\xad])', '\\1s \\2s \\3am', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvba_3").lower() in plvrMasco and m.group("Mscvba_4") in plvrVbrar and not m.group("Mscvba_4") + m.group(4) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvba_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvba_6>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|am)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4a', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvba_5").lower() in plvrMasco and m.group("Mscvba_6") in plvrVbrar and not m.group("Mscvba_6") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvba_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvba_8>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|a)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4am', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvba_7").lower() in plvrMasco and m.group("Mscvba_8") in plvrVbrar and not m.group("Mscvba_8") + m.group(5) in excvbar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvba_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvba_10>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|am)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4a', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvba_9").lower() in plvrMasco and m.group("Mscvba_10") in plvrVbrar and not m.group("Mscvba_10") + m.group(5) in excvbar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvba_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvba_12>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|a)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4am', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvba_11").lower() in plvrMasco and m.group("Mscvba_12") in plvrVbrar and not m.group("Mscvba_12") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscvba_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvba_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvba_19>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|am)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4a', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvba_18").lower() in plvrMasco and m.group("Mscvba_19") in plvrVbrar and not m.group("Mscvba_19") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscvba_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvba_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvba_22>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|a)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4am', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvba_21").lower() in plvrMasco and m.group("Mscvba_22") in plvrVbrar and not m.group("Mscvba_22") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mscvbb_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbb_2>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', '\\1 \\2 \\3ava', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbb_1").lower() in plvrMasco and m.group("Mscvbb_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mscvbb_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbb_4>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', '\\1s \\2s \\3avam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbb_3").lower() in plvrMasco and m.group("Mscvbb_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbb_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbb_6>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ava', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbb_5").lower() in plvrMasco and m.group("Mscvbb_6") in plvrVbrar and not m.group("Mscvbb_6") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbb_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbb_8>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4avam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbb_7").lower() in plvrMasco and m.group("Mscvbb_8") in plvrVbrar and not m.group("Mscvbb_8") + m.group(5) in excvbar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbb_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbb_10>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ava', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbb_9").lower() in plvrMasco and m.group("Mscvbb_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbb_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbb_12>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4avam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbb_11").lower() in plvrMasco and m.group("Mscvbb_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscvbb_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbb_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbb_19>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4ava', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbb_18").lower() in plvrMasco and m.group("Mscvbb_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscvbb_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbb_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbb_22>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4avam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbb_21").lower() in plvrMasco and m.group("Mscvbb_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mscvbc_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbc_2>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', '\\1 \\2 \\3o', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbc_1").lower() in plvrMasco and m.group("Mscvbc_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mscvbc_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbc_4>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', '\\1s \\2s \\3aram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbc_3").lower() in plvrMasco and m.group("Mscvbc_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbc_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbc_6>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4o', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbc_5").lower() in plvrMasco and m.group("Mscvbc_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbc_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbc_8>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4aram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbc_7").lower() in plvrMasco and m.group("Mscvbc_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbc_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbc_10>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4o', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbc_9").lower() in plvrMasco and m.group("Mscvbc_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbc_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbc_12>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4aram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbc_11").lower() in plvrMasco and m.group("Mscvbc_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscvbc_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbc_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbc_19>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4o', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbc_18").lower() in plvrMasco and m.group("Mscvbc_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscvbc_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbc_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbc_22>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4aram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbc_21").lower() in plvrMasco and m.group("Mscvbc_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mscvbd_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbd_2>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', '\\1 \\2 \\3ço', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbd_1").lower() in plvrMasco and m.group("Mscvbd_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mscvbd_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbd_4>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', '\\1s \\2s \\3çaram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbd_3").lower() in plvrMasco and m.group("Mscvbd_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbd_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbd_6>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ço', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbd_5").lower() in plvrMasco and m.group("Mscvbd_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbd_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbd_8>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4çaram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbd_7").lower() in plvrMasco and m.group("Mscvbd_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbd_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbd_10>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ço', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbd_9").lower() in plvrMasco and m.group("Mscvbd_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbd_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbd_12>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4çaram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbd_11").lower() in plvrMasco and m.group("Mscvbd_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscvbd_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbd_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbd_19>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4ço', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbd_18").lower() in plvrMasco and m.group("Mscvbd_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscvbd_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbd_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbd_22>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4çaram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbd_21").lower() in plvrMasco and m.group("Mscvbd_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mscvbe_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbe_2>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', '\\1 \\2 \\3co', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbe_1").lower() in plvrMasco and m.group("Mscvbe_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mscvbe_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbe_4>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', '\\1s \\2s \\3caram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbe_3").lower() in plvrMasco and m.group("Mscvbe_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbe_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbe_6>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4co', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbe_5").lower() in plvrMasco and m.group("Mscvbe_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbe_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbe_8>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4caram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbe_7").lower() in plvrMasco and m.group("Mscvbe_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbe_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbe_10>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4co', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbe_9").lower() in plvrMasco and m.group("Mscvbe_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbe_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbe_12>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4caram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbe_11").lower() in plvrMasco and m.group("Mscvbe_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscvbe_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbe_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbe_19>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4co', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbe_18").lower() in plvrMasco and m.group("Mscvbe_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscvbe_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbe_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbe_22>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4caram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbe_21").lower() in plvrMasco and m.group("Mscvbe_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mscvbf_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbf_2>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', '\\1 \\2 \\3go', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbf_1").lower() in plvrMasco and m.group("Mscvbf_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mscvbf_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbf_4>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', '\\1s \\2s \\3garam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbf_3").lower() in plvrMasco and m.group("Mscvbf_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbf_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbf_6>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4go', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbf_5").lower() in plvrMasco and m.group("Mscvbf_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbf_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbf_8>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4garam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbf_7").lower() in plvrMasco and m.group("Mscvbf_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbf_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbf_10>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4go', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbf_9").lower() in plvrMasco and m.group("Mscvbf_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbf_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbf_12>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4garam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbf_11").lower() in plvrMasco and m.group("Mscvbf_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscvbf_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbf_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbf_19>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4go', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbf_18").lower() in plvrMasco and m.group("Mscvbf_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscvbf_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbf_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbf_22>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4garam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbf_21").lower() in plvrMasco and m.group("Mscvbf_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mscvbg_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbg_2>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', '\\1 \\2 \\3ará', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbg_1").lower() in plvrMasco and m.group("Mscvbg_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mscvbg_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbg_4>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', '\\1s \\2s \\3arão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbg_3").lower() in plvrMasco and m.group("Mscvbg_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbg_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbg_6>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ará', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbg_5").lower() in plvrMasco and m.group("Mscvbg_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbg_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbg_8>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4arão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbg_7").lower() in plvrMasco and m.group("Mscvbg_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbg_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbg_10>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ará', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbg_9").lower() in plvrMasco and m.group("Mscvbg_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbg_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbg_12>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4arão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbg_11").lower() in plvrMasco and m.group("Mscvbg_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscvbg_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbg_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbg_19>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4ará', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbg_18").lower() in plvrMasco and m.group("Mscvbg_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscvbg_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbg_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbg_22>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4arão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbg_21").lower() in plvrMasco and m.group("Mscvbg_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mscvbh_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbh_2>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', '\\1 \\2 \\3aria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbh_1").lower() in plvrMasco and m.group("Mscvbh_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mscvbh_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbh_4>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', '\\1s \\2s \\3ariam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbh_3").lower() in plvrMasco and m.group("Mscvbh_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbh_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbh_6>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4aria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbh_5").lower() in plvrMasco and m.group("Mscvbh_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbh_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbh_8>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4ariam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbh_7").lower() in plvrMasco and m.group("Mscvbh_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbh_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbh_10>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4aria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbh_9").lower() in plvrMasco and m.group("Mscvbh_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbh_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbh_12>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4ariam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbh_11").lower() in plvrMasco and m.group("Mscvbh_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscvbh_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mscvbh_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Mscvbh_19>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4aria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbh_18").lower() in plvrMasco and m.group("Mscvbh_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscvbh_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mscvbh_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mscvbh_22>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4ariam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mscvbh_21").lower() in plvrMasco and m.group("Mscvbh_22") in plvrVbrar'],
# Mfoa - masculino
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfovba_1>[a-zçáéíóúâêô]+)o (?P<Mfovba_2>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|am)(?![-\\w–\xad])', '\\1 \\2o \\3a', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovba_1").lower() in plvrMfoa and m.group("Mfovba_2") in plvrVbrar and not m.group("Mfovba_2") + m.group(4) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfovba_3>[a-zçáéíóúâêô]+)os (?P<Mfovba_4>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|a)(?![-\\w–\xad])', '\\1s \\2os \\3am', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovba_3").lower() in plvrMfoa and m.group("Mfovba_4") in plvrVbrar and not m.group("Mfovba_4") + m.group(4) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovba_5>[a-zçáéíóúâêô]+)o (?P<Mfovba_6>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|am)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4a', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovba_5").lower() in plvrMfoa and m.group("Mfovba_6") in plvrVbrar and not m.group("Mfovba_6") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovba_7>[a-zçáéíóúâêô]+)os (?P<Mfovba_8>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|a)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4am', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovba_7").lower() in plvrMfoa and m.group("Mfovba_8") in plvrVbrar and not m.group("Mfovba_8") + m.group(5) in excvbar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovba_9>[a-zçáéíóúâêô]+)o (?P<Mfovba_10>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|am)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4a', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovba_9").lower() in plvrMfoa and m.group("Mfovba_10") in plvrVbrar and not m.group("Mfovba_10") + m.group(5) in excvbar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovba_11>[a-zçáéíóúâêô]+)os (?P<Mfovba_12>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|a)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4am', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovba_11").lower() in plvrMfoa and m.group("Mfovba_12") in plvrVbrar and not m.group("Mfovba_12") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfovba_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovba_18>[a-zçáéíóúâêô]+)o (?P<Mfovba_19>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|am)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4a', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovba_18").lower() in plvrMfoa and m.group("Mfovba_19") in plvrVbrar and not m.group("Mfovba_19") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfovba_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovba_21>[a-zçáéíóúâêô]+)os (?P<Mfovba_22>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|a)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4am', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovba_21").lower() in plvrMfoa and m.group("Mfovba_22") in plvrVbrar and not m.group("Mfovba_22") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfovbb_1>[a-zçáéíóúâêô]+)o (?P<Mfovbb_2>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', '\\1 \\2o \\3ava', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbb_1").lower() in plvrMfoa and m.group("Mfovbb_2") in plvrVbrar and not m.group("Mfovbb_2") + m.group(4) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfovbb_3>[a-zçáéíóúâêô]+)os (?P<Mfovbb_4>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', '\\1s \\2os \\3avam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbb_3").lower() in plvrMfoa and m.group("Mfovbb_4") in plvrVbrar and not m.group("Mfovbb_4") + m.group(4) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbb_5>[a-zçáéíóúâêô]+)o (?P<Mfovbb_6>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ava', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbb_5").lower() in plvrMfoa and m.group("Mfovbb_6") in plvrVbrar and not m.group("Mfovbb_6") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbb_7>[a-zçáéíóúâêô]+)os (?P<Mfovbb_8>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4avam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbb_7").lower() in plvrMfoa and m.group("Mfovbb_8") in plvrVbrar and not m.group("Mfovbb_8") + m.group(5) in excvbar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbb_9>[a-zçáéíóúâêô]+)o (?P<Mfovbb_10>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ava', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbb_9").lower() in plvrMfoa and m.group("Mfovbb_10") in plvrVbrar and not m.group("Mfovbb_10") + m.group(5) in excvbar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbb_11>[a-zçáéíóúâêô]+)os (?P<Mfovbb_12>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4avam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbb_11").lower() in plvrMfoa and m.group("Mfovbb_12") in plvrVbrar and not m.group("Mfovbb_12") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfovbb_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbb_18>[a-zçáéíóúâêô]+)o (?P<Mfovbb_19>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4ava', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbb_18").lower() in plvrMfoa and m.group("Mfovbb_19") in plvrVbrar and not m.group("Mfovbb_19") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfovbb_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbb_21>[a-zçáéíóúâêô]+)os (?P<Mfovbb_22>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4avam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbb_21").lower() in plvrMfoa and m.group("Mfovbb_22") in plvrVbrar and not m.group("Mfovbb_22") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfovbc_1>[a-zçáéíóúâêô]+)o (?P<Mfovbc_2>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', '\\1 \\2o \\3o', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbc_1").lower() in plvrMfoa and m.group("Mfovbc_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfovbc_3>[a-zçáéíóúâêô]+)os (?P<Mfovbc_4>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', '\\1s \\2os \\3aram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbc_3").lower() in plvrMfoa and m.group("Mfovbc_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbc_5>[a-zçáéíóúâêô]+)o (?P<Mfovbc_6>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4o', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbc_5").lower() in plvrMfoa and m.group("Mfovbc_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbc_7>[a-zçáéíóúâêô]+)os (?P<Mfovbc_8>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4aram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbc_7").lower() in plvrMfoa and m.group("Mfovbc_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbc_9>[a-zçáéíóúâêô]+)o (?P<Mfovbc_10>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4o', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbc_9").lower() in plvrMfoa and m.group("Mfovbc_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbc_11>[a-zçáéíóúâêô]+)os (?P<Mfovbc_12>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4aram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbc_11").lower() in plvrMfoa and m.group("Mfovbc_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfovbc_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbc_18>[a-zçáéíóúâêô]+)o (?P<Mfovbc_19>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4o', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbc_18").lower() in plvrMfoa and m.group("Mfovbc_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfovbc_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbc_21>[a-zçáéíóúâêô]+)os (?P<Mfovbc_22>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4aram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbc_21").lower() in plvrMfoa and m.group("Mfovbc_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfovbd_1>[a-zçáéíóúâêô]+)o (?P<Mfovbd_2>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', '\\1 \\2o \\3ço', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbd_1").lower() in plvrMfoa and m.group("Mfovbd_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfovbd_3>[a-zçáéíóúâêô]+)os (?P<Mfovbd_4>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', '\\1s \\2os \\3çaram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbd_3").lower() in plvrMfoa and m.group("Mfovbd_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbd_5>[a-zçáéíóúâêô]+)o (?P<Mfovbd_6>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ço', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbd_5").lower() in plvrMfoa and m.group("Mfovbd_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbd_7>[a-zçáéíóúâêô]+)os (?P<Mfovbd_8>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4çaram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbd_7").lower() in plvrMfoa and m.group("Mfovbd_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbd_9>[a-zçáéíóúâêô]+)o (?P<Mfovbd_10>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ço', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbd_9").lower() in plvrMfoa and m.group("Mfovbd_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbd_11>[a-zçáéíóúâêô]+)os (?P<Mfovbd_12>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4çaram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbd_11").lower() in plvrMfoa and m.group("Mfovbd_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfovbd_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbd_18>[a-zçáéíóúâêô]+)o (?P<Mfovbd_19>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4ço', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbd_18").lower() in plvrMfoa and m.group("Mfovbd_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfovbd_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbd_21>[a-zçáéíóúâêô]+)os (?P<Mfovbd_22>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4çaram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbd_21").lower() in plvrMfoa and m.group("Mfovbd_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfovbe_1>[a-zçáéíóúâêô]+)o (?P<Mfovbe_2>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', '\\1 \\2o \\3co', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbe_1").lower() in plvrMfoa and m.group("Mfovbe_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfovbe_3>[a-zçáéíóúâêô]+)os (?P<Mfovbe_4>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', '\\1s \\2os \\3caram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbe_3").lower() in plvrMfoa and m.group("Mfovbe_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbe_5>[a-zçáéíóúâêô]+)o (?P<Mfovbe_6>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4co', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbe_5").lower() in plvrMfoa and m.group("Mfovbe_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbe_7>[a-zçáéíóúâêô]+)os (?P<Mfovbe_8>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4caram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbe_7").lower() in plvrMfoa and m.group("Mfovbe_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbe_9>[a-zçáéíóúâêô]+)o (?P<Mfovbe_10>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4co', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbe_9").lower() in plvrMfoa and m.group("Mfovbe_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbe_11>[a-zçáéíóúâêô]+)os (?P<Mfovbe_12>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4caram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbe_11").lower() in plvrMfoa and m.group("Mfovbe_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfovbe_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbe_18>[a-zçáéíóúâêô]+)o (?P<Mfovbe_19>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4co', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbe_18").lower() in plvrMfoa and m.group("Mfovbe_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfovbe_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbe_21>[a-zçáéíóúâêô]+)os (?P<Mfovbe_22>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4caram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbe_21").lower() in plvrMfoa and m.group("Mfovbe_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfovbf_1>[a-zçáéíóúâêô]+)o (?P<Mfovbf_2>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', '\\1 \\2o \\3go', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbf_1").lower() in plvrMfoa and m.group("Mfovbf_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfovbf_3>[a-zçáéíóúâêô]+)os (?P<Mfovbf_4>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', '\\1s \\2os \\3garam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbf_3").lower() in plvrMfoa and m.group("Mfovbf_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbf_5>[a-zçáéíóúâêô]+)o (?P<Mfovbf_6>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4go', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbf_5").lower() in plvrMfoa and m.group("Mfovbf_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbf_7>[a-zçáéíóúâêô]+)os (?P<Mfovbf_8>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4garam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbf_7").lower() in plvrMfoa and m.group("Mfovbf_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbf_9>[a-zçáéíóúâêô]+)o (?P<Mfovbf_10>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4go', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbf_9").lower() in plvrMfoa and m.group("Mfovbf_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbf_11>[a-zçáéíóúâêô]+)os (?P<Mfovbf_12>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4garam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbf_11").lower() in plvrMfoa and m.group("Mfovbf_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfovbf_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbf_18>[a-zçáéíóúâêô]+)o (?P<Mfovbf_19>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4go', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbf_18").lower() in plvrMfoa and m.group("Mfovbf_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfovbf_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbf_21>[a-zçáéíóúâêô]+)os (?P<Mfovbf_22>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4garam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbf_21").lower() in plvrMfoa and m.group("Mfovbf_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfovbg_1>[a-zçáéíóúâêô]+)o (?P<Mfovbg_2>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', '\\1 \\2o \\3ará', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbg_1").lower() in plvrMfoa and m.group("Mfovbg_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfovbg_3>[a-zçáéíóúâêô]+)os (?P<Mfovbg_4>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', '\\1s \\2os \\3arão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbg_3").lower() in plvrMfoa and m.group("Mfovbg_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbg_5>[a-zçáéíóúâêô]+)o (?P<Mfovbg_6>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ará', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbg_5").lower() in plvrMfoa and m.group("Mfovbg_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbg_7>[a-zçáéíóúâêô]+)os (?P<Mfovbg_8>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4arão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbg_7").lower() in plvrMfoa and m.group("Mfovbg_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbg_9>[a-zçáéíóúâêô]+)o (?P<Mfovbg_10>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ará', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbg_9").lower() in plvrMfoa and m.group("Mfovbg_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbg_11>[a-zçáéíóúâêô]+)os (?P<Mfovbg_12>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4arão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbg_11").lower() in plvrMfoa and m.group("Mfovbg_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfovbg_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbg_18>[a-zçáéíóúâêô]+)o (?P<Mfovbg_19>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4ará', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbg_18").lower() in plvrMfoa and m.group("Mfovbg_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfovbg_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbg_21>[a-zçáéíóúâêô]+)os (?P<Mfovbg_22>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4arão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbg_21").lower() in plvrMfoa and m.group("Mfovbg_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfovbh_1>[a-zçáéíóúâêô]+)o (?P<Mfovbh_2>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', '\\1 \\2o \\3aria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbh_1").lower() in plvrMfoa and m.group("Mfovbh_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfovbh_3>[a-zçáéíóúâêô]+)os (?P<Mfovbh_4>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', '\\1s \\2os \\3ariam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbh_3").lower() in plvrMfoa and m.group("Mfovbh_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbh_5>[a-zçáéíóúâêô]+)o (?P<Mfovbh_6>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4aria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbh_5").lower() in plvrMfoa and m.group("Mfovbh_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbh_7>[a-zçáéíóúâêô]+)os (?P<Mfovbh_8>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4ariam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbh_7").lower() in plvrMfoa and m.group("Mfovbh_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbh_9>[a-zçáéíóúâêô]+)o (?P<Mfovbh_10>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4aria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbh_9").lower() in plvrMfoa and m.group("Mfovbh_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbh_11>[a-zçáéíóúâêô]+)os (?P<Mfovbh_12>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4ariam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbh_11").lower() in plvrMfoa and m.group("Mfovbh_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfovbh_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfovbh_18>[a-zçáéíóúâêô]+)o (?P<Mfovbh_19>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4aria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbh_18").lower() in plvrMfoa and m.group("Mfovbh_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfovbh_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfovbh_21>[a-zçáéíóúâêô]+)os (?P<Mfovbh_22>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4ariam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfovbh_21").lower() in plvrMfoa and m.group("Mfovbh_22") in plvrVbrar'],
# Mfoa - feminino
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mfavba_1>[a-zçáéíóúâêô]+)a (?P<Mfavba_2>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|am)(?![-\\w–\xad])', '\\1 \\2a \\3a', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavba_1").lower() in plvrMfoa and m.group("Mfavba_2") in plvrVbrar and not m.group("Mfavba_2") + m.group(4) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mfavba_3>[a-zçáéíóúâêô]+)as (?P<Mfavba_4>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|a)(?![-\\w–\xad])', '\\1s \\2as \\3am', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavba_3").lower() in plvrMfoa and m.group("Mfavba_4") in plvrVbrar and not m.group("Mfavba_4") + m.group(4) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavba_5>[a-zçáéíóúâêô]+)a (?P<Mfavba_6>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|am)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4a', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavba_5").lower() in plvrMfoa and m.group("Mfavba_6") in plvrVbrar and not m.group("Mfavba_6") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavba_7>[a-zçáéíóúâêô]+)as (?P<Mfavba_8>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|a)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4am', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavba_7").lower() in plvrMfoa and m.group("Mfavba_8") in plvrVbrar and not m.group("Mfavba_8") + m.group(5) in excvbar'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavba_9>[a-zçáéíóúâêô]+)a (?P<Mfavba_10>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|am)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4a', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavba_9").lower() in plvrMfoa and m.group("Mfavba_10") in plvrVbrar and not m.group("Mfavba_10") + m.group(5) in excvbar'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavba_11>[a-zçáéíóúâêô]+)as (?P<Mfavba_12>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|a)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4am', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavba_11").lower() in plvrMfoa and m.group("Mfavba_12") in plvrVbrar and not m.group("Mfavba_12") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfavba_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavba_18>[a-zçáéíóúâêô]+)a (?P<Mfavba_19>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|am)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4a', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavba_18").lower() in plvrMfoa and m.group("Mfavba_19") in plvrVbrar and not m.group("Mfavba_19") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfavba_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavba_21>[a-zçáéíóúâêô]+)as (?P<Mfavba_22>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|a)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4am', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavba_21").lower() in plvrMfoa and m.group("Mfavba_22") in plvrVbrar and not m.group("Mfavba_22") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mfavbb_1>[a-zçáéíóúâêô]+)a (?P<Mfavbb_2>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', '\\1 \\2a \\3ava', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbb_1").lower() in plvrMfoa and m.group("Mfavbb_2") in plvrVbrar and not m.group("Mfavbb_2") + m.group(4) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mfavbb_3>[a-zçáéíóúâêô]+)as (?P<Mfavbb_4>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', '\\1s \\2as \\3avam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbb_3").lower() in plvrMfoa and m.group("Mfavbb_4") in plvrVbrar and not m.group("Mfavbb_4") + m.group(4) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbb_5>[a-zçáéíóúâêô]+)a (?P<Mfavbb_6>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ava', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbb_5").lower() in plvrMfoa and m.group("Mfavbb_6") in plvrVbrar and not m.group("Mfavbb_6") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbb_7>[a-zçáéíóúâêô]+)as (?P<Mfavbb_8>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4avam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbb_7").lower() in plvrMfoa and m.group("Mfavbb_8") in plvrVbrar and not m.group("Mfavbb_8") + m.group(5) in excvbar'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbb_9>[a-zçáéíóúâêô]+)a (?P<Mfavbb_10>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ava', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbb_9").lower() in plvrMfoa and m.group("Mfavbb_10") in plvrVbrar and not m.group("Mfavbb_10") + m.group(5) in excvbar'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbb_11>[a-zçáéíóúâêô]+)as (?P<Mfavbb_12>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4avam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbb_11").lower() in plvrMfoa and m.group("Mfavbb_12") in plvrVbrar and not m.group("Mfavbb_12") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfavbb_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbb_18>[a-zçáéíóúâêô]+)a (?P<Mfavbb_19>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4ava', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbb_18").lower() in plvrMfoa and m.group("Mfavbb_19") in plvrVbrar and not m.group("Mfavbb_19") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfavbb_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbb_21>[a-zçáéíóúâêô]+)as (?P<Mfavbb_22>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4avam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbb_21").lower() in plvrMfoa and m.group("Mfavbb_22") in plvrVbrar and not m.group("Mfavbb_22") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mfavbc_1>[a-zçáéíóúâêô]+)a (?P<Mfavbc_2>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', '\\1 \\2a \\3o', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbc_1").lower() in plvrMfoa and m.group("Mfavbc_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mfavbc_3>[a-zçáéíóúâêô]+)as (?P<Mfavbc_4>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', '\\1s \\2as \\3aram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbc_3").lower() in plvrMfoa and m.group("Mfavbc_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbc_5>[a-zçáéíóúâêô]+)a (?P<Mfavbc_6>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4o', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbc_5").lower() in plvrMfoa and m.group("Mfavbc_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbc_7>[a-zçáéíóúâêô]+)as (?P<Mfavbc_8>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4aram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbc_7").lower() in plvrMfoa and m.group("Mfavbc_8") in plvrVbrar'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbc_9>[a-zçáéíóúâêô]+)a (?P<Mfavbc_10>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4o', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbc_9").lower() in plvrMfoa and m.group("Mfavbc_10") in plvrVbrar'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbc_11>[a-zçáéíóúâêô]+)as (?P<Mfavbc_12>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4aram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbc_11").lower() in plvrMfoa and m.group("Mfavbc_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfavbc_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbc_18>[a-zçáéíóúâêô]+)a (?P<Mfavbc_19>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4o', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbc_18").lower() in plvrMfoa and m.group("Mfavbc_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfavbc_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbc_21>[a-zçáéíóúâêô]+)as (?P<Mfavbc_22>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4aram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbc_21").lower() in plvrMfoa and m.group("Mfavbc_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mfavbd_1>[a-zçáéíóúâêô]+)a (?P<Mfavbd_2>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', '\\1 \\2a \\3ço', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbd_1").lower() in plvrMfoa and m.group("Mfavbd_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mfavbd_3>[a-zçáéíóúâêô]+)as (?P<Mfavbd_4>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', '\\1s \\2as \\3çaram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbd_3").lower() in plvrMfoa and m.group("Mfavbd_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbd_5>[a-zçáéíóúâêô]+)a (?P<Mfavbd_6>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ço', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbd_5").lower() in plvrMfoa and m.group("Mfavbd_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbd_7>[a-zçáéíóúâêô]+)as (?P<Mfavbd_8>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4çaram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbd_7").lower() in plvrMfoa and m.group("Mfavbd_8") in plvrVbrar'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbd_9>[a-zçáéíóúâêô]+)a (?P<Mfavbd_10>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ço', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbd_9").lower() in plvrMfoa and m.group("Mfavbd_10") in plvrVbrar'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbd_11>[a-zçáéíóúâêô]+)as (?P<Mfavbd_12>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4çaram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbd_11").lower() in plvrMfoa and m.group("Mfavbd_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfavbd_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbd_18>[a-zçáéíóúâêô]+)a (?P<Mfavbd_19>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4ço', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbd_18").lower() in plvrMfoa and m.group("Mfavbd_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfavbd_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbd_21>[a-zçáéíóúâêô]+)as (?P<Mfavbd_22>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4çaram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbd_21").lower() in plvrMfoa and m.group("Mfavbd_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mfavbe_1>[a-zçáéíóúâêô]+)a (?P<Mfavbe_2>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', '\\1 \\2a \\3co', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbe_1").lower() in plvrMfoa and m.group("Mfavbe_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mfavbe_3>[a-zçáéíóúâêô]+)as (?P<Mfavbe_4>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', '\\1s \\2as \\3caram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbe_3").lower() in plvrMfoa and m.group("Mfavbe_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbe_5>[a-zçáéíóúâêô]+)a (?P<Mfavbe_6>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4co', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbe_5").lower() in plvrMfoa and m.group("Mfavbe_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbe_7>[a-zçáéíóúâêô]+)as (?P<Mfavbe_8>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4caram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbe_7").lower() in plvrMfoa and m.group("Mfavbe_8") in plvrVbrar'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbe_9>[a-zçáéíóúâêô]+)a (?P<Mfavbe_10>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4co', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbe_9").lower() in plvrMfoa and m.group("Mfavbe_10") in plvrVbrar'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbe_11>[a-zçáéíóúâêô]+)as (?P<Mfavbe_12>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4caram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbe_11").lower() in plvrMfoa and m.group("Mfavbe_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfavbe_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbe_18>[a-zçáéíóúâêô]+)a (?P<Mfavbe_19>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4co', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbe_18").lower() in plvrMfoa and m.group("Mfavbe_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfavbe_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbe_21>[a-zçáéíóúâêô]+)as (?P<Mfavbe_22>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4caram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbe_21").lower() in plvrMfoa and m.group("Mfavbe_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mfavbf_1>[a-zçáéíóúâêô]+)a (?P<Mfavbf_2>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', '\\1 \\2a \\3go', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbf_1").lower() in plvrMfoa and m.group("Mfavbf_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mfavbf_3>[a-zçáéíóúâêô]+)as (?P<Mfavbf_4>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', '\\1s \\2as \\3garam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbf_3").lower() in plvrMfoa and m.group("Mfavbf_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbf_5>[a-zçáéíóúâêô]+)a (?P<Mfavbf_6>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4go', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbf_5").lower() in plvrMfoa and m.group("Mfavbf_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbf_7>[a-zçáéíóúâêô]+)as (?P<Mfavbf_8>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4garam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbf_7").lower() in plvrMfoa and m.group("Mfavbf_8") in plvrVbrar'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbf_9>[a-zçáéíóúâêô]+)a (?P<Mfavbf_10>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4go', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbf_9").lower() in plvrMfoa and m.group("Mfavbf_10") in plvrVbrar'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbf_11>[a-zçáéíóúâêô]+)as (?P<Mfavbf_12>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4garam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbf_11").lower() in plvrMfoa and m.group("Mfavbf_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfavbf_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbf_18>[a-zçáéíóúâêô]+)a (?P<Mfavbf_19>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4go', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbf_18").lower() in plvrMfoa and m.group("Mfavbf_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfavbf_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbf_21>[a-zçáéíóúâêô]+)as (?P<Mfavbf_22>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4garam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbf_21").lower() in plvrMfoa and m.group("Mfavbf_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mfavbg_1>[a-zçáéíóúâêô]+)a (?P<Mfavbg_2>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', '\\1 \\2a \\3ará', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbg_1").lower() in plvrMfoa and m.group("Mfavbg_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mfavbg_3>[a-zçáéíóúâêô]+)as (?P<Mfavbg_4>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', '\\1s \\2as \\3arão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbg_3").lower() in plvrMfoa and m.group("Mfavbg_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbg_5>[a-zçáéíóúâêô]+)a (?P<Mfavbg_6>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ará', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbg_5").lower() in plvrMfoa and m.group("Mfavbg_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbg_7>[a-zçáéíóúâêô]+)as (?P<Mfavbg_8>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4arão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbg_7").lower() in plvrMfoa and m.group("Mfavbg_8") in plvrVbrar'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbg_9>[a-zçáéíóúâêô]+)a (?P<Mfavbg_10>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ará', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbg_9").lower() in plvrMfoa and m.group("Mfavbg_10") in plvrVbrar'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbg_11>[a-zçáéíóúâêô]+)as (?P<Mfavbg_12>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4arão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbg_11").lower() in plvrMfoa and m.group("Mfavbg_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfavbg_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbg_18>[a-zçáéíóúâêô]+)a (?P<Mfavbg_19>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4ará', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbg_18").lower() in plvrMfoa and m.group("Mfavbg_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfavbg_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbg_21>[a-zçáéíóúâêô]+)as (?P<Mfavbg_22>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4arão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbg_21").lower() in plvrMfoa and m.group("Mfavbg_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mfavbh_1>[a-zçáéíóúâêô]+)a (?P<Mfavbh_2>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', '\\1 \\2a \\3aria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbh_1").lower() in plvrMfoa and m.group("Mfavbh_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mfavbh_3>[a-zçáéíóúâêô]+)as (?P<Mfavbh_4>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', '\\1s \\2as \\3ariam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbh_3").lower() in plvrMfoa and m.group("Mfavbh_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbh_5>[a-zçáéíóúâêô]+)a (?P<Mfavbh_6>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4aria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbh_5").lower() in plvrMfoa and m.group("Mfavbh_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbh_7>[a-zçáéíóúâêô]+)as (?P<Mfavbh_8>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4ariam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbh_7").lower() in plvrMfoa and m.group("Mfavbh_8") in plvrVbrar'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbh_9>[a-zçáéíóúâêô]+)a (?P<Mfavbh_10>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4aria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbh_9").lower() in plvrMfoa and m.group("Mfavbh_10") in plvrVbrar'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbh_11>[a-zçáéíóúâêô]+)as (?P<Mfavbh_12>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4ariam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbh_11").lower() in plvrMfoa and m.group("Mfavbh_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfavbh_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mfavbh_18>[a-zçáéíóúâêô]+)a (?P<Mfavbh_19>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4aria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbh_18").lower() in plvrMfoa and m.group("Mfavbh_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfavbh_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mfavbh_21>[a-zçáéíóúâêô]+)as (?P<Mfavbh_22>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4ariam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfavbh_21").lower() in plvrMfoa and m.group("Mfavbh_22") in plvrVbrar'],
# Masca
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msavba_1>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavba_2>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|am)(?![-\\w–\xad])', '\\1 \\2 \\3a', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavba_1").lower() in plvrMasca and m.group("Msavba_2") in plvrVbrar and not m.group("Msavba_2") + m.group(4) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msavba_3>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavba_4>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|a)(?![-\\w–\xad])', '\\1s \\2s \\3am', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavba_3").lower() in plvrMasca and m.group("Msavba_4") in plvrVbrar and not m.group("Msavba_4") + m.group(4) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavba_5>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavba_6>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|am)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4a', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavba_5").lower() in plvrMasca and m.group("Msavba_6") in plvrVbrar and not m.group("Msavba_6") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavba_7>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavba_8>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|a)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4am', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavba_7").lower() in plvrMasca and m.group("Msavba_8") in plvrVbrar and not m.group("Msavba_8") + m.group(5) in excvbar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavba_9>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavba_10>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|am)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4a', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavba_9").lower() in plvrMasca and m.group("Msavba_10") in plvrVbrar and not m.group("Msavba_10") + m.group(5) in excvbar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavba_11>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavba_12>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|a)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4am', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavba_11").lower() in plvrMasca and m.group("Msavba_12") in plvrVbrar and not m.group("Msavba_12") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msavba_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavba_18>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavba_19>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|am)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4a', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavba_18").lower() in plvrMasca and m.group("Msavba_19") in plvrVbrar and not m.group("Msavba_19") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msavba_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavba_21>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavba_22>[a-z]+[bcdfghjlmnprstvxzç])(o|amos|ais|a)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4am', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavba_21").lower() in plvrMasca and m.group("Msavba_22") in plvrVbrar and not m.group("Msavba_22") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msavbb_1>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbb_2>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', '\\1 \\2 \\3ava', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbb_1").lower() in plvrMasca and m.group("Msavbb_2") in plvrVbrar and not m.group("Msavbb_2") + m.group(4) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msavbb_3>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbb_4>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', '\\1s \\2s \\3avam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbb_3").lower() in plvrMasca and m.group("Msavbb_4") in plvrVbrar and not m.group("Msavbb_4") + m.group(4) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbb_5>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbb_6>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ava', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbb_5").lower() in plvrMasca and m.group("Msavbb_6") in plvrVbrar and not m.group("Msavbb_6") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbb_7>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbb_8>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4avam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbb_7").lower() in plvrMasca and m.group("Msavbb_8") in plvrVbrar and not m.group("Msavbb_8") + m.group(5) in excvbar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbb_9>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbb_10>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ava', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbb_9").lower() in plvrMasca and m.group("Msavbb_10") in plvrVbrar and not m.group("Msavbb_10") + m.group(5) in excvbar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbb_11>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbb_12>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4avam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbb_11").lower() in plvrMasca and m.group("Msavbb_12") in plvrVbrar and not m.group("Msavbb_12") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msavbb_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbb_18>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbb_19>[a-z]+[bcdfghjlmnprstvxzç])(avas|ávamos|áveis|avam)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4ava', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbb_18").lower() in plvrMasca and m.group("Msavbb_19") in plvrVbrar and not m.group("Msavbb_16") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msavbb_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbb_21>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbb_22>[a-z]+[bcdfghjlmnprstvxzç])(ava|avas|ávamos|áveis)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4avam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbb_21").lower() in plvrMasca and m.group("Msavbb_22") in plvrVbrar and not m.group("Msavbb_22") + m.group(5) in excvbar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msavbc_1>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbc_2>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', '\\1 \\2 \\3o', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbc_1").lower() in plvrMasca and m.group("Msavbc_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msavbc_3>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbc_4>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', '\\1s \\2s \\3aram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbc_3").lower() in plvrMasca and m.group("Msavbc_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbc_5>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbc_6>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4o', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbc_5").lower() in plvrMasca and m.group("Msavbc_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbc_7>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbc_8>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4aram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbc_7").lower() in plvrMasca and m.group("Msavbc_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbc_9>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbc_10>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4o', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbc_9").lower() in plvrMasca and m.group("Msavbc_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbc_11>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbc_12>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4aram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbc_11").lower() in plvrMasca and m.group("Msavbc_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msavbc_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbc_18>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbc_19>[a-z]+[bdfhjlmnprstvxz])(ei|aste|amos|astes|aram)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4o', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbc_18").lower() in plvrMasca and m.group("Msavbc_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msavbc_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbc_21>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbc_22>[a-z]+[bdfhjlmnprstvxz])(ei|aste|ou|amos|astes)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4aram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbc_21").lower() in plvrMasca and m.group("Msavbc_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msavbd_1>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbd_2>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', '\\1 \\2 \\3ço', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbd_1").lower() in plvrMasca and m.group("Msavbd_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msavbd_3>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbd_4>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', '\\1s \\2s \\3çaram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbd_3").lower() in plvrMasca and m.group("Msavbd_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbd_5>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbd_6>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ço', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbd_5").lower() in plvrMasca and m.group("Msavbd_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbd_7>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbd_8>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4çaram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbd_7").lower() in plvrMasca and m.group("Msavbd_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbd_9>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbd_10>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ço', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbd_9").lower() in plvrMasca and m.group("Msavbd_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbd_11>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbd_12>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4çaram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbd_11").lower() in plvrMasca and m.group("Msavbd_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msavbd_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbd_18>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbd_19>[a-z]+)(cei|çaste|çamos|çastes|çaram)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4ço', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbd_18").lower() in plvrMasca and m.group("Msavbd_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msavbd_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbd_21>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbd_22>[a-z]+)(cei|çaste|çou|çamos|çastes)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4çaram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbd_21").lower() in plvrMasca and m.group("Msavbd_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msavbe_1>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbe_2>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', '\\1 \\2 \\3co', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbe_1").lower() in plvrMasca and m.group("Msavbe_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msavbe_3>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbe_4>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', '\\1s \\2s \\3caram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbe_3").lower() in plvrMasca and m.group("Msavbe_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbe_5>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbe_6>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4co', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbe_5").lower() in plvrMasca and m.group("Msavbe_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbe_7>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbe_8>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4caram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbe_7").lower() in plvrMasca and m.group("Msavbe_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbe_9>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbe_10>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4co', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbe_9").lower() in plvrMasca and m.group("Msavbe_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbe_11>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbe_12>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4caram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbe_11").lower() in plvrMasca and m.group("Msavbe_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msavbe_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbe_18>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbe_19>[a-z]+)(quei|caste|camos|castes|caram)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4co', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbe_18").lower() in plvrMasca and m.group("Msavbe_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msavbe_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbe_21>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbe_22>[a-z]+)(quei|caste|cou|camos|castes)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4caram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbe_21").lower() in plvrMasca and m.group("Msavbe_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msavbf_1>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbf_2>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', '\\1 \\2 \\3go', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbf_1").lower() in plvrMasca and m.group("Msavbf_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msavbf_3>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbf_4>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', '\\1s \\2s \\3garam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbf_3").lower() in plvrMasca and m.group("Msavbf_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbf_5>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbf_6>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4go', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbf_5").lower() in plvrMasca and m.group("Msavbf_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbf_7>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbf_8>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4garam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbf_7").lower() in plvrMasca and m.group("Msavbf_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbf_9>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbf_10>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4go', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbf_9").lower() in plvrMasca and m.group("Msavbf_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbf_11>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbf_12>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4garam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbf_11").lower() in plvrMasca and m.group("Msavbf_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msavbf_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbf_18>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbf_19>[a-z]+)(guei|gaste|gamos|gastes|garam)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4go', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbf_18").lower() in plvrMasca and m.group("Msavbf_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msavbf_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbf_21>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbf_22>[a-z]+)(guei|gaste|gou|gamos|gastes)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4garam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbf_21").lower() in plvrMasca and m.group("Msavbf_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msavbg_1>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbg_2>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', '\\1 \\2 \\3ará', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbg_1").lower() in plvrMasca and m.group("Msavbg_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msavbg_3>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbg_4>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', '\\1s \\2s \\3arão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbg_3").lower() in plvrMasca and m.group("Msavbg_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbg_5>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbg_6>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ará', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbg_5").lower() in plvrMasca and m.group("Msavbg_6") in plvrVbrar and not excfrvb.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbg_7>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbg_8>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4arão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbg_7").lower() in plvrMasca and m.group("Msavbg_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbg_9>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbg_10>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ará', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbg_9").lower() in plvrMasca and m.group("Msavbg_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbg_11>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbg_12>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4arão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbg_11").lower() in plvrMasca and m.group("Msavbg_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msavbg_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbg_18>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbg_19>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|aremos|areis|arão)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4ará', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbg_18").lower() in plvrMasca and m.group("Msavbg_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msavbg_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbg_21>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbg_22>[a-z]+[bcdfghjlmnprstvxzç])(arei|arás|ará|aremos|areis)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4arão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbg_21").lower() in plvrMasca and m.group("Msavbg_22") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msavbh_1>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbh_2>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', '\\1 \\2 \\3aria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbh_1").lower() in plvrMasca and m.group("Msavbh_2") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msavbh_3>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbh_4>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', '\\1s \\2s \\3ariam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbh_3").lower() in plvrMasca and m.group("Msavbh_4") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbh_5>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbh_6>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4aria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbh_5").lower() in plvrMasca and m.group("Msavbh_6") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbh_7>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbh_8>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4ariam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbh_7").lower() in plvrMasca and m.group("Msavbh_8") in plvrVbrar'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbh_9>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbh_10>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4aria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbh_9").lower() in plvrMasca and m.group("Msavbh_10") in plvrVbrar'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbh_11>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbh_12>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4ariam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbh_11").lower() in plvrMasca and m.group("Msavbh_12") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msavbh_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msavbh_18>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msavbh_19>[a-z]+[bcdfghjlmnprstvxzç])(arias|aríamos|aríeis|ariam)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4aria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbh_18").lower() in plvrMasca and m.group("Msavbh_19") in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msavbh_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msavbh_21>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msavbh_22>[a-z]+[bcdfghjlmnprstvxzç])(aria|arias|aríamos|aríeis)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4ariam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msavbh_21").lower() in plvrMasca and m.group("Msavbh_22") in plvrVbrar'],
# Verbos Irregulares - GERAL
# Concordancia verbos irregulares terceira pessoa - plvrMasco
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Vbitpa_1>[a-záâãçéêíóôú]+[o]) (?P<Vbitpa_2>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + aavbPst[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpa_1").lower() in plvrMasco and m.group("Vbitpa_2") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Vbitpa_3>[a-záâãçéêíóôú]+[o])s (?P<Vbitpa_4>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s " + aavbSpt[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpa_3").lower() in plvrMasco and m.group("Vbitpa_4") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitpa_5>[a-záâãçéêíóôú]+[o]) (?P<Vbitpa_6>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + " " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpa_5").lower() in plvrMasco and m.group("Vbitpa_6") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitpa_7>[a-záâãçéêíóôú]+[o])s (?P<Vbitpa_8>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "s " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpa_7").lower() in plvrMasco and m.group("Vbitpa_8") in acvbSpt'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitpa_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Vbitpa_10>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + " " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpa_9").lower() in plvrMasco and m.group("Vbitpa_10") in acvbPst'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitpa_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Vbitpa_12>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "s " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpa_11").lower() in plvrMasco and m.group("Vbitpa_12") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpa_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitpa_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Vbitpa_19>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + " " + m.group(3) + " " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpa_18").lower() in plvrMasco and m.group("Vbitpa_19") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpa_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitpa_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Vbitpa_22>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + "s " + m.group(3) + "s " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpa_21").lower() in plvrMasco and m.group("Vbitpa_22") in acvbSpt'],
# Concordancia verbos irregulares terceira pessoa - plvrMfoa - masculino
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Vbitpb_1>[a-zçáéíóúâêô]+)o (?P<Vbitpb_2>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "o " + aavbPst[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpb_1").lower() in plvrMfoa and m.group("Vbitpb_2") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Vbitpb_3>[a-zçáéíóúâêô]+)os (?P<Vbitpb_4>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "os " + aavbSpt[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpb_3").lower() in plvrMfoa and m.group("Vbitpb_4") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitpb_5>[a-zçáéíóúâêô]+)o (?P<Vbitpb_6>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + "o " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpb_5").lower() in plvrMfoa and m.group("Vbitpb_6") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitpb_7>[a-zçáéíóúâêô]+)os (?P<Vbitpb_8>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "os " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpb_7").lower() in plvrMfoa and m.group("Vbitpb_8") in acvbSpt'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitpb_9>[a-zçáéíóúâêô]+)o (?P<Vbitpb_10>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + "o " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpb_9").lower() in plvrMfoa and m.group("Vbitpb_10") in acvbPst'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitpb_11>[a-zçáéíóúâêô]+)os (?P<Vbitpb_12>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "os " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpb_11").lower() in plvrMfoa and m.group("Vbitpb_12") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpb_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitpb_18>[a-zçáéíóúâêô]+)o (?P<Vbitpb_19>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + " " + m.group(3) + "o " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpb_18").lower() in plvrMfoa and m.group("Vbitpb_19") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpb_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitpb_21>[a-zçáéíóúâêô]+)os (?P<Vbitpb_22>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + "s " + m.group(3) + "os " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpb_21").lower() in plvrMfoa and m.group("Vbitpb_22") in acvbSpt'],
# Concordancia verbos irregulares terceira pessoa - plvrMfoa - feminino
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Vbitpc_1>[a-zçáéíóúâêô]+)a (?P<Vbitpc_2>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "a " + aavbPst[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpc_1").lower() in plvrMfoa and m.group("Vbitpc_2") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Vbitpc_3>[a-zçáéíóúâêô]+)as (?P<Vbitpc_4>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "as " + aavbSpt[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpc_3").lower() in plvrMfoa and m.group("Vbitpc_4") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Vbitpc_5>[a-zçáéíóúâêô]+)a (?P<Vbitpc_6>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + "a " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpc_5").lower() in plvrMfoa and m.group("Vbitpc_6") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Vbitpc_7>[a-zçáéíóúâêô]+)as (?P<Vbitpc_8>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "as " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpc_7").lower() in plvrMfoa and m.group("Vbitpc_8") in acvbSpt'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Vbitpc_9>[a-zçáéíóúâêô]+)a (?P<Vbitpc_10>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + "a " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpc_9").lower() in plvrMfoa and m.group("Vbitpc_10") in acvbPst'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Vbitpc_11>[a-zçáéíóúâêô]+)as (?P<Vbitpc_12>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "as " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpc_11").lower() in plvrMfoa and m.group("Vbitpc_12") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpc_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Vbitpc_18>[a-zçáéíóúâêô]+)a (?P<Vbitpc_19>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + " " + m.group(3) + "a " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpc_18").lower() in plvrMfoa and m.group("Vbitpc_19") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpc_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Vbitpc_21>[a-zçáéíóúâêô]+)as (?P<Vbitpc_22>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + "s " + m.group(3) + "as " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpc_21").lower() in plvrMfoa and m.group("Vbitpc_22") in acvbSpt'],
# Concordancia verbos irregulares terceira pessoa - plvrMasca
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Vbitpd_1>[a-záâãçéêíóôú]+[a]) (?P<Vbitpd_2>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + aavbPst[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpd_1").lower() in plvrMasca and m.group("Vbitpd_2") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Vbitpd_3>[a-záâãçéêíóôú]+[a])s (?P<Vbitpd_4>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s " + aavbSpt[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpd_3").lower() in plvrMasca and m.group("Vbitpd_4") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitpd_5>[a-záâãçéêíóôú]+[a]) (?P<Vbitpd_6>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + " " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpd_5").lower() in plvrMasca and m.group("Vbitpd_6") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitpd_7>[a-záâãçéêíóôú]+[a])s (?P<Vbitpd_8>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "s " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpd_7").lower() in plvrMasca and m.group("Vbitpd_8") in acvbSpt'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitpd_9>[a-zA-Záâãçéêíóôú]+[a]) (?P<Vbitpd_10>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + " " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpd_9").lower() in plvrMasca and m.group("Vbitpd_10") in acvbPst'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitpd_11>[a-zA-Záâãçéêíóôú]+[a])s (?P<Vbitpd_12>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "s " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpd_11").lower() in plvrMasca and m.group("Vbitpd_12") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpd_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitpd_18>[a-zA-Záâãçéêíóôú]+[a]) (?P<Vbitpd_19>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + " " + m.group(3) + " " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpd_18").lower() in plvrMasca and m.group("Vbitpd_19") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpd_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitpd_21>[a-zA-Záâãçéêíóôú]+[a])s (?P<Vbitpd_22>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + "s " + m.group(3) + "s " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpd_21").lower() in plvrMasca and m.group("Vbitpd_22") in acvbSpt'],
# Concordancia verbos irregulares terceira pessoa - plvrFema
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Vbitpe_1>[a-záâãçéêíóôú]+[a]) (?P<Vbitpe_2>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + aavbPst[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpe_1").lower() in plvrFema and m.group("Vbitpe_2") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Vbitpe_3>[a-záâãçéêíóôú]+[a])s (?P<Vbitpe_4>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s " + aavbSpt[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpe_3").lower() in plvrFema and m.group("Vbitpe_4") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Vbitpe_5>[a-záâãçéêíóôú]+[a]) (?P<Vbitpe_6>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + " " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpe_5").lower() in plvrFema and m.group("Vbitpe_6") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Vbitpe_7>[a-záâãçéêíóôú]+[a])s (?P<Vbitpe_8>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "s " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpe_7").lower() in plvrFema and m.group("Vbitpe_8") in acvbSpt'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Vbitpe_9>[a-záâãçéêíóôú]+[a]) (?P<Vbitpe_10>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + " " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpe_9").lower() in plvrFema and m.group("Vbitpe_10") in acvbPst'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Vbitpe_11>[a-záâãçéêíóôú]+[a])s (?P<Vbitpe_12>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "s " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpe_11").lower() in plvrFema and m.group("Vbitpe_12") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpe_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Vbitpe_18>[a-záâãçéêíóôú]+[a]) (?P<Vbitpe_19>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + " " + m.group(3) + " " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpe_18").lower() in plvrFema and m.group("Vbitpe_19") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpe_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Vbitpe_21>[a-záâãçéêíóôú]+[a])s (?P<Vbitpe_22>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + "s " + m.group(3) + "s " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpe_21").lower() in plvrFema and m.group("Vbitpe_22") in acvbSpt'],
# Concordancia verbos irregulares terceira pessoa - plvrInva - masculino
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Vbitpf_1>[a-záâãçéêíóôú]+[a]) (?P<Vbitpf_2>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + aavbPst[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpf_1").lower() in plvrInva and m.group("Vbitpf_2") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Vbitpf_3>[a-záâãçéêíóôú]+[a])s (?P<Vbitpf_4>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s " + aavbSpt[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpf_3").lower() in plvrInva and m.group("Vbitpf_4") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitpf_5>[a-záâãçéêíóôú]+[a]) (?P<Vbitpf_6>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + " " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpf_5").lower() in plvrInva and m.group("Vbitpf_6") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitpf_7>[a-záâãçéêíóôú]+[a])s (?P<Vbitpf_8>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "s " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpf_7").lower() in plvrInva and m.group("Vbitpf_8") in acvbSpt'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitpf_9>[a-zA-Záâãçéêíóôú]+[a]) (?P<Vbitpf_10>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + " " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpf_9").lower() in plvrInva and m.group("Vbitpf_10") in acvbPst'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitpf_11>[a-zA-Záâãçéêíóôú]+[a])s (?P<Vbitpf_12>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "s " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpf_11").lower() in plvrInva and m.group("Vbitpf_12") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpf_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitpf_18>[a-zA-Záâãçéêíóôú]+[a]) (?P<Vbitpf_19>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + " " + m.group(3) + " " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpf_18").lower() in plvrInva and m.group("Vbitpf_19") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpf_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitpf_21>[a-zA-Záâãçéêíóôú]+[a])s (?P<Vbitpf_22>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + "s " + m.group(3) + "s " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpf_21").lower() in plvrInva and m.group("Vbitpf_22") in acvbSpt'],
# Concordancia verbos irregulares terceira pessoa - plvrInva - feminino
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Vbitpg_1>[a-záâãçéêíóôú]+[a]) (?P<Vbitpg_2>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + aavbPst[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpg_1").lower() in plvrInva and m.group("Vbitpg_2") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Vbitpg_3>[a-záâãçéêíóôú]+[a])s (?P<Vbitpg_4>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s " + aavbSpt[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpg_3").lower() in plvrInva and m.group("Vbitpg_4") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Vbitpg_5>[a-záâãçéêíóôú]+[a]) (?P<Vbitpg_6>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + " " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpg_5").lower() in plvrInva and m.group("Vbitpg_6") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Vbitpg_7>[a-záâãçéêíóôú]+[a])s (?P<Vbitpg_8>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "s " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpg_7").lower() in plvrInva and m.group("Vbitpg_8") in acvbSpt'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Vbitpg_9>[a-záâãçéêíóôú]+[a]) (?P<Vbitpg_10>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + " " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpg_9").lower() in plvrInva and m.group("Vbitpg_10") in acvbPst'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Vbitpg_11>[a-záâãçéêíóôú]+[a])s (?P<Vbitpg_12>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "s " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpg_11").lower() in plvrInva and m.group("Vbitpg_12") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpg_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Vbitpg_18>[a-záâãçéêíóôú]+[a]) (?P<Vbitpg_19>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + " " + m.group(3) + " " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpg_18").lower() in plvrInva and m.group("Vbitpg_19") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpg_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Vbitpg_21>[a-záâãçéêíóôú]+[a])s (?P<Vbitpg_22>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + "s " + m.group(3) + "s " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpg_21").lower() in plvrInva and m.group("Vbitpg_22") in acvbSpt'],
# Concordancia verbos irregulares terceira pessoa - plvrMasce - masculino
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Vbitph_1>[a-zçáéíóúâêô]+)e (?P<Vbitph_2>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "e " + aavbPst[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitph_1").lower() in plvrMasce and m.group("Vbitph_2") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Vbitph_3>[a-zçáéíóúâêô]+)es (?P<Vbitph_4>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es " + aavbSpt[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitph_3").lower() in plvrMasce and m.group("Vbitph_4") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitph_5>[a-zçáéíóúâêô]+)e (?P<Vbitph_6>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + "e " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitph_5").lower() in plvrMasce and m.group("Vbitph_6") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitph_7>[a-zçáéíóúâêô]+)es (?P<Vbitph_8>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "es " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitph_7").lower() in plvrMasce and m.group("Vbitph_8") in acvbSpt'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitph_9>[a-zçáéíóúâêô]+)e (?P<Vbitph_10>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + "e " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitph_9").lower() in plvrMasce and m.group("Vbitph_10") in acvbPst'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitph_11>[a-zçáéíóúâêô]+)es (?P<Vbitph_12>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "es " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitph_11").lower() in plvrMasce and m.group("Vbitph_12") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitph_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitph_18>[a-zçáéíóúâêô]+)e (?P<Vbitph_19>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + " " + m.group(3) + "e " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitph_18").lower() in plvrMasce and m.group("Vbitph_19") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitph_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitph_21>[a-zçáéíóúâêô]+)es (?P<Vbitph_22>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + "s " + m.group(3) + "es " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitph_21").lower() in plvrMasce and m.group("Vbitph_22") in acvbSpt'],
# Concordancia verbos irregulares terceira pessoa - plvrFeme - feminino
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Vbitpi_1>[a-zçáéíóúâêô]+)e (?P<Vbitpi_2>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "e " + aavbPst[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpi_1").lower() in plvrFeme and m.group("Vbitpi_2") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Vbitpi_3>[a-zçáéíóúâêô]+)es (?P<Vbitpi_4>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es " + aavbSpt[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpi_3").lower() in plvrFeme and m.group("Vbitpi_4") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Vbitpi_5>[a-zçáéíóúâêô]+)e (?P<Vbitpi_6>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + "e " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpi_5").lower() in plvrFeme and m.group("Vbitpi_6") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Vbitpi_7>[a-zçáéíóúâêô]+)es (?P<Vbitpi_8>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "es " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpi_7").lower() in plvrFeme and m.group("Vbitpi_8") in acvbSpt'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Vbitpi_9>[a-zçáéíóúâêô]+)e (?P<Vbitpi_10>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + "e " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpi_9").lower() in plvrFeme and m.group("Vbitpi_10") in acvbPst'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Vbitpi_11>[a-zçáéíóúâêô]+)es (?P<Vbitpi_12>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "es " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpi_11").lower() in plvrFeme and m.group("Vbitpi_12") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpi_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Vbitpi_18>[a-zçáéíóúâêô]+)e (?P<Vbitpi_19>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + " " + m.group(3) + "e " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpi_18").lower() in plvrFeme and m.group("Vbitpi_19") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpi_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Vbitpi_21>[a-zçáéíóúâêô]+)es (?P<Vbitpi_22>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + "s " + m.group(3) + "es " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpi_21").lower() in plvrFeme and m.group("Vbitpi_22") in acvbSpt'],
# Concordancia verbos irregulares terceira pessoa - plvrMfe - masculino
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Vbitpj_1>[a-zçáéíóúâêô]+)e (?P<Vbitpj_2>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "e " + aavbPst[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpj_1").lower() in plvrMfe and m.group("Vbitpj_2") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Vbitpj_3>[a-zçáéíóúâêô]+)es (?P<Vbitpj_4>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es " + aavbSpt[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpj_3").lower() in plvrMfe and m.group("Vbitpj_4") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitpj_5>[a-zçáéíóúâêô]+)e (?P<Vbitpj_6>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + "e " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpj_5").lower() in plvrMfe and m.group("Vbitpj_6") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitpj_7>[a-zçáéíóúâêô]+)es (?P<Vbitpj_8>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "es " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpj_7").lower() in plvrMfe and m.group("Vbitpj_8") in acvbSpt'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitpj_9>[a-zçáéíóúâêô]+)e (?P<Vbitpj_10>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + "e " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpj_9").lower() in plvrMfe and m.group("Vbitpj_10") in acvbPst'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitpj_11>[a-zçáéíóúâêô]+)es (?P<Vbitpj_12>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "es " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpj_11").lower() in plvrMfe and m.group("Vbitpj_12") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpj_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Vbitpj_18>[a-zçáéíóúâêô]+)e (?P<Vbitpj_19>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + " " + m.group(3) + "e " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpj_18").lower() in plvrMfe and m.group("Vbitpj_19") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpj_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Vbitpj_21>[a-zçáéíóúâêô]+)es (?P<Vbitpj_22>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + "s " + m.group(3) + "es " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpj_21").lower() in plvrMfe and m.group("Vbitpj_22") in acvbSpt'],
# Concordancia verbos irregulares terceira pessoa - plvrMfe - feminino
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Vbitpk_1>[a-zçáéíóúâêô]+)e (?P<Vbitpk_2>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "e " + aavbPst[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpk_1").lower() in plvrMfe and m.group("Vbitpk_2") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Vbitpk_3>[a-zçáéíóúâêô]+)es (?P<Vbitpk_4>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es " + aavbSpt[m.group(3)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpk_3").lower() in plvrMfe and m.group("Vbitpk_4") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Vbitpk_5>[a-zçáéíóúâêô]+)e (?P<Vbitpk_6>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + "e " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpk_5").lower() in plvrMfe and m.group("Vbitpk_6") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Vbitpk_7>[a-zçáéíóúâêô]+)es (?P<Vbitpk_8>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "es " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpk_7").lower() in plvrMfe and m.group("Vbitpk_8") in acvbSpt'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Vbitpk_9>[a-zçáéíóúâêô]+)e (?P<Vbitpk_10>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + " " + m.group(3) + "e " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpk_9").lower() in plvrMfe and m.group("Vbitpk_10") in acvbPst'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Vbitpk_11>[a-zçáéíóúâêô]+)es (?P<Vbitpk_12>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s " + m.group(3) + "es " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpk_11").lower() in plvrMfe and m.group("Vbitpk_12") in acvbSpt'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpk_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Vbitpk_18>[a-zçáéíóúâêô]+)e (?P<Vbitpk_19>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + " " + m.group(3) + "e " + aavbPst[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpk_18").lower() in plvrMfe and m.group("Vbitpk_19") in acvbPst'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vbitpk_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Vbitpk_21>[a-zçáéíóúâêô]+)es (?P<Vbitpk_22>[a-záãçéêíóô]+)(?![-\\w–\xad])', '= m.group(1) + "mente " + m.group(2) + "s " + m.group(3) + "es " + aavbSpt[m.group(4)]', 'Não há concordância verbal. Você quis dizer:', 'm.group("Vbitpk_21").lower() in plvrMfe and m.group("Vbitpk_22") in acvbSpt'],
# FIM Verbos Irregulares - GERAL
# CONCORDANCIA VERBAL - verbos regulares terminados em er
# presente do indicativo [bdhilmnoprstuvxz]er
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvba_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvba_2>[a-z]+[bdhilmnoprstuvxz])(o|es|emos|eis|em)(?![-\\w–\xad])', '\\1 \\2 \\3e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvba_1").lower() in plvrMasco and m.group("Msxvba_2") in plvrVbrxer and not m.group("Msxvba_2") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvba_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvba_4>[a-z]+[bdhilmnoprstuvxz])(o|es|e|emos|eis)(?![-\\w–\xad])', '\\1s \\2s \\3em', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvba_3").lower() in plvrMasco and m.group("Msxvba_4") in plvrVbrxer and not m.group("Msxvba_4") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvba_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvba_6>[a-z]+[bdhilmnoprstuvxz])(o|es|emos|eis|em)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvba_5").lower() in plvrMasco and m.group("Msxvba_6") in plvrVbrxer and not m.group("Msxvba_6") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvba_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvba_8>[a-z]+[bdhilmnoprstuvxz])(o|es|e|emos|eis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4em', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvba_7").lower() in plvrMasco and m.group("Msxvba_8") in plvrVbrxer and not m.group("Msxvba_8") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvba_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvba_10>[a-z]+[bdhilmnoprstuvxz])(o|es|emos|eis|em)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvba_9").lower() in plvrMasco and m.group("Msxvba_10") in plvrVbrxer and not m.group("Msxvba_10") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvba_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvba_12>[a-z]+[bdhilmnoprstuvxz])(o|es|e|emos|eis)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4em', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvba_11").lower() in plvrMasco and m.group("Msxvba_12") in plvrVbrxer and not m.group("Msxvba_12") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvba_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvba_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvba_19>[a-z]+[bdhilmnoprstuvxz])(o|es|emos|eis|em)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvba_18").lower() in plvrMasco and m.group("Msxvba_19") in plvrVbrxer and not m.group("Msxvba_19") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvba_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvba_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvba_22>[a-z]+[bdhilmnoprstuvxz])(o|es|e|emos|eis)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4em', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvba_21").lower() in plvrMasco and m.group("Msxvba_22") in plvrVbrxer and not m.group("Msxvba_22") + m.group(5) in exvrVbrxer'],
# presente do indicativo cer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbb_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbb_2>[a-z]+)(ço|ces|cemos|ceis|cem)(?![-\\w–\xad])', '\\1 \\2 \\3ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbb_1").lower() in plvrMasco and m.group("Msxvbb_2") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbb_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbb_4>[a-z]+)(ço|ces|cemos|ceis|ce)(?![-\\w–\xad])', '\\1s \\2s \\3cem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbb_3").lower() in plvrMasco and m.group("Msxvbb_4") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbb_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbb_6>[a-z]+)(ço|ces|cemos|ceis|cem)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbb_5").lower() in plvrMasco and m.group("Msxvbb_6") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbb_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbb_8>[a-z]+)(ço|ces|cemos|ceis|ce)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4cem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbb_7").lower() in plvrMasco and m.group("Msxvbb_8") in plvrVbrcer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbb_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbb_10>[a-z]+)(ço|ces|cemos|ceis|cem)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbb_9").lower() in plvrMasco and m.group("Msxvbb_10") in plvrVbrcer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbb_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbb_12>[a-z]+)(ço|ces|cemos|ceis|ce)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4cem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbb_11").lower() in plvrMasco and m.group("Msxvbb_12") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbb_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbb_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbb_19>[a-z]+)(ço|ces|cemos|ceis|cem)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbb_18").lower() in plvrMasco and m.group("Msxvbb_19") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbb_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbb_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbb_22>[a-z]+)(ço|ces|cemos|ceis|ce)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4cem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbb_21").lower() in plvrMasco and m.group("Msxvbb_22") in plvrVbrcer'],
# presente do indicativo guer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbc_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbc_2>[a-z]+[g])(o|ues|uemos|ueis|uem)(?![-\\w–\xad])', '\\1 \\2 \\3ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbc_1").lower() in plvrMasco and m.group("Msxvbc_2") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbc_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbc_4>[a-z]+[g])(o|ues|uemos|ueis|ue)(?![-\\w–\xad])', '\\1s \\2s \\3uem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbc_3").lower() in plvrMasco and m.group("Msxvbc_4") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbc_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbc_6>[a-z]+[g])(o|ues|uemos|ueis|uem)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbc_5").lower() in plvrMasco and m.group("Msxvbc_6") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbc_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbc_8>[a-z]+[g])(o|ues|uemos|ueis|ue)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4uem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbc_7").lower() in plvrMasco and m.group("Msxvbc_8") in plvrVbruer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbc_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbc_10>[a-z]+[g])(o|ues|uemos|ueis|uem)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbc_9").lower() in plvrMasco and m.group("Msxvbc_10") in plvrVbruer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbc_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbc_12>[a-z]+[g])(o|ues|uemos|ueis|ue)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4uem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbc_11").lower() in plvrMasco and m.group("Msxvbc_12") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbc_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbc_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbc_19>[a-z]+[g])(o|ues|uemos|ueis|uem)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbc_18").lower() in plvrMasco and m.group("Msxvbc_19") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbc_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbc_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbc_22>[a-z]+[g])(o|ues|uemos|ueis|ue)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4uem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbc_21").lower() in plvrMasco and m.group("Msxvbc_22") in plvrVbruer'],
# presente do indicativo ger
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbd_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbd_2>[a-z]+)(jo|ges|gemos|geis|gem)(?![-\\w–\xad])', '\\1 \\2 \\3ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbd_1").lower() in plvrMasco and m.group("Msxvbd_2") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbd_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbd_4>[a-z]+)(jo|ges|gemos|geis|ge)(?![-\\w–\xad])', '\\1s \\2s \\3gem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbd_3").lower() in plvrMasco and m.group("Msxvbd_4") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbd_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbd_6>[a-z]+)(jo|ges|gemos|geis|gem)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbd_5").lower() in plvrMasco and m.group("Msxvbd_6") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbd_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbd_8>[a-z]+)(jo|ges|gemos|geis|ge)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4gem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbd_7").lower() in plvrMasco and m.group("Msxvbd_8") in plvrVbrger'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbd_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbd_10>[a-z]+)(jo|ces|cemos|ceis|cem)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbd_9").lower() in plvrMasco and m.group("Msxvbd_10") in plvrVbrger'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbd_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbd_12>[a-z]+)(jo|ges|gemos|geis|ge)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4gem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbd_11").lower() in plvrMasco and m.group("Msxvbd_12") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbd_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbd_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbd_19>[a-z]+)(jo|ges|gemos|geis|gem)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbd_18").lower() in plvrMasco and m.group("Msxvbd_19") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbd_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbd_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbd_22>[a-z]+)(jo|ges|gemos|geis|ge)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4gem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbd_21").lower() in plvrMasco and m.group("Msxvbd_22") in plvrVbrger'],
# preterito perfeito [bdhilmnoprstuvxz]er
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbe_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbe_2>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eram)(?![-\\w–\xad])', '\\1 \\2 \\3e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbe_1").lower() in plvrMasco and m.group("Msxvbe_2") in plvrVbrxer and not m.group("Msxvbe_2") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbe_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbe_4>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eu)(?![-\\w–\xad])', '\\1s \\2s \\3eram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbe_3").lower() in plvrMasco and m.group("Msxvbe_4") in plvrVbrxer and not m.group("Msxvbe_4") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbe_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbe_6>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbe_5").lower() in plvrMasco and m.group("Msxvbe_6") in plvrVbrxer and not m.group("Msxvbe_6") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbe_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbe_8>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eu)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4eram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbe_7").lower() in plvrMasco and m.group("Msxvbe_8") in plvrVbrxer and not m.group("Msxvbe_8") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbe_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbe_10>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbe_9").lower() in plvrMasco and m.group("Msxvbe_10") in plvrVbrxer and not m.group("Msxvbe_10") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbe_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbe_12>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eu)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4eram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbe_11").lower() in plvrMasco and m.group("Msxvbe_12") in plvrVbrxer and not m.group("Msxvbe_12") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbe_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbe_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbe_19>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eram)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbe_18").lower() in plvrMasco and m.group("Msxvbe_19") in plvrVbrxer and not m.group("Msxvbe_19") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbe_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbe_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbe_22>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eu)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4eram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbe_21").lower() in plvrMasco and m.group("Msxvbe_22") in plvrVbrxer and not m.group("Msxvbe_22") + m.group(5) in exvrVbrxer'],
# preterito perfeito cer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbf_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbf_2>[a-z]+)(ci|ceste|cemos|cestes|ceram)(?![-\\w–\xad])', '\\1 \\2 \\3ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbf_1").lower() in plvrMasco and m.group("Msxvbf_2") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbf_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbf_4>[a-z]+)(ci|ceste|cemos|cestes|ceu)(?![-\\w–\xad])', '\\1s \\2s \\3ceram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbf_3").lower() in plvrMasco and m.group("Msxvbf_4") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbf_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbf_6>[a-z]+)(ci|ceste|cemos|cestes|ceram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbf_5").lower() in plvrMasco and m.group("Msxvbf_6") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbf_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbf_8>[a-z]+)(ci|ceste|cemos|cestes|ceu)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4ceram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbf_7").lower() in plvrMasco and m.group("Msxvbf_8") in plvrVbrcer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbf_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbf_10>[a-z]+)(ci|ceste|cemos|cestes|ceram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbf_9").lower() in plvrMasco and m.group("Msxvbf_10") in plvrVbrcer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbf_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbf_12>[a-z]+)(ci|ceste|cemos|cestes|ceu)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4ceram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbf_11").lower() in plvrMasco and m.group("Msxvbf_12") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbf_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbf_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbf_19>[a-z]+)(ci|ceste|cemos|cestes|ceram)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbf_18").lower() in plvrMasco and m.group("Msxvbf_19") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbf_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbf_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbf_22>[a-z]+)(ci|ceste|cemos|cestes|ceu)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4ceram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbf_21").lower() in plvrMasco and m.group("Msxvbf_22") in plvrVbrcer'],
# preterito perfeito guer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbg_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbg_2>[a-z]+[g])(ui|ueste|uemos|uestes|ueram)(?![-\\w–\xad])', '\\1 \\2 \\3ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbg_1").lower() in plvrMasco and m.group("Msxvbg_2") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbg_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbg_4>[a-z]+[g])(ui|ueste|uemos|uestes|ueu)(?![-\\w–\xad])', '\\1s \\2s \\3ueram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbg_3").lower() in plvrMasco and m.group("Msxvbg_4") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbg_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbg_6>[a-z]+[g])(ui|ueste|uemos|uestes|ueram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbg_5").lower() in plvrMasco and m.group("Msxvbg_6") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbg_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbg_8>[a-z]+[g])(ui|ueste|uemos|uestes|ueu)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4ueram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbg_7").lower() in plvrMasco and m.group("Msxvbg_8") in plvrVbruer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbg_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbg_10>[a-z]+[g])(ui|ueste|uemos|uestes|ueram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbg_9").lower() in plvrMasco and m.group("Msxvbg_10") in plvrVbruer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbg_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbg_12>[a-z]+[g])(ui|ueste|uemos|uestes|ueu)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4ueram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbg_11").lower() in plvrMasco and m.group("Msxvbg_12") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbg_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbg_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbg_19>[a-z]+[g])(ui|ueste|uemos|uestes|ueram)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbg_18").lower() in plvrMasco and m.group("Msxvbg_19") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbg_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbg_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbg_22>[a-z]+[g])(ui|ueste|uemos|uestes|ueu)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4ueram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbg_21").lower() in plvrMasco and m.group("Msxvbg_22") in plvrVbruer'],
# preterito perfeito ger
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbh_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbh_2>[a-z]+)(gi|geste|gemos|gestes|geram)(?![-\\w–\xad])', '\\1 \\2 \\3ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbh_1").lower() in plvrMasco and m.group("Msxvbh_2") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbh_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbh_4>[a-z]+)(gi|geste|gemos|gestes|geu)(?![-\\w–\xad])', '\\1s \\2s \\3geram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbh_3").lower() in plvrMasco and m.group("Msxvbh_4") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbh_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbh_6>[a-z]+)(gi|geste|gemos|gestes|geram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbh_5").lower() in plvrMasco and m.group("Msxvbh_6") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbh_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbh_8>[a-z]+)(gi|geste|gemos|gestes|geu)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4geram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbh_7").lower() in plvrMasco and m.group("Msxvbh_8") in plvrVbrger'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbh_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbh_10>[a-z]+)(gi|geste|gemos|gestes|geram)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbh_9").lower() in plvrMasco and m.group("Msxvbh_10") in plvrVbrger'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbh_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbh_12>[a-z]+)(gi|geste|gemos|gestes|geu)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4geram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbh_11").lower() in plvrMasco and m.group("Msxvbh_12") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbh_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbh_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbh_19>[a-z]+)(gi|geste|gemos|gestes|geram)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbh_18").lower() in plvrMasco and m.group("Msxvbh_19") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbh_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbh_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbh_22>[a-z]+)(gi|geste|gemos|gestes|geu)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4geram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbh_21").lower() in plvrMasco and m.group("Msxvbh_22") in plvrVbrger'],
# preterito imperfeito [bdhilmnoprstuvxz]er
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbi_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbi_2>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', '\\1 \\2 \\3ia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbi_1").lower() in plvrMasco and m.group("Msxvbi_2") in plvrVbrxer and not m.group("Msxvbi_2") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbi_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbi_4>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|ia)(?![-\\w–\xad])', '\\1s \\2s \\3iam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbi_3").lower() in plvrMasco and m.group("Msxvbi_4") in plvrVbrxer and not m.group("Msxvbi_4") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbi_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbi_6>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbi_5").lower() in plvrMasco and m.group("Msxvbi_6") in plvrVbrxer and not m.group("Msxvbi_6") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbi_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbi_8>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|ia)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4iam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbi_7").lower() in plvrMasco and m.group("Msxvbi_8") in plvrVbrxer and not m.group("Msxvbi_8") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbi_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbi_10>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbi_9").lower() in plvrMasco and m.group("Msxvbi_10") in plvrVbrxer and not m.group("Msxvbi_10") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbi_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbi_12>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|ia)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4iam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbi_11").lower() in plvrMasco and m.group("Msxvbi_12") in plvrVbrxer and not m.group("Msxvbi_12") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbi_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbi_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbi_19>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4ia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbi_18").lower() in plvrMasco and m.group("Msxvbi_19") in plvrVbrxer and not m.group("Msxvbi_19") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbi_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbi_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbi_22>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|ia)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4iam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbi_21").lower() in plvrMasco and m.group("Msxvbi_22") in plvrVbrxer and not m.group("Msxvbi_22") + m.group(5) in exvrVbrxer'],
# preterito imperfeito cer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbj_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbj_2>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', '\\1 \\2 \\3cia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbj_1").lower() in plvrMasco and m.group("Msxvbj_2") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbj_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbj_4>[a-z]+)(cias|cíamos|cíeis|cia)(?![-\\w–\xad])', '\\1s \\2s \\3ciam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbj_3").lower() in plvrMasco and m.group("Msxvbj_4") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbj_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbj_6>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4cia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbj_5").lower() in plvrMasco and m.group("Msxvbj_6") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbj_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbj_8>[a-z]+)(cias|cíamos|cíeis|cia)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4ciam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbj_7").lower() in plvrMasco and m.group("Msxvbj_8") in plvrVbrcer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbj_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbj_10>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4cia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbj_9").lower() in plvrMasco and m.group("Msxvbj_10") in plvrVbrcer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbj_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbj_12>[a-z]+)(cias|cíamos|cíeis|cia)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4ciam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbj_11").lower() in plvrMasco and m.group("Msxvbj_12") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbj_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbj_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbj_19>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4cia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbj_18").lower() in plvrMasco and m.group("Msxvbj_19") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbj_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbj_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbj_22>[a-z]+)(cias|cíamos|cíeis|cia)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4ciam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbj_21").lower() in plvrMasco and m.group("Msxvbj_22") in plvrVbrcer'],
# preterito imperfeito guer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbk_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbk_2>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', '\\1 \\2 \\3uia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbk_1").lower() in plvrMasco and m.group("Msxvbk_2") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbk_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbk_4>[a-z]+[g])(uias|uíamos|uíeis|uia)(?![-\\w–\xad])', '\\1s \\2s \\3uiam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbk_3").lower() in plvrMasco and m.group("Msxvbk_4") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbk_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbk_6>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4uia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbk_5").lower() in plvrMasco and m.group("Msxvbk_6") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbk_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbk_8>[a-z]+[g])(uias|uíamos|uíeis|uia)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4uiam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbk_7").lower() in plvrMasco and m.group("Msxvbk_8") in plvrVbruer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbk_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbk_10>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4uia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbk_9").lower() in plvrMasco and m.group("Msxvbk_10") in plvrVbruer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbk_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbk_12>[a-z]+[g])(uias|uíamos|uíeis|uia)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4uiam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbk_11").lower() in plvrMasco and m.group("Msxvbk_12") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbk_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbk_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbk_19>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4uia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbk_18").lower() in plvrMasco and m.group("Msxvbk_19") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbk_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbk_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbk_22>[a-z]+[g])(uias|uíamos|uíeis|uia)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4uiam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbk_21").lower() in plvrMasco and m.group("Msxvbk_22") in plvrVbruer'],
# preterito imperfeito ger
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbl_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbl_2>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', '\\1 \\2 \\3gia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbl_1").lower() in plvrMasco and m.group("Msxvbl_2") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbl_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbl_4>[a-z]+)(gias|gíamos|gíeis|gia)(?![-\\w–\xad])', '\\1s \\2s \\3giam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbl_3").lower() in plvrMasco and m.group("Msxvbl_4") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbl_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbl_6>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4gia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbl_5").lower() in plvrMasco and m.group("Msxvbl_6") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbl_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbl_8>[a-z]+)(gias|gíamos|gíeis|gia)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4giam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbl_7").lower() in plvrMasco and m.group("Msxvbl_8") in plvrVbrger'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbl_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbl_10>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4gia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbl_9").lower() in plvrMasco and m.group("Msxvbl_10") in plvrVbrger'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbl_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbl_12>[a-z]+)(gias|gíamos|gíeis|gia)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4giam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbl_11").lower() in plvrMasco and m.group("Msxvbl_12") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbl_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbl_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbl_19>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4gia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbl_18").lower() in plvrMasco and m.group("Msxvbl_19") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbl_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbl_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbl_22>[a-z]+)(gias|gíamos|gíeis|gia)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4giam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbl_21").lower() in plvrMasco and m.group("Msxvbl_22") in plvrVbrger'],
# futuro do presente [bdhilmnoprstuvxz]er
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbm_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbm_2>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erão)(?![-\\w–\xad])', '\\1 \\2 \\3erá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbm_1").lower() in plvrMasco and m.group("Msxvbm_2") in plvrVbrxer and not m.group("Msxvbm_2") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbm_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbm_4>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erá)(?![-\\w–\xad])', '\\1s \\2s \\3erão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbm_3").lower() in plvrMasco and m.group("Msxvbm_4") in plvrVbrxer and not m.group("Msxvbm_4") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbm_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbm_6>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erão)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4erá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbm_5").lower() in plvrMasco and m.group("Msxvbm_6") in plvrVbrxer and not m.group("Msxvbm_6") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbm_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbm_8>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erá)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4erão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbm_7").lower() in plvrMasco and m.group("Msxvbm_8") in plvrVbrxer and not m.group("Msxvbm_8") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbm_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbm_10>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erão)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4erá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbm_9").lower() in plvrMasco and m.group("Msxvbm_10") in plvrVbrxer and not m.group("Msxvbm_10") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbm_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbm_12>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erá)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4erão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbm_11").lower() in plvrMasco and m.group("Msxvbm_12") in plvrVbrxer and not m.group("Msxvbm_12") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbm_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbm_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbm_19>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erão)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4erá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbm_18").lower() in plvrMasco and m.group("Msxvbm_19") in plvrVbrxer and not m.group("Msxvbm_19") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbm_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbm_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbm_22>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erá)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4erão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbm_21").lower() in plvrMasco and m.group("Msxvbm_22") in plvrVbrxer and not m.group("Msxvbm_22") + m.group(5) in exvrVbrxer'],
# futuro do presente cer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbn_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbn_2>[a-z]+)(cerei|cerás|ceremos|cereis|cerão)(?![-\\w–\xad])', '\\1 \\2 \\3cerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbn_1").lower() in plvrMasco and m.group("Msxvbn_2") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbn_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbn_4>[a-z]+)(cerei|cerás|ceremos|cereis|cerá)(?![-\\w–\xad])', '\\1s \\2s \\3cerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbn_3").lower() in plvrMasco and m.group("Msxvbn_4") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbn_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbn_6>[a-z]+)(cerei|cerás|ceremos|cereis|cerão)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4cerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbn_5").lower() in plvrMasco and m.group("Msxvbn_6") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbn_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbn_8>[a-z]+)(cerei|cerás|ceremos|cereis|cerá)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4cerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbn_7").lower() in plvrMasco and m.group("Msxvbn_8") in plvrVbrcer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbn_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbn_10>[a-z]+)(cerei|cerás|ceremos|cereis|cerão)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4cerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbn_9").lower() in plvrMasco and m.group("Msxvbn_10") in plvrVbrcer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbn_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbn_12>[a-z]+)(cerei|cerás|ceremos|cereis|cerá)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4cerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbn_11").lower() in plvrMasco and m.group("Msxvbn_12") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbn_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbn_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbn_19>[a-z]+)(cerei|cerás|ceremos|cereis|cerão)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4cerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbn_18").lower() in plvrMasco and m.group("Msxvbn_19") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbn_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbn_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbn_22>[a-z]+)(cerei|cerás|ceremos|cereis|cerá)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4cerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbn_21").lower() in plvrMasco and m.group("Msxvbn_22") in plvrVbrcer'],
# futuro do presente guer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbo_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbo_2>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerão)(?![-\\w–\xad])', '\\1 \\2 \\3uerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbo_1").lower() in plvrMasco and m.group("Msxvbo_2") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbo_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbo_4>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerá)(?![-\\w–\xad])', '\\1s \\2s \\3uerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbo_3").lower() in plvrMasco and m.group("Msxvbo_4") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbo_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbo_6>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerão)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4uerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbo_5").lower() in plvrMasco and m.group("Msxvbo_6") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbo_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbo_8>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerá)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4uerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbo_7").lower() in plvrMasco and m.group("Msxvbo_8") in plvrVbruer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbo_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbo_10>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerão)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4uerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbo_9").lower() in plvrMasco and m.group("Msxvbo_10") in plvrVbruer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbo_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbo_12>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerá)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4uerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbo_11").lower() in plvrMasco and m.group("Msxvbo_12") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbo_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbo_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbo_19>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerão)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4uerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbo_18").lower() in plvrMasco and m.group("Msxvbo_19") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbo_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbo_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbo_22>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerá)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4uerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbo_21").lower() in plvrMasco and m.group("Msxvbo_22") in plvrVbruer'],
# futuro do presente ger
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbp_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbp_2>[a-z]+)(gerei|gerás|geremos|gereis|gerão)(?![-\\w–\xad])', '\\1 \\2 \\3gerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbp_1").lower() in plvrMasco and m.group("Msxvbp_2") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbp_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbp_4>[a-z]+)(gerei|gerás|geremos|gereis|gerá)(?![-\\w–\xad])', '\\1s \\2s \\3gerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbp_3").lower() in plvrMasco and m.group("Msxvbp_4") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbp_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbp_6>[a-z]+)(gerei|gerás|geremos|gereis|gerão)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4gerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbp_5").lower() in plvrMasco and m.group("Msxvbp_6") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbp_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbp_8>[a-z]+)(gerei|gerás|geremos|gereis|gerá)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4gerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbp_7").lower() in plvrMasco and m.group("Msxvbp_8") in plvrVbrger'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbp_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbp_10>[a-z]+)(gerei|gerás|geremos|gereis|gerão)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4gerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbp_9").lower() in plvrMasco and m.group("Msxvbp_10") in plvrVbrger'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbp_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbp_12>[a-z]+)(gerei|gerás|geremos|gereis|gerá)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4gerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbp_11").lower() in plvrMasco and m.group("Msxvbp_12") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbp_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbp_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbp_19>[a-z]+)(gerei|gerás|geremos|gereis|gerão)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4gerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbp_18").lower() in plvrMasco and m.group("Msxvbp_19") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbp_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbp_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbp_22>[a-z]+)(gerei|gerás|geremos|gereis|gerá)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4gerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbp_21").lower() in plvrMasco and m.group("Msxvbp_22") in plvrVbrger'],
# futuro do preterito [bdhilmnoprstuvxz]er
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbq_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbq_2>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', '\\1 \\2 \\3eria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbq_1").lower() in plvrMasco and m.group("Msxvbq_2") in plvrVbrxer and not m.group("Msxvbq_2") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbq_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbq_4>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eria)(?![-\\w–\xad])', '\\1s \\2s \\3eriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbq_3").lower() in plvrMasco and m.group("Msxvbq_4") in plvrVbrxer and not m.group("Msxvbq_4") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbq_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbq_6>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4eria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbq_5").lower() in plvrMasco and m.group("Msxvbq_6") in plvrVbrxer and not m.group("Msxvbq_6") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbq_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbq_8>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eria)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4eriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbq_7").lower() in plvrMasco and m.group("Msxvbq_8") in plvrVbrxer and not m.group("Msxvbq_8") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbq_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbq_10>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4eria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbq_9").lower() in plvrMasco and m.group("Msxvbq_10") in plvrVbrxer and not m.group("Msxvbq_10") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbq_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbq_12>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eria)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4eriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbq_11").lower() in plvrMasco and m.group("Msxvbq_12") in plvrVbrxer and not m.group("Msxvbq_12") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbq_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbq_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbq_19>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4eria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbq_18").lower() in plvrMasco and m.group("Msxvbq_19") in plvrVbrxer and not m.group("Msxvbq_19") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbq_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbq_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbq_22>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eria)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4eriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbq_21").lower() in plvrMasco and m.group("Msxvbq_22") in plvrVbrxer and not m.group("Msxvbq_22") + m.group(5) in exvrVbrxer'],
# futuro do preterito cer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbr_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbr_2>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', '\\1 \\2 \\3ceria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbr_1").lower() in plvrMasco and m.group("Msxvbr_2") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbr_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbr_4>[a-z]+)(cerias|ceríamos|ceríeis|ceria)(?![-\\w–\xad])', '\\1s \\2s \\3ceriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbr_3").lower() in plvrMasco and m.group("Msxvbr_4") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbr_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbr_6>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ceria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbr_5").lower() in plvrMasco and m.group("Msxvbr_6") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbr_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbr_8>[a-z]+)(cerias|ceríamos|ceríeis|ceria)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4ceriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbr_7").lower() in plvrMasco and m.group("Msxvbr_8") in plvrVbrcer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbr_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbr_10>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ceria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbr_9").lower() in plvrMasco and m.group("Msxvbr_10") in plvrVbrcer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbr_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbr_12>[a-z]+)(cerias|ceríamos|ceríeis|ceria)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4ceriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbr_11").lower() in plvrMasco and m.group("Msxvbr_12") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbr_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbr_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbr_19>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4ceria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbr_18").lower() in plvrMasco and m.group("Msxvbr_19") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbr_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbr_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbr_22>[a-z]+)(cerias|ceríamos|ceríeis|ceria)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4ceriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbr_21").lower() in plvrMasco and m.group("Msxvbr_22") in plvrVbrcer'],
# futuro do preterito guer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbs_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbs_2>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', '\\1 \\2 \\3ueria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbs_1").lower() in plvrMasco and m.group("Msxvbs_2") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbs_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbs_4>[a-z]+[g])(uerias|ueríamos|ueríeis|ueria)(?![-\\w–\xad])', '\\1s \\2s \\3ueriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbs_3").lower() in plvrMasco and m.group("Msxvbs_4") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbs_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbs_6>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ueria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbs_5").lower() in plvrMasco and m.group("Msxvbs_6") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbs_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbs_8>[a-z]+[g])(uerias|ueríamos|ueríeis|ueria)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4ueriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbs_7").lower() in plvrMasco and m.group("Msxvbs_8") in plvrVbruer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbs_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbs_10>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4ueria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbs_9").lower() in plvrMasco and m.group("Msxvbs_10") in plvrVbruer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbs_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbs_12>[a-z]+[g])(uerias|ueríamos|ueríeis|ueria)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4ueriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbs_11").lower() in plvrMasco and m.group("Msxvbs_12") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbs_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbs_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbs_19>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4ueria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbs_18").lower() in plvrMasco and m.group("Msxvbs_19") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbs_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbs_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbs_22>[a-z]+[g])(uerias|ueríamos|ueríeis|ueria)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4ueriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbs_21").lower() in plvrMasco and m.group("Msxvbs_22") in plvrVbruer'],
# futuro do preterito ger
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Msxvbt_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbt_2>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', '\\1 \\2 \\3geria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbt_1").lower() in plvrMasco and m.group("Msxvbt_2") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Msxvbt_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbt_4>[a-z]+)(gerias|geríamos|geríeis|geria)(?![-\\w–\xad])', '\\1s \\2s \\3geriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbt_3").lower() in plvrMasco and m.group("Msxvbt_4") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbt_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbt_6>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4geria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbt_5").lower() in plvrMasco and m.group("Msxvbt_6") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbt_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbt_8>[a-z]+)(gerias|geríamos|geríeis|geria)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4geriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbt_7").lower() in plvrMasco and m.group("Msxvbt_8") in plvrVbrger'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbt_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbt_10>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', '\\1 \\2 \\3 \\4geria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbt_9").lower() in plvrMasco and m.group("Msxvbt_10") in plvrVbrger'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbt_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbt_12>[a-z]+)(gerias|geríamos|geríeis|geria)(?![-\\w–\xad])', '\\1 \\2s \\3s \\4geriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbt_11").lower() in plvrMasco and m.group("Msxvbt_12") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbt_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Msxvbt_18>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msxvbt_19>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', '\\1mente \\2 \\3 \\4geria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbt_18").lower() in plvrMasco and m.group("Msxvbt_19") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxvbt_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Msxvbt_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Msxvbt_22>[a-z]+)(gerias|geríamos|geríeis|geria)(?![-\\w–\xad])', '\\1mente \\2s \\3s \\4geriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msxvbt_21").lower() in plvrMasco and m.group("Msxvbt_22") in plvrVbrger'],
# Mfoa - masculino
# presente do indicativo [bdhilmnoprstuvxz]er
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvba_1>[a-zçáéíóúâêô]+)o (?P<Mfxvba_2>[a-z]+[bdhilmnoprstuvxz])(o|es|emos|eis|em)(?![-\\w–\xad])', '\\1 \\2o \\3e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvba_1").lower() in plvrMfoa and m.group("Mfxvba_2") in plvrVbrxer and not m.group("Mfxvba_2") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvba_3>[a-zçáéíóúâêô]+)os (?P<Mfxvba_4>[a-z]+[bdhilmnoprstuvxz])(o|e|emos|eis)(?![-\\w–\xad])', '\\1s \\2os \\3em', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvba_3").lower() in plvrMfoa and m.group("Mfxvba_4") in plvrVbrxer and not m.group("Mfxvba_4") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvba_5>[a-zçáéíóúâêô]+)o (?P<Mfxvba_6>[a-z]+[bdhilmnoprstuvxz])(o|es|emos|eis|em)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvba_5").lower() in plvrMfoa and m.group("Mfxvba_6") in plvrVbrxer and not m.group("Mfxvba_6") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvba_7>[a-zçáéíóúâêô]+)os (?P<Mfxvba_8>[a-z]+[bdhilmnoprstuvxz])(o|e|emos|eis)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4em', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvba_7").lower() in plvrMfoa and m.group("Mfxvba_8") in plvrVbrxer and not m.group("Mfxvba_8") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvba_9>[a-zçáéíóúâêô]+)o (?P<Mfxvba_10>[a-z]+[bdhilmnoprstuvxz])(o|es|emos|eis|em)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvba_9").lower() in plvrMfoa and m.group("Mfxvba_10") in plvrVbrxer and not m.group("Mfxvba_10") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvba_11>[a-zçáéíóúâêô]+)os (?P<Mfxvba_12>[a-z]+[bdhilmnoprstuvxz])(o|e|emos|eis)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4em', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvba_11").lower() in plvrMfoa and m.group("Mfxvba_12") in plvrVbrxer and not m.group("Mfxvba_12") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvba_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvba_18>[a-zçáéíóúâêô]+)o (?P<Mfxvba_19>[a-z]+[bdhilmnoprstuvxz])(o|es|emos|eis|em)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvba_18").lower() in plvrMfoa and m.group("Mfxvba_19") in plvrVbrxer and not m.group("Mfxvba_19") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvba_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvba_21>[a-zçáéíóúâêô]+)os (?P<Mfxvba_22>[a-z]+[bdhilmnoprstuvxz])(o|es|e|emos|eis)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4em', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvba_21").lower() in plvrMfoa and m.group("Mfxvba_22") in plvrVbrxer and not m.group("Mfxvba_22") + m.group(5) in exvrVbrxer'],
# presente do indicativo cer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbb_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbb_2>[a-z]+)(ço|ces|cemos|ceis|cem)(?![-\\w–\xad])', '\\1 \\2o \\3ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbb_1").lower() in plvrMfoa and m.group("Mfxvbb_2") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbb_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbb_4>[a-z]+)(ço|ces|cemos|ceis|ce)(?![-\\w–\xad])', '\\1s \\2os \\3cem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbb_3").lower() in plvrMfoa and m.group("Mfxvbb_4") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbb_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbb_6>[a-z]+)(ço|ces|cemos|ceis|cem)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbb_5").lower() in plvrMfoa and m.group("Mfxvbb_6") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbb_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbb_8>[a-z]+)(ço|ces|cemos|ceis|ce)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4cem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbb_7").lower() in plvrMfoa and m.group("Mfxvbb_8") in plvrVbrcer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbb_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbb_10>[a-z]+)(ço|ces|cemos|ceis|cem)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbb_9").lower() in plvrMfoa and m.group("Mfxvbb_10") in plvrVbrcer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbb_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbb_12>[a-z]+)(ço|ces|cemos|ceis|ce)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4cem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbb_11").lower() in plvrMfoa and m.group("Mfxvbb_12") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbb_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbb_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbb_19>[a-z]+)(ço|ces|cemos|ceis|cem)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbb_18").lower() in plvrMfoa and m.group("Mfxvbb_19") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbb_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbb_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbb_22>[a-z]+)(ço|ces|cemos|ceis|ce)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4cem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbb_21").lower() in plvrMfoa and m.group("Mfxvbb_22") in plvrVbrcer'],
# presente do indicativo guer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbc_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbc_2>[a-z]+[g])(o|ues|uemos|ueis|uem)(?![-\\w–\xad])', '\\1 \\2o \\3ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbc_1").lower() in plvrMfoa and m.group("Mfxvbc_2") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbc_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbc_4>[a-z]+[g])(o|ues|uemos|ueis|ue)(?![-\\w–\xad])', '\\1s \\2os \\3uem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbc_3").lower() in plvrMfoa and m.group("Mfxvbc_4") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbc_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbc_6>[a-z]+[g])(o|ues|uemos|ueis|uem)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbc_5").lower() in plvrMfoa and m.group("Mfxvbc_6") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbc_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbc_8>[a-z]+[g])(o|ues|uemos|ueis|ue)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4uem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbc_7").lower() in plvrMfoa and m.group("Mfxvbc_8") in plvrVbruer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbc_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbc_10>[a-z]+[g])(o|ues|uemos|ueis|uem)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbc_9").lower() in plvrMfoa and m.group("Mfxvbc_10") in plvrVbruer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbc_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbc_12>[a-z]+[g])(o|ues|uemos|ueis|ue)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4uem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbc_11").lower() in plvrMfoa and m.group("Mfxvbc_12") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbc_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbc_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbc_19>[a-z]+[g])(o|ues|uemos|ueis|uem)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbc_18").lower() in plvrMfoa and m.group("Mfxvbc_19") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbc_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbc_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbc_22>[a-z]+[g])(o|ues|uemos|ueis|ue)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4uem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbc_21").lower() in plvrMfoa and m.group("Mfxvbc_22") in plvrVbruer'],
# presente do indicativo ger
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbd_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbd_2>[a-z]+)(jo|ges|gemos|geis|gem)(?![-\\w–\xad])', '\\1 \\2o \\3ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbd_1").lower() in plvrMfoa and m.group("Mfxvbd_2") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbd_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbd_4>[a-z]+)(jo|ges|gemos|geis|ge)(?![-\\w–\xad])', '\\1s \\2os \\3gem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbd_3").lower() in plvrMfoa and m.group("Mfxvbd_4") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbd_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbd_6>[a-z]+)(jo|ges|gemos|geis|gem)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbd_5").lower() in plvrMfoa and m.group("Mfxvbd_6") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbd_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbd_8>[a-z]+)(jo|ges|gemos|geis|ge)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4gem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbd_7").lower() in plvrMfoa and m.group("Mfxvbd_8") in plvrVbrger'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbd_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbd_10>[a-z]+)(jo|ces|cemos|ceis|cem)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbd_9").lower() in plvrMfoa and m.group("Mfxvbd_10") in plvrVbrger'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbd_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbd_12>[a-z]+)(jo|ges|gemos|geis|ge)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4gem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbd_11").lower() in plvrMfoa and m.group("Mfxvbd_12") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbd_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbd_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbd_19>[a-z]+)(jo|ges|gemos|geis|gem)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbd_18").lower() in plvrMfoa and m.group("Mfxvbd_19") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbd_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbd_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbd_22>[a-z]+)(jo|ges|gemos|geis|ge)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4gem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbd_21").lower() in plvrMfoa and m.group("Mfxvbd_22") in plvrVbrger'],
# preterito perfeito [bdhilmnoprstuvxz]er
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbe_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbe_2>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eram)(?![-\\w–\xad])', '\\1 \\2o \\3e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbe_1").lower() in plvrMfoa and m.group("Mfxvbe_2") in plvrVbrxer and not m.group("Mfxvbe_2") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbe_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbe_4>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eu)(?![-\\w–\xad])', '\\1s \\2os \\3eram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbe_3").lower() in plvrMfoa and m.group("Mfxvbe_4") in plvrVbrxer and not m.group("Mfxvbe_4") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbe_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbe_6>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eram)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbe_5").lower() in plvrMfoa and m.group("Mfxvbe_6") in plvrVbrxer and not m.group("Mfxvbe_6") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbe_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbe_8>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eu)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4eram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbe_7").lower() in plvrMfoa and m.group("Mfxvbe_8") in plvrVbrxer and not m.group("Mfxvbe_8") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbe_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbe_10>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eram)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbe_9").lower() in plvrMfoa and m.group("Mfxvbe_10") in plvrVbrxer and not m.group("Mfxvbe_10") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbe_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbe_12>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eu)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4eram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbe_11").lower() in plvrMfoa and m.group("Mfxvbe_12") in plvrVbrxer and not m.group("Mfxvbe_12") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbe_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbe_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbe_19>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eram)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbe_18").lower() in plvrMfoa and m.group("Mfxvbe_19") in plvrVbrxer and not m.group("Mfxvbe_19") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbe_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbe_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbe_22>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eu)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4eram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbe_21").lower() in plvrMfoa and m.group("Mfxvbe_22") in plvrVbrxer and not m.group("Mfxvbe_22") + m.group(5) in exvrVbrxer'],
# preterito perfeito cer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbf_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbf_2>[a-z]+)(ci|ceste|cemos|cestes|ceram)(?![-\\w–\xad])', '\\1 \\2o \\3ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbf_1").lower() in plvrMfoa and m.group("Mfxvbf_2") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbf_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbf_4>[a-z]+)(ci|ceste|cemos|cestes|ceu)(?![-\\w–\xad])', '\\1s \\2os \\3ceram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbf_3").lower() in plvrMfoa and m.group("Mfxvbf_4") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbf_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbf_6>[a-z]+)(ci|ceste|cemos|cestes|ceram)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbf_5").lower() in plvrMfoa and m.group("Mfxvbf_6") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbf_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbf_8>[a-z]+)(ci|ceste|cemos|cestes|ceu)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4ceram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbf_7").lower() in plvrMfoa and m.group("Mfxvbf_8") in plvrVbrcer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbf_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbf_10>[a-z]+)(ci|ceste|cemos|cestes|ceram)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbf_9").lower() in plvrMfoa and m.group("Mfxvbf_10") in plvrVbrcer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbf_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbf_12>[a-z]+)(ci|ceste|cemos|cestes|ceu)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4ceram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbf_11").lower() in plvrMfoa and m.group("Mfxvbf_12") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbf_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbf_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbf_19>[a-z]+)(ci|ceste|cemos|cestes|ceram)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbf_18").lower() in plvrMfoa and m.group("Mfxvbf_19") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbf_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbf_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbf_22>[a-z]+)(ci|ceste|cemos|cestes|ceu)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4ceram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbf_21").lower() in plvrMfoa and m.group("Mfxvbf_22") in plvrVbrcer'],
# preterito perfeito guer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbg_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbg_2>[a-z]+[g])(ui|ueste|uemos|uestes|ueram)(?![-\\w–\xad])', '\\1 \\2o \\3ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbg_1").lower() in plvrMfoa and m.group("Mfxvbg_2") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbg_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbg_4>[a-z]+[g])(ui|ueste|uemos|uestes|ueu)(?![-\\w–\xad])', '\\1s \\2os \\3ueram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbg_3").lower() in plvrMfoa and m.group("Mfxvbg_4") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbg_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbg_6>[a-z]+[g])(ui|ueste|uemos|uestes|ueram)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbg_5").lower() in plvrMfoa and m.group("Mfxvbg_6") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbg_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbg_8>[a-z]+[g])(ui|ueste|uemos|uestes|ueu)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4ueram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbg_7").lower() in plvrMfoa and m.group("Mfxvbg_8") in plvrVbruer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbg_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbg_10>[a-z]+[g])(ui|ueste|uemos|uestes|ueram)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbg_9").lower() in plvrMfoa and m.group("Mfxvbg_10") in plvrVbruer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbg_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbg_12>[a-z]+[g])(ui|ueste|uemos|uestes|ueu)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4ueram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbg_11").lower() in plvrMfoa and m.group("Mfxvbg_12") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbg_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbg_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbg_19>[a-z]+[g])(ui|ueste|uemos|uestes|ueram)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbg_18").lower() in plvrMfoa and m.group("Mfxvbg_19") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbg_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbg_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbg_22>[a-z]+[g])(ui|ueste|uemos|uestes|ueu)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4ueram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbg_21").lower() in plvrMfoa and m.group("Mfxvbg_22") in plvrVbruer'],
# preterito perfeito ger
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbh_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbh_2>[a-z]+)(gi|geste|gemos|gestes|geram)(?![-\\w–\xad])', '\\1 \\2o \\3ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbh_1").lower() in plvrMfoa and m.group("Mfxvbh_2") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbh_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbh_4>[a-z]+)(gi|geste|gemos|gestes|geu)(?![-\\w–\xad])', '\\1s \\2os \\3geram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbh_3").lower() in plvrMfoa and m.group("Mfxvbh_4") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbh_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbh_6>[a-z]+)(gi|geste|gemos|gestes|geram)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbh_5").lower() in plvrMfoa and m.group("Mfxvbh_6") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbh_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbh_8>[a-z]+)(gi|geste|gemos|gestes|geu)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4geram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbh_7").lower() in plvrMfoa and m.group("Mfxvbh_8") in plvrVbrger'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbh_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbh_10>[a-z]+)(gi|geste|gemos|gestes|geram)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbh_9").lower() in plvrMfoa and m.group("Mfxvbh_10") in plvrVbrger'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbh_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbh_12>[a-z]+)(gi|geste|gemos|gestes|geu)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4geram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbh_11").lower() in plvrMfoa and m.group("Mfxvbh_12") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbh_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbh_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbh_19>[a-z]+)(gi|geste|gemos|gestes|geram)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbh_18").lower() in plvrMfoa and m.group("Mfxvbh_19") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbh_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbh_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbh_22>[a-z]+)(gi|geste|gemos|gestes|geu)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4geram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbh_21").lower() in plvrMfoa and m.group("Mfxvbh_22") in plvrVbrger'],
# preterito imperfeito [bdhilmnoprstuvxz]er
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbi_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbi_2>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', '\\1 \\2o \\3ia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbi_1").lower() in plvrMfoa and m.group("Mfxvbi_2") in plvrVbrxer and not m.group("Mfxvbi_2") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbi_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbi_4>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|ia)(?![-\\w–\xad])', '\\1s \\2os \\3iam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbi_3").lower() in plvrMfoa and m.group("Mfxvbi_4") in plvrVbrxer and not m.group("Mfxvbi_4") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbi_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbi_6>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbi_5").lower() in plvrMfoa and m.group("Mfxvbi_6") in plvrVbrxer and not m.group("Mfxvbi_6") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbi_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbi_8>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|ia)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4iam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbi_7").lower() in plvrMfoa and m.group("Mfxvbi_8") in plvrVbrxer and not m.group("Mfxvbi_8") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbi_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbi_10>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbi_9").lower() in plvrMfoa and m.group("Mfxvbi_10") in plvrVbrxer and not m.group("Mfxvbi_10") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbi_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbi_12>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|ia)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4iam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbi_11").lower() in plvrMfoa and m.group("Mfxvbi_12") in plvrVbrxer and not m.group("Mfxvbi_12") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbi_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbi_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbi_19>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4ia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbi_18").lower() in plvrMfoa and m.group("Mfxvbi_19") in plvrVbrxer and not m.group("Mfxvbi_19") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbi_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbi_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbi_22>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|ia)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4iam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbi_21").lower() in plvrMfoa and m.group("Mfxvbi_22") in plvrVbrxer and not m.group("Mfxvbi_22") + m.group(5) in exvrVbrxer'],
# preterito imperfeito cer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbj_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbj_2>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', '\\1 \\2o \\3cia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbj_1").lower() in plvrMfoa and m.group("Mfxvbj_2") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbj_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbj_4>[a-z]+)(cias|cíamos|cíeis|cia)(?![-\\w–\xad])', '\\1s \\2os \\3ciam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbj_3").lower() in plvrMfoa and m.group("Mfxvbj_4") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbj_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbj_6>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4cia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbj_5").lower() in plvrMfoa and m.group("Mfxvbj_6") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbj_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbj_8>[a-z]+)(cias|cíamos|cíeis|cia)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4ciam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbj_7").lower() in plvrMfoa and m.group("Mfxvbj_8") in plvrVbrcer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbj_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbj_10>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4cia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbj_9").lower() in plvrMfoa and m.group("Mfxvbj_10") in plvrVbrcer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbj_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbj_12>[a-z]+)(cias|cíamos|cíeis|cia)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4ciam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbj_11").lower() in plvrMfoa and m.group("Mfxvbj_12") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbj_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbj_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbj_19>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4cia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbj_18").lower() in plvrMfoa and m.group("Mfxvbj_19") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbj_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbj_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbj_22>[a-z]+)(cias|cíamos|cíeis|cia)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4ciam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbj_21").lower() in plvrMfoa and m.group("Mfxvbj_22") in plvrVbrcer'],
# preterito imperfeito guer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbk_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbk_2>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', '\\1 \\2o \\3uia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbk_1").lower() in plvrMfoa and m.group("Mfxvbk_2") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbk_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbk_4>[a-z]+[g])(uias|uíamos|uíeis|uia)(?![-\\w–\xad])', '\\1s \\2os \\3uiam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbk_3").lower() in plvrMfoa and m.group("Mfxvbk_4") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbk_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbk_6>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4uia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbk_5").lower() in plvrMfoa and m.group("Mfxvbk_6") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbk_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbk_8>[a-z]+[g])(uias|uíamos|uíeis|uia)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4uiam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbk_7").lower() in plvrMfoa and m.group("Mfxvbk_8") in plvrVbruer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbk_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbk_10>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4uia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbk_9").lower() in plvrMfoa and m.group("Mfxvbk_10") in plvrVbruer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbk_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbk_12>[a-z]+[g])(uias|uíamos|uíeis|uia)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4uiam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbk_11").lower() in plvrMfoa and m.group("Mfxvbk_12") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbk_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbk_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbk_19>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4uia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbk_18").lower() in plvrMfoa and m.group("Mfxvbk_19") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbk_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbk_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbk_22>[a-z]+[g])(uias|uíamos|uíeis|uia)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4uiam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbk_21").lower() in plvrMfoa and m.group("Mfxvbk_22") in plvrVbruer'],
# preterito imperfeito ger
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbl_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbl_2>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', '\\1 \\2o \\3gia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbl_1").lower() in plvrMfoa and m.group("Mfxvbl_2") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbl_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbl_4>[a-z]+)(gias|gíamos|gíeis|gia)(?![-\\w–\xad])', '\\1s \\2os \\3giam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbl_3").lower() in plvrMfoa and m.group("Mfxvbl_4") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbl_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbl_6>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4gia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbl_5").lower() in plvrMfoa and m.group("Mfxvbl_6") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbl_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbl_8>[a-z]+)(gias|gíamos|gíeis|gia)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4giam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbl_7").lower() in plvrMfoa and m.group("Mfxvbl_8") in plvrVbrger'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbl_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbl_10>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4gia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbl_9").lower() in plvrMfoa and m.group("Mfxvbl_10") in plvrVbrger'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbl_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbl_12>[a-z]+)(gias|gíamos|gíeis|gia)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4giam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbl_11").lower() in plvrMfoa and m.group("Mfxvbl_12") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbl_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbl_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbl_19>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4gia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbl_18").lower() in plvrMfoa and m.group("Mfxvbl_19") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbl_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbl_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbl_22>[a-z]+)(gias|gíamos|gíeis|gia)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4giam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbl_21").lower() in plvrMfoa and m.group("Mfxvbl_22") in plvrVbrger'],
# futuro do presente [bdhilmnoprstuvxz]er
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbm_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbm_2>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erão)(?![-\\w–\xad])', '\\1 \\2o \\3erá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbm_1").lower() in plvrMfoa and m.group("Mfxvbm_2") in plvrVbrxer and not m.group("Mfxvbm_2") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbm_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbm_4>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erá)(?![-\\w–\xad])', '\\1s \\2os \\3erão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbm_3").lower() in plvrMfoa and m.group("Mfxvbm_4") in plvrVbrxer and not m.group("Mfxvbm_4") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbm_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbm_6>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erão)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4erá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbm_5").lower() in plvrMfoa and m.group("Mfxvbm_6") in plvrVbrxer and not m.group("Mfxvbm_6") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbm_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbm_8>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erá)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4erão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbm_7").lower() in plvrMfoa and m.group("Mfxvbm_8") in plvrVbrxer and not m.group("Mfxvbm_8") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbm_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbm_10>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erão)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4erá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbm_9").lower() in plvrMfoa and m.group("Mfxvbm_10") in plvrVbrxer and not m.group("Mfxvbm_10") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbm_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbm_12>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erá)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4erão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbm_11").lower() in plvrMfoa and m.group("Mfxvbm_12") in plvrVbrxer and not m.group("Mfxvbm_12") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbm_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbm_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbm_19>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erão)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4erá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbm_18").lower() in plvrMfoa and m.group("Mfxvbm_19") in plvrVbrxer and not m.group("Mfxvbm_19") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbm_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbm_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbm_22>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erá)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4erão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbm_21").lower() in plvrMfoa and m.group("Mfxvbm_22") in plvrVbrxer and not m.group("Mfxvbm_22") + m.group(5) in exvrVbrxer'],
# futuro do presente cer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbn_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbn_2>[a-z]+)(cerei|cerás|ceremos|cereis|cerão)(?![-\\w–\xad])', '\\1 \\2o \\3cerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbn_1").lower() in plvrMfoa and m.group("Mfxvbn_2") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbn_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbn_4>[a-z]+)(cerei|cerás|ceremos|cereis|cerá)(?![-\\w–\xad])', '\\1s \\2os \\3cerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbn_3").lower() in plvrMfoa and m.group("Mfxvbn_4") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbn_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbn_6>[a-z]+)(cerei|cerás|ceremos|cereis|cerão)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4cerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbn_5").lower() in plvrMfoa and m.group("Mfxvbn_6") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbn_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbn_8>[a-z]+)(cerei|cerás|ceremos|cereis|cerá)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4cerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbn_7").lower() in plvrMfoa and m.group("Mfxvbn_8") in plvrVbrcer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbn_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbn_10>[a-z]+)(cerei|cerás|ceremos|cereis|cerão)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4cerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbn_9").lower() in plvrMfoa and m.group("Mfxvbn_10") in plvrVbrcer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbn_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbn_12>[a-z]+)(cerei|cerás|ceremos|cereis|cerá)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4cerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbn_11").lower() in plvrMfoa and m.group("Mfxvbn_12") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbn_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbn_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbn_19>[a-z]+)(cerei|cerás|ceremos|cereis|cerão)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4cerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbn_18").lower() in plvrMfoa and m.group("Mfxvbn_19") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbn_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbn_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbn_22>[a-z]+)(cerei|cerás|ceremos|cereis|cerá)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4cerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbn_21").lower() in plvrMfoa and m.group("Mfxvbn_22") in plvrVbrcer'],
# futuro do presente guer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbo_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbo_2>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerão)(?![-\\w–\xad])', '\\1 \\2o \\3uerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbo_1").lower() in plvrMfoa and m.group("Mfxvbo_2") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbo_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbo_4>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerá)(?![-\\w–\xad])', '\\1s \\2os \\3uerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbo_3").lower() in plvrMfoa and m.group("Mfxvbo_4") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbo_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbo_6>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerão)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4uerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbo_5").lower() in plvrMfoa and m.group("Mfxvbo_6") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbo_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbo_8>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerá)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4uerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbo_7").lower() in plvrMfoa and m.group("Mfxvbo_8") in plvrVbruer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbo_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbo_10>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerão)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4uerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbo_9").lower() in plvrMfoa and m.group("Mfxvbo_10") in plvrVbruer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbo_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbo_12>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerá)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4uerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbo_11").lower() in plvrMfoa and m.group("Mfxvbo_12") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbo_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbo_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbo_19>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerão)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4uerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbo_18").lower() in plvrMfoa and m.group("Mfxvbo_19") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbo_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbo_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbo_22>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerá)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4uerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbo_21").lower() in plvrMfoa and m.group("Mfxvbo_22") in plvrVbruer'],
# futuro do presente ger
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbp_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbp_2>[a-z]+)(gerei|gerás|geremos|gereis|gerão)(?![-\\w–\xad])', '\\1 \\2o \\3gerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbp_1").lower() in plvrMfoa and m.group("Mfxvbp_2") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbp_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbp_4>[a-z]+)(gerei|gerás|geremos|gereis|gerá)(?![-\\w–\xad])', '\\1s \\2os \\3gerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbp_3").lower() in plvrMfoa and m.group("Mfxvbp_4") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbp_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbp_6>[a-z]+)(gerei|gerás|geremos|gereis|gerão)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4gerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbp_5").lower() in plvrMfoa and m.group("Mfxvbp_6") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbp_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbp_8>[a-z]+)(gerei|gerás|geremos|gereis|gerá)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4gerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbp_7").lower() in plvrMfoa and m.group("Mfxvbp_8") in plvrVbrger'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbp_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbp_10>[a-z]+)(gerei|gerás|geremos|gereis|gerão)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4gerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbp_9").lower() in plvrMfoa and m.group("Mfxvbp_10") in plvrVbrger'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbp_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbp_12>[a-z]+)(gerei|gerás|geremos|gereis|gerá)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4gerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbp_11").lower() in plvrMfoa and m.group("Mfxvbp_12") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbp_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbp_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbp_19>[a-z]+)(gerei|gerás|geremos|gereis|gerão)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4gerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbp_18").lower() in plvrMfoa and m.group("Mfxvbp_19") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbp_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbp_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbp_22>[a-z]+)(gerei|gerás|geremos|gereis|gerá)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4gerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbp_21").lower() in plvrMfoa and m.group("Mfxvbp_22") in plvrVbrger'],
# futuro do preterito [bdhilmnoprstuvxz]er
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbq_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbq_2>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', '\\1 \\2o \\3eria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbq_1").lower() in plvrMfoa and m.group("Mfxvbq_2") in plvrVbrxer and not m.group("Mfxvbq_2") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbq_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbq_4>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eria)(?![-\\w–\xad])', '\\1s \\2os \\3eriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbq_3").lower() in plvrMfoa and m.group("Mfxvbq_4") in plvrVbrxer and not m.group("Mfxvbq_4") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbq_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbq_6>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4eria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbq_5").lower() in plvrMfoa and m.group("Mfxvbq_6") in plvrVbrxer and not m.group("Mfxvbq_6") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbq_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbq_8>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eria)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4eriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbq_7").lower() in plvrMfoa and m.group("Mfxvbq_8") in plvrVbrxer and not m.group("Mfxvbq_8") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbq_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbq_10>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4eria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbq_9").lower() in plvrMfoa and m.group("Mfxvbq_10") in plvrVbrxer and not m.group("Mfxvbq_10") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbq_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbq_12>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eria)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4eriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbq_11").lower() in plvrMfoa and m.group("Mfxvbq_12") in plvrVbrxer and not m.group("Mfxvbq_12") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbq_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbq_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbq_19>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4eria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbq_18").lower() in plvrMfoa and m.group("Mfxvbq_19") in plvrVbrxer and not m.group("Mfxvbq_19") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbq_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbq_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbq_22>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eria)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4eriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbq_21").lower() in plvrMfoa and m.group("Mfxvbq_22") in plvrVbrxer and not m.group("Mfxvbq_22") + m.group(5) in exvrVbrxer'],
# futuro do preterito cer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbr_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbr_2>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', '\\1 \\2o \\3ceria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbr_1").lower() in plvrMfoa and m.group("Mfxvbr_2") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbr_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbr_4>[a-z]+)(cerias|ceríamos|ceríeis|ceria)(?![-\\w–\xad])', '\\1s \\2os \\3ceriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbr_3").lower() in plvrMfoa and m.group("Mfxvbr_4") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbr_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbr_6>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ceria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbr_5").lower() in plvrMfoa and m.group("Mfxvbr_6") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbr_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbr_8>[a-z]+)(cerias|ceríamos|ceríeis|ceria)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4ceriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbr_7").lower() in plvrMfoa and m.group("Mfxvbr_8") in plvrVbrcer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbr_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbr_10>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ceria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbr_9").lower() in plvrMfoa and m.group("Mfxvbr_10") in plvrVbrcer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbr_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbr_12>[a-z]+)(cerias|ceríamos|ceríeis|ceria)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4ceriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbr_11").lower() in plvrMfoa and m.group("Mfxvbr_12") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbr_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbr_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbr_19>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4ceria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbr_18").lower() in plvrMfoa and m.group("Mfxvbr_19") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbr_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbr_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbr_22>[a-z]+)(cerias|ceríamos|ceríeis|ceria)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4ceriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbr_21").lower() in plvrMfoa and m.group("Mfxvbr_22") in plvrVbrcer'],
# futuro do preterito guer
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbs_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbs_2>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', '\\1 \\2o \\3ueria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbs_1").lower() in plvrMfoa and m.group("Mfxvbs_2") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbs_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbs_4>[a-z]+[g])(uerias|ueríamos|ueríeis|ueria)(?![-\\w–\xad])', '\\1s \\2os \\3ueriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbs_3").lower() in plvrMfoa and m.group("Mfxvbs_4") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbs_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbs_6>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ueria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbs_5").lower() in plvrMfoa and m.group("Mfxvbs_6") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbs_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbs_8>[a-z]+[g])(uerias|ueríamos|ueríeis|ueria)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4ueriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbs_7").lower() in plvrMfoa and m.group("Mfxvbs_8") in plvrVbruer'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbs_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbs_10>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4ueria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbs_9").lower() in plvrMfoa and m.group("Mfxvbs_10") in plvrVbruer'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbs_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbs_12>[a-z]+[g])(uerias|ueríamos|ueríeis|ueria)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4ueriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbs_11").lower() in plvrMfoa and m.group("Mfxvbs_12") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbs_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbs_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbs_19>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4ueria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbs_18").lower() in plvrMfoa and m.group("Mfxvbs_19") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbs_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbs_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbs_22>[a-z]+[g])(uerias|ueríamos|ueríeis|ueria)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4ueriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbs_21").lower() in plvrMfoa and m.group("Mfxvbs_22") in plvrVbruer'],
# futuro do preterito ger
 ['(?u)(?<![-\\w–.,\xad])(Algum|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu) (?P<Mfxvbt_1>[a-zçáéíóúâêô]+)o (?P<Mfxvbt_2>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', '\\1 \\2o \\3geria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbt_1").lower() in plvrMfoa and m.group("Mfxvbt_2") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(Algun|Esse|Este|Meu|Nosso|O|Outro|Seu|Teu|Vário)s (?P<Mfxvbt_3>[a-zçáéíóúâêô]+)os (?P<Mfxvbt_4>[a-z]+)(gerias|geríamos|geríeis|geria)(?![-\\w–\xad])', '\\1s \\2os \\3geriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbt_3").lower() in plvrMfoa and m.group("Mfxvbt_4") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbt_5>[a-zçáéíóúâêô]+)o (?P<Mfxvbt_6>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4geria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbt_5").lower() in plvrMfoa and m.group("Mfxvbt_6") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbt_7>[a-zçáéíóúâêô]+)os (?P<Mfxvbt_8>[a-z]+)(gerias|geríamos|geríeis|geria)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4geriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbt_7").lower() in plvrMfoa and m.group("Mfxvbt_8") in plvrVbrger'],
 ['(?u)([,;]) (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbt_9>[a-zçáéíóúâêô]+)o (?P<Mfxvbt_10>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', '\\1 \\2 \\3o \\4geria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbt_9").lower() in plvrMfoa and m.group("Mfxvbt_10") in plvrVbrger'],
 ['(?u)([,;]) (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbt_11>[a-zçáéíóúâêô]+)os (?P<Mfxvbt_12>[a-z]+)(gerias|geríamos|geríeis|geria)(?![-\\w–\xad])', '\\1 \\2s \\3os \\4geriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbt_11").lower() in plvrMfoa and m.group("Mfxvbt_12") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbt_17>[a-zA-Zç]+)mente (algum|esse|este|meu|nosso|o|outro|seu|teu) (?P<Mfxvbt_18>[a-zçáéíóúâêô]+)o (?P<Mfxvbt_19>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', '\\1mente \\2 \\3o \\4geria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbt_18").lower() in plvrMfoa and m.group("Mfxvbt_19") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mfxvbt_20>[a-zA-Zç]+)mente (algun|esse|este|meu|nosso|o|outro|seu|teu|vário)s (?P<Mfxvbt_21>[a-zçáéíóúâêô]+)os (?P<Mfxvbt_22>[a-z]+)(gerias|geríamos|geríeis|geria)(?![-\\w–\xad])', '\\1mente \\2s \\3os \\4geriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mfxvbt_21").lower() in plvrMfoa and m.group("Mfxvbt_22") in plvrVbrger'],
# Mfoa - feminino
# presente do indicativo [bdhilmnoprstuvxz]er
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvba_1>[a-zçáéíóúâêô]+)a (?P<Mafvba_2>[a-z]+[bdhilmnoprstuvxz])(o|es|emos|eis|em)(?![-\\w–\xad])', '\\1 \\2a \\3e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvba_1").lower() in plvrMfoa and m.group("Mafvba_2") in plvrVbrxer and not m.group("Mafvba_2") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvba_3>[a-zçáéíóúâêô]+)as (?P<Mafvba_4>[a-z]+[bdhilmnoprstuvxz])(o|es|e|emos|eis)(?![-\\w–\xad])', '\\1s \\2as \\3em', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvba_3").lower() in plvrMfoa and m.group("Mafvba_4") in plvrVbrxer and not m.group("Mafvba_4") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvba_5>[a-zçáéíóúâêô]+)a (?P<Mafvba_6>[a-z]+[bdhilmnoprstuvxz])(o|es|emos|eis|em)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvba_5").lower() in plvrMfoa and m.group("Mafvba_6") in plvrVbrxer and not m.group("Mafvba_6") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvba_7>[a-zçáéíóúâêô]+)as (?P<Mafvba_8>[a-z]+[bdhilmnoprstuvxz])(o|es|e|emos|eis)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4em', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvba_7").lower() in plvrMfoa and m.group("Mafvba_8") in plvrVbrxer and not m.group("Mafvba_8") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvba_9>[a-zçáéíóúâêô]+)a (?P<Mafvba_10>[a-z]+[bdhilmnoprstuvxz])(o|es|emos|eis|em)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvba_9").lower() in plvrMfoa and m.group("Mafvba_10") in plvrVbrxer and not m.group("Mafvba_10") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvba_11>[a-zçáéíóúâêô]+)as (?P<Mafvba_12>[a-z]+[bdhilmnoprstuvxz])(o|es|e|emos|eis)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4em', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvba_11").lower() in plvrMfoa and m.group("Mafvba_12") in plvrVbrxer and not m.group("Mafvba_12") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvba_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvba_18>[a-zçáéíóúâêô]+)a (?P<Mafvba_19>[a-z]+[bdhilmnoprstuvxz])(o|es|emos|eis|em)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvba_18").lower() in plvrMfoa and m.group("Mafvba_19") in plvrVbrxer and not m.group("Mafvba_19") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvba_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvba_21>[a-zçáéíóúâêô]+)as (?P<Mafvba_22>[a-z]+[bdhilmnoprstuvxz])(o|es|e|emos|eis)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4em', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvba_21").lower() in plvrMfoa and m.group("Mafvba_22") in plvrVbrxer and not m.group("Mafvba_22") + m.group(5) in exvrVbrxer'],
# presente do indicativo cer
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbb_1>[a-zçáéíóúâêô]+)a (?P<Mafvbb_2>[a-z]+)(ço|ces|cemos|ceis|cem)(?![-\\w–\xad])', '\\1 \\2a \\3ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbb_1").lower() in plvrMfoa and m.group("Mafvbb_2") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbb_3>[a-zçáéíóúâêô]+)as (?P<Mafvbb_4>[a-z]+)(ço|ces|cemos|ceis|ce)(?![-\\w–\xad])', '\\1s \\2as \\3cem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbb_3").lower() in plvrMfoa and m.group("Mafvbb_4") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbb_5>[a-zçáéíóúâêô]+)a (?P<Mafvbb_6>[a-z]+)(ço|ces|cemos|ceis|cem)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbb_5").lower() in plvrMfoa and m.group("Mafvbb_6") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbb_7>[a-zçáéíóúâêô]+)as (?P<Mafvbb_8>[a-z]+)(ço|ces|cemos|ceis|ce)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4cem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbb_7").lower() in plvrMfoa and m.group("Mafvbb_8") in plvrVbrcer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbb_9>[a-zçáéíóúâêô]+)a (?P<Mafvbb_10>[a-z]+)(ço|ces|cemos|ceis|cem)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbb_9").lower() in plvrMfoa and m.group("Mafvbb_10") in plvrVbrcer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbb_11>[a-zçáéíóúâêô]+)as (?P<Mafvbb_12>[a-z]+)(ço|ces|cemos|ceis|ce)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4cem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbb_11").lower() in plvrMfoa and m.group("Mafvbb_12") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbb_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbb_18>[a-zçáéíóúâêô]+)a (?P<Mafvbb_19>[a-z]+)(ço|ces|cemos|ceis|cem)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbb_18").lower() in plvrMfoa and m.group("Mafvbb_19") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbb_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbb_21>[a-zçáéíóúâêô]+)as (?P<Mafvbb_22>[a-z]+)(ço|ces|cemos|ceis|ce)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4cem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbb_21").lower() in plvrMfoa and m.group("Mafvbb_22") in plvrVbrcer'],
# presente do indicativo guer
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbc_1>[a-zçáéíóúâêô]+)a (?P<Mafvbc_2>[a-z]+[g])(o|ues|uemos|ueis|uem)(?![-\\w–\xad])', '\\1 \\2a \\3ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbc_1").lower() in plvrMfoa and m.group("Mafvbc_2") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbc_3>[a-zçáéíóúâêô]+)as (?P<Mafvbc_4>[a-z]+[g])(o|ues|uemos|ueis|ue)(?![-\\w–\xad])', '\\1s \\2as \\3uem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbc_3").lower() in plvrMfoa and m.group("Mafvbc_4") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbc_5>[a-zçáéíóúâêô]+)a (?P<Mafvbc_6>[a-z]+[g])(o|ues|uemos|ueis|uem)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbc_5").lower() in plvrMfoa and m.group("Mafvbc_6") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbc_7>[a-zçáéíóúâêô]+)as (?P<Mafvbc_8>[a-z]+[g])(o|ues|uemos|ueis|ue)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4uem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbc_7").lower() in plvrMfoa and m.group("Mafvbc_8") in plvrVbruer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbc_9>[a-zçáéíóúâêô]+)a (?P<Mafvbc_10>[a-z]+[g])(o|ues|uemos|ueis|uem)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbc_9").lower() in plvrMfoa and m.group("Mafvbc_10") in plvrVbruer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbc_11>[a-zçáéíóúâêô]+)as (?P<Mafvbc_12>[a-z]+[g])(o|ues|uemos|ueis|ue)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4uem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbc_11").lower() in plvrMfoa and m.group("Mafvbc_12") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbc_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbc_18>[a-zçáéíóúâêô]+)a (?P<Mafvbc_19>[a-z]+[g])(o|ues|uemos|ueis|uem)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbc_18").lower() in plvrMfoa and m.group("Mafvbc_19") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbc_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbc_21>[a-zçáéíóúâêô]+)as (?P<Mafvbc_22>[a-z]+[g])(o|ues|uemos|ueis|ue)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4uem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbc_21").lower() in plvrMfoa and m.group("Mafvbc_22") in plvrVbruer'],
# presente do indicativo ger
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbd_1>[a-zçáéíóúâêô]+)a (?P<Mafvbd_2>[a-z]+)(jo|ges|gemos|geis|gem)(?![-\\w–\xad])', '\\1 \\2a \\3ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbd_1").lower() in plvrMfoa and m.group("Mafvbd_2") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbd_3>[a-zçáéíóúâêô]+)as (?P<Mafvbd_4>[a-z]+)(jo|ges|gemos|geis|ge)(?![-\\w–\xad])', '\\1s \\2as \\3gem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbd_3").lower() in plvrMfoa and m.group("Mafvbd_4") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbd_5>[a-zçáéíóúâêô]+)a (?P<Mafvbd_6>[a-z]+)(jo|ges|gemos|geis|gem)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbd_5").lower() in plvrMfoa and m.group("Mafvbd_6") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbd_7>[a-zçáéíóúâêô]+)as (?P<Mafvbd_8>[a-z]+)(jo|ges|gemos|geis|ge)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4gem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbd_7").lower() in plvrMfoa and m.group("Mafvbd_8") in plvrVbrger'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbd_9>[a-zçáéíóúâêô]+)a (?P<Mafvbd_10>[a-z]+)(jo|ces|cemos|ceis|cem)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbd_9").lower() in plvrMfoa and m.group("Mafvbd_10") in plvrVbrger'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbd_11>[a-zçáéíóúâêô]+)as (?P<Mafvbd_12>[a-z]+)(jo|ges|gemos|geis|ge)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4gem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbd_11").lower() in plvrMfoa and m.group("Mafvbd_12") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbd_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbd_18>[a-zçáéíóúâêô]+)a (?P<Mafvbd_19>[a-z]+)(jo|ges|gemos|geis|gem)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbd_18").lower() in plvrMfoa and m.group("Mafvbd_19") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbd_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbd_21>[a-zçáéíóúâêô]+)as (?P<Mafvbd_22>[a-z]+)(jo|ges|gemos|geis|ge)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4gem', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbd_21").lower() in plvrMfoa and m.group("Mafvbd_22") in plvrVbrger'],
# preterito perfeito [bdhilmnoprstuvxz]er
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbe_1>[a-zçáéíóúâêô]+)a (?P<Mafvbe_2>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eram)(?![-\\w–\xad])', '\\1 \\2a \\3e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbe_1").lower() in plvrMfoa and m.group("Mafvbe_2") in plvrVbrxer and not m.group("Mafvbe_2") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbe_3>[a-zçáéíóúâêô]+)as (?P<Mafvbe_4>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eu)(?![-\\w–\xad])', '\\1s \\2as \\3eram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbe_3").lower() in plvrMfoa and m.group("Mafvbe_4") in plvrVbrxer and not m.group("Mafvbe_4") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbe_5>[a-zçáéíóúâêô]+)a (?P<Mafvbe_6>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eram)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbe_5").lower() in plvrMfoa and m.group("Mafvbe_6") in plvrVbrxer and not m.group("Mafvbe_6") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbe_7>[a-zçáéíóúâêô]+)as (?P<Mafvbe_8>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eu)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4eram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbe_7").lower() in plvrMfoa and m.group("Mafvbe_8") in plvrVbrxer and not m.group("Mafvbe_8") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbe_9>[a-zçáéíóúâêô]+)a (?P<Mafvbe_10>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eram)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbe_9").lower() in plvrMfoa and m.group("Mafvbe_10") in plvrVbrxer and not m.group("Mafvbe_10") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbe_11>[a-zçáéíóúâêô]+)as (?P<Mafvbe_12>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eu)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4eram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbe_11").lower() in plvrMfoa and m.group("Mafvbe_12") in plvrVbrxer and not m.group("Mafvbe_12") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbe_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbe_18>[a-zçáéíóúâêô]+)a (?P<Mafvbe_19>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eram)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbe_18").lower() in plvrMfoa and m.group("Mafvbe_19") in plvrVbrxer and not m.group("Mafvbe_19") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbe_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbe_21>[a-zçáéíóúâêô]+)as (?P<Mafvbe_22>[a-z]+[bdhilmnoprstuvxz])(i|este|emos|estes|eu)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4eram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbe_21").lower() in plvrMfoa and m.group("Mafvbe_22") in plvrVbrxer and not m.group("Mafvbe_22") + m.group(5) in exvrVbrxer'],
# preterito perfeito cer
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbf_1>[a-zçáéíóúâêô]+)a (?P<Mafvbf_2>[a-z]+)(ci|ceste|cemos|cestes|ceram)(?![-\\w–\xad])', '\\1 \\2a \\3ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbf_1").lower() in plvrMfoa and m.group("Mafvbf_2") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbf_3>[a-zçáéíóúâêô]+)as (?P<Mafvbf_4>[a-z]+)(ci|ceste|cemos|cestes|ceu)(?![-\\w–\xad])', '\\1s \\2as \\3ceram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbf_3").lower() in plvrMfoa and m.group("Mafvbf_4") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbf_5>[a-zçáéíóúâêô]+)a (?P<Mafvbf_6>[a-z]+)(ci|ceste|cemos|cestes|ceram)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbf_5").lower() in plvrMfoa and m.group("Mafvbf_6") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbf_7>[a-zçáéíóúâêô]+)as (?P<Mafvbf_8>[a-z]+)(ci|ceste|cemos|cestes|ceu)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4ceram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbf_7").lower() in plvrMfoa and m.group("Mafvbf_8") in plvrVbrcer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbf_9>[a-zçáéíóúâêô]+)a (?P<Mafvbf_10>[a-z]+)(ci|ceste|cemos|cestes|ceram)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbf_9").lower() in plvrMfoa and m.group("Mafvbf_10") in plvrVbrcer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbf_11>[a-zçáéíóúâêô]+)as (?P<Mafvbf_12>[a-z]+)(ci|ceste|cemos|cestes|ceu)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4ceram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbf_11").lower() in plvrMfoa and m.group("Mafvbf_12") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbf_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbf_18>[a-zçáéíóúâêô]+)a (?P<Mafvbf_19>[a-z]+)(ci|ceste|cemos|cestes|ceram)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbf_18").lower() in plvrMfoa and m.group("Mafvbf_19") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbf_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbf_21>[a-zçáéíóúâêô]+)as (?P<Mafvbf_22>[a-z]+)(ci|ceste|cemos|cestes|ceu)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4ceram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbf_21").lower() in plvrMfoa and m.group("Mafvbf_22") in plvrVbrcer'],
# preterito perfeito guer
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbg_1>[a-zçáéíóúâêô]+)a (?P<Mafvbg_2>[a-z]+[g])(ui|ueste|uemos|uestes|ueram)(?![-\\w–\xad])', '\\1 \\2a \\3ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbg_1").lower() in plvrMfoa and m.group("Mafvbg_2") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbg_3>[a-zçáéíóúâêô]+)as (?P<Mafvbg_4>[a-z]+[g])(ui|ueste|uemos|uestes|ueu)(?![-\\w–\xad])', '\\1s \\2as \\3ueram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbg_3").lower() in plvrMfoa and m.group("Mafvbg_4") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbg_5>[a-zçáéíóúâêô]+)a (?P<Mafvbg_6>[a-z]+[g])(ui|ueste|uemos|uestes|ueram)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbg_5").lower() in plvrMfoa and m.group("Mafvbg_6") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbg_7>[a-zçáéíóúâêô]+)as (?P<Mafvbg_8>[a-z]+[g])(ui|ueste|uemos|uestes|ueu)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4ueram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbg_7").lower() in plvrMfoa and m.group("Mafvbg_8") in plvrVbruer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbg_9>[a-zçáéíóúâêô]+)a (?P<Mafvbg_10>[a-z]+[g])(ui|ueste|uemos|uestes|ueram)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbg_9").lower() in plvrMfoa and m.group("Mafvbg_10") in plvrVbruer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbg_11>[a-zçáéíóúâêô]+)as (?P<Mafvbg_12>[a-z]+[g])(ui|ueste|uemos|uestes|ueu)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4ueram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbg_11").lower() in plvrMfoa and m.group("Mafvbg_12") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbg_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbg_18>[a-zçáéíóúâêô]+)a (?P<Mafvbg_19>[a-z]+[g])(ui|ueste|uemos|uestes|ueram)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4ue', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbg_18").lower() in plvrMfoa and m.group("Mafvbg_19") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbg_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbg_21>[a-zçáéíóúâêô]+)as (?P<Mafvbg_22>[a-z]+[g])(ui|ueste|uemos|uestes|ueu)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4ueram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbg_21").lower() in plvrMfoa and m.group("Mafvbg_22") in plvrVbruer'],
# preterito perfeito ger
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbh_1>[a-zçáéíóúâêô]+)a (?P<Mafvbh_2>[a-z]+)(gi|geste|gemos|gestes|geram)(?![-\\w–\xad])', '\\1 \\2a \\3ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbh_1").lower() in plvrMfoa and m.group("Mafvbh_2") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbh_3>[a-zçáéíóúâêô]+)as (?P<Mafvbh_4>[a-z]+)(gi|geste|gemos|gestes|geu)(?![-\\w–\xad])', '\\1s \\2as \\3geram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbh_3").lower() in plvrMfoa and m.group("Mafvbh_4") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbh_5>[a-zçáéíóúâêô]+)a (?P<Mafvbh_6>[a-z]+)(gi|geste|gemos|gestes|geram)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbh_5").lower() in plvrMfoa and m.group("Mafvbh_6") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbh_7>[a-zçáéíóúâêô]+)as (?P<Mafvbh_8>[a-z]+)(gi|geste|gemos|gestes|geu)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4geram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbh_7").lower() in plvrMfoa and m.group("Mafvbh_8") in plvrVbrger'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbh_9>[a-zçáéíóúâêô]+)a (?P<Mafvbh_10>[a-z]+)(gi|geste|gemos|gestes|geram)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbh_9").lower() in plvrMfoa and m.group("Mafvbh_10") in plvrVbrger'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbh_11>[a-zçáéíóúâêô]+)as (?P<Mafvbh_12>[a-z]+)(gi|geste|gemos|gestes|geu)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4geram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbh_11").lower() in plvrMfoa and m.group("Mafvbh_12") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbh_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbh_18>[a-zçáéíóúâêô]+)a (?P<Mafvbh_19>[a-z]+)(gi|geste|gemos|gestes|geram)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4ge', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbh_18").lower() in plvrMfoa and m.group("Mafvbh_19") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbh_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbh_21>[a-zçáéíóúâêô]+)as (?P<Mafvbh_22>[a-z]+)(gi|geste|gemos|gestes|geu)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4geram', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbh_21").lower() in plvrMfoa and m.group("Mafvbh_22") in plvrVbrger'],
# preterito imperfeito [bdhilmnoprstuvxz]er
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbi_1>[a-zçáéíóúâêô]+)a (?P<Mafvbi_2>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', '\\1 \\2a \\3ia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbi_1").lower() in plvrMfoa and m.group("Mafvbi_2") in plvrVbrxer and not m.group("Mafvbi_2") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbi_3>[a-zçáéíóúâêô]+)as (?P<Mafvbi_4>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|ia)(?![-\\w–\xad])', '\\1s \\2as \\3iam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbi_3").lower() in plvrMfoa and m.group("Mafvbi_4") in plvrVbrxer and not m.group("Mafvbi_4") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbi_5>[a-zçáéíóúâêô]+)a (?P<Mafvbi_6>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbi_5").lower() in plvrMfoa and m.group("Mafvbi_6") in plvrVbrxer and not m.group("Mafvbi_6") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbi_7>[a-zçáéíóúâêô]+)as (?P<Mafvbi_8>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|ia)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4iam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbi_7").lower() in plvrMfoa and m.group("Mafvbi_8") in plvrVbrxer and not m.group("Mafvbi_8") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbi_9>[a-zçáéíóúâêô]+)a (?P<Mafvbi_10>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbi_9").lower() in plvrMfoa and m.group("Mafvbi_10") in plvrVbrxer and not m.group("Mafvbi_10") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbi_11>[a-zçáéíóúâêô]+)as (?P<Mafvbi_12>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|ia)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4iam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbi_11").lower() in plvrMfoa and m.group("Mafvbi_12") in plvrVbrxer and not m.group("Mafvbi_12") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbi_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbi_18>[a-zçáéíóúâêô]+)a (?P<Mafvbi_19>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|iam)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4ia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbi_18").lower() in plvrMfoa and m.group("Mafvbi_19") in plvrVbrxer and not m.group("Mafvbi_19") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbi_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbi_21>[a-zçáéíóúâêô]+)as (?P<Mafvbi_22>[a-z]+[bdhilmnoprstuvxz])(ias|íamos|íeis|ia)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4iam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbi_21").lower() in plvrMfoa and m.group("Mafvbi_22") in plvrVbrxer and not m.group("Mafvbi_22") + m.group(5) in exvrVbrxer'],
# preterito imperfeito cer
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbj_1>[a-zçáéíóúâêô]+)a (?P<Mafvbj_2>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', '\\1 \\2a \\3cia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbj_1").lower() in plvrMfoa and m.group("Mafvbj_2") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbj_3>[a-zçáéíóúâêô]+)as (?P<Mafvbj_4>[a-z]+)(cias|cíamos|cíeis|cia)(?![-\\w–\xad])', '\\1s \\2as \\3ciam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbj_3").lower() in plvrMfoa and m.group("Mafvbj_4") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbj_5>[a-zçáéíóúâêô]+)a (?P<Mafvbj_6>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4cia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbj_5").lower() in plvrMfoa and m.group("Mafvbj_6") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbj_7>[a-zçáéíóúâêô]+)as (?P<Mafvbj_8>[a-z]+)(cias|cíamos|cíeis|cia)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4ciam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbj_7").lower() in plvrMfoa and m.group("Mafvbj_8") in plvrVbrcer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbj_9>[a-zçáéíóúâêô]+)a (?P<Mafvbj_10>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4cia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbj_9").lower() in plvrMfoa and m.group("Mafvbj_10") in plvrVbrcer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbj_11>[a-zçáéíóúâêô]+)as (?P<Mafvbj_12>[a-z]+)(cias|cíamos|cíeis|cia)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4ciam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbj_11").lower() in plvrMfoa and m.group("Mafvbj_12") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbj_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbj_18>[a-zçáéíóúâêô]+)a (?P<Mafvbj_19>[a-z]+)(cias|cíamos|cíeis|ciam)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4cia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbj_18").lower() in plvrMfoa and m.group("Mafvbj_19") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbj_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbj_21>[a-zçáéíóúâêô]+)as (?P<Mafvbj_22>[a-z]+)(cias|cíamos|cíeis|cia)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4ciam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbj_21").lower() in plvrMfoa and m.group("Mafvbj_22") in plvrVbrcer'],
# preterito imperfeito guer
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbk_1>[a-zçáéíóúâêô]+)a (?P<Mafvbk_2>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', '\\1 \\2a \\3uia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbk_1").lower() in plvrMfoa and m.group("Mafvbk_2") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbk_3>[a-zçáéíóúâêô]+)as (?P<Mafvbk_4>[a-z]+[g])(uias|uíamos|uíeis|uia)(?![-\\w–\xad])', '\\1s \\2as \\3uiam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbk_3").lower() in plvrMfoa and m.group("Mafvbk_4") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbk_5>[a-zçáéíóúâêô]+)a (?P<Mafvbk_6>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4uia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbk_5").lower() in plvrMfoa and m.group("Mafvbk_6") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbk_7>[a-zçáéíóúâêô]+)as (?P<Mafvbk_8>[a-z]+[g])(uias|uíamos|uíeis|uia)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4uiam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbk_7").lower() in plvrMfoa and m.group("Mafvbk_8") in plvrVbruer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbk_9>[a-zçáéíóúâêô]+)a (?P<Mafvbk_10>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4uia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbk_9").lower() in plvrMfoa and m.group("Mafvbk_10") in plvrVbruer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbk_11>[a-zçáéíóúâêô]+)as (?P<Mafvbk_12>[a-z]+[g])(uias|uíamos|uíeis|uia)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4uiam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbk_11").lower() in plvrMfoa and m.group("Mafvbk_12") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbk_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbk_18>[a-zçáéíóúâêô]+)a (?P<Mafvbk_19>[a-z]+[g])(uias|uíamos|uíeis|uiam)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4uia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbk_18").lower() in plvrMfoa and m.group("Mafvbk_19") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbk_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbk_21>[a-zçáéíóúâêô]+)as (?P<Mafvbk_22>[a-z]+[g])(uias|uíamos|uíeis|uia)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4uiam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbk_21").lower() in plvrMfoa and m.group("Mafvbk_22") in plvrVbruer'],
# preterito imperfeito ger
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbl_1>[a-zçáéíóúâêô]+)a (?P<Mafvbl_2>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', '\\1 \\2a \\3gia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbl_1").lower() in plvrMfoa and m.group("Mafvbl_2") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbl_3>[a-zçáéíóúâêô]+)as (?P<Mafvbl_4>[a-z]+)(gias|gíamos|gíeis|gia)(?![-\\w–\xad])', '\\1s \\2as \\3giam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbl_3").lower() in plvrMfoa and m.group("Mafvbl_4") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbl_5>[a-zçáéíóúâêô]+)a (?P<Mafvbl_6>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4gia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbl_5").lower() in plvrMfoa and m.group("Mafvbl_6") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbl_7>[a-zçáéíóúâêô]+)as (?P<Mafvbl_8>[a-z]+)(gias|gíamos|gíeis|gia)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4giam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbl_7").lower() in plvrMfoa and m.group("Mafvbl_8") in plvrVbrger'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbl_9>[a-zçáéíóúâêô]+)a (?P<Mafvbl_10>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4gia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbl_9").lower() in plvrMfoa and m.group("Mafvbl_10") in plvrVbrger'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbl_11>[a-zçáéíóúâêô]+)as (?P<Mafvbl_12>[a-z]+)(gias|gíamos|gíeis|gia)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4giam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbl_11").lower() in plvrMfoa and m.group("Mafvbl_12") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbl_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbl_18>[a-zçáéíóúâêô]+)a (?P<Mafvbl_19>[a-z]+)(gias|gíamos|gíeis|giam)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4gia', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbl_18").lower() in plvrMfoa and m.group("Mafvbl_19") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbl_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbl_21>[a-zçáéíóúâêô]+)as (?P<Mafvbl_22>[a-z]+)(gias|gíamos|gíeis|gia)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4giam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbl_21").lower() in plvrMfoa and m.group("Mafvbl_22") in plvrVbrger'],
# futuro do presente [bdhilmnoprstuvxz]er
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbm_1>[a-zçáéíóúâêô]+)a (?P<Mafvbm_2>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erão)(?![-\\w–\xad])', '\\1 \\2a \\3erá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbm_1").lower() in plvrMfoa and m.group("Mafvbm_2") in plvrVbrxer and not m.group("Mafvbm_2") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbm_3>[a-zçáéíóúâêô]+)as (?P<Mafvbm_4>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erá)(?![-\\w–\xad])', '\\1s \\2as \\3erão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbm_3").lower() in plvrMfoa and m.group("Mafvbm_4") in plvrVbrxer and not m.group("Mafvbm_4") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbm_5>[a-zçáéíóúâêô]+)a (?P<Mafvbm_6>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erão)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4erá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbm_5").lower() in plvrMfoa and m.group("Mafvbm_6") in plvrVbrxer and not m.group("Mafvbm_6") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbm_7>[a-zçáéíóúâêô]+)as (?P<Mafvbm_8>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erá)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4erão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbm_7").lower() in plvrMfoa and m.group("Mafvbm_8") in plvrVbrxer and not m.group("Mafvbm_8") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbm_9>[a-zçáéíóúâêô]+)a (?P<Mafvbm_10>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erão)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4erá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbm_9").lower() in plvrMfoa and m.group("Mafvbm_10") in plvrVbrxer and not m.group("Mafvbm_10") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbm_11>[a-zçáéíóúâêô]+)as (?P<Mafvbm_12>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erá)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4erão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbm_11").lower() in plvrMfoa and m.group("Mafvbm_12") in plvrVbrxer and not m.group("Mafvbm_12") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbm_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbm_18>[a-zçáéíóúâêô]+)a (?P<Mafvbm_19>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erão)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4erá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbm_18").lower() in plvrMfoa and m.group("Mafvbm_19") in plvrVbrxer and not m.group("Mafvbm_19") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbm_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbm_21>[a-zçáéíóúâêô]+)as (?P<Mafvbm_22>[a-z]+[bdhilmnoprstuvxz])(erei|erás|eremos|ereis|erá)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4erão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbm_21").lower() in plvrMfoa and m.group("Mafvbm_22") in plvrVbrxer and not m.group("Mafvbm_22") + m.group(5) in exvrVbrxer'],
# futuro do presente cer
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbn_1>[a-zçáéíóúâêô]+)a (?P<Mafvbn_2>[a-z]+)(cerei|cerás|ceremos|cereis|cerão)(?![-\\w–\xad])', '\\1 \\2a \\3cerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbn_1").lower() in plvrMfoa and m.group("Mafvbn_2") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbn_3>[a-zçáéíóúâêô]+)as (?P<Mafvbn_4>[a-z]+)(cerei|cerás|ceremos|cereis|cerá)(?![-\\w–\xad])', '\\1s \\2as \\3cerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbn_3").lower() in plvrMfoa and m.group("Mafvbn_4") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbn_5>[a-zçáéíóúâêô]+)a (?P<Mafvbn_6>[a-z]+)(cerei|cerás|ceremos|cereis|cerão)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4cerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbn_5").lower() in plvrMfoa and m.group("Mafvbn_6") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbn_7>[a-zçáéíóúâêô]+)as (?P<Mafvbn_8>[a-z]+)(cerei|cerás|ceremos|cereis|cerá)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4cerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbn_7").lower() in plvrMfoa and m.group("Mafvbn_8") in plvrVbrcer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbn_9>[a-zçáéíóúâêô]+)a (?P<Mafvbn_10>[a-z]+)(cerei|cerás|ceremos|cereis|cerão)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4cerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbn_9").lower() in plvrMfoa and m.group("Mafvbn_10") in plvrVbrcer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbn_11>[a-zçáéíóúâêô]+)as (?P<Mafvbn_12>[a-z]+)(cerei|cerás|ceremos|cereis|cerá)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4cerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbn_11").lower() in plvrMfoa and m.group("Mafvbn_12") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbn_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbn_18>[a-zçáéíóúâêô]+)a (?P<Mafvbn_19>[a-z]+)(cerei|cerás|ceremos|cereis|cerão)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4cerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbn_18").lower() in plvrMfoa and m.group("Mafvbn_19") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbn_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbn_21>[a-zçáéíóúâêô]+)as (?P<Mafvbn_22>[a-z]+)(cerei|cerás|ceremos|cereis|cerá)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4cerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbn_21").lower() in plvrMfoa and m.group("Mafvbn_22") in plvrVbrcer'],
# futuro do presente guer
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbo_1>[a-zçáéíóúâêô]+)a (?P<Mafvbo_2>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerão)(?![-\\w–\xad])', '\\1 \\2a \\3uerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbo_1").lower() in plvrMfoa and m.group("Mafvbo_2") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbo_3>[a-zçáéíóúâêô]+)as (?P<Mafvbo_4>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerá)(?![-\\w–\xad])', '\\1s \\2as \\3uerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbo_3").lower() in plvrMfoa and m.group("Mafvbo_4") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbo_5>[a-zçáéíóúâêô]+)a (?P<Mafvbo_6>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerão)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4uerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbo_5").lower() in plvrMfoa and m.group("Mafvbo_6") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbo_7>[a-zçáéíóúâêô]+)as (?P<Mafvbo_8>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerá)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4uerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbo_7").lower() in plvrMfoa and m.group("Mafvbo_8") in plvrVbruer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbo_9>[a-zçáéíóúâêô]+)a (?P<Mafvbo_10>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerão)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4uerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbo_9").lower() in plvrMfoa and m.group("Mafvbo_10") in plvrVbruer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbo_11>[a-zçáéíóúâêô]+)as (?P<Mafvbo_12>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerá)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4uerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbo_11").lower() in plvrMfoa and m.group("Mafvbo_12") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbo_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbo_18>[a-zçáéíóúâêô]+)a (?P<Mafvbo_19>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerão)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4uerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbo_18").lower() in plvrMfoa and m.group("Mafvbo_19") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbo_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbo_21>[a-zçáéíóúâêô]+)as (?P<Mafvbo_22>[a-z]+[g])(uerei|uerás|ueremos|uereis|uerá)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4uerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbo_21").lower() in plvrMfoa and m.group("Mafvbo_22") in plvrVbruer'],
# futuro do presente ger
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbp_1>[a-zçáéíóúâêô]+)a (?P<Mafvbp_2>[a-z]+)(gerei|gerás|geremos|gereis|gerão)(?![-\\w–\xad])', '\\1 \\2a \\3gerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbp_1").lower() in plvrMfoa and m.group("Mafvbp_2") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbp_3>[a-zçáéíóúâêô]+)as (?P<Mafvbp_4>[a-z]+)(gerei|gerás|geremos|gereis|gerá)(?![-\\w–\xad])', '\\1s \\2as \\3gerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbp_3").lower() in plvrMfoa and m.group("Mafvbp_4") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbp_5>[a-zçáéíóúâêô]+)a (?P<Mafvbp_6>[a-z]+)(gerei|gerás|geremos|gereis|gerão)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4gerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbp_5").lower() in plvrMfoa and m.group("Mafvbp_6") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbp_7>[a-zçáéíóúâêô]+)as (?P<Mafvbp_8>[a-z]+)(gerei|gerás|geremos|gereis|gerá)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4gerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbp_7").lower() in plvrMfoa and m.group("Mafvbp_8") in plvrVbrger'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbp_9>[a-zçáéíóúâêô]+)a (?P<Mafvbp_10>[a-z]+)(gerei|gerás|geremos|gereis|gerão)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4gerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbp_9").lower() in plvrMfoa and m.group("Mafvbp_10") in plvrVbrger'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbp_11>[a-zçáéíóúâêô]+)as (?P<Mafvbp_12>[a-z]+)(gerei|gerás|geremos|gereis|gerá)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4gerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbp_11").lower() in plvrMfoa and m.group("Mafvbp_12") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbp_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbp_18>[a-zçáéíóúâêô]+)a (?P<Mafvbp_19>[a-z]+)(gerei|gerás|geremos|gereis|gerão)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4gerá', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbp_18").lower() in plvrMfoa and m.group("Mafvbp_19") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbp_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbp_21>[a-zçáéíóúâêô]+)as (?P<Mafvbp_22>[a-z]+)(gerei|gerás|geremos|gereis|gerá)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4gerão', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbp_21").lower() in plvrMfoa and m.group("Mafvbp_22") in plvrVbrger'],
# futuro do preterito [bdhilmnoprstuvxz]er
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbq_1>[a-zçáéíóúâêô]+)a (?P<Mafvbq_2>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', '\\1 \\2a \\3eria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbq_1").lower() in plvrMfoa and m.group("Mafvbq_2") in plvrVbrxer and not m.group("Mafvbq_2") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbq_3>[a-zçáéíóúâêô]+)as (?P<Mafvbq_4>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eria)(?![-\\w–\xad])', '\\1s \\2as \\3eriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbq_3").lower() in plvrMfoa and m.group("Mafvbq_4") in plvrVbrxer and not m.group("Mafvbq_4") + m.group(4) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbq_5>[a-zçáéíóúâêô]+)a (?P<Mafvbq_6>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4eria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbq_5").lower() in plvrMfoa and m.group("Mafvbq_6") in plvrVbrxer and not m.group("Mafvbq_6") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbq_7>[a-zçáéíóúâêô]+)as (?P<Mafvbq_8>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eria)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4eriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbq_7").lower() in plvrMfoa and m.group("Mafvbq_8") in plvrVbrxer and not m.group("Mafvbq_8") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbq_9>[a-zçáéíóúâêô]+)a (?P<Mafvbq_10>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4eria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbq_9").lower() in plvrMfoa and m.group("Mafvbq_10") in plvrVbrxer and not m.group("Mafvbq_10") + m.group(5) in exvrVbrxer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbq_11>[a-zçáéíóúâêô]+)as (?P<Mafvbq_12>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eria)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4eriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbq_11").lower() in plvrMfoa and m.group("Mafvbq_12") in plvrVbrxer and not m.group("Mafvbq_12") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbq_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbq_18>[a-zçáéíóúâêô]+)a (?P<Mafvbq_19>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eriam)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4eria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbq_18").lower() in plvrMfoa and m.group("Mafvbq_19") in plvrVbrxer and not m.group("Mafvbq_19") + m.group(5) in exvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbq_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbq_21>[a-zçáéíóúâêô]+)as (?P<Mafvbq_22>[a-z]+[bdhilmnoprstuvxz])(erias|eríamos|eríeis|eria)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4eriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbq_21").lower() in plvrMfoa and m.group("Mafvbq_22") in plvrVbrxer and not m.group("Mafvbq_22") + m.group(5) in exvrVbrxer'],
# futuro do preterito cer
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbr_1>[a-zçáéíóúâêô]+)a (?P<Mafvbr_2>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', '\\1 \\2a \\3ceria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbr_1").lower() in plvrMfoa and m.group("Mafvbr_2") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbr_3>[a-zçáéíóúâêô]+)as (?P<Mafvbr_4>[a-z]+)(cerias|ceríamos|ceríeis|ceria)(?![-\\w–\xad])', '\\1s \\2as \\3ceriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbr_3").lower() in plvrMfoa and m.group("Mafvbr_4") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbr_5>[a-zçáéíóúâêô]+)a (?P<Mafvbr_6>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ceria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbr_5").lower() in plvrMfoa and m.group("Mafvbr_6") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbr_7>[a-zçáéíóúâêô]+)as (?P<Mafvbr_8>[a-z]+)(cerias|ceríamos|ceríeis|ceria)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4ceriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbr_7").lower() in plvrMfoa and m.group("Mafvbr_8") in plvrVbrcer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbr_9>[a-zçáéíóúâêô]+)a (?P<Mafvbr_10>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ceria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbr_9").lower() in plvrMfoa and m.group("Mafvbr_10") in plvrVbrcer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbr_11>[a-zçáéíóúâêô]+)as (?P<Mafvbr_12>[a-z]+)(cerias|ceríamos|ceríeis|ceria)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4ceriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbr_11").lower() in plvrMfoa and m.group("Mafvbr_12") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbr_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbr_18>[a-zçáéíóúâêô]+)a (?P<Mafvbr_19>[a-z]+)(cerias|ceríamos|ceríeis|ceriam)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4ceria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbr_18").lower() in plvrMfoa and m.group("Mafvbr_19") in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbr_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbr_21>[a-zçáéíóúâêô]+)as (?P<Mafvbr_22>[a-z]+)(cerias|ceríamos|ceríeis|ceria)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4ceriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbr_21").lower() in plvrMfoa and m.group("Mafvbr_22") in plvrVbrcer'],
# futuro do preterito guer
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbs_1>[a-zçáéíóúâêô]+)a (?P<Mafvbs_2>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', '\\1 \\2a \\3ueria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbs_1").lower() in plvrMfoa and m.group("Mafvbs_2") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbs_3>[a-zçáéíóúâêô]+)as (?P<Mafvbs_4>[a-z]+[g])(uerias|ueríamos|ueríeis|ueria)(?![-\\w–\xad])', '\\1s \\2as \\3ueriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbs_3").lower() in plvrMfoa and m.group("Mafvbs_4") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbs_5>[a-zçáéíóúâêô]+)a (?P<Mafvbs_6>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ueria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbs_5").lower() in plvrMfoa and m.group("Mafvbs_6") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbs_7>[a-zçáéíóúâêô]+)as (?P<Mafvbs_8>[a-z]+[g])(uerias|ueríamos|ueríeis|ueria)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4ueriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbs_7").lower() in plvrMfoa and m.group("Mafvbs_8") in plvrVbruer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbs_9>[a-zçáéíóúâêô]+)a (?P<Mafvbs_10>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4ueria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbs_9").lower() in plvrMfoa and m.group("Mafvbs_10") in plvrVbruer'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbs_11>[a-zçáéíóúâêô]+)as (?P<Mafvbs_12>[a-z]+[g])(uerias|ueríamos|ueríeis|ueria)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4ueriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbs_11").lower() in plvrMfoa and m.group("Mafvbs_12") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbs_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbs_18>[a-zçáéíóúâêô]+)a (?P<Mafvbs_19>[a-z]+[g])(uerias|ueríamos|ueríeis|ueriam)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4ueria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbs_18").lower() in plvrMfoa and m.group("Mafvbs_19") in plvrVbruer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbs_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbs_21>[a-zçáéíóúâêô]+)as (?P<Mafvbs_22>[a-z]+[g])(uerias|ueríamos|ueríeis|ueria)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4ueriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbs_21").lower() in plvrMfoa and m.group("Mafvbs_22") in plvrVbruer'],
# futuro do preterito ger
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua) (?P<Mafvbt_1>[a-zçáéíóúâêô]+)a (?P<Mafvbt_2>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', '\\1 \\2a \\3geria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbt_1").lower() in plvrMfoa and m.group("Mafvbt_2") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(Alguma|Essa|Esta|Minha|Nossa|A|Outra|Sua|Tua|Vária)s (?P<Mafvbt_3>[a-zçáéíóúâêô]+)as (?P<Mafvbt_4>[a-z]+)(gerias|geríamos|geríeis|geria)(?![-\\w–\xad])', '\\1s \\2as \\3geriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbt_3").lower() in plvrMfoa and m.group("Mafvbt_4") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbt_5>[a-zçáéíóúâêô]+)a (?P<Mafvbt_6>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4geria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbt_5").lower() in plvrMfoa and m.group("Mafvbt_6") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]té|[Ee]mbora|[Ee]nquanto|[Jj]amais|[Mm]as|[Oo]nde|[Pp]ara|[Pp]ois|[Pp]orque|[Qq]uando|[Qq]ue|[Ss]e|[Tt]alvez) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbt_7>[a-zçáéíóúâêô]+)as (?P<Mafvbt_8>[a-z]+)(gerias|geríamos|geríeis|geria)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4geriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbt_7").lower() in plvrMfoa and m.group("Mafvbt_8") in plvrVbrger'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbt_9>[a-zçáéíóúâêô]+)a (?P<Mafvbt_10>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', '\\1 \\2 \\3a \\4geria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbt_9").lower() in plvrMfoa and m.group("Mafvbt_10") in plvrVbrger'],
 ['(?u)([,;]) (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbt_11>[a-zçáéíóúâêô]+)as (?P<Mafvbt_12>[a-z]+)(gerias|geríamos|geríeis|geria)(?![-\\w–\xad])', '\\1 \\2s \\3as \\4geriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbt_11").lower() in plvrMfoa and m.group("Mafvbt_12") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbt_17>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua) (?P<Mafvbt_18>[a-zçáéíóúâêô]+)a (?P<Mafvbt_19>[a-z]+)(gerias|geríamos|geríeis|geriam)(?![-\\w–\xad])', '\\1mente \\2 \\3a \\4geria', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbt_18").lower() in plvrMfoa and m.group("Mafvbt_19") in plvrVbrger'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mafvbt_20>[a-zA-Zç]+)mente (alguma|essa|esta|minha|nossa|a|outra|sua|tua|vária)s (?P<Mafvbt_21>[a-zçáéíóúâêô]+)as (?P<Mafvbt_22>[a-z]+)(gerias|geríamos|geríeis|geria)(?![-\\w–\xad])', '\\1mente \\2s \\3as \\4geriam', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mafvbt_21").lower() in plvrMfoa and m.group("Mafvbt_22") in plvrVbrger'],
# FIM CONCORDANCIA VERBAL
# a fora - afora
 ['(?u)(?<![-\\w–.,\xad])([Aa]) fora(?![-\\w–\xad])', '\\1fora', 'Você quis dizer:', False],
# Fim a fora - afora
# divida - divda (acento)
 ['(?u)(?<![-\\w–.,\xad])([Dd]a|[Nn]a|[Pp]ela|[Mm]inha|[Dd]e|[Ss]ua|[Nn]ossa|[Ee]m|à|[Ee]ssa|[Nn]essa|[Ee]sta|[Pp]or|[Ee]norme|[Tt]inha|[Vv]elha) divida(?![-\\w–\xad])', '\\1 dívida', 'Faltou o acento em dívida? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])divida(?![-\\w–\xad])', 'dívida', 'Faltou o acento em dívida? Você quis dizer:', 'not excdivida.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])dividas(?![-\\w–\xad])', 'dívidas', 'Faltou o acento em dívida? Você quis dizer:', False],
# Fim divida - divda (acento)
# espirar - expirar
 ['(?u)(?<![-\\w–.,\xad])([Ee])spir([aeoá])([a-zãçõ]+)(?![-\\w–\xad])', '\\1xpir\\2\\3', 'X em vez de S? Você quis dizer:', 'not "spiral" in TEXT and not "spirais" in TEXT and not "spiras" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])spir([aeoá])([a-zãçõ]+)-se(?![-\\w–\xad])', '\\1xpir\\2\\3-se', 'X em vez de S? Você quis dizer:', False],
# FIM espirar - expirar
# Termino - termno
 ['(?u)(?<![-\\w–.,\xad])([Tt])ermino d(a|as|o|os|e)(?![-\\w–\xad])', '\\1érmino d\\2', 'Faltou o acento? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ara termino(?![-\\w–\xad])', '\\1ara término', 'Faltou o acento? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])([eo]) termino(?![-\\w–\xad])', '\\1\\2 término', 'Faltou o acento? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([NnAa])o termino(?![-\\w–\xad])', '\\1o término', 'Faltou o acento? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([SS])eu termino(?![-\\w–\xad])', '\\1eu término', 'Faltou o acento? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ii])nício e termino(?![-\\w–\xad])', '\\1nício e término', 'Faltou o acento? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo]) termino(?![-\\w–\xad])', '\\1 término', 'Faltou o acento? Você quis dizer:', False],
# FIM Termino - termno
# mestre - mestra
 ['(?u)(?<![-\\w–.,\xad])([Aa])belha ([Mm])estre(?![-\\w–\xad])', '\\1belha \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])mostra ([Mm])estre(?![-\\w–\xad])', '\\1mostra \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])rte ([Mm])estre(?![-\\w–\xad])', '\\1rte \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])ateria ([Mm])estre(?![-\\w–\xad])', '\\1ateria \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])oa ([Mm])estre(?![-\\w–\xad])', '\\1oa \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])have ([Mm])estre(?![-\\w–\xad])', '\\1have \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])oluna ([Mm])estre(?![-\\w–\xad])', '\\1oluna \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ivina ([Mm])estre(?![-\\w–\xad])', '\\1ivina \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Gg])aleria ([Mm])estre(?![-\\w–\xad])', '\\1aleria \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ii])deia ([Mm])estre(?![-\\w–\xad])', '\\1deia \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ll])ição ([Mm])estre(?![-\\w–\xad])', '\\1ição \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ll])inha ([Mm])estre(?![-\\w–\xad])', '\\1inha \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])adre ([Mm])estre(?![-\\w–\xad])', '\\1adre \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])ola ([Mm])estre(?![-\\w–\xad])', '\\1ola \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])bra ([Mm])estre(?![-\\w–\xad])', '\\1bra \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])arede ([Mm])estre(?![-\\w–\xad])', '\\1arede \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])rópria ([Mm])estre(?![-\\w–\xad])', '\\1rópria \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Rr])ainha ([Mm])estre(?![-\\w–\xad])', '\\1ainha \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])enha ([Mm])estre(?![-\\w–\xad])', '\\1enha \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])uprema ([Mm])estre(?![-\\w–\xad])', '\\1uprema \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])nha ([Mm])estre(?![-\\w–\xad])', '\\1nha \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])elha ([Mm])estre(?![-\\w–\xad])', '\\1elha \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])iga ([Mm])estre(?![-\\w–\xad])', '\\1iga \\2estra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])belhas ([Mm])estres(?![-\\w–\xad])', '\\1belhas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])mostras ([Mm])estres(?![-\\w–\xad])', '\\1mostras \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])rtes ([Mm])estres(?![-\\w–\xad])', '\\1rtes \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])aterias ([Mm])estres(?![-\\w–\xad])', '\\1aterias \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])oas ([Mm])estres(?![-\\w–\xad])', '\\1oas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])haves ([Mm])estres(?![-\\w–\xad])', '\\1haves \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])olunas ([Mm])estres(?![-\\w–\xad])', '\\1olunas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ivinas ([Mm])estres(?![-\\w–\xad])', '\\1ivinas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Gg])alerias ([Mm])estres(?![-\\w–\xad])', '\\1alerias \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ii])deias ([Mm])estres(?![-\\w–\xad])', '\\1deias \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ll])ições ([Mm])estres(?![-\\w–\xad])', '\\1ições \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ll])inhas ([Mm])estres(?![-\\w–\xad])', '\\1inhas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])adres ([Mm])estres(?![-\\w–\xad])', '\\1adres \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])olas ([Mm])estres(?![-\\w–\xad])', '\\1olas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])bras ([Mm])estres(?![-\\w–\xad])', '\\1bras \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])aredes ([Mm])estres(?![-\\w–\xad])', '\\1aredes \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])róprias ([Mm])estres(?![-\\w–\xad])', '\\1róprias \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Rr])ainhas ([Mm])estres(?![-\\w–\xad])', '\\1ainhas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])enhas ([Mm])estres(?![-\\w–\xad])', '\\1enhas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])upremas ([Mm])estres(?![-\\w–\xad])', '\\1upremas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])nhas ([Mm])estres(?![-\\w–\xad])', '\\1nhas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])elhas ([Mm])estres(?![-\\w–\xad])', '\\1elhas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])igas ([Mm])estres(?![-\\w–\xad])', '\\1igas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])belhas ([Mm])estre(?![-\\w–\xad])', '\\1belhas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])mostras ([Mm])estre(?![-\\w–\xad])', '\\1mostras \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])rtes ([Mm])estre(?![-\\w–\xad])', '\\1rtes \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])aterias ([Mm])estre(?![-\\w–\xad])', '\\1aterias \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])oas ([Mm])estre(?![-\\w–\xad])', '\\1oas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])haves ([Mm])estre(?![-\\w–\xad])', '\\1haves \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])olunas ([Mm])estre(?![-\\w–\xad])', '\\1olunas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ivinas ([Mm])estre(?![-\\w–\xad])', '\\1ivinas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Gg])alerias ([Mm])estre(?![-\\w–\xad])', '\\1alerias \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ii])deias ([Mm])estre(?![-\\w–\xad])', '\\1deias \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ll])ições ([Mm])estre(?![-\\w–\xad])', '\\1ições \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ll])inhas ([Mm])estre(?![-\\w–\xad])', '\\1inhas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])adres ([Mm])estre(?![-\\w–\xad])', '\\1adres \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])olas ([Mm])estre(?![-\\w–\xad])', '\\1olas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])bras ([Mm])estre(?![-\\w–\xad])', '\\1bras \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])aredes ([Mm])estre(?![-\\w–\xad])', '\\1aredes \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])róprias ([Mm])estre(?![-\\w–\xad])', '\\1róprias \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Rr])ainhas ([Mm])estre(?![-\\w–\xad])', '\\1ainhas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])enhas ([Mm])estre(?![-\\w–\xad])', '\\1enhas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])upremas ([Mm])estre(?![-\\w–\xad])', '\\1upremas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])nhas ([Mm])estre(?![-\\w–\xad])', '\\1nhas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])elhas ([Mm])estre(?![-\\w–\xad])', '\\1elhas \\2estras', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])igas ([Mm])estre(?![-\\w–\xad])', '\\1igas \\2estras', 'Você quis dizer:', False],
# FIM mestre - mestra
# paronimo critica
 ['(?u)(?<![-\\w–.,\xad])([Aa])s criticas(?![-\\w–\xad])', '\\1s críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([DdNn])a critica(?![-\\w–\xad])', '\\1a crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([DdNn])as criticas(?![-\\w–\xad])', '\\1as críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])m critica(?![-\\w–\xad])', '\\1m crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])m criticas(?![-\\w–\xad])', '\\1m críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])e critica(?![-\\w–\xad])', '\\1e crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])e criticas(?![-\\w–\xad])', '\\1e críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ela critica(?![-\\w–\xad])', '\\1ela crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elas criticas(?![-\\w–\xad])', '\\1ela críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ara critica(?![-\\w–\xad])', '\\1ara crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ara a critica(?![-\\w–\xad])', '\\1ara a crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ara criticas(?![-\\w–\xad])', '\\1ara críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])or critica(?![-\\w–\xad])', '\\1or crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])or criticas(?![-\\w–\xad])', '\\1or críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])assa critica(?![-\\w–\xad])', '\\1assa crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uito critica(?![-\\w–\xad])', '\\1uito crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uito criticas(?![-\\w–\xad])', '\\1uito críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])ão criticas(?![-\\w–\xad])', '\\1ão críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])stão criticas(?![-\\w–\xad])', '\\1stão críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Éé]) critica(?![-\\w–\xad])', '\\1 crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])stá critica(?![-\\w–\xad])', '\\1stá crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])oi critica(?![-\\w–\xad])', '\\1oi crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]|[Aa]quela|da|na|[Nn]essa|[Nn]esta|[Pp]ela|[Uu]ma) fase critica(?![-\\w–\xad])', '\\1 fase crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]|[Aa]quela|da|na|[Nn]essa|[Nn]esta|[Pp]ela|[Uu]ma)s fases criticas(?![-\\w–\xad])', '\\1s fases críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) principal critica(?![-\\w–\xad])', '\\1 principal crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s principais criticas(?![-\\w–\xad])', '\\1s principais críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]|[Aa]quela|da|na|[Nn]essa|[Nn]esta|[Pp]ela|[Pp]or|[Uu]ma) situação critica(?![-\\w–\xad])', '\\1 situação crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]|[Aa]quela|da|na|[Nn]essa|[Nn]esta|[Pp]ela|[Uu]ma)s situações criticas(?![-\\w–\xad])', '\\1s situações críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])or situações criticas(?![-\\w–\xad])', '\\1or situações críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])astante critica(?![-\\w–\xad])', '\\1astante crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])astante criticas(?![-\\w–\xad])', '\\1astante críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])ais critica(?![-\\w–\xad])', '\\1ais crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])ais criticas(?![-\\w–\xad])', '\\1ais críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]|da|de|[Uu]ma) consciência critica(?![-\\w–\xad])', '\\1 consciência crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])isão critica(?![-\\w–\xad])', '\\1isão crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ritica ([Ll])iterária(?![-\\w–\xad])', '\\1rítica \\2iterária', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riticas ([Ll])iterárias(?![-\\w–\xad])', '\\1ríticas \\2iterárias', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ritica ferrenha(?![-\\w–\xad])', '\\1rítica ferrenha', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riticas ferrenhas(?![-\\w–\xad])', '\\1ríticas ferrenhas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ritica feroz(?![-\\w–\xad])', '\\1rítica feroz', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riticas ferozes(?![-\\w–\xad])', '\\1ríticas ferozes', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ritica feita(?![-\\w–\xad])', '\\1rítica feita', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riticas feitas(?![-\\w–\xad])', '\\1ríticas feitas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Gg])rave critica(?![-\\w–\xad])', '\\1rave crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Gg])raves criticas(?![-\\w–\xad])', '\\1raves críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Rr])etorno a critica(?![-\\w–\xad])', '\\1etorno a crítica\\n\\1etorno à crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])emória critica(?![-\\w–\xad])', '\\1emória crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])rimeira critica(?![-\\w–\xad])', '\\1rimeira crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])rimeiras criticas(?![-\\w–\xad])', '\\1rimeiras críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ll])eitura critica(?![-\\w–\xad])', '\\1eitura crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ll])eituras criticas(?![-\\w–\xad])', '\\1eituras críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])eoria critica(?![-\\w–\xad])', '\\1eoria crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ura critica(?![-\\w–\xad])', '\\1ura crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uras criticas(?![-\\w–\xad])', '\\1uras críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Zz])ona critica(?![-\\w–\xad])', '\\1ona crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Zz])onas criticas(?![-\\w–\xad])', '\\1onas críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma critica(?![-\\w–\xad])', '\\1lguma crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas criticas(?![-\\w–\xad])', '\\1lgumas críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])om critica(?![-\\w–\xad])', '\\1om crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])om criticas(?![-\\w–\xad])', '\\1om críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(debat|ger|rebat|receb|respond|sofr)e criticas(?![-\\w–\xad])', '\\1e críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Minh|minh|Noss|noss|Su|su|Tu|tu)a critica(?![-\\w–\xad])', '\\1a crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Minh|minh|Noss|noss|Su|su|Tu|tu)as criticas(?![-\\w–\xad])', '\\1as críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])gera criticas(?![-\\w–\xad])', 'gera críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])f([aei])z criticas(?![-\\w–\xad])', 'f\\1z críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])à criticas(?![-\\w–\xad])', 'às críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])às criticas(?![-\\w–\xad])', 'às críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riticas (eram|são|serão)(?![-\\w–\xad])', '\\1ríticas \\2', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])egundo a critica(?![-\\w–\xad])', '\\1egundo a crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Jj])unto a critica(?![-\\w–\xad])', '\\1unto a crítica', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ritica (?P<Crta_1>[a-záâãçéêíóôõú]+)(?![-\\w–\xad])', '\\1rítica \\2', 'Faltou o acento. Você quis dizer:', 'm.group("Crta_1") in "ao-da-do-aos-das-dos" and not m.group("Crta_1") in "a-o-os-as"'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riticas (?P<Crta_2>[a-záâãçéêíóôõú]+)(?![-\\w–\xad])', '\\1ríticas \\2', 'Faltou o acento. Você quis dizer:', 'm.group("Crta_2") in "ao-da-do-aos-das-dos" and not m.group("Crta_2") in "a-o-os-as"'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riticas (?P<Crta_3>[a-záâãçéêíóôõú]+)adas(?![-\\w–\xad])', '\\1ríticas \\2adas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riticas (?P<Crta_4>[a-záâãçéêíóôõú]+)idas(?![-\\w–\xad])', '\\1ríticas \\2idas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])riticas (?P<Crta_5>[a-záâãçéêíóôõú]+)ivas(?![-\\w–\xad])', '\\1ríticas \\2ivas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([CC])riticas que(?![-\\w–\xad])', '\\1ríticas que', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Crta_6>[a-zA-Zç]+)eu criticas(?![-\\w–\xad])', '\\1eu críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Crta_7>[a-zA-Zç]+)ou criticas(?![-\\w–\xad])', '\\1ou críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Crta_8>[a-zA-Zç]+)([aeiou])ram criticas(?![-\\w–\xad])', '\\1\\2ram críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Crta_9>[a-zA-Zç]+)([ae])m criticas(?![-\\w–\xad])', '\\1\\2m críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Crta_10>[a-zA-Zç]+)([aei])r criticas(?![-\\w–\xad])', '\\1\\2r críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Crta_11>[a-zA-Zç]+)([aei])mos criticas(?![-\\w–\xad])', '\\1\\2mos críticas', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])rítica alguns(?![-\\w–\xad])', '\\1ritica alguns', 'Sem o acento? Você quis dizer:', False],
# Fim paronimo critica
# paronimo critico
 ['(?u)(?<![-\\w–.,\xad])([DdNn])o critico(?![-\\w–\xad])', '\\1o crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])e critico(?![-\\w–\xad])', '\\1e crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elo critico(?![-\\w–\xad])', '\\1elo crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ara critico(?![-\\w–\xad])', '\\1ara crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ara o critico(?![-\\w–\xad])', '\\1ara a crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])or critico(?![-\\w–\xad])', '\\1or crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uito critico(?![-\\w–\xad])', '\\1uito crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Éé]) critico(?![-\\w–\xad])', '\\1 crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])stá critico(?![-\\w–\xad])', '\\1stá crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo]) principal critico(?![-\\w–\xad])', '\\1 principal crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])astante critico(?![-\\w–\xad])', '\\1astante crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])ais critico(?![-\\w–\xad])', '\\1ais crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])quele critico(?![-\\w–\xad])', '\\1quele crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])ator critico(?![-\\w–\xad])', '\\1ator crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])onto critico(?![-\\w–\xad])', '\\1onto crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])omento critico(?![-\\w–\xad])', '\\1omento crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])enso critico(?![-\\w–\xad])', '\\1enso crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([CC])ritico ([Ll])iterário(?![-\\w–\xad])', '\\1rítico \\2iterário', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([CC])ritico ferrenho(?![-\\w–\xad])', '\\1rítico ferrenho', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])egundo o critico(?![-\\w–\xad])', '\\1egundo o crítico', 'Faltou o acento. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Crit_1>[a-záâãçéêíóôõú]+) critico(?![-\\w–\xad])', '\\1 crítico', 'Faltou o acento. Você quis dizer:', 'm.group("Crit_1") in pcritico'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ritico (?P<Crit_2>[a-záâãçéêíóôõú]+)(?![-\\w–\xad])', '\\1rítico \\2', 'Faltou o acento. Você quis dizer:', 'm.group("Crit_2") in "ao-da-do-aos-das-dos" and not m.group("Crit_2") in "a-o-os-as"'],
# Fim paronimo critico
# Senso e Censo
 ['(?u)(?<![-\\w–.,\xad])([Ss])enso ([Dd])emográfico(?![-\\w–\xad])', 'censo demográfico\\nCenso demográfico\\nCenso Demográfico', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])enso ([Ee])scolar(?![-\\w–\xad])', 'censo escolar\\nCenso escolar\\nCenso Escolar', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])enso ([Ee])stadual(?![-\\w–\xad])', 'censo estadual\\nCenso estadual\\nCenso Estadual', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])([Ee][Nn][Ss][Oo]) ([0-9]+)(?![-\\w–\xad])', 'C\\2 \\3', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo]) Senso(?![-\\w–\xad])', '\\1 Censo', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])último ([Ss])enso(?![-\\w–\xad])', 'último Censo', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])enso(?![-\\w–\xad])', 'Censo', 'Você quis dizer:', '"IBGE" in TEXT'],
# Fim Senso e Censo
# Regras para substantivos masculinos tambem encontrados em conjugacoes verbais. Ex. roubo, acerto, conserto.
 ['(?u)(?<![-\\w–.,\xad])([Aa])os (?P<Psv_1>[a-zç]+[o])(?![-\\w–\xad])', '\\1o \\2\\n\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_1") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])as (?P<Psv_2>[a-zç]+[o])(?![-\\w–\xad])', '\\1o \\2\\n\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_2") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])os (?P<Psv_3>[a-zç]+[o])(?![-\\w–\xad])', '\\1o \\2\\n\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_3") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])esmas (?P<Psv_4>[a-zç]+[o])(?![-\\w–\xad])', '\\1esmo \\2\\n\\1esmos \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_4") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])esmos (?P<Psv_5>[a-zç]+[o])(?![-\\w–\xad])', '\\1esmo \\2\\n\\1esmos \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_5") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])as (?P<Psv_6>[a-zç]+[o])(?![-\\w–\xad])', '\\1o \\2\\n\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_6") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])os (?P<Psv_7>[a-zç]+[o])(?![-\\w–\xad])', '\\1o \\2\\n\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_7") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elas (?P<Psv_8>[a-zç]+[o])(?![-\\w–\xad])', '\\1elo \\2\\n\\1elos \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_8") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elos (?P<Psv_9>[a-zç]+[o])(?![-\\w–\xad])', '\\1elo \\2\\n\\1elos \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_9") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])a (?P<Psv_10>[a-zç]+[o])(?![-\\w–\xad])', '\\1á \\2\\n\\1o \\2', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_10") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])a (?P<Psv_11>[a-zç]+[o])s(?![-\\w–\xad])', '\\1á \\2s\\n\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_11") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])a (?P<Psv_12>[a-zç]+[o])(?![-\\w–\xad])', '\\1o \\2', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_12") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ela (?P<Psv_13>[a-zç]+[o])(?![-\\w–\xad])', '\\1elo \\2', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_13") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])as (?P<Psv_14>[a-zç]+[o])s(?![-\\w–\xad])', '\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_14") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])esmas (?P<Psv_15>[a-zç]+[o])s(?![-\\w–\xad])', '\\1esmos \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_15") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])as (?P<Psv_16>[a-zç]+[o])s(?![-\\w–\xad])', '\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_16") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elas (?P<Psv_17>[a-zç]+[o])s(?![-\\w–\xad])', '\\1elos \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_17") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])o (?P<Psv_18>[a-zç]+[o])s(?![-\\w–\xad])', '\\1o \\2\\n\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_18") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])o (?P<Psv_19>[a-zç]+[o])s(?![-\\w–\xad])', '\\1o \\2\\n\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_19") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])o (?P<Psv_20>[a-zç]+[o])s(?![-\\w–\xad])', '\\1o \\2\\n\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_20") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elo (?P<Psv_21>[a-zç]+[o])s(?![-\\w–\xad])', '\\1elo \\2\\n\\1elos \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_21") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Oo]) (?P<Psv_22>[a-zç]+[o])s(?![-\\w–\xad])', '\\1 \\2\\n\\1s \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_22") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])As (?P<Psv_23>[a-zç]+[o])s(?![-\\w–\xad])', 'Os \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_23") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])as (?P<Psv_24>[a-zç]+[o])s(?![-\\w–\xad])', 'os \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_24") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])a (?P<Psv_25>[a-zç]+[o])s(?![-\\w–\xad])', '\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_25") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ela (?P<Psv_26>[a-zç]+[o])s(?![-\\w–\xad])', '\\1elos \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_26") in plMascovb'],
 ['(?u)(?<![-\\w–.,\xad])([Oo])s (?P<Psv_27>[a-zç]+[o])(?![-\\w–\xad])', '\\1 \\2\\n\\1s \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_27") in plMascovb'],
# fim Regras
# Regras para substantivos femininos tambem encontrados em conjugacoes verbais. Ex. ajuda, cria, algema.
 ['(?u)(?<![-\\w–.,\xad])([Mm])esma (?P<Pvs_1>[a-zç]+[a])s(?![-\\w–\xad])', '\\1esma \\2\\n\\1esmas \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_1") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])as (?P<Pvs_2>[a-zç]+[a])(?![-\\w–\xad])', '\\1a \\2\\n\\1as \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_2") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])os (?P<Pvs_3>[a-zç]+[a])(?![-\\w–\xad])', '\\1a \\2\\n\\1as \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_3") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])esmas (?P<Pvs_4>[a-zç]+[a])(?![-\\w–\xad])', '\\1esma \\2\\n\\1esmas \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_4") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])esmos (?P<Pvs_5>[a-zç]+[a])(?![-\\w–\xad])', '\\1esma \\2\\n\\1esmas \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_5") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])as (?P<Pvs_6>[a-zç]+[a])(?![-\\w–\xad])', '\\1a \\2\\n\\1as \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_6") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])o (?P<Pvs_7>[a-zç]+[a])(?![-\\w–\xad])', '\\1a \\2', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_7") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elas (?P<Pvs_8>[a-zç]+[a])(?![-\\w–\xad])', '\\1ela \\2\\n\\1elas \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_8") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elos (?P<Pvs_9>[a-zç]+[a])(?![-\\w–\xad])', '\\1ela \\2\\n\\1elas \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_9") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])o (?P<Pvs_10>[a-zç]+[a])(?![-\\w–\xad])', '\\1a \\2', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_10") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])a (?P<Pvs_11>[a-zç]+[a])s(?![-\\w–\xad])', '\\1á \\2s\\n\\1a \\2\\n\\1as \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_11") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])o (?P<Pvs_12>[a-zç]+[a])s(?![-\\w–\xad])', '\\1as \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_12") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elo (?P<Pvs_13>[a-zç]+[a])(?![-\\w–\xad])', '\\1ela \\2', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_13") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])os (?P<Pvs_14>[a-zç]+[a])s(?![-\\w–\xad])', '\\1as \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_14") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])esmos (?P<Pvs_15>[a-zç]+[a])s(?![-\\w–\xad])', '\\1esmas \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_15") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])o (?P<Pvs_16>[a-zç]+[a])s(?![-\\w–\xad])', '\\1as \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_16") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elos (?P<Pvs_17>[a-zç]+[a])s(?![-\\w–\xad])', '\\1elas \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_17") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])aos (?P<Psv_18>[a-zç]+[a])s(?![-\\w–\xad])', 'às \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_18") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])Aos (?P<Psv_19>[a-zç]+[a])s(?![-\\w–\xad])', 'Às \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_19") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])ao (?P<Psv_20>[a-zç]+[a])(?![-\\w–\xad])', 'à \\2', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_20") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elo (?P<Pvs_21>[a-zç]+[a])s(?![-\\w–\xad])', '\\1ela \\2\\n\\1elas \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_21") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])Ao (?P<Psv_22>[a-zç]+[a])(?![-\\w–\xad])', 'À \\2', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psv_22") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])Os (?P<Pvs_23>[a-zç]+[a])s(?![-\\w–\xad])', 'As \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_23") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])os (?P<Pvs_24>[a-zç]+[a])s(?![-\\w–\xad])', 'as \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_24") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])a (?P<Pvs_25>[a-zç]+[a])s(?![-\\w–\xad])', '\\1as \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_25") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ela (?P<Pvs_26>[a-zç]+[a])s(?![-\\w–\xad])', '\\1elas \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_26") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Psv_27>[a-zç]+[a])s(?![-\\w–\xad])', 'às \\2s', 'Você quis dizer:', 'm.group("Psv_27") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])À (?P<Psv_28>[a-zç]+[a])s(?![-\\w–\xad])', 'Às \\2s', 'Você quis dizer:', 'm.group("Psv_28") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])O (?P<Pvs_29>[a-zç]+[a])(?![-\\w–\xad])', 'A \\1', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_29") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])Os (?P<Pvs_30>[a-zç]+[a])(?![-\\w–\xad])', 'A \\1\\nAs \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_30") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])Os (?P<Pvs_31>[a-zç]+[a])s(?![-\\w–\xad])', 'As \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_31") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])A (?P<Pvs_32>[a-zç]+[a])s(?![-\\w–\xad])', 'A \\1\\nAs \\1s\\nHá \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_32") in plFemavb'],
 ['(?u)(?<![-\\w–.,\xad])As (?P<Pvs_33>[a-zç]+[a])(?![-\\w–\xad])', 'A \\1\\nAs \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_33") in plFemavb'],
 ['(?u)\\b([,]) o (?P<Pvs_34>[a-zç]+[a])(?![-\\w–\xad])', ', a \\1', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_34") in plFemavb'],
 ['(?u)\\b([,]) os (?P<Pvs_35>[a-zç]+[a])(?![-\\w–\xad])', ', a \\1\\n, as \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_35") in plFemavb'],
 ['(?u)\\b([,]) os (?P<Pvs_36>[a-zç]+[a])s(?![-\\w–\xad])', ', as \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_36") in plFemavb'],
 ['(?u)\\b([,]) a (?P<Pvs_37>[a-zç]+[a])s(?![-\\w–\xad])', ', a \\1\\n, as \\1s\\n, há \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_37") in plFemavb'],
 ['(?u)\\b([,]) as (?P<Pvs_38>[a-zç]+[a])(?![-\\w–\xad])', ', a \\1\\n, as \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvs_38") in plFemavb'],
# fim Regras
# Regras para substantivos dois generos tambem encontrados em conjugacoes verbais. Ex. recruta, reserva.
 ['(?u)(?<![-\\w–.,\xad])([Mm])esma (?P<Pvas_1>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1esma \\2\\n\\1esmas \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvas_1") in plInvavb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])as (?P<Pvas_2>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1a \\2\\n\\1as \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvas_2") in plInvavb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])os (?P<Pvas_3>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1o \\2\\n\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvas_3") in plInvavb'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])esmas (?P<Pvas_4>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1esma \\2\\n\\1esmas \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvas_4") in plInvavb'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])esmos (?P<Pvas_5>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1esmo \\2\\n\\1esmos \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvas_5") in plInvavb'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])as (?P<Pvas_6>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1a \\2\\n\\1as \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvas_6") in plInvavb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elas (?P<Pvas_8>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1ela \\2\\n\\1elas \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvas_8") in plInvavb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elos (?P<Pvas_9>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1elo \\2\\n\\1elos \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvas_9") in plInvavb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])a (?P<Pvas_11>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1á \\2s\\n\\1a \\2\\n\\1as \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvas_11") in plInvavb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])o (?P<Pvas_12>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvas_12") in plInvavb'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])o (?P<Pvas_16>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvas_16") in plInvavb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ela (?P<Pvas_17>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1ela \\2\\n\\1elas \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvas_17") in plInvavb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elo (?P<Pvas_21>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1elo \\2\\n\\1elos \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvas_21") in plInvavb'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])a (?P<Pvas_25>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1as \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvas_25") in plInvavb'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Psv_27>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', 'às \\2s', 'Você quis dizer:', 'm.group("Psv_27") in plInvavb'],
 ['(?u)(?<![-\\w–.,\xad])À (?P<Psv_28>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', 'Às \\2s', 'Você quis dizer:', 'm.group("Psv_28") in plInvavb'],
 ['(?u)(?<![-\\w–.,\xad])Os (?P<Pvas_30>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', 'O \\1\\nOs \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvas_30") in plInvavb'],
 ['(?u)(?<![-\\w–.,\xad])As (?P<Pvas_33>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', 'A \\1\\nAs \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvas_33") in plInvavb'],
 ['(?u)\\b([,]) os (?P<Pvas_35>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', ', o \\1\\n, os \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvas_35") in plInvavb'],
# fim Regras
# Regras para substantivos dois generos tambem encontrados em conjugacoes verbais. Ex. corte.
 ['(?u)(?<![-\\w–.,\xad])([Mm])esma (?P<Pves_1>[a-zç]+[e])s(?![-\\w–\xad])', '\\1esma \\2\\n\\1esmas \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pves_1") in plMfevb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])as (?P<Pves_2>[a-zç]+[e])(?![-\\w–\xad])', '\\1a \\2\\n\\1as \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pves_2") in plMfevb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])os (?P<Pves_3>[a-zç]+[e])(?![-\\w–\xad])', '\\1o \\2\\n\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pves_3") in plMfevb'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])esmas (?P<Pves_4>[a-zç]+[e])(?![-\\w–\xad])', '\\1esma \\2\\n\\1esmas \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pves_4") in plMfevb'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])esmos (?P<Pves_5>[a-zç]+[e])(?![-\\w–\xad])', '\\1esmo \\2\\n\\1esmos \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pves_5") in plMfevb'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])as (?P<Pves_6>[a-zç]+[e])(?![-\\w–\xad])', '\\1a \\2\\n\\1as \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pves_6") in plMfevb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elas (?P<Pves_8>[a-zç]+[e])(?![-\\w–\xad])', '\\1ela \\2\\n\\1elas \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pves_8") in plMfevb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elos (?P<Pves_9>[a-zç]+[e])(?![-\\w–\xad])', '\\1elo \\2\\n\\1elos \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pves_9") in plMfevb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])a (?P<Pves_11>[a-zç]+[e])s(?![-\\w–\xad])', '\\1á \\2s\\n\\1a \\2\\n\\1as \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pves_11") in plMfevb'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])o (?P<Pves_12>[a-zç]+[e])s(?![-\\w–\xad])', '\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pves_12") in plMfevb'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])o (?P<Pves_16>[a-zç]+[e])s(?![-\\w–\xad])', '\\1os \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pves_16") in plMfevb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ela (?P<Pves_17>[a-zç]+[e])s(?![-\\w–\xad])', '\\1ela \\2\\n\\1elas \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pves_17") in plMfevb'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elo (?P<Pves_21>[a-zç]+[e])s(?![-\\w–\xad])', '\\1elo \\2\\n\\1elos \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pves_21") in plMfevb'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])a (?P<Pves_25>[a-zç]+[e])s(?![-\\w–\xad])', '\\1as \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pves_25") in plMfevb'],
 ['(?u)(?<![-\\w–.,\xad])à (?P<Psv_27>[a-zç]+[e])s(?![-\\w–\xad])', 'às \\2s', 'Você quis dizer:', 'm.group("Psv_27") in plMfevb'],
 ['(?u)(?<![-\\w–.,\xad])À (?P<Psv_28>[a-zç]+[e])s(?![-\\w–\xad])', 'Às \\2s', 'Você quis dizer:', 'm.group("Psv_28") in plMfevb'],
 ['(?u)(?<![-\\w–.,\xad])Os (?P<Pves_30>[a-zç]+[e])(?![-\\w–\xad])', 'O \\1\\nOs \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pves_30") in plMfevb'],
 ['(?u)(?<![-\\w–.,\xad])As (?P<Pves_33>[a-zç]+[e])(?![-\\w–\xad])', 'A \\1\\nAs \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pves_33") in plMfevb'],
 ['(?u)\\b([,]) os (?P<Pves_35>[a-zç]+[e])(?![-\\w–\xad])', ', o \\1\\n, os \\1s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pves_35") in plMfevb'],
# fim Regras
 ['(?u)(?<![-\\w–.,\xad])á(?![-\\w–\xad])', 'à', 'Acento grave. Você quis dizer:', '" á " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])eio hora(?![-\\w–\xad])', '\\1eia hora', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])eio (envelope|palmo|copo|comprimido|quilo|metro|centímetro|milímetro|minuto|quilômetro|século|campo|tempo|capítulo|ano|físico|mundo|científico|artístico)s(?![-\\w–\xad])', '\\1eio \\2', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])½ (envelope|palmo|copo|comprimido|quilo|metro|centímetro|milímetro|minuto|quilômetro|século|campo|tempo|capítulo|ano)s(?![-\\w–\xad])', '½ \\2', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])eio (envelope|palmo|copo|comprimido|quilo|metro|centímetro|milímetro|quilômetro|século|campo|tempo|capítulo|ano)s(?![-\\w–\xad])', '\\1eio) \\2', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])eia (unidade|cartela|xícara|drágea|cápsula|légua|tarefa|taça)s(?![-\\w–\xad])', '\\1eia \\2', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])eia (colher)es(?![-\\w–\xad])', '\\1eia \\2', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])eia (embalage)ns(?![-\\w–\xad])', '\\1eia \\2m', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])½ (unidade|xícara|drágea|cápsula|légua|tarefa|taça)s(?![-\\w–\xad])', '½ \\2', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])½ (colher)es(?![-\\w–\xad])', '½ \\2', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])eia (unidade|xícara|drágea|cápsula|légua|tarefa|taça)s(?![-\\w–\xad])', '\\1eia) \\2', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])½ (unidade|xícara|drágea|cápsula|légua|tarefa|taça)s(?![-\\w–\xad])', '½ \\2', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Osvaldo Gonçalves ([Cc])ruz(?![-\\w–\xad])', 'Oswaldo Cruz\\nOswaldo Gonçalves Cruz', 'O nome do médico, cientista e sanitarista é escrito com W. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Vital Brasil(?![-\\w–\xad])', 'Vital Brazil\\nVital Brazil Mineiro da Campanha', 'O sobrenome do pesquisador biomédico brasileiro é escrito com Z. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ii])rmãos Vi(l|ll)as B(o|ô)as(?![-\\w–\xad])', '\\1rmãos Villas-Bôas\\nOrlando Villas-Bôas\\nCláudio Villas-Bôas\\nLeonardo Villas-Bôas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ii])rmãos Vi(l|ll)as-Boas(?![-\\w–\xad])', '\\1rmãos Villas-Bôas\\nOrlando Villas-Bôas\\nCláudio Villas-Bôas\\nLeonardo Villas-Bôas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Vi(l|ll)a Lob(o|os)(?![-\\w–\xad])', 'Villa-Lobos\\nHeitor Villa-Lobos', 'O compositor brasileiro de Bachianas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])A([ií])rton ([SC])e(n|nn)a(?![-\\w–\xad])', 'Ayrton Senna\\nAyrton Senna da Silva', 'O piloto brasileiro de fórmula 1? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uque de ([Cc])aixas(?![-\\w–\xad])', 'Duque de Caxias\\nLuís Alves de Lima e Silva', 'O pacificador, Marechal de Ferro? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])ari([ae]) Cure(?![-\\w–\xad])', 'Marie Curie', 'A primeira cientista a receber dois Prêmios Nobel? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Charles Darvi([mn])(?![-\\w–\xad])', 'Charles Darwin\\nCharles Robert Darwin', 'Cientista criador da teoria da evolução das espécies? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]) e(?![-\\w–\xad])', '\\1\\n\\1 é', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])brasil(?![-\\w–\xad])', 'Brasil', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])estados Unidos(?![-\\w–\xad])', 'Estados Unidos', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])estados unidos(?![-\\w–\xad])', 'Estados Unidos', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) gente (?P<Age_1>[a-záâçéêíóôú]+[m][o][s])(?![-\\w–\xad])', 'nós \\g<Age_1>', 'Falta de concordância. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])as dois(?![-\\w–\xad])', 'os dois', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])As dois(?![-\\w–\xad])', 'Os dois', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([DdNn])as dois(?![-\\w–\xad])', '\\1os dois', 'Falta de concordância. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elas dois(?![-\\w–\xad])', '\\1elos dois', 'Falta de concordância. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])a dois(?![-\\w–\xad])', '\\1á dois\\n\\1os dois', 'Falta de concordância. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])a dois(?![-\\w–\xad])', '\\1os dois', 'Falta de concordância. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ela dois(?![-\\w–\xad])', '\\1elos dois', 'Falta de concordância. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])os duas(?![-\\w–\xad])', 'as duas', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Os duas(?![-\\w–\xad])', 'As duas', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([DdNn])os duas(?![-\\w–\xad])', '\\1as duas', 'Falta de concordância. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elos duas(?![-\\w–\xad])', '\\1elas duas', 'Falta de concordância. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])o duas(?![-\\w–\xad])', '\\1as duas', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])o duas(?![-\\w–\xad])', '\\1as duas', 'Falta de concordância. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elo duas(?![-\\w–\xad])', '\\1elas duas', 'Falta de concordância. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])a duas(?![-\\w–\xad])', '\\1á duas\\n\\1as duas', 'Falta de concordância. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])a duas(?![-\\w–\xad])', '\\1as duas', 'Falta de concordância. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ela duas(?![-\\w–\xad])', '\\1elas duas', 'Falta de concordância. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma ([bm])ilhão(?![-\\w–\xad])', '\\1m \\2ilhão', 'Numeral precisa concordar em gênero com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas ([bm])ilhões(?![-\\w–\xad])', '\\1ois \\2ilhões', 'Numeral precisa concordar em gênero com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uzentas ([bm])ilhões de(?![-\\w–\xad])', '\\1uzentos \\2ilhões de', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])rezentas ([bm])ilhões de(?![-\\w–\xad])', '\\1rezentos \\2ilhões de', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uatrocentas ([bm])ilhões de(?![-\\w–\xad])', '\\1uatrocentos \\2ilhões de', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uinhentas ([bm])ilhões de(?![-\\w–\xad])', '\\1uinhentos \\2ilhões de', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])eiscentas ([bm])ilhões de(?![-\\w–\xad])', '\\1eiscentos \\2ilhões de', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])etecentas ([bm])ilhões de(?![-\\w–\xad])', '\\1etecentos \\2ilhões de', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])itocentas ([bm])ilhões de(?![-\\w–\xad])', '\\1itocentos \\2ilhões de', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])ovecentas ([bm])ilhões de(?![-\\w–\xad])', '\\1ovecentos \\2ilhões de', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])as duas ([bm])ilhões(?![-\\w–\xad])', 'os dois \\1ilhões', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])As duas ([bm])ilhões(?![-\\w–\xad])', 'Os dois \\1ilhões', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])as três ([bm])ilhões(?![-\\w–\xad])', 'os três \\1ilhões', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])as seis ([bm])ilhões(?![-\\w–\xad])', 'os seis \\1ilhões', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])as sete ([bm])ilhões(?![-\\w–\xad])', 'os sete \\1ilhões', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])as nove ([bm])ilhões(?![-\\w–\xad])', 'os nove \\1ilhões', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])as cem ([bm])ilhões(?![-\\w–\xad])', 'os cem \\1ilhões', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])as (?P<Ngs_1>[a-zA-Z0-9áâçéêíóôú]+[o]) ([bm])ilhões de(?![-\\w–\xad])', 'os \\g<Ngs_1> \\2ilhões de', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])as (?P<Ngs_1>[a-zA-Z0-9áâçéêíóôú]+[z][e]) ([bm])ilhões de(?![-\\w–\xad])', 'os \\g<Ngs_1> \\2ilhões de', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])as duzentas ([bm])ilhões de(?![-\\w–\xad])', 'os duzentos \\1ilhões de', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])as trezentas ([bm])ilhões de(?![-\\w–\xad])', 'os trezentos \\1ilhões de', 'Artigo precisa concordar em gênero com numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])as quatrocentas ([bm])ilhões de(?![-\\w–\xad])', 'os quatrocentos \\2ilhões de', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])as quinhentas ([bm])ilhões de(?![-\\w–\xad])', 'os quinhentos \\1ilhões de', 'Artigo precisa concordar em gênero com o Numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])as seiscentas ([bm])ilhões de(?![-\\w–\xad])', 'os seiscentos \\1ilhões de', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])as setecentas ([bm])ilhões de(?![-\\w–\xad])', 'os setecentos \\1ilhões de', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])as oitocentas ([bm])ilhões de(?![-\\w–\xad])', 'os oitocentos \\1ilhões de', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])as novecentas ([bm])ilhões de(?![-\\w–\xad])', 'os novecentos \\1ilhões de', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])As três ([bm])ilhões(?![-\\w–\xad])', 'Os três \\1ilhões', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])As seis ([bm])ilhões(?![-\\w–\xad])', 'Os seis \\1ilhões', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])As sete ([bm])ilhões(?![-\\w–\xad])', 'Os sete \\1ilhões', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])As nove ([bm])ilhões(?![-\\w–\xad])', 'Os nove \\1ilhões', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])As cem ([bm])ilhões(?![-\\w–\xad])', 'Os cem \\1ilhões', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])As (?P<Ngs_1>[a-zA-Z0-9áâçéêíóôú]+[o]) ([bm])ilhões de(?![-\\w–\xad])', 'Os \\g<Ngs_1> \\2ilhões de', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])As (?P<Ngs_1>[a-zA-Z0-9áâçéêíóôú]+[z][e]) ([bm])ilhões de(?![-\\w–\xad])', 'Os \\g<Ngs_1> \\2ilhões de', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])As duzentas ([bm])ilhões de(?![-\\w–\xad])', 'Os duzentos \\1ilhões de', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])As trezentas ([bm])ilhões de(?![-\\w–\xad])', 'Os trezentos \\1ilhões de', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])As quatrocentas ([bm])ilhões de(?![-\\w–\xad])', 'Os quatrocentos \\2ilhões de', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])As quinhentas ([bm])ilhões de(?![-\\w–\xad])', 'Os quinhentos \\1ilhões de', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])As seiscentas ([bm])ilhões de(?![-\\w–\xad])', 'Os seiscentos \\1ilhões de', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])As setecentas ([bm])ilhões de(?![-\\w–\xad])', 'Os setecentos \\1ilhões de', 'Artigo precisa concordar em gênero com o umeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])As oitocentas ([bm])ilhões de(?![-\\w–\xad])', 'Os oitocentos \\1ilhões de', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])As novecentas ([bm])ilhões de(?![-\\w–\xad])', 'OS novecentos \\1ilhões de', 'Artigo precisa concordar em gênero com o numeral. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])[a][s] duas ([bm])ilhões(?![-\\w–\xad])', '\\1os dois \\2ilhões', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])[a][s] três ([bm])ilhões(?![-\\w–\xad])', '\\1os três \\2ilhões', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])[a][s] seis ([bm])ilhões(?![-\\w–\xad])', '\\1os seis \\2ilhões', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])[a][s] sete ([bm])ilhões(?![-\\w–\xad])', '\\1os sete \\2ilhões', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])[a][s] nove ([bm])ilhões(?![-\\w–\xad])', '\\1os nove \\2ilhões', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])[a][s] cem ([bm])ilhões(?![-\\w–\xad])', '\\1os cem \\2ilhões', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])[a][s] (?P<Ngs_1>[a-zA-Z0-9áâçéêíóôú]+[o]) ([bm])ilhões de(?![-\\w–\xad])', '\\1os \\g<Ngs_1> \\2ilhões de', 'Artigo precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])[a][s] (?P<Ngs_1>[a-zA-Z0-9áâçéêíóôú]+[z][e]) ([bm])ilhões de(?![-\\w–\xad])', '\\1os \\g<Ngs_1> \\2ilhões de', 'Artigo precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])[a][s] duzentas ([bm])ilhões de(?![-\\w–\xad])', '\\1os duzentos \\2ilhões de', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])[a][s] trezentas ([bm])ilhões de(?![-\\w–\xad])', '\\1os trezentos \\2ilhões de', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])[a][s] quatrocentas ([bm])ilhões de(?![-\\w–\xad])', '\\1os quatrocentos \\2ilhões de', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])[a][s] quinhentas ([bm])ilhões de(?![-\\w–\xad])', '\\1os quinhentos \\2ilhões de', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])[a][s] seiscentas ([bm])ilhões de(?![-\\w–\xad])', '\\1os seiscentos \\2ilhões de', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])[a][s] setecentas ([bm])ilhões de(?![-\\w–\xad])', '\\1os setecentos \\2ilhões de', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])[a][s] oitocentas ([bm])ilhões de(?![-\\w–\xad])', '\\1os oitocentos \\2ilhões de', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])[a][s] novecentas ([bm])ilhões de(?![-\\w–\xad])', '\\1os novecentos \\2ilhões de', 'Numeral precisa concordar em gênero. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ngs_2>[1][,][0-9]+) ([bm])ilhões(?![-\\w–\xad])', '\\g<Ngs_2> \\2ilhão', 'Plural só a partir de 2. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])[s][ ](?P<Ngs_2>[1][,][0-9]+) ([bm])ilhões(?![-\\w–\xad])', '\\1 \\g<Ngs_2> \\2ilhão', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])[oa][s][ ](?P<Ngs_2>[1][,][0-9]+) ([bm])ilhões(?![-\\w–\xad])', '\\1o \\g<Ngs_2> \\3ilhão', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])1 (b|m|tr|quatr)ilhões(?![-\\w–\xad])', '1 \\1ilhão', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([23456789]) (b|m|tr|quatr)ilhão(?![-\\w–\xad])', '\\1 \\2ilhões', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([123456789][0-9]+) (b|m|tr|quatr)ilhão(?![-\\w–\xad])', '\\1 \\2ilhões', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([23456789][,][0-9]+) (b|m|tr|quatr)ilhão(?![-\\w–\xad])', '\\1 \\2ilhões', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([123456789][0-9]+)[,]([0-9]+) (b|m|tr|quatr)ilhão(?![-\\w–\xad])', '\\1,\\2 \\3ilhões', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão devem(?![-\\w–\xad])', 'milhão deve', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão já devem(?![-\\w–\xad])', 'milhão já deve', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão não devem(?![-\\w–\xad])', 'milhão não deve', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão faziam(?![-\\w–\xad])', 'milhão fazia', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão já faziam(?![-\\w–\xad])', 'milhão já fazia', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão não faziam(?![-\\w–\xad])', 'milhão não fazia', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão fizeram(?![-\\w–\xad])', 'milhão fez', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão já fizeram(?![-\\w–\xad])', 'milhão já fez', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão não fizeram(?![-\\w–\xad])', 'milhão não fez', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão ficaram(?![-\\w–\xad])', 'milhão fico', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão já ficaram(?![-\\w–\xad])', 'milhão já fico', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão não ficaram(?![-\\w–\xad])', 'milhão não fico', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão foram(?![-\\w–\xad])', 'milhão foi', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão já foram(?![-\\w–\xad])', 'milhão já foi', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão não foram(?![-\\w–\xad])', 'milhão não foi', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão homenagearam(?![-\\w–\xad])', 'milhão homenageo', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão já homenagearam(?![-\\w–\xad])', 'milhão já homenageo', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão não homenagearam(?![-\\w–\xad])', 'milhão não homenageo', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão homenageiam(?![-\\w–\xad])', 'milhão homenageia', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão já homenageiam(?![-\\w–\xad])', 'milhão já homenageia', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão não homenageiam(?![-\\w–\xad])', 'milhão não homenageia', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão morreram(?![-\\w–\xad])', 'milhão morre', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão já morreram(?![-\\w–\xad])', 'milhão já morre', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão não morreram(?![-\\w–\xad])', 'milhão não morre', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão morrem(?![-\\w–\xad])', 'milhão morre', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão já morrem(?![-\\w–\xad])', 'milhão já morre', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão não morrem(?![-\\w–\xad])', 'milhão não morre', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão perderam(?![-\\w–\xad])', 'milhão perde', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão já perderam(?![-\\w–\xad])', 'milhão já perde', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão não perderam(?![-\\w–\xad])', 'milhão não perde', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão saem(?![-\\w–\xad])', 'milhão sai', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão já saem(?![-\\w–\xad])', 'milhão já sai', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão não saem(?![-\\w–\xad])', 'milhão não sai', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão saíram(?![-\\w–\xad])', 'milhão sai', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão já saíram(?![-\\w–\xad])', 'milhão já sai', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão não saíram(?![-\\w–\xad])', 'milhão não sai', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão são(?![-\\w–\xad])', 'milhão é', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão já são(?![-\\w–\xad])', 'milhão já é', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão não são(?![-\\w–\xad])', 'milhão não é', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão serão(?![-\\w–\xad])', 'milhão será', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão já serão(?![-\\w–\xad])', 'milhão já será', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão não serão(?![-\\w–\xad])', 'milhão não será', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão terão(?![-\\w–\xad])', 'milhão terá', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão já terão(?![-\\w–\xad])', 'milhão já terá', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão não terão(?![-\\w–\xad])', 'milhão não terá', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão estarão(?![-\\w–\xad])', 'milhão estará', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão já estarão(?![-\\w–\xad])', 'milhão já estará', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])milhão não estarão(?![-\\w–\xad])', 'milhão não estará', 'Verbo precisa concordar com substantivo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ll])âmpada ([Ff])lorescente(?![-\\w–\xad])', '\\1âmpada \\2luorescente', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ll])âmpadas ([Ff])lorescentes(?![-\\w–\xad])', '\\1âmpadas \\2luorescentes', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])[e][g]([oa]) em fragrante(?![-\\w–\xad])', '\\1eg\\2 em flagrante', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])[e][g]([oa])[s] em fragrante(?![-\\w–\xad])', '\\1eg\\2s em flagrante', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])interviu(?![-\\w–\xad])', 'interveio', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])olicia(?![-\\w–\xad])', '\\1olícia', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])xiste (?P<Ext_1>[a-zA-Záâçéêíóôú]+[aeo])[s](?![-\\w–\xad])', '\\1xistem \\g<Ext_1>s', 'Falta de concordância.Você quis dizer:', 'not m.group("Ext_1") in excExiste'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])xistia (?P<Ext_2>[a-zA-Záâçéêíóôú]+[aeo])[s](?![-\\w–\xad])', '\\1xistiam \\g<Ext_2>s', 'Falta de concordância.Você quis dizer:', 'not m.group("Ext_2") in excExiste'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])xistiria (?P<Ext_3>[a-zA-Záâçéêíóôú]+[aeo])[s](?![-\\w–\xad])', '\\1xistiriam \\g<Ext_3>s', 'Falta de concordância.Você quis dizer:', 'not m.group("Ext_3") in excExiste'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])o ([mst])eu ver(?![-\\w–\xad])', '\\1 \\2eu ver', 'Não existe artigo na expressão. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])o nosso ver(?![-\\w–\xad])', '\\1 nosso ver', 'Não existe artigo na expressão. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Ao invés de(?![-\\w–\xad])', 'Em vez de', 'Invés = contrário. Ex.: "Novo ao invés de velho". "Em vez de" significa "no lugar de". Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])ao invés de(?![-\\w–\xad])', 'em vez de', 'Invés = contrário. Ex.: "Novo ao invés de velho". "Em vez de" significa "no lugar de". Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Hh])ouveram(?![-\\w–\xad])', '\\1ouve', 'Haver, no sentido de existir, fica invariável. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])ao invés de(?![-\\w–\xad])', 'em vez de', '"Ao invés de" significa "ao contrário de". "Em vez de" quer dizer "no lugar de". Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])vou estar(?![-\\w–\xad])', 'estarei', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])vai estar(?![-\\w–\xad])', 'estará', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])vão estar(?![-\\w–\xad])', 'estarão', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])vamos estar(?![-\\w–\xad])', 'estaremos', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(supr|extr|infr|ultr|meg)[a] (?P<Prx_1>[ah][a-záâãçéêíóôõú]+[aelomrs])(?![-\\w–\xad])', '\\1a-\\g<Prx_1>', 'Você quis dizer:', 'not m.group("Prx_1") in AosExcecao'],
 ['(?u)(?<![-\\w–.,\xad])(supr|extr|infr|ultr|meg)[a] (?P<Prx_2>[bcdefgijlmnopqtuvxz][a-záâãçéêíóôõú]+[aelomrs])(?![-\\w–\xad])', '\\1a\\g<Prx_2>', 'Você quis dizer:', 'not m.group("Prx_2") in AosExcecao'],
 ['(?u)(?<![-\\w–.,\xad])(supr|extr|infr|ultr|meg)[a] (?P<Prx_3>[r][a-záâãçéêíóôõú]+[aelomrs])(?![-\\w–\xad])', '\\1ar\\g<Prx_3>', 'Você quis dizer:', 'not m.group("Prx_3") in AosExcecao'],
 ['(?u)(?<![-\\w–.,\xad])(supr|extr|infr|ultr|meg)[a] (?P<Prx_4>[s][a-záâãçéêíóôõú]+[aelomrs])(?![-\\w–\xad])', '\\1as\\g<Prx_4>', 'Você quis dizer:', 'not m.group("Prx_4") in AosExcecao'],
 ['(?u)(?<![-\\w–.,\xad])(supe|inte|hipe|cibe|Supe|Inte|Hipe|Cibe)[r] (?P<Pxr_1>[rh][a-záâãçéêíóôõú]+[aeolmrsz])(?![-\\w–\xad])', '\\1r-\\g<Pxr_1>', 'Você quis dizer:', 'not m.group("Pxr_1") in AosExcecao'],
 ['(?u)(?<![-\\w–.,\xad])(supe|inte|hipe|cibe|Supe|Inte|Hipe|Cibe)[r] (?P<Pxr_2>[abcdefgijlmnopqstuvxz][a-záâãçéêíóôõú]+[aeolmrsz])(?![-\\w–\xad])', '\\1r\\g<Pxr_2>', 'Você quis dizer:', 'not m.group("Pxr_2") in AosExcecao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]ut|[Pp]seud|[Mm]acr|[Mm]icr|[Nn]e|[Bb]i|[Mm]ot|[Gg]e|[Nn]an)[o] (?P<Pxo_1>[ohô][a-záâãçéêíóôõú]+[aelors])(?![-\\w–\xad])', '\\1o-\\g<Pxo_1>', 'Você quis dizer:', 'not m.group("Pxo_1") in AosExcecao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]ut|[Pp]seud|[Mm]acr|[Mm]icr|[Nn]e|[Bb]i|[Mm]ot|[Gg]e|[Nn]an)[o] (?P<Pxo_2>[abcdefgijlmnpqtuvxz][a-záâãçéêíóôõú]+[aeos])(?![-\\w–\xad])', '\\1o\\g<Pxo_2>', 'Você quis dizer:', 'not m.group("Pxo_2") in AosExcecao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]ut|[Pp]seud|[Mm]acr|[Mm]icr|[Nn]e|[Bb]i|[Mm]ot|[Gg]e|[Nn]an)[o] (?P<Pxo_3>[r][a-záâãçéêíóôõú]+[aos])(?![-\\w–\xad])', '\\1or\\g<Pxo_3>', 'Você quis dizer:', 'not m.group("Pxo_3") in AosExcecao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]ut|[Pp]seud|[Mm]acr|[Mm]icr|[Nn]e|[Bb]i|[Mm]ot|[Gg]e|[Nn]an)[o] (?P<Pxo_4>[s][a-záâãçéêíóôõú]+[aos])(?![-\\w–\xad])', '\\1os\\g<Pxo_4>', 'Você quis dizer:', 'not m.group("Pxo_4") in AosExcecao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]nt|[Aa]rqu|[Ss]em|[Mm]ult|[Pp]lur|[Mm]in)[i] (?P<Pxi_1>[ih][a-záâãçéêíóôõú]+[aelmorsz])(?![-\\w–\xad])', '\\1i-\\g<Pxi_1>', 'Você quis dizer:', 'not m.group("Pxi_1") in AosExcecao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]nt|[Aa]rqu|[Ss]em|[Mm]ult|[Pp]lur|[Mm]in)[i] (?P<Pxi_2>[abcdefgjlmnopqtuvxzáâ][a-záâãçéêíóôõú]+[aelmorsz])(?![-\\w–\xad])', '\\1i\\g<Pxi_2>', 'Você quis dizer:', 'not m.group("Pxi_2") in AosExcecao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]nt|[Aa]rqu|[Ss]em|[Mm]ult|[Pp]lur|[Mm]in)[i] (?P<Pri_3>[r][a-záâãçéêíóôõú]+[aelmorsz])(?![-\\w–\xad])', '\\1ir\\g<Pxi_3>', 'Você quis dizer:', 'not m.group("Pxi_3") in AosExcecao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]nt|[Aa]rqu|[Ss]em|[Mm]ult|[Pp]lur|[Mm]in)[i] (?P<Pri_4>[s][a-záâãçéêíóôõú]+[aelmorsz])(?![-\\w–\xad])', '\\1is\\g<Pxi_4>', 'Você quis dizer:', 'not m.group("Pxi_4") in AosExcecao'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontra (?P<Pxct_1>[ah][a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '\\1ontra-\\g<Pxct_1>', 'Você quis dizer:', 'm.group("Pxct_1") in pfxContraah and not exccontra.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontra (?P<Pxct_2>[bcdefgijlmnopqtuvxz][a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '\\1ontra\\g<Pxct_2>', 'Você quis dizer:', 'm.group("Pxct_2") in pfxContrajto and not exccontra.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontra (?P<Pxct_3>[r][a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '\\1ontrar\\g<Pxct_3>', 'Você quis dizer:', 'm.group("Pxct_3") in pfxContrars and not exccontra.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ontra (?P<Pxct_4>[s][a-zA-Zçáéíóúâêôãõ]+)(?![-\\w–\xad])', '\\1ontras\\g<Pxct_4>', 'Você quis dizer:', 'm.group("Pxct_4") in pfxContrars and not exccontra.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])ub (?P<Pxb_1>[brhBRH][a-záâãçéêíóôõú]+[aelmorsz])(?![-\\w–\xad])', '\\1ub-\\g<Pxb_1>', 'Você quis dizer:', 'not m.group("Pxb_1") in AosExcecao'],
 ['(?u)(?<![-\\w–.,\xad])([Ss])ub (?P<Pxb_2>[acdefgjlmnopqstuvxz][a-záâãçéêíóôõú]+[aelmorsz])(?![-\\w–\xad])', '\\1ub\\g<Pxb_2>', 'Você quis dizer:', 'not m.group("Pxb_2") in AosExcecao'],
 ['(?u)(?<![-\\w–.,\xad])([Rr])ecém (?P<Pxm_1>[a-záâãçéêíóôõú]+[aos])(?![-\\w–\xad])', '\\1ecém-\\g<Pxm_1>', 'Você quis dizer:', 'not m.group("Pxm_1") in AosExcecao'],
 ['(?u)(?<![-\\w–.,\xad])([0-9]+) mega(?![-\\w–\xad])', '\\1 Mega', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([0-9]+) [Mm]egas(?![-\\w–\xad])', '\\1 Mega', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([0-9]+) giga(?![-\\w–\xad])', '\\1 Giga', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([0-9]+) [Gg]igas(?![-\\w–\xad])', '\\1 Giga', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([0-9]+) tera(?![-\\w–\xad])', '\\1 Tera', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([0-9]+) [Tt]eras(?![-\\w–\xad])', '\\1 Tera', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([0-9]+) peta(?![-\\w–\xad])', '\\1 Peta', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([0-9]+) [Pp]etas(?![-\\w–\xad])', '\\1 Peta', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])laca ([Mm])ãe(?![-\\w–\xad])', '\\1laca-\\2ãe', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])lacas ([Mm])ãe(?![-\\w–\xad])', '\\1lacas-\\2ãe', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])lacas ([Mm])ães(?![-\\w–\xad])', '\\1lacas-\\2ãe', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])azem (?P<Fza_1>[a-z0-9áâãçéêíóôõú]+) (milênio|século|ano|mese|dia)[s] que(?![-\\w–\xad])', '\\1az \\g<Fza_1> \\3s que', 'Fazer é impessoal quando exprime tempo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])azem (?P<Fza_2>[a-z0-9áâãçéêíóôõú]+) (milênio|século|ano|mese|dia)[s] d([ao])(?![-\\w–\xad])', '\\1az \\g<Fza_2> \\3s d\\4', 'Fazer é impessoal quando exprime tempo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])azem (?P<Fza_3>[a-z0-9áâãçéêíóôõú]+) (milênio|século|ano|mese|dia)[s] d([ao])s(?![-\\w–\xad])', '\\1az \\g<Fza_3> \\3s d\\4s', 'Fazer é impessoal quando exprime tempo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])izeram (?P<Fze_1>[a-z0-9áâãçéêíóôõú]+) (milênio|século|ano|mese|dia)[s] que(?![-\\w–\xad])', '\\1ez \\g<Fze_1> \\3s que', 'Fazer é impessoal quando exprime tempo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])izeram (?P<Fze_2>[a-z0-9áâãçéêíóôõú]+) (milênio|século|ano|mese|dia)[s] d([ao])(?![-\\w–\xad])', '\\1ez \\g<Fze_2> \\3s d\\4', 'Fazer é impessoal quando exprime tempo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])izeram (?P<Fze_3>[a-z0-9áâãçéêíóôõú]+) (milênio|século|ano|mese|dia)[s] d([ao])s(?![-\\w–\xad])', '\\1ez \\g<Fze_3> \\3s d\\4s', 'Fazer é impessoal quando exprime tempo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])aziam (?P<Fzi_1>[a-z0-9áâãçéêíóôõú]+) (milênio|século|ano|mese|dia)[s] que(?![-\\w–\xad])', '\\1azia \\g<Fzi_1> \\3s que', 'Fazer é impessoal quando exprime tempo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])aziam (?P<Fzi_2>[a-z0-9áâãçéêíóôõú]+) (milênio|século|ano|mese|dia)[s] d([ao])(?![-\\w–\xad])', '\\1azia \\g<Fzi_2> \\3s d\\4', 'Fazer é impessoal quando exprime tempo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])aziam (?P<Fzi_3>[a-z0-9áâãçéêíóôõú]+) (milênio|século|ano|mese|dia)[s] d([ao])s(?![-\\w–\xad])', '\\1azia \\g<Fzi_3> \\3s d\\4s', 'Fazer é impessoal quando exprime tempo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])arão (?P<Fzb_1>[a-z0-9áâãçéêíóôõú]+) (milênio|século|ano|mese|dia)[s] que(?![-\\w–\xad])', '\\1ará \\g<Fzb_1> \\3s que', 'Fazer é impessoal quando exprime tempo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])arão (?P<Fzb_2>[a-z0-9áâãçéêíóôõú]+) (milênio|século|ano|mese|dia)[s] d([ao])(?![-\\w–\xad])', '\\1ará \\g<Fzb_2> \\3s d\\4', 'Fazer é impessoal quando exprime tempo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])arão (?P<Fzb_3>[a-z0-9áâãçéêíóôõú]+) (milênio|século|ano|mese|dia)[s] d([ao])s(?![-\\w–\xad])', '\\1ará \\g<Fzb_3> \\3s d\\4s', 'Fazer é impessoal quando exprime tempo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])ariam (?P<Fzm_1>[a-z0-9áâãçéêíóôõú]+) (milênio|século|ano|mese|dia)[s] que(?![-\\w–\xad])', '\\1aria \\g<Fzb_1> \\3s que', 'Fazer é impessoal quando exprime tempo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])ariam (?P<Fzm_2>[a-z0-9áâãçéêíóôõú]+) (milênio|século|ano|mese|dia)[s] d([ao])(?![-\\w–\xad])', '\\1aria \\g<Fzb_2> \\3s d\\4', 'Fazer é impessoal quando exprime tempo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])ariam (?P<Fzm_3>[a-z0-9áâãçéêíóôõú]+) (milênio|século|ano|mese|dia)[s] d([ao])s(?![-\\w–\xad])', '\\1aria \\g<Fzb_3> \\3s d\\4s', 'Fazer é impessoal quando exprime tempo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo]) ([Óó])culos(?![-\\w–\xad])', '\\1s \\2culos', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])a por(?![-\\w–\xad])', 'a pôr', 'A palavra POR, na forma verbal, é acentuada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])o por(?![-\\w–\xad])', '\\1o pôr', 'A palavra POR, na forma verbal, é acentuada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])de por(?![-\\w–\xad])', 'de pôr', 'A palavra POR, na forma verbal, é acentuada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo]) por d([ao])(?![-\\w–\xad])', '\\1 pôr d\\2', 'A palavra POR, na forma verbal, é acentuada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])o por d([ao])(?![-\\w–\xad])', '\\1o pôr d\\2', 'A palavra POR, na forma verbal, é acentuada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo]) por d([ao])s(?![-\\w–\xad])', '\\1 pôr d\\2s', 'A palavra POR, na forma verbal, é acentuada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])o por d([ao])s(?![-\\w–\xad])', '\\1o pôr d\\2s', 'A palavra POR, na forma verbal, é acentuada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])por em(?![-\\w–\xad])', 'pôr em', 'A palavra POR, na forma verbal, é acentuada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(lhes|lhe|me|te|vou|fui|foi|foram|vão|ia|iam|quis|quiseram|vamos|vai|tentei|tentamos|preciso|precisamos|precisei|precisarei|onde|para) por ([ao])(?![-\\w–\xad])', '\\1 pôr \\2', 'A palavra POR, na forma verbal, é acentuada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(lhes|lhe|me|te|vou|fui|foi|foram|vão|ia|iam|quis|quiseram|vamos|vai|tentei|tentamos|preciso|precisamos|precisei|precisarei|onde|para) por ([ao])s(?![-\\w–\xad])', '\\1 pôr \\2s', 'A palavra POR, na forma verbal, é acentuada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Melhor|melhor|têm|tem|tinha|tinham|há|terá|teremos|temos|Temos|terão|tiveram|tenho|Tenho|teve|tive|Tive) que por ([ao])(?![-\\w–\xad])', '\\1 que pôr \\2', 'A palavra POR, na forma verbal, é acentuada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Melhor|melhor|têm|tem|tinha|tinham|há|terá|teremos|temos|Temos|terão|tiveram|tenho|Tenho|teve|tive|Tive) que por ([ao])s(?![-\\w–\xad])', '\\1 que pôr \\2s', 'A palavra POR, na forma verbal, é acentuada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Melhor|melhor|têm|tem|tinha|tinham|há|terá|teremos|temos|Temos|terão|tiveram|tenho|Tenho|teve|tive|Tive) que por (um|uma|uns|umas|mais|na|nas|no|nos|esse|esses|essa|essas|isso|tudo|todo|todos|toda|todas)(?![-\\w–\xad])', '\\1 que pôr \\2', 'A palavra POR, na forma verbal, é acentuada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ara por (tudo|ordem)(?![-\\w–\xad])', '\\1ara pôr \\2', 'A palavra POR, na forma verbal, é acentuada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ara por fim (a|à|ao)(?![-\\w–\xad])', '\\1ara pôr fim \\2', 'A palavra POR, na forma verbal, é acentuada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ara por fim (a|à|ao)s(?![-\\w–\xad])', '\\1ara pôr fim \\2s', 'A palavra POR, na forma verbal, é acentuada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo]) EUA(?![-\\w–\xad])', '\\1s EUA', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo]) Estados Unidos(?![-\\w–\xad])', '\\1s Estados Unidos', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])guarda chuva(?![-\\w–\xad])', 'guarda-chuva', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])guarda chuvas(?![-\\w–\xad])', 'guarda-chuvas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])guardas chuva(?![-\\w–\xad])', 'guarda-chuvas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])guardas chuvas(?![-\\w–\xad])', 'guarda-chuvas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Irei (?P<Iri_1>[a-zç]+[ai][r])(?![-\\w–\xad])', '= m.group("Iri_1").capitalize() + \'ei \'', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])irei (?P<Iri_2>[a-zç]+[ai][r])(?![-\\w–\xad])', '\\g<Iri_2>ei', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])Irei (?P<Iri_3>[a-zç]+[bcdfgjlmnprstvx][e][r])(?![-\\w–\xad])', '= m.group("Iri_3").capitalize() + \'ei \'', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])irei (?P<Iri_4>[a-zç]+[bcdfgjlmnprstvx][e][r])(?![-\\w–\xad])', '\\g<Iri_4>ei', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])Irei (?P<Iri_5>[a-zç]+)[z][e][r](?![-\\w–\xad])', '= m.group("Iri_5").capitalize() + \'rei \'', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])irei (?P<Iri_6>[a-zç]+)[z][e][r](?![-\\w–\xad])', '\\g<Iri_6>rei', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])Iremos (?P<Irs_1>[a-zç]+[ai][r])(?![-\\w–\xad])', '= m.group("Irs_1").capitalize() + \'emos \'', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])iremos (?P<Irs_2>[a-zç]+[ai][r])(?![-\\w–\xad])', '\\g<Irs_2>emos', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])Iremos (?P<Irs_3>[a-zç]+[bcdfgjlmnprstvx][e][r])(?![-\\w–\xad])', '= m.group("Irs_3").capitalize() + \'emos \'', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])iremos (?P<Irs_4>[a-zç]+[bcdfgjlmnprstvx][e][r])(?![-\\w–\xad])', '\\g<Irs_4>emos', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])Iremos (?P<Irs_5>[a-zç]+)[z][e][r](?![-\\w–\xad])', '= m.group("Irs_5").capitalize() + \'remos \'', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])iremos (?P<Irs_6>[a-zç]+)[z][e][r](?![-\\w–\xad])', '\\g<Irs_6>remos', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])irá (?P<Ira_2>[a-zç]+[ai][r])(?![-\\w–\xad])', '\\g<Ira_2>á', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])irá (?P<Ira_4>[a-zç]+[bcdfgjlmnprstvx][e][r])(?![-\\w–\xad])', '\\g<Ira_4>á', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])irá (?P<Ira_6>[a-zç]+)[z][e][r](?![-\\w–\xad])', '\\g<Ira_6>rá', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])irão (?P<Iro_2>[a-zç]+[ai][r])(?![-\\w–\xad])', '\\g<Iro_2>ão', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])irão (?P<Iro_4>[a-zç]+[bcdfgjlmnprstvx][e][r])(?![-\\w–\xad])', '\\g<Iro_4>ão', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])irão (?P<Iro_6>[a-zç]+)[z][e][r](?![-\\w–\xad])', '\\g<Iro_6>rão', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])Iria (?P<Iri_10>[a-zç]+[ai][r])(?![-\\w–\xad])', '= m.group("Iri_10").capitalize() + \'ia \'', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])iria (?P<Iri_11>[a-zç]+[ai][r])(?![-\\w–\xad])', '\\g<Iri_11>ia', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])Iria (?P<Iri_12>[a-zç]+[bcdfgjlmnprstvx][e][r])(?![-\\w–\xad])', '= m.group("Iri_12").capitalize() + \'ia \'', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])iria (?P<Iri_13>[a-zç]+[bcdfgjlmnprstvx][e][r])(?![-\\w–\xad])', '\\g<Iri_13>ia', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])Iria (?P<Iri_14>[a-zç]+)[z][e][r](?![-\\w–\xad])', '= m.group("Iri_14").capitalize() + \'ria \'', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])iria (?P<Iri_15>[a-zç]+)[z][e][r](?![-\\w–\xad])', '\\g<Iri_15>ria', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])Iriam (?P<Iri_16>[a-zç]+[ai][r])(?![-\\w–\xad])', '= m.group("Iri_16").capitalize() + \'iam \'', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])iriam (?P<Iri_17>[a-zç]+[ai][r])(?![-\\w–\xad])', '\\g<Iri_17>iam', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])Iriam (?P<Iri_18>[a-zç]+[bcdfgjlmnprstvx][e][r])(?![-\\w–\xad])', '= m.group("Iri_18").capitalize() + \'iam \'', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])iriam (?P<Iri_19>[a-zç]+[bcdfgjlmnprstvx][e][r])(?![-\\w–\xad])', '\\g<Iri_19>iam', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])Iriam (?P<Iri_20>[a-zç]+)[z][e][r](?![-\\w–\xad])', '= m.group("Iri_20").capitalize() + \'riam \'', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])iriam (?P<Iri_21>[a-zç]+)[z][e][r](?![-\\w–\xad])', '\\g<Iri_21>riam', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])Estará sendo(?![-\\w–\xad])', 'Será', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])estará sendo(?![-\\w–\xad])', 'será', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])Estarão sendo(?![-\\w–\xad])', 'Serão', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])estarão sendo(?![-\\w–\xad])', 'serão', 'Melhor se substituir por:', False],
 ['(?u)(?<![-\\w–.,\xad])tinha falo(?![-\\w–\xad])', 'tinha falado', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])havia falo(?![-\\w–\xad])', 'havia falado', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])o vomito(?![-\\w–\xad])', 'o vômito', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])d([eo]) vomito(?![-\\w–\xad])', 'd\\1 vômito', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([eu])m vomito(?![-\\w–\xad])', '\\1m vômito', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])com vomito(?![-\\w–\xad])', 'com vômito', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])sem vomito(?![-\\w–\xad])', 'sem vômito', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])para vomito(?![-\\w–\xad])', 'para vômito', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vmt_1>caus[a-z]+) vomito(?![-\\w–\xad])', '\\g<Vmt_1> vômito', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Vmt_2>provoc[a-z]+) vomito(?![-\\w–\xad])', '\\g<Vmt_2> vômito', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])pesar da (?P<Aps_1>[a-zA-Záâçéêíóôúã]+) (?P<Aps_2>[a-zç]+[aeio][r])(?![-\\w–\xad])', '\\1pesar de a \\g<Aps_1> \\g<Aps_2>', 'Contração "da" inadequada. Deve-se isolar o artigo quando o elemento após a preposição funcionar como sujeito do verbo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])pesar da (?P<Aps_3>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_4>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_5>[a-zç]+[aeio][r])(?![-\\w–\xad])', '\\1pesar de a \\g<Aps_3> \\g<Aps_4> \\g<Aps_5>', 'Contração "da" inadequada. Deve-se isolar o artigo quando o elemento após a preposição funcionar como sujeito do verbo. Você quis dizer:', 'not m.group("Aps_4") in excApesarda'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])pesar da (?P<Aps_6>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_7>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_8>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_9>[a-zç]+[aeio][r])(?![-\\w–\xad])', '\\1pesar de a \\g<Aps_6> \\g<Aps_7> \\g<Aps_8> \\g<Aps_9>', 'Contração "da" inadequada. Deve-se isolar o artigo quando o elemento após a preposição funcionar como sujeito do verbo. Você quis dizer:', 'not m.group("Aps_7") in excApesarda and not m.group("Aps_8") in excApesarda'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])pesar da (?P<Aps_10>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_11>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_12>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_13>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_14>[a-zç]+[aeio][r])(?![-\\w–\xad])', '\\1pesar de a \\g<Aps_10> \\g<Aps_11> \\g<Aps_12> \\g<Aps_13> \\g<Aps_14>', 'Contração "da" inadequada. Deve-se isolar o artigo quando o elemento após a preposição funcionar como sujeito do verbo. Você quis dizer:', 'not m.group("Aps_11") in excApesarda and not m.group("Aps_12") in excApesarda and not m.group("Aps_13") in excApesarda'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])pesar das (?P<Aps_15>[a-zA-Záâçéêíóôúã]+) (?P<Aps_16>[a-zç]+[aeio][r])(?![-\\w–\xad])', '\\1pesar de as \\g<Aps_15> \\g<Aps_16>', 'Contração "da" inadequada. Deve-se isolar o artigo quando o elemento após a preposição funcionar como sujeito do verbo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])pesar das (?P<Aps_17>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_18>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_19>[a-zç]+[aeio][r])(?![-\\w–\xad])', '\\1pesar de as \\g<Aps_17> \\g<Aps_18> \\g<Aps_19>', 'Contração "da" inadequada. Deve-se isolar o artigo quando o elemento após a preposição funcionar como sujeito do verbo. Você quis dizer:', 'not m.group("Aps_18") in excApesarda'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])pesar das (?P<Aps_20>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_21>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_22>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_23>[a-zç]+[aeio][r])(?![-\\w–\xad])', '\\1pesar de as \\g<Aps_20> \\g<Aps_21> \\g<Aps_22> \\g<Aps_23>', 'Contração "da" inadequada. Deve-se isolar o artigo quando o elemento após a preposição funcionar como sujeito do verbo. Você quis dizer:', 'not m.group("Aps_21") in excApesarda and not m.group("Aps_22") in excApesarda'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])pesar das (?P<Aps_24>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_25>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_26>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_27>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Aps_28>[a-zç]+[aeio][r])(?![-\\w–\xad])', '\\1pesar de as \\g<Aps_24> \\g<Aps_25> \\g<Aps_26> \\g<Aps_27> \\g<Aps_28>', 'Contração "da" inadequada. Deve-se isolar o artigo quando o elemento após a preposição funcionar como sujeito do verbo. Você quis dizer:', 'not m.group("Aps_25") in excApesarda and not m.group("Aps_26") in excApesarda and not m.group("Aps_27") in excApesarda'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])pesar do (?P<Apz_1>[a-zA-Záâçéêíóôúã]+) (?P<Apz_2>[a-zç]+[aeio][r])(?![-\\w–\xad])', '\\1pesar de o \\g<Apz_1> \\g<Apz_2>', 'Contração "do" inadequada. Deve-se isolar o artigo quando o elemento após a preposição funcionar como sujeito do verbo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])pesar do (?P<Apz_3>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_4>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_5>[a-zç]+[aeio][r])(?![-\\w–\xad])', '\\1pesar de o \\g<Apz_3> \\g<Apz_4> \\g<Apz_5>', 'Contração "do" inadequada. Deve-se isolar o artigo quando o elemento após a preposição funcionar como sujeito do verbo. Você quis dizer:', 'not m.group("Apz_4") in excApesarda'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])pesar do (?P<Apz_6>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_7>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_8>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_9>[a-zç]+[aeio][r])(?![-\\w–\xad])', '\\1pesar de o \\g<Apz_6> \\g<Apz_7> \\g<Apz_8> \\g<Apz_9>', 'Contração "do" inadequada. Deve-se isolar o artigo quando o elemento após a preposição funcionar como sujeito do verbo. Você quis dizer:', 'not m.group("Apz_7") in excApesarda and not m.group("Apz_8") in excApesarda'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])pesar do (?P<Apz_10>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_11>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_12>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_13>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_14>[a-zç]+[aeio][r])(?![-\\w–\xad])', '\\1pesar de o \\g<Apz_10> \\g<Apz_11> \\g<Apz_12> \\g<Apz_13> \\g<Apz_14>', 'Contração "do" inadequada. Deve-se isolar o artigo quando o elemento após a preposição funcionar como sujeito do verbo. Você quis dizer:', 'not m.group("Apz_11") in excApesarda and not m.group("Apz_12") in excApesarda and not m.group("Apz_13") in excApesarda'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])pesar dos (?P<Apz_15>[a-zA-Záâçéêíóôúã]+) (?P<Apz_16>[a-zç]+[aeio][r])(?![-\\w–\xad])', '\\1pesar de os \\g<Apz_15> \\g<Apz_16>', 'Contração "dos" inadequada. Deve-se isolar o artigo quando o elemento após a preposição funcionar como sujeito do verbo. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])pesar dos (?P<Apz_17>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_18>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_19>[a-zç]+[aeio][r])(?![-\\w–\xad])', '\\1pesar de os \\g<Apz_17> \\g<Apz_18> \\g<Apz_19>', 'Contração "dos" inadequada. Deve-se isolar o artigo quando o elemento após a preposição funcionar como sujeito do verbo. Você quis dizer:', 'not m.group("Apz_18") in excApesarda'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])pesar dos (?P<Apz_20>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_21>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_22>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_23>[a-zç]+[aeio][r])(?![-\\w–\xad])', '\\1pesar de os \\g<Apz_20> \\g<Apz_21> \\g<Apz_22> \\g<Apz_23>', 'Contração "dos" inadequada. Deve-se isolar o artigo quando o elemento após a preposição funcionar como sujeito do verbo. Você quis dizer:', 'not m.group("Apz_21") in excApesarda and not m.group("Apz_22") in excApesarda'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])pesar dos (?P<Apz_24>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_25>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_26>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_27>[a-zA-Záâçéêíóôúã]+[aeosm]) (?P<Apz_28>[a-zç]+[aeio][r])(?![-\\w–\xad])', '\\1pesar de os \\g<Apz_24> \\g<Apz_25> \\g<Apz_26> \\g<Apz_27> \\g<Apz_28>', 'Contração "dos" inadequada. Deve-se isolar o artigo quando o elemento após a preposição funcionar como sujeito do verbo. Você quis dizer:', 'not m.group("Apz_25") in excApesarda and not m.group("Apz_26") in excApesarda and not m.group("Apz_27") in excApesarda'],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ngenheir([ao]) ([Ee])létric([ao])(?![-\\w–\xad])', '\\1ngenheir\\2 \\3letricista', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ngenheir([ao])s ([Ee])létric([ao])s(?![-\\w–\xad])', '\\1ngenheir\\2s \\3letricistas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ng. ([Ee])létrico(?![-\\w–\xad])', '\\1ng. \\2letricista', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ng.º ([Ee])létrico(?![-\\w–\xad])', '\\1ng.º \\2letricista', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])ao ([Dd])eus dará(?![-\\w–\xad])', 'ao deus-dará', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])rco da ([Vv])elha(?![-\\w–\xad])', '\\1rco-da-velha', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])rquivo ([Ff])onte(?![-\\w–\xad])', '\\1rquivo-fonte', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])rquivos ([Ff])ontes(?![-\\w–\xad])', '\\1rquivos-fontes', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxílio ([Dd])esemprego(?![-\\w–\xad])', '\\1uxílio-desemprego', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxílio ([Dd])oença(?![-\\w–\xad])', '\\1uxílio-doença', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxílio ([Ee])ducação(?![-\\w–\xad])', '\\1uxílio-educação', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxílio ([Ff])uneral(?![-\\w–\xad])', '\\1uxílio-funeral', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxílio ([Mm])aternidade(?![-\\w–\xad])', '\\1uxílio-maternidade', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxílio ([Nn])atalidade(?![-\\w–\xad])', '\\1uxílio-natalidade', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxílio ([Aa])cidentário(?![-\\w–\xad])', '\\1uxílio-acidentário', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxílio ([Aa])cidente(?![-\\w–\xad])', '\\1uxílio-acidente', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxílio ([Aa])limentação(?![-\\w–\xad])', '\\1uxílio-alimentação', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxílio ([Ee])nfermidade(?![-\\w–\xad])', '\\1uxílio-enfermidade', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxílio ([Rr])eclusão(?![-\\w–\xad])', '\\1uxílio-reclusão', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxílio ([Rr])efeição(?![-\\w–\xad])', '\\1uxílio-refeição', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxílio ([Tt])ransporte(?![-\\w–\xad])', '\\1uxílio-transporte', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxílio ([Pp])aletó(?![-\\w–\xad])', '\\1uxílio-paletó', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxílio ([Cc])reche(?![-\\w–\xad])', '\\1uxílio-creche', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Aa])limentação(?![-\\w–\xad])', '\\1ale-alimentação', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Bb])rinde(?![-\\w–\xad])', '\\1ale-brinde', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Cc])ambrense(?![-\\w–\xad])', '\\1ale-cambrense', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Cc])ambrenses(?![-\\w–\xad])', '\\1ale-cambrenses', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Cc])ompra(?![-\\w–\xad])', '\\1ale-compra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Cc])ultura(?![-\\w–\xad])', '\\1ale-cultura', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Gg])ás(?![-\\w–\xad])', '\\1ale-gás', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Pp])araiban([ao])(?![-\\w–\xad])', '\\1ale-paraiban\\3', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Pp])araiban([ao])s(?![-\\w–\xad])', '\\1ale-paraiban\\3s', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Pp])esense(?![-\\w–\xad])', '\\1ale-pesense', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Pp])esenses(?![-\\w–\xad])', '\\1ale-pesenses', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Rr])efeição(?![-\\w–\xad])', '\\1ale-refeição', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Tt])ransporte(?![-\\w–\xad])', '\\1ale-transporte', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Vv])arguense(?![-\\w–\xad])', '\\1ale-varguense', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Vv])arguenses(?![-\\w–\xad])', '\\1ale-varguenses', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Vv])erdense(?![-\\w–\xad])', '\\1ale-verdense', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Vv])erdenses(?![-\\w–\xad])', '\\1ale-verdenses', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Aa])limentação(?![-\\w–\xad])', '\\1ales-alimentação', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Bb])rinde(?![-\\w–\xad])', '\\1ales-brinde', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Cc])ambrense(?![-\\w–\xad])', '\\1ale-cambrense', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Cc])ambrenses(?![-\\w–\xad])', '\\1ale-cambrenses', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Cc])ompra(?![-\\w–\xad])', '\\1ales-compra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Cc])ultura(?![-\\w–\xad])', '\\1ales-cultura', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Gg])ás(?![-\\w–\xad])', '\\1ales-gás', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Pp])araiban([ao])(?![-\\w–\xad])', '\\1ale-paraiban\\3', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Pp])araiban([ao])s(?![-\\w–\xad])', '\\1ale-paraiban\\3s', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Pp])esense(?![-\\w–\xad])', '\\1ale-pesense', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Pp])esenses(?![-\\w–\xad])', '\\1ale-pesenses', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Rr])efeição(?![-\\w–\xad])', '\\1ales-refeição', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Tt])ransporte(?![-\\w–\xad])', '\\1ales-transporte', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Vv])arguense(?![-\\w–\xad])', '\\1ale-varguense', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Vv])arguenses(?![-\\w–\xad])', '\\1ale-varguenses', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Vv])erdense(?![-\\w–\xad])', '\\1ale-verdense', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Vv])erdenses(?![-\\w–\xad])', '\\1ale-verdenses', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Aa])limentações(?![-\\w–\xad])', '\\1ales-alimentação', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Bb])rindes(?![-\\w–\xad])', '\\1ales-brinde', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Cc])ompras(?![-\\w–\xad])', '\\1ales-compra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Cc])ulturas(?![-\\w–\xad])', '\\1ales-cultura', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Gg])ases(?![-\\w–\xad])', '\\1ales-gás', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Rr])efeições(?![-\\w–\xad])', '\\1ales-refeição', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ales ([Tt])ransportes(?![-\\w–\xad])', '\\1ales-transporte', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Aa])limentações(?![-\\w–\xad])', '\\1ales-alimentação', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Bb])rindes(?![-\\w–\xad])', '\\1ales-brinde', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Cc])ompras(?![-\\w–\xad])', '\\1ales-compra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Cc])ulturas(?![-\\w–\xad])', '\\1ales-cultura', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Gg])ases(?![-\\w–\xad])', '\\1ales-gás', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Rr])efeições(?![-\\w–\xad])', '\\1ales-refeição', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ale ([Tt])ransportes(?![-\\w–\xad])', '\\1ales-transporte', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxilio ([Dd])esemprego(?![-\\w–\xad])', '\\1uxílio-desemprego', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxilio ([Dd])oença(?![-\\w–\xad])', '\\1uxílio-doença', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxilio ([Ee])ducação(?![-\\w–\xad])', '\\1uxílio-educação', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxilio ([Ff])uneral(?![-\\w–\xad])', '\\1uxílio-funeral', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxilio ([Mm])aternidade(?![-\\w–\xad])', '\\1uxílio-maternidade', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])uxilio ([Nn])atalidade(?![-\\w–\xad])', '\\1uxílio-natalidade', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ana de ([Aa])çúcar(?![-\\w–\xad])', '\\1ana-de-açúcar', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Áá])gua de ([Cc])olônia(?![-\\w–\xad])', '\\1gua-de-colônia', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])porcento(?![-\\w–\xad])', 'por cento', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo]) celebro(?![-\\w–\xad])', '\\1 cérebro', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([adn])o celebro(?![-\\w–\xad])', '\\1o cérebro', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([MTSmts])eu celebro(?![-\\w–\xad])', '\\1eu cérebro', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([eu])m celebro(?![-\\w–\xad])', '\\1m cérebro', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elo celebro(?![-\\w–\xad])', '\\1elo cérebro', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])de celebro(?![-\\w–\xad])', 'de cérebro', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])próprio celebro(?![-\\w–\xad])', 'próprio cérebro', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])mesmo celebro(?![-\\w–\xad])', 'mesmo cérebro', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])esse celebro(?![-\\w–\xad])', 'esse cérebro', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])com celebro(?![-\\w–\xad])', 'com cérebro', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])grande celebro(?![-\\w–\xad])', 'grande cérebro', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])pequeno celebro(?![-\\w–\xad])', 'pequeno cérebro', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])a nível de(?![-\\w–\xad])', 'em nível de', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])A nível de(?![-\\w–\xad])', 'Em nível de', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])em ([Vv])ind([ao])(?![-\\w–\xad])', '\\1em-vind\\3', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])em ([Vv])ind([ao]s)(?![-\\w–\xad])', '\\1em-vind\\3', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])em ([Aa])venturad([ao])(?![-\\w–\xad])', '\\1em-aventurad\\3', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])em ([Aa])venturad([ao]s)(?![-\\w–\xad])', '\\1em-aventurad\\3', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pay_2>[a-zA-Záâçéêíóôúã]+[a][d][o]) pais(?![-\\w–\xad])', '\\1 país\\n\\1s pais', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pay_3>[a-zA-Záâçéêíóôúã]+[a][d][o][r]) pais(?![-\\w–\xad])', '\\1 país\\n\\1es pais', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pay_4>[a-zA-Z]+)ável pais(?![-\\w–\xad])', '\\1ável país\\n\\1áveis pais', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pay_5>[a-zA-Z]+)ível pais(?![-\\w–\xad])', '\\1ível país\\n\\1íveis pais', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma grama de(?![-\\w–\xad])', '\\1m grama de', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas gramas de(?![-\\w–\xad])', '\\1ois gramas de', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uzentas gramas de(?![-\\w–\xad])', '\\1uzentos gramas de', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])rezentas gramas de(?![-\\w–\xad])', '\\1rezentos gramas de', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uatrocentas gramas de(?![-\\w–\xad])', '\\1uatrocentos gramas de', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uinhentas gramas de(?![-\\w–\xad])', '\\1uinhentos gramas de', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])eiscentas gramas de(?![-\\w–\xad])', '\\1eiscentos gramas de', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])etecentas gramas de(?![-\\w–\xad])', '\\1etecentos gramas de', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])itocentas gramas de(?![-\\w–\xad])', '\\1itocentos gramas de', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])ovecentas gramas de(?![-\\w–\xad])', '\\1ovecentos gramas de', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([DdRr])enuncias(?![-\\w–\xad])', '\\1enúncias', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria são(?![-\\w–\xad])', '\\1 maioria é', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria estão(?![-\\w–\xad])', '\\1 maioria está', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria vão(?![-\\w–\xad])', '\\1 maioria vai', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria foram(?![-\\w–\xad])', '\\1 maioria foi', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria querem(?![-\\w–\xad])', '\\1 maioria quer', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria fizeram(?![-\\w–\xad])', '\\1 maioria fez', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria (?P<May_1>[a-zA-Z]+[bcdefghijlmnopstx])am(?![-\\w–\xad])', '\\1 maioria \\g<May_1>a', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria (?P<May_2>[a-zA-Z]+)avam(?![-\\w–\xad])', '\\1 maioria \\g<May_2>ava', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria (?P<May_3>[a-zA-Z]+)rão(?![-\\w–\xad])', '\\1 maioria \\g<May_3>rá', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria (?P<May_4>[a-zA-Z]+)zem(?![-\\w–\xad])', '\\1 maioria \\g<May_4>z', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria (?P<May_5>[a-zA-Z]+[bcdefghijlmnopstvx])aram(?![-\\w–\xad])', '\\1 maioria \\g<May_5>o', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria (?P<May_6>[a-zA-Z]+[bcdefghijlmnopsrtvx])eram(?![-\\w–\xad])', '\\1 maioria \\g<May_6>e', 'Verbo deve concordar com o sujeito. Você quis dizer:', 'not m.group("May_6") in excVerbo'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria (?P<May_7>[a-zA-Z]+[bcdefghijlmnopsrtvx])iram(?![-\\w–\xad])', '\\1 maioria \\g<May_7>i', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria não são(?![-\\w–\xad])', '\\1 maioria não é', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria não estão(?![-\\w–\xad])', '\\1 maioria não está', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria não vão(?![-\\w–\xad])', '\\1 maioria não vai', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria não foram(?![-\\w–\xad])', '\\1 maioria não foi', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria não querem(?![-\\w–\xad])', '\\1 maioria não quer', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria não fizeram(?![-\\w–\xad])', '\\1 maioria não fez', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria não (?P<Mao_1>[a-zA-Z]+[bcdefghijlmnopstx])am(?![-\\w–\xad])', '\\1 maioria não \\g<Mao_1>a', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria não (?P<Mao_2>[a-zA-Z]+)avam(?![-\\w–\xad])', '\\1 maioria não \\g<Mao_2>ava', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria não (?P<Mao_3>[a-zA-Z]+)rão(?![-\\w–\xad])', '\\1 maioria não \\g<Mao_3>rá', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria não (?P<Mao_4>[a-zA-Z]+)zem(?![-\\w–\xad])', '\\1 maioria não \\g<Mao_4>z', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria não (?P<Mao_5>[a-zA-Z]+[bcdefghijlmnopstvx])aram(?![-\\w–\xad])', '\\1 maioria não \\g<Mao_5>o', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria não (?P<Mao_6>[a-zA-Z]+[bcdefghijlmnoprstvx])eram(?![-\\w–\xad])', '\\1 maioria não \\g<Mao_6>e', 'Verbo deve concordar com o sujeito. Você quis dizer:', 'not m.group("Mao_6") in excVerbo'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria não (?P<Mao_7>[a-zA-Z]+[bcdefghijlmnoprstvx])iram(?![-\\w–\xad])', '\\1 maioria não \\g<Mao_7>i', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria já são(?![-\\w–\xad])', '\\1 maioria já é', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria já estão(?![-\\w–\xad])', '\\1 maioria já está', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria já vão(?![-\\w–\xad])', '\\1 maioria já vai', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria já foram(?![-\\w–\xad])', '\\1 maioria já foi', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria já querem(?![-\\w–\xad])', '\\1 maioria já quer', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria já fizeram(?![-\\w–\xad])', '\\1 maioria já fez', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria já (?P<Maj_1>[a-zA-Z]+[bcdefghijlmnopstx])am(?![-\\w–\xad])', '\\1 maioria já \\g<Maj_1>a', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria já (?P<Maj_2>[a-zA-Z]+)avam(?![-\\w–\xad])', '\\1 maioria já \\g<Maj_2>ava', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria já (?P<Maj_3>[a-zA-Z]+)rão(?![-\\w–\xad])', '\\1 maioria já \\g<Maj_3>rá', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria já (?P<Maj_4>[a-zA-Z]+)zem(?![-\\w–\xad])', '\\1 maioria já \\g<Maj_4>z', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria já (?P<Maj_5>[a-zA-Z]+[bcdefghijlmnopstvx])aram(?![-\\w–\xad])', '\\1 maioria já \\g<Maj_5>o', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria já (?P<Maj_6>[a-zA-Z]+[bcdefghijlmnoprstvx])eram(?![-\\w–\xad])', '\\1 maioria já \\g<Maj_6>e', 'Verbo deve concordar com o sujeito. Você quis dizer:', 'not m.group("Maj_6") in excVerbo'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria já (?P<Maj_7>[a-zA-Z]+[bcdefghijlmnoprstvx])iram(?![-\\w–\xad])', '\\1 maioria já \\g<Maj_7>i', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria até são(?![-\\w–\xad])', '\\1 maioria até é', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria até estão(?![-\\w–\xad])', '\\1 maioria até está', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria até vão(?![-\\w–\xad])', '\\1 maioria até vai', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria até foram(?![-\\w–\xad])', '\\1 maioria até foi', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria até querem(?![-\\w–\xad])', '\\1 maioria até quer', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria até fizeram(?![-\\w–\xad])', '\\1 maioria até fez', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria até (?P<Mae_1>[a-zA-Z]+[bcdefghijlmnopstx])am(?![-\\w–\xad])', '\\1 maioria até \\g<Mae_1>a', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria até (?P<Mae_2>[a-zA-Z]+)avam(?![-\\w–\xad])', '\\1 maioria até \\g<Mae_2>ava', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria até (?P<Mae_3>[a-zA-Z]+)rão(?![-\\w–\xad])', '\\1 maioria até \\g<Mae_3>rá', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria até (?P<Mae_4>[a-zA-Z]+)zem(?![-\\w–\xad])', '\\1 maioria até \\g<Mae_4>z', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria até (?P<Mae_5>[a-zA-Z]+[bcdefghijlmnopstvx])aram(?![-\\w–\xad])', '\\1 maioria até \\g<Mae_5>o', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria até (?P<Mae_6>[a-zA-Z]+[bcdefghijlmnoprstvx])eram(?![-\\w–\xad])', '\\1 maioria até \\g<Mae_6>e', 'Verbo deve concordar com o sujeito. Você quis dizer:', 'not m.group("Mae_6") in excVerbo'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria até (?P<Mae_7>[a-zA-Z]+[bcdefghijlmnoprstvx])iram(?![-\\w–\xad])', '\\1 maioria até \\g<Mae_7>i', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria se (?P<Max_1>[a-zA-Z]+[bcdefghijlmnopstx])am(?![-\\w–\xad])', '\\1 maioria se \\g<Max_1>a', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria se (?P<Max_2>[a-zA-Z]+)avam(?![-\\w–\xad])', '\\1 maioria se \\g<Max_2>ava', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria se (?P<Max_3>[a-zA-Z]+)rão(?![-\\w–\xad])', '\\1 maioria se \\g<Max_3>rá', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria se (?P<Max_4>[a-zA-Z]+)zem(?![-\\w–\xad])', '\\1 maioria se \\g<Max_4>z', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria se (?P<Max_5>[a-zA-Z]+[bcdefghijlmnopstvx])aram(?![-\\w–\xad])', '\\1 maioria se \\g<Max_5>o', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria se (?P<Max_6>[a-zA-Z]+[bcdefghijlmnopsrtvx])eram(?![-\\w–\xad])', '\\1 maioria se \\g<Max_6>e', 'Verbo deve concordar com o sujeito. Você quis dizer:', 'not m.group("Max_6") in excVerbo'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria se (?P<Max_7>[a-zA-Z]+[bcdefghijlmnoprstvx])iram(?![-\\w–\xad])', '\\1 maioria se \\g<Max_7>i', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria tiveram(?![-\\w–\xad])', '\\1 maioria teve', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria não tiveram(?![-\\w–\xad])', '\\1 maioria não teve', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria já tiveram(?![-\\w–\xad])', '\\1 maioria já teve', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria até tiveram(?![-\\w–\xad])', '\\1 maioria até teve', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria estiveram(?![-\\w–\xad])', '\\1 maioria esteve', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria não estiveram(?![-\\w–\xad])', '\\1 maioria não esteve', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria já estiveram(?![-\\w–\xad])', '\\1 maioria já esteve', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) maioria até estiveram(?![-\\w–\xad])', '\\1 maioria até esteve', 'Verbo deve concordar com o sujeito. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Bem estar(?![-\\w–\xad])', 'Bem-estar', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])o bem estar(?![-\\w–\xad])', 'o bem-estar', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])d([eo]) bem estar(?![-\\w–\xad])', 'd\\1 bem-estar', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Act_2>[a-zA-Z]+)(?![-\\w–\xad])', '= aaGrafia[m.group(1)]', 'Você quis dizer:', 'm.group(1) in acGrafia'],
 ['(?u)(?<![-\\w–.,\xad])([Hh])ora aula(?![-\\w–\xad])', '\\1ora-aula', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Hh])oras aula(?![-\\w–\xad])', '\\1oras-aula', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Hh])oras aulas(?![-\\w–\xad])', '\\1oras-aula', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mas_a>[a-zA-Záâçéêíóôú]+) mas ainda assim (?P<Mas_b>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mas_a>, mas, ainda assim, \\g<Mas_b>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mas_c>[a-zA-Záâçéêíóôú]+), mas ainda assim (?P<Mas_d>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mas_c>, mas, ainda assim, \\g<Mas_d>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mas_e>[a-zA-Záâçéêíóôú]+), mas, ainda assim (?P<Mas_f>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mas_e>, mas, ainda assim, \\g<Mas_f>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mas_g>[a-zA-Záâçéêíóôú]+) mas ainda assim, (?P<Mas_h>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mas_g>, mas, ainda assim, \\g<Mas_h>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mas_i>[a-zA-Záâçéêíóôú]+) mas, ainda assim, (?P<Mas_j>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mas_i>, mas, ainda assim, \\g<Mas_j>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mas_k>[a-zA-Záâçéêíóôú]+), mas ainda assim, (?P<Mas_l>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mas_k>, mas, ainda assim, \\g<Mas_l>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mma_a>[a-zA-Záâçéêíóôú]+) mas mesmo assim (?P<Mma_b>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mma_a>, mas, mesmo assim, \\g<Mma_b>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mma_c>[a-zA-Záâçéêíóôú]+), mas mesmo assim (?P<Mma_d>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mma_c>, mas, mesmo assim, \\g<Mma_d>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mma_e>[a-zA-Záâçéêíóôú]+), mas, mesmo assim (?P<Mma_f>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mma_e>, mas, mesmo assim, \\g<Mma_f>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mma_g>[a-zA-Záâçéêíóôú]+) mas mesmo assim, (?P<Mma_h>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mma_g>, mas, mesmo assim, \\g<Mma_h>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mma_i>[a-zA-Záâçéêíóôú]+) mas, mesmo assim, (?P<Mma_j>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mma_i>, mas, mesmo assim, \\g<Mma_j>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mma_k>[a-zA-Záâçéêíóôú]+), mas mesmo assim, (?P<Mma_l>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mma_k>, mas, mesmo assim, \\g<Mma_l>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mnv_a>[a-zA-Záâçéêíóôú]+) mas na verdade (?P<Mnv_b>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mnv_a>, mas, na verdade, \\g<Mnv_b>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mnv_c>[a-zA-Záâçéêíóôú]+), mas na verdade (?P<Mnv_d>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mnv_c>, mas, na verdade, \\g<Mnv_d>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mnv_e>[a-zA-Záâçéêíóôú]+), mas, na verdade (?P<Mnv_f>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mnv_e>, mas, na verdade, \\g<Mnv_f>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mnv_g>[a-zA-Záâçéêíóôú]+) mas na verdade, (?P<Mnv_h>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mnv_g>, mas, na verdade, \\g<Mnv_h>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mnv_i>[a-zA-Záâçéêíóôú]+) mas, na verdade, (?P<Mnv_j>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mnv_i>, mas, na verdade, \\g<Mnv_j>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mnv_k>[a-zA-Záâçéêíóôú]+), mas na verdade, (?P<Mnv_l>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mnv_k>, mas, na verdade, \\g<Mnv_l>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mad_a>[a-zA-Záâçéêíóôú]+) mas apesar disso (?P<Mad_b>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mad_a>, mas, apesar disso, \\g<Mad_b>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mad_c>[a-zA-Záâçéêíóôú]+), mas apesar disso (?P<Mad_d>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mad_c>, mas, apesar disso, \\g<Mad_d>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mad_e>[a-zA-Záâçéêíóôú]+), mas, apesar disso (?P<Mad_f>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mad_e>, mas, apesar disso, \\g<Mad_f>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mad_g>[a-zA-Záâçéêíóôú]+) mas apesar disso, (?P<Mad_h>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mad_g>, mas, apesar disso, \\g<Mad_h>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mad_i>[a-zA-Záâçéêíóôú]+) mas, apesar disso, (?P<Mad_j>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mad_i>, mas, apesar disso, \\g<Mad_j>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mad_k>[a-zA-Záâçéêíóôú]+), mas apesar disso, (?P<Mad_l>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mad_k>, mas, apesar disso, \\g<Mad_l>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mnf_a>[a-zA-Záâçéêíóôú]+) mas no fundo (?P<Mnf_b>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mnf_a>, mas, no fundo, \\g<Mnf_b>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mnf_c>[a-zA-Záâçéêíóôú]+), mas no fundo (?P<Mnf_d>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mnf_c>, mas, no fundo, \\g<Mnf_d>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mnf_e>[a-zA-Záâçéêíóôú]+), mas, no fundo (?P<Mnf_f>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mnf_e>, mas, no fundo, \\g<Mnf_f>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mnf_g>[a-zA-Záâçéêíóôú]+) mas no fundo, (?P<Mnf_h>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mnf_g>, mas, no fundo, \\g<Mnf_h,', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mnf_i>[a-zA-Záâçéêíóôú]+) mas, no fundo, (?P<Mnf_j>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mnf_i>, mas, no fundo, \\g<Mnf_j>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mnf_k>[a-zA-Záâçéêíóôú]+), mas no fundo, (?P<Mnf_l>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mnf_k>, mas, no fundo, \\g<Mnf_l>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mmt_a>[a-zA-Záâçéêíóôú]+) mas ao mesmo tempo (?P<Mmt_b>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mmt_a>, mas, ao mesmo tempo, \\g<Mmt_b>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mmt_c>[a-zA-Záâçéêíóôú]+), mas ao mesmo tempo (?P<Mmt_d>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mmt_c>, mas, ao mesmo tempo, \\g<Mmt_d>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mmt_e>[a-zA-Záâçéêíóôú]+), mas, ao mesmo tempo (?P<Mmt_f>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mmt_e>, mas, ao mesmo tempo, \\g<Mmt_f>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mmt_g>[a-zA-Záâçéêíóôú]+) mas ao mesmo tempo, (?P<Mmt_h>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mmt_g>, mas, ao mesmo tempo, \\g<Mmt_h>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mmt_i>[a-zA-Záâçéêíóôú]+) mas, ao mesmo tempo, (?P<Mmt_j>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mmt_i>, mas, ao mesmo tempo, \\g<Mmt_j>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mmt_k>[a-zA-Záâçéêíóôú]+), mas ao mesmo tempo, (?P<Mmt_l>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mmt_k>, mas, ao mesmo tempo, \\g<Mmt_l>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mmt_a>[a-zA-Záâçéêíóôú]+) mas em contrapartida (?P<Mmt_b>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mmt_a>, mas, em contrapartida, \\g<Mmt_b>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mmt_c>[a-zA-Záâçéêíóôú]+), mas em contrapartida (?P<Mmt_d>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mmt_c>, mas, em contrapartida, \\g<Mmt_d>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mmt_e>[a-zA-Záâçéêíóôú]+), mas, em contrapartida (?P<Mmt_f>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mmt_e>, mas, em contrapartida, \\g<Mmt_f>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mmt_g>[a-zA-Záâçéêíóôú]+) mas em contrapartida, (?P<Mmt_h>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mmt_g>, mas, em contrapartida, \\g<Mmt_h>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mmt_i>[a-zA-Záâçéêíóôú]+) mas, em contrapartida, (?P<Mmt_j>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mmt_i>, mas, em contrapartida, \\g<Mmt_j>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mmt_k>[a-zA-Záâçéêíóôú]+), mas em contrapartida, (?P<Mmt_l>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mmt_k>, mas, em contrapartida, \\g<Mmt_l>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mpl_a>[a-zA-Záâçéêíóôú]+) mas por outro lado (?P<Mpl_b>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mpl_a>, mas, por outro lado, \\g<Mpl_b>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mpl_c>[a-zA-Záâçéêíóôú]+), mas por outro lado (?P<Mpl_d>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mpl_c>, mas, por outro lado, \\g<Mpl_d>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mpl_e>[a-zA-Záâçéêíóôú]+), mas, por outro lado (?P<Mpl_f>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mpl_e>, mas, por outro lado, \\g<Mpl_f>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mpl_g>[a-zA-Záâçéêíóôú]+) mas por outro lado, (?P<Mpl_h>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mpl_g>, mas, por outro lado, \\g<Mpl_h>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mpl_i>[a-zA-Záâçéêíóôú]+) mas, por outro lado, (?P<Mpl_j>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mpl_i>, mas, por outro lado, \\g<Mpl_j>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mpl_k>[a-zA-Záâçéêíóôú]+), mas por outro lado, (?P<Mpl_l>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mpl_k>, mas, por outro lado, \\g<Mpl_l>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mrt_a>[a-zA-Záâçéêíóôú]+) mas de repente (?P<Mrt_b>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mrt_a>, mas, de repente, \\g<Mrt_b>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mrt_c>[a-zA-Záâçéêíóôú]+), mas de repente (?P<Mrt_d>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mrt_c>, mas, de repente, \\g<Mrt_d>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mrt_e>[a-zA-Záâçéêíóôú]+), mas, de repente (?P<Mrt_f>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mrt_e>, mas, de repente, \\g<Mrt_f>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mrt_g>[a-zA-Záâçéêíóôú]+) mas de repente, (?P<Mrt_h>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mrt_g>, mas, de repente, \\g<Mrt_h>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mrt_i>[a-zA-Záâçéêíóôú]+) mas, de repente, (?P<Mrt_j>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mrt_i>, mas, de repente, \\g<Mrt_j>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mrt_k>[a-zA-Záâçéêíóôú]+), mas de repente, (?P<Mrt_l>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mrt_k>, mas, de repente, \\g<Mrt_l>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mqf_a>[a-zA-Záâçéêíóôú]+) mas de qualquer forma (?P<Mqf_b>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mqf_a>, mas, de qualquer forma, \\g<Mqf_b>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mqf_c>[a-zA-Záâçéêíóôú]+), mas de qualquer forma (?P<Mqf_d>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mqf_c>, mas, de qualquer forma, \\g<Mqf_d>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mqf_e>[a-zA-Záâçéêíóôú]+), mas, de qualquer forma (?P<Mqf_f>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mqf_e>, mas, de qualquer forma, \\g<Mqf_f>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mqf_g>[a-zA-Záâçéêíóôú]+) mas de qualquer forma, (?P<Mqf_h>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mqf_g>, mas, de qualquer forma, \\g<Mqf_h>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mqf_i>[a-zA-Záâçéêíóôú]+) mas, de qualquer forma, (?P<Mqf_j>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mqf_i>, mas, de qualquer forma, \\g<Mqf_j>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mqf_k>[a-zA-Záâçéêíóôú]+), mas de qualquer forma, (?P<Mqf_l>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mqf_k>, mas, de qualquer forma, \\g<Mqf_l>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mge_a>[a-zA-Záâçéêíóôú]+) mas em geral (?P<Mge_b>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mge_a>, mas, em geral, \\g<Mge_b>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mge_c>[a-zA-Záâçéêíóôú]+), mas em geral (?P<Mge_d>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mge_c>, mas, em geral, \\g<Mge_d>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mge_e>[a-zA-Záâçéêíóôú]+), mas, em geral (?P<Mge_f>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mge_e>, mas, em geral, \\g<Mge_f>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mge_g>[a-zA-Záâçéêíóôú]+) mas em geral, (?P<Mge_h>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mge_g>, mas, em geral, \\g<Mge_h>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mge_i>[a-zA-Záâçéêíóôú]+) mas, em geral, (?P<Mge_j>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mge_i>, mas, em geral, \\g<Mge_j>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mge_k>[a-zA-Záâçéêíóôú]+), mas em geral, (?P<Mge_l>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mge_k>, mas, em geral, \\g<Mge_l>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mpa_a>[a-zA-Záâçéêíóôú]+) mas na prática (?P<Mpa_b>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mpa_a>, mas, na prática, \\g<Mpa_b>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mpa_c>[a-zA-Záâçéêíóôú]+), mas na prática (?P<Mpa_d>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mpa_c>, mas, na prática, \\g<Mpa_d>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mpa_e>[a-zA-Záâçéêíóôú]+), mas, na prática (?P<Mpa_f>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mpa_e>, mas, na prática, \\g<Mpa_f>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mpa_g>[a-zA-Záâçéêíóôú]+) mas na prática, (?P<Mpa_h>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mpa_g>, mas, na prática, \\g<Mpa_h>', 'Faltaram as pausas? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mpa_i>[a-zA-Záâçéêíóôú]+) mas, na prática, (?P<Mpa_j>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mpa_i>, mas, na prática, \\g<Mpa_j>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mpa_k>[a-zA-Záâçéêíóôú]+), mas na prática, (?P<Mpa_l>[a-zA-Záâçéêíóôú]+)(?![-\\w–\xad])', '\\g<Mpa_k>, mas, na prática, \\g<Mpa_l>', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mms_1>[a-zA-Záâçéêíóôú]+) mas (?P<Mms_2>[a-z]+[aelsz])mente(?![-\\w–\xad])', '\\g<Mms_1>, mas \\g<Mms_2>mente', 'Faltou a pausa? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ideo(?![-\\w–\xad])', '\\1ídeo', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])r condicionado(?![-\\w–\xad])', '\\1r-condicionado', 'Você quis dizer:', 'not "parelho de ar condicionado" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])parelh(o|os) de ([Aa])r-condicionado(?![-\\w–\xad])', '\\1parelh\\2 de \\3r condicionado', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])parelh(o|os) de ([Aa])res-condicionados(?![-\\w–\xad])', '\\1parelh\\2 de \\3r condicionado', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])r condicionados(?![-\\w–\xad])', '\\1res-condicionados', 'O plural de ar-condicionado é ares-condicionados.', 'not "parelho de ar condicionado" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])parelh(o|os) de ([Aa])r condicionados(?![-\\w–\xad])', '\\1parelh\\2 de \\3r condicionado', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmo_0>[a-zA-Z]+)s (?P<Pmo_1>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_0") in aaSingular and m.group("Pmo_1") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmo_2>[a-zA-Z]+) (?P<Pmo_3>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_2") in aaSingular and m.group("Pmo_3") in plvrMasco and not m.group("Pmo_2") in "-Da-da-"'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])a (?P<Dda_1>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '\\1o \\2\\n\\1os \\2s\\n\\1á \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dda_1") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmo_4>[a-zA-Z]+) (?P<Pmo_5>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_4") in acSingular and m.group("Pmo_5") in plvrMasco and not (m.group("Pmo_4") in "-A-" and m.group("Pmo_5") in excplMasco) and not m.group("Pmo_4") in "-Da-da-"'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])a (?P<Dda_2>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '\\1o \\2\\n\\1á \\2', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dda_2") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmo_6>[a-zA-Z]+)s (?P<Pmo_7>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_6") in acSingular and m.group("Pmo_7") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pmo_8>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "ários " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_8") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])árias (?P<Pmo_9>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "ários " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_9") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitas (?P<Pmo_10>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "uitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_10") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uita (?P<Pmo_11>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "\\n" + m.group(1) + "uitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_11") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])Muit[ao] (?P<Pmo_12>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= "Muito " + m.group(2) + "\\nMuitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_12") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])muita (?P<Pmo_30>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= "muito " + m.group(2) + "\\nmuitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_30") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])muito (?P<Pmo_31>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= "muito " + m.group(2) + "\\nmuitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_31") in plvrMasco and not m.group("Pmo_31") in exMuiMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pmo_13>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "\\n" + m.group(1) + "uitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_13") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucas (?P<Pmo_14>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "oucos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_14") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouca (?P<Pmo_15>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "ouco " + m.group(2) + "\\n" + m.group(1) + "oucos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_15") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pmo_16>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "ouco " + m.group(2) + "\\n" + m.group(1) + "oucos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_16") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pmo_17>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "ouco " + m.group(2) + "\\n" + m.group(1) + "oucos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_17") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odas (?P<Pmo_14>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "odos os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_14") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])oda (?P<Pmo_15>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "odo " + m.group(2) + "\\n" + m.group(1) + "odos os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_15") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pmo_16>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "odo " + m.group(2) + "\\n" + m.group(1) + "odos os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_16") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pmo_17>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "odo " + m.group(2) + "\\n" + m.group(1) + "odos os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_17") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmo_18>[a-zA-Z]+)s mesmos (?P<Pmo_19>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_18") in abSingular and m.group("Pmo_19") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmo_20>[a-zA-Z]+)s mesmas (?P<Pmo_21>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_20") in acSingular and m.group("Pmo_21") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmo_22>[a-zA-Z]+) mesmo (?P<Pmo_23>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_22") in abSingular and m.group("Pmo_23") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmo_24>[a-zA-Z]+) mesma (?P<Pmo_25>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_24") in acSingular and m.group("Pmo_25") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmo_26>[a-zA-Z]+) mesma (?P<Pmo_27>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_26") in acSingular and m.group("Pmo_27") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmo_28>[a-zA-Z]+)s mesmas (?P<Pmo_29>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_28") in acSingular and m.group("Pmo_29") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmo_a>[a-zA-Z]+) (?P<Pmo_b>[a-zA-Záâãçéêíóôú]+)inhos(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "inho\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_a") in aaSingular and not m.group("Pmo_b") in excInho'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmo_c>[a-zA-Z]+)s (?P<Pmo_d>[a-zA-Záâãçéêíóôú]+)inho(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "inho\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_c") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmo_e>[a-zA-Z]+) (?P<Pmo_f>[a-zA-Záâãçéêíóôú]+)inho(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "inho"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_e") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmo_g>[a-zA-Z]+)s (?P<Pmo_h>[a-zA-Záâãçéêíóôú]+)ismo(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ismo\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ismos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_g") in aaSingular and not "icroo" in m.group("Pmo_h")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmo_i>[a-zA-Z]+) (?P<Pmo_j>[a-zA-Záâãçéêíóôú]+)ismos(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ismo\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ismos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_i") in aaSingular and not "icroo" in m.group("Pmo_j")'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmo_k>[a-zA-Z]+) (?P<Pmo_l>[a-zA-Záâãçéêíóôú]+)ismo(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ismo"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmo_k") in acSingular and not "icroo" in m.group("Pmo_l")'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Pum_a>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_a") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Pum_b>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_b") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pum_c>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_c") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pum_d>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_d") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pum_e>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_e") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pum_f>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_f") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pum_g>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_g") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pum_h>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_h") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([U])m (?P<Pum_i>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "\\n" + m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_i") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pum_j>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_j") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pum_k>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_k") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pum_l>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_l") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pum_m>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_m") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pum_n>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_n") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pum_o>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "\\n" + m.group(1) + "lguns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_o") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pum_p>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_p") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pum_q>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_q") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pum_r>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_r") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pum_s>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_s") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pum_t>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_t") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pum_u>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "\\n" + m.group(1) + "enhuns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_u") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pum_v>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_v") in plvrMasco and not m.group("Pum_v") in excplMasco'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pum_w>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_w") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pum_x>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_x") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pum_y>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pum_y") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Poum_0>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= "Um " + m.group(2) + "\\nUns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Poum_0") in plvrMasco'],
 ['(?u)\\b([,]) um (?P<Poum_1>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= ", um " + m.group(2) + "\\n, uns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Poum_1") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Poum_0>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Poum_0") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Poum_0>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Poum_0") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Poum_2>[a-zA-Záâãçéêíóôú]+) um (?P<Poum_3>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Poum_3") in plvrMasco and not m.group("Poum_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Poum_4>[a-zA-Záâãçéêíóôú]+) e um (?P<Poum_5>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "\\n" + m.group(1) + " e uns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Poum_5") in plvrMasco and not m.group("Poum_4") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Poum_6>[a-zA-Záâãçéêíóôú]+) e um (?P<Poum_7>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Poum_7") in plvrMasco and m.group("Poum_6").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Poum_8>[a-zA-Záâãçéêíóôú]+) e uns (?P<Poum_9>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Poum_9") in plvrMasco and m.group("Poum_8").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Poum_10>[a-zA-Záâãçéêíóôú]+) (?P<Poum_11>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Poum_11") in plvrMasco and m.group("Poum_10").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Poum_12>[0-9]+) (?P<Poum_13>[a-záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Poum_13") in plvrMasco and not m.group("Poum_12") in "00000000001" and not excYmasco.search(TEXT)'],
 ['(?u)\\b([.])(?P<Poum_14>[0-9][0-9][0-9]) (?P<Poum_15>[a-záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "s"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Poum_15") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Poum_16>[0-9]+) (?P<Poum_17>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2)', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Poum_17") in plvrMasco and m.group("Poum_16") in "00000000001" and not excYmasco.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Poum_17>[a-zA-Záâãçéêíóôú]+)as (?P<Poum_18>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Poum_18") in plvrMasco and m.group("Poum_17").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Poum_19>[a-zA-Záâãçéêíóôú]+)as (?P<Poum_20>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Poum_20") in plvrMasco and m.group("Poum_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Poum_21>[01][,][0-9]+) (?P<Poum_22>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '\\1 \\2', 'Plural só a partir de 2. Você quis dizer:', 'm.group("Poum_22") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Poum_23>[2-9][,][0-9]+) (?P<Poum_24>[a-záâãçéêíóôú]+[o])(?![-\\w–\xad])', '\\1 \\2s', 'Você quis dizer:', 'm.group("Poum_24") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Poum_25>[1-9][0-9][,][0-9]+) (?P<Poum_26>[a-záâãçéêíóôú]+[o])(?![-\\w–\xad])', '\\1 \\2s', 'Você quis dizer:', 'm.group("Poum_26") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Poum_27>[1-9][0-9][0-9][,][0-9]+) (?P<Poum_28>[a-záâãçéêíóôú]+[o])(?![-\\w–\xad])', '\\1 \\2s', 'Você quis dizer:', 'm.group("Poum_28") in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxmo_0>[a-zA-Z]+)s (?P<Pxmo_1>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_0") in aaSingular and m.group("Pxmo_1") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxmo_2>[a-zA-Z]+) (?P<Pxmo_3>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_2") in aaSingular and m.group("Pxmo_3") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxmo_4>[a-zA-Z]+) (?P<Pxmo_5>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_4") in acSingular and m.group("Pxmo_5") in plvrMasxo and not (m.group("Pxmo_4") in "-A-" and m.group("Pxmo_5") in excplMasco)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxmo_6>[a-zA-Z]+)s (?P<Pxmo_7>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_6") in acSingular and m.group("Pxmo_7") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pxmo_8>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "ários " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_8") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])árias (?P<Pxmo_9>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "ários " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_9") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitas (?P<Pxmo_10>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "uitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_10") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uita (?P<Pxmo_11>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "\\n" + m.group(1) + "uitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_11") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao] (?P<Pxmo_12>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "\\n" + m.group(1) + "uitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_12") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pxmo_13>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "\\n" + m.group(1) + "uitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_13") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucas (?P<Pxmo_14>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "oucos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_14") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouca (?P<Pxmo_15>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "ouco " + m.group(2) + "\\n" + m.group(1) + "oucos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_15") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pxmo_16>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "ouco " + m.group(2) + "\\n" + m.group(1) + "oucos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_16") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pxmo_17>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "ouco " + m.group(2) + "\\n" + m.group(1) + "oucos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_17") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odas (?P<Pxmo_14>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "odos os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_14") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])oda (?P<Pxmo_15>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "odo " + m.group(2) + "\\n" + m.group(1) + "odos os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_15") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pxmo_16>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "odo " + m.group(2) + "\\n" + m.group(1) + "odos os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_16") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pxmo_17>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "odo " + m.group(2) + "\\n" + m.group(1) + "odos os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_17") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxmo_18>[a-zA-Z]+)s mesmos (?P<Pxmo_19>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_18") in abSingular and m.group("Pxmo_19") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxmo_20>[a-zA-Z]+)s mesmas (?P<Pxmo_21>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_20") in acSingular and m.group("Pxmo_21") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxmo_22>[a-zA-Z]+) mesmo (?P<Pxmo_23>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_22") in abSingular and m.group("Pxmo_23") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxmo_24>[a-zA-Z]+) mesma (?P<Pxmo_25>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_24") in acSingular and m.group("Pxmo_25") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxmo_26>[a-zA-Z]+) mesma (?P<Pxmo_27>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_26") in acSingular and m.group("Pxmo_27") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxmo_28>[a-zA-Z]+)s mesmas (?P<Pxmo_29>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_28") in acSingular and m.group("Pxmo_29") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxmo_a>[a-zA-Z]+) (?P<Pxmo_b>[a-zA-Záâãçéêíóôú]+)inhos(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "inho\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_a") in aaSingular and not m.group("Pxmo_b") in excInho'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxmo_c>[a-zA-Z]+)s (?P<Pxmo_d>[a-zA-Záâãçéêíóôú]+)inho(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "inho\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_c") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxmo_e>[a-zA-Z]+) (?P<Pxmo_f>[a-zA-Záâãçéêíóôú]+)inho(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "inho"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxmo_e") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Pxum_a>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_a") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Pxum_b>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_b") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pxum_c>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_c") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pxum_d>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_d") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pxum_e>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_e") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pxum_f>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_f") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pxum_g>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_g") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pxum_h>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_h") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([U])m (?P<Pxum_i>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "\\n" + m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_i") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pxum_j>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_j") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pxum_k>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_k") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pxum_l>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_l") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pxum_m>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_m") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pxum_n>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_n") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pxum_o>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "\\n" + m.group(1) + "lguns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_o") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pxum_p>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_p") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pxum_q>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_q") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pxum_r>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_r") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pxum_s>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_s") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pxum_t>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_t") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pxum_u>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "\\n" + m.group(1) + "enhuns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_u") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pxum_v>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_v") in plvrMasxo and not m.group("Pxum_v") in excplMasco'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pxum_w>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_w") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pxum_x>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_x") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pxum_y>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_y") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Pxum_0>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= "Um " + m.group(2) + "\\nUns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_0") in plvrMasxo'],
 ['(?u)\\b([,]) um (?P<Pxum_1>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= ", um " + m.group(2) + "\\n, uns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_1") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Pxum_0>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_0") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Pxum_0>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_0") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxum_2>[a-zA-Záâãçéêíóôú]+) um (?P<Pxum_3>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_3") in plvrMasxo and not m.group("Pxum_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxum_4>[a-zA-Záâãçéêíóôú]+) e um (?P<Pxum_5>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "\\n" + m.group(1) + " e uns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_5") in plvrMasxo and not m.group("Pxum_4") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxum_6>[a-zA-Záâãçéêíóôú]+) e um (?P<Pxum_7>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_7") in plvrMasxo and m.group("Pxum_6").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxum_8>[a-zA-Záâãçéêíóôú]+) e uns (?P<Pxum_9>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_9") in plvrMasxo and m.group("Pxum_8").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxum_10>[a-zA-Záâãçéêíóôú]+) (?P<Pxum_11>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_11") in plvrMasxo and m.group("Pxum_10").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxum_12>[0-9]+) (?P<Pxum_13>[a-záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pxum_13") in plvrMasxo and not m.group("Pxum_12") in "00000000001" and not excYmasco.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pxum_14>[0-9][0-9][0-9]) (?P<Pxum_15>[a-záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "s"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pxum_15") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxum_16>[0-9]+) (?P<Pxum_17>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2)', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pxum_17") in plvrMasxo and m.group("Pxum_16") in "00000000001" and not excYMasco.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxum_17>[a-zA-Záâãçéêíóôú]+)as (?P<Pxum_18>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_18") in plvrMasxo and m.group("Pxum_17").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pxum_19>[a-zA-Záâãçéêíóôú]+)as (?P<Pxum_20>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pxum_20") in plvrMasxo and m.group("Pxum_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pma_0>[a-zA-Z]+)s (?P<Pma_1>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_0") in aaSingular and m.group("Pma_1") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pma_2>[a-zA-Z]+) (?P<Pma_3>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_2") in aaSingular and m.group("Pma_3") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pma_4>[a-zA-Z]+) (?P<Pma_5>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_4") in acSingular and m.group("Pma_5") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pma_6>[a-zA-Z]+)s (?P<Pma_7>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_6") in acSingular and m.group("Pma_7") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pma_8>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "ários " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_8") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])árias (?P<Pma_9>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "ários " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_9") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitas (?P<Pma_10>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "uitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_10") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uita (?P<Pma_11>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "\\n" + m.group(1) + "uitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_11") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao] (?P<Pma_12>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "\\n" + m.group(1) + "uitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_12") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pma_13>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "\\n" + m.group(1) + "uitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_13") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucas (?P<Pma_14>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "oucos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_14") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouca (?P<Pma_15>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "ouco " + m.group(2) + "\\n" + m.group(1) + "oucos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_15") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pma_16>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "ouco " + m.group(2) + "\\n" + m.group(1) + "oucos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_16") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pma_17>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "ouco " + m.group(2) + "\\n" + m.group(1) + "oucos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_17") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odas (?P<Pma_14>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "odos os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_14") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])oda (?P<Pma_15>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "odo " + m.group(2) + "\\n" + m.group(1) + "odos os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_15") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pma_16>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "odo " + m.group(2) + "\\n" + m.group(1) + "odos os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_16") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pma_17>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "odo " + m.group(2) + "\\n" + m.group(1) + "odos os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_17") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pma_18>[a-zA-Z]+)s mesmos (?P<Pma_19>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_18") in abSingular and m.group("Pma_19") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pma_20>[a-zA-Z]+)s mesmas (?P<Pma_21>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_20") in acSingular and m.group("Pma_21") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pma_22>[a-zA-Z]+) mesmo (?P<Pma_23>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_22") in abSingular and m.group("Pma_23") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pma_24>[a-zA-Z]+) mesma (?P<Pma_25>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_24") in acSingular and m.group("Pma_25") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pma_26>[a-zA-Z]+) mesma (?P<Pma_27>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_26") in acSingular and m.group("Pma_27") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pma_28>[a-zA-Z]+)s mesmas (?P<Pma_29>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pma_28") in acSingular and m.group("Pma_29") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Pmm_a>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_a") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Pmm_b>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_b") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pmm_c>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_c") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pmm_d>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_d") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pmm_e>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_e") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pmm_f>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_f") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pmm_g>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_g") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pmm_h>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_h") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([U])m (?P<Pmm_i>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "\\n" + m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_i") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pmm_j>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_j") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pmm_k>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_k") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pmm_l>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_l") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pmm_m>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_m") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pmm_n>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_n") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pmm_o>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "\\n" + m.group(1) + "lguns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_o") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pmm_p>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_p") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pmm_q>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_q") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pmm_r>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_r") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pmm_s>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_s") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pmm_t>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_t") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pmm_u>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "\\n" + m.group(1) + "enhuns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_u") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pmm_v>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_v") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pmm_w>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_w") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pmm_x>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_x") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pmm_y>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmm_y") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Pomm_0>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= "Um " + m.group(2) + "\\nUns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pomm_0") in plvrMasca'],
 ['(?u)\\b([,]) um (?P<Pomm_1>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= ", um " + m.group(2) + "\\n, uns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pomm_1") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Pomm_0>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pomm_0") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Pomm_0>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pomm_0") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pomm_2>[a-zA-Záâãçéêíóôú]+) um (?P<Pomm_3>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pomm_3") in plvrMasca and not m.group("Pomm_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pomm_4>[a-zA-Záâãçéêíóôú]+) e um (?P<Pomm_5>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "\\n" + m.group(1) + " e uns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pomm_5") in plvrMasca and not m.group("Pomm_4") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pomm_6>[a-zA-Záâãçéêíóôú]+) e um (?P<Pomm_7>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pomm_7") in plvrMasca and m.group("Pomm_6").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pomm_8>[a-zA-Záâãçéêíóôú]+) e uns (?P<Pomm_9>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pomm_9") in plvrMasca and m.group("Pomm_8").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pomm_10>[a-zA-Záâãçéêíóôú]+) (?P<Pomm_11>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pomm_11") in plvrMasca and m.group("Pomm_10").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pomm_12>[0-9]+) (?P<Pomm_13>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pomm_13") in plvrMasca and not m.group("Pomm_12") in "00000000001" and not excYmasca.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pomm_14>[0-9][0-9][0-9]) (?P<Pomm_15>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "s"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pomm_15") in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pomm_16>[0-9]+) (?P<Pomm_17>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2)', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pomm_17") in plvrMasca and m.group("Pomm_16") in "00000000001" and not excYmasca.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pomm_17>[a-zA-Záâãçéêíóôú]+)as (?P<Pomm_18>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pomm_18") in plvrMasca and m.group("Pomm_17").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pomm_19>[a-zA-Záâãçéêíóôú]+)as (?P<Pomm_20>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pomm_20") in plvrMasca and m.group("Pomm_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_a>[a-zA-Z]+) (?P<Pfto_b>[a-zA-Zç]+o)s(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_a") in aaSingular and m.group("Pfto_b") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_c>[a-zA-Z]+)s (?P<Pfto_d>[a-zA-Zç]+o)(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_c") in aaSingular and m.group("Pfto_d") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_e>[a-zA-Z]+) (?P<Pfto_f>[a-zA-Zç]+o)(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_e") in abSingular and m.group("Pfto_f") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pfto_8>[a-zA-Záâãçéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_8") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pfto_9>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_9") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitos (?P<Pfto_10>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= m.group(1) + "uitas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_10") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uito (?P<Pfto_11>[a-zA-Záâãçéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "\\n" + m.group(1) + "uitas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_11") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao] (?P<Pfto_12>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "\\n" + m.group(1) + "uitas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_12") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pfto_13>[a-zA-Záâãçéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "\\n" + m.group(1) + "uitas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_13") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucos (?P<Pfto_14>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= m.group(1) + "oucas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_14") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouco (?P<Pfto_15>[a-zA-Záâãçéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "\\n" + m.group(1) + "oucas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_15") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pfto_16>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "\\n" + m.group(1) + "oucas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_16") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pfto_17>[a-zA-Záâãçéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "\\n" + m.group(1) + "oucas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_17") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_18>[a-zA-Z]+)s mesmos (?P<Pfto_19>[a-zA-Záâãçéêíóôú]+o)(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_18") in abSingular and m.group("Pfto_19") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_20>[a-zA-Z]+)s mesmas (?P<Pfto_21>[a-zA-Záâãçéêíóôú]+o)(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_20") in acSingular and m.group("Pfto_21") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_22>[a-zA-Z]+) mesmo (?P<Pfto_23>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_22") in abSingular and m.group("Pfto_23") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_24>[a-zA-Z]+) mesma (?P<Pfto_25>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_24") in acSingular and m.group("Pfto_25") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_26>[a-zA-Z]+) mesmo (?P<Pfto_27>[a-zA-Záâãçéêíóôú]+o)(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_26") in abSingular and m.group("Pfto_27") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_28>[a-zA-Z]+)s mesmos (?P<Pfto_29>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_28") in abSingular and m.group("Pfto_29") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Pfto_30>[a-zA-Záâãçéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_30") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Pfto_31>[a-zA-Záâãéêíóôú]+o)s(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "\\n" + m.group(1) + "mas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_31") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)mas (?P<Pfto_32>[a-zA-Záâãéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "\\n" + m.group(1) + "mas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_32") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfto_33>[a-zA-Záâãéêíóôú]+o)s(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "\\n" + m.group(1) + "mas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_33") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfto_34>[a-zA-Záâãéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "\\n" + m.group(1) + "mas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_34") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfto_35>[a-zA-Záâãéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_35") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfto_36>[a-zA-Záâãéêíóôú]+o)s(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_36") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Pfto_37>[a-zA-Záâãéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_37") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pfto_38>[a-zA-Záâãéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_38") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pfto_39>[a-zA-Záâãéêíóôú]+o)s(?![-\\w–\xad])', '= "Uma " + m.group(2) + "\\nUmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_39") in plvrFemo'],
 ['(?u)\\b([,]) uma (?P<Pfto_40>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= ", uma " + m.group(2) + "\\n, umas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_40") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pfto_41>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_41") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pfto_42>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_42") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_43>[a-zA-Záâãçéêíóôú]+) uma (?P<Pfto_44>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "\\n" + m.group(1) + " umas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pfto_43") in "-E-e-" and m.group("Pfto_44") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_45>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pfto_46>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "\\n" + m.group(1) + " e umas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pfto_45") in numEfem and m.group("Pfto_46") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_47>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pfto_48>[a-zA-Záâãçéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_47").lower() in numEfem and m.group("Pfto_48") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_49>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pfto_50>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_49").lower() in numEfem and m.group("Pfto_50") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_51>[a-zA-Záâãçéêíóôú]+) (?P<Pfto_52>[a-zA-Záâãçéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_51").lower() in numFem and m.group("Pfto_52") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_53>[0-9]+) (?P<Pfto_54>[a-zA-Záâãçéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pfto_53") in "00000000001" and not excYmasco.search(TEXT) and m.group("Pfto_54") in plvrFemo'],
 ['(?u)\\b([.])(?P<Pfto_55>[0-9][0-9][0-9]) (?P<Pfto_56>[a-zA-Záâãçéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(4) + "nças"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pfto_56") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_57>[0-9]+) (?P<Pfto_58>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2)', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pfto_57") in "00000000001" and not excYmasco.search(TEXT) and m.group("Pfto_58") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_59>[a-zA-Záâãçéêíóôú]+)os (?P<Pfto_60>[a-zA-Záâãçéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_59").lower() in nuMfmoas and m.group("Pfto_60") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfto_61>[a-zA-Záâãçéêíóôú]+)os (?P<Pfto_62>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_61").lower() in nuMfmoas and m.group("Pfto_62") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pfto_63>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= m.group(1) + "odas as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_63") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pfto_64>[a-zA-Záâãçéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "\\n" + m.group(1) + "odas as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_64") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pfto_65>[a-zA-Záâãçéêíóôú]+o)s(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "\\n" + m.group(1) + "odas as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_65") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pfto_66>[a-zA-Záâãçéêíóôú]+o)(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "\\n" + m.group(1) + "odas as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfto_66") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_0>[a-zA-Z]+)s (?P<Pfa_1>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_0") in aaSingular and m.group("Pfa_1") in plvrFema and not "estes sua" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_2>[a-zA-Z]+) (?P<Pfa_3>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_2") in aaSingular and m.group("Pfa_3") in plvrFema and not "este sua" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_4>[a-zA-Z]+) (?P<Pfa_5>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_4") in abSingular and m.group("Pfa_5") in plvrFema and not (m.group("Pfa_4") in "Oo" and m.group("Pfa_5") in excplFema) and not "este sua" in TEXT and not "rimeiro minha" in TEXT and not (m.group("Pfa_5") == "camisa" and excamisa.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_6>[a-zA-Z]+)s (?P<Pfa_7>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_6") in abSingular and m.group("Pfa_7") in plvrFema and not (m.group("Pfa_6") in "Oo" and m.group("Pfa_7") in excplFema)'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pfa_8>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_8") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pfa_9>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_9") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitos (?P<Pfa_10>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "s\\n" + m.group(1) + "uitas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_10") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uita (?P<Pfa_12>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "\\n" + m.group(1) + "uita " + m.group(2) + "\\n" + m.group(1) + "uitas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_12") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pfa_13>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "\\n" + m.group(1) + "uita " + m.group(2) + "\\n" + m.group(1) + "uitas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_13") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucos (?P<Pfa_14>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "oucas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_14") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pfa_16>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "\\n" + m.group(1) + "oucas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_16") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pfa_17>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "\\n" + m.group(1) + "oucas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_17") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pfa_54>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "odas as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_54") in plvrFema and not " a todos " + m.group("Pfa_54") in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pfa_55>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "\\n" + m.group(1) + "odas as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_55") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pfa_56>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "\\n" + m.group(1) + "odas as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_56") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pfa_57>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "\\n" + m.group(1) + "odas as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_57") in plvrFema and not " a todos " + m.group("Pfa_57") in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_18>[a-zA-Z]+)s mesmos (?P<Pfa_19>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_18") in abSingular and m.group("Pfa_19") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_20>[a-zA-Z]+)s mesmas (?P<Pfa_21>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_20") in acSingular and m.group("Pfa_21") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_22>[a-zA-Z]+) mesmo (?P<Pfa_23>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_22") in abSingular and m.group("Pfa_23") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_24>[a-zA-Z]+) mesma (?P<Pfa_25>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_24") in acSingular and m.group("Pfa_25") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_26>[a-zA-Z]+) mesmo (?P<Pfa_27>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_26") in abSingular and m.group("Pfa_27") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_28>[a-zA-Z]+)s mesmos (?P<Pfa_29>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_28") in abSingular and m.group("Pfa_29") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_a>[a-zA-Z]+) (?P<Pfa_b>[a-zA-Záâãéêíóôú]+)([aeiou])nças(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "nça\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_a") in aaSingular and not m.group("Pfa_b") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_c>[a-zA-Z]+)s (?P<Pfa_d>[a-zA-Záâãéêíóôú]+)([aeiou])nça(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "nça\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_c") in aaSingular and not m.group("Pfa_d") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_e>[a-zA-Z]+) (?P<Pfa_f>[a-zA-Záâãéêíóôú]+)([aeiou])nça(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "nça"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_e") in abSingular and not m.group("Pfa_f") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pfaa_8>[a-zA-Záâãçéêíóôú]+[aeiou])nça(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pfaa_8") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pfaa_9>[a-zA-Záâãçéêíóôú]+[aeiou])nças(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pfaa_9") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitos (?P<Pfaa_10>[a-zA-Záâãçéêíóôú]+[aeiou])nças(?![-\\w–\xad])', '= m.group(1) + "uitas " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pfaa_10") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uito (?P<Pfaa_11>[a-zA-Záâãçéêíóôú]+[aeiou])nça(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "nça\\n" + m.group(1) + "uitas " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pfaa_11") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao] (?P<Pfaa_12>[a-zA-Záâãçéêíóôú]+[aeiou])nças(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "nça\\n" + m.group(1) + "uitas " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pfaa_12") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pfaa_13>[a-zA-Záâãçéêíóôú]+[aeiou])nça(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "nça\\n" + m.group(1) + "uitas " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pfaa_13") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucos (?P<Pfaa_14>[a-zA-Záâãçéêíóôú]+[aeiou])nças(?![-\\w–\xad])', '= m.group(1) + "oucas " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pfaa_14") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouco (?P<Pfaa_15>[a-zA-Záâãçéêíóôú]+[aeiou])nça(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "nça\\n" + m.group(1) + "oucas " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pfaa_15") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pfaa_16>[a-zA-Záâãçéêíóôú]+[aeiou])nças(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "nça\\n" + m.group(1) + "oucas " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pfaa_16") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pfaa_17>[a-zA-Záâãçéêíóôú]+[aeiou])nça(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "nça\\n" + m.group(1) + "oucas " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pfaa_17") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pfaa_18>[a-zA-Záâãçéêíóôú]+[aeiou])nças(?![-\\w–\xad])', '= m.group(1) + "odas as " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pfaa_18") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pfaa_19>[a-zA-Záâãçéêíóôú]+[aeiou])nça(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "nça\\n" + m.group(1) + "odas as " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pfaa_19") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pfaa_20>[a-zA-Záâãçéêíóôú]+[aeiou])nças(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "nça\\n" + m.group(1) + "odas as " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pfaa_20") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pfaa_21>[a-zA-Záâãçéêíóôú]+[aeiou])nça(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "nça\\n" + m.group(1) + "odas as " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pfaa_21") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaa_22>[a-zA-Z]+)s mesmos (?P<Pfaa_23>[a-zA-Záâãçéêíóôú]+[aeiou])nça(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "nça\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaa_22") in abSingular and not m.group("Pfaa_23") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaa_24>[a-zA-Z]+)s mesmas (?P<Pfaa_25>[a-zA-Záâãçéêíóôú]+[aeiou])nça(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "nça\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaa_24") in acSingular and not m.group("Pfaa_25") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaa_26>[a-zA-Z]+) mesmo (?P<Pfaa_27>[a-zA-Záâãçéêíóôú]+[aeiou])nças(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "nça\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaa_26") in abSingular and not m.group("Pfaa_27") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaa_28>[a-zA-Z]+) mesma (?P<Pfaa_29>[a-zA-Záâãçéêíóôú]+[aeiou])nças(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "nça\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaa_28") in acSingular and not m.group("Pfaa_29") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaa_30>[a-zA-Z]+) mesmo (?P<Pfaa_31>[a-zA-Záâãçéêíóôú]+[aeiou])nça(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "nça"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaa_30") in abSingular and not m.group("Pfaa_31") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaa_32>[a-zA-Z]+)s mesmos (?P<Pfaa_33>[a-zA-Záâãçéêíóôú]+[aeiou])nças(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s mesmas " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaa_32") in abSingular and not m.group("Pfaa_33") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Pfaa_34>[a-zA-Záâãçéêíóôú]+[aeiou])nça(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "nça\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pfaa_34") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Pafa_4>[a-zA-Záâãéêíóôú]+)([aeiou])nças(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "nça\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pafa_4") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)mas (?P<Pafa_5>[a-zA-Záâãéêíóôú]+)([aeiou])nça(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "nça\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pafa_5") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pafa_6>[a-zA-Záâãéêíóôú]+)([aeiou])nças(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "nça\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pafa_6") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pafa_7>[a-zA-Záâãéêíóôú]+)([aeiou])nça(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "nça\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pafa_7") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pafa_8>[a-zA-Záâãéêíóôú]+)([aeiou])nça(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "nça"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pafa_8") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pafa_9>[a-zA-Záâãéêíóôú]+)([aeiou])nças(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pafa_9") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])as (?P<Pafa_10>[a-zA-Záâãéêíóôú]+)([aeiou])nça(?![-\\w–\xad])', '= "as " + m.group(1) + m.group(2) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pafa_10") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pafa_11>[a-zA-Záâãéêíóôú]+)([aeiou])nça(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pafa_11") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pbfa_0>[a-zA-Záâãéêíóôú]+)([aeiou])nças(?![-\\w–\xad])', '= "Uma " + m.group(2) + m.group(3) + "nça\\nUmas " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfa_0") in excpLvrnca'],
 ['(?u)\\b([,]) uma (?P<Pbfa_1>[a-zA-Záâãçéêíóôú]+)([aeiou])nças(?![-\\w–\xad])', '= ", uma " + m.group(2) + m.group(3) + "nça\\n, umas " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfa_1") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pbfa_2>[a-zA-Záâãçéêíóôú]+)([aeiou])nças(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + m.group(3) + "nça"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfa_2") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pbfa_3>[a-zA-Záâãçéêíóôú]+)([aeiou])nças(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + m.group(3) + "nça"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfa_3") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_4>[a-zA-Záâãçéêíóôú]+) uma (?P<Pbfa_5>[a-zA-Záâãçéêíóôú]+)([aeiou])nças(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + m.group(3) + "nça\\n" + m.group(1) + " umas " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfa_4") in "-E-e-" and not m.group("Pbfa_5") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_6>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfa_7>[a-zA-Záâãçéêíóôú]+)([aeiou])nças(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "nça\\n" + m.group(1) + " e umas " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfa_6") in numEfem and not m.group("Pbfa_7") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_8>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfa_9>[a-zA-Záâãçéêíóôú]+)([aeiou])nça(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfa_8").lower() in numEfem and not m.group("Pbfa_9") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_10>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pbfa_11>[a-zA-Záâãçéêíóôú]+)([aeiou])nças(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfa_10").lower() in numEfem and not m.group("Pbfa_11") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_12>[a-zA-Záâãçéêíóôú]+) (?P<Pbfa_13>[a-zA-Záâãçéêíóôú]+)([aeiou])nça(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfa_12").lower() in numFem and not m.group("Pbfa_13") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_14>[0-9]+) (?P<Pbfa_15>[a-zA-Záâãçéêíóôú]+)([aeiou])nça(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pbfa_14") in "00000000001" and not excYnca.search(TEXT) and not m.group("Pbfa_15") in excpLvrnca'],
 ['(?u)\\b([.])(?P<Pbfa_16>[0-9][0-9][0-9]) (?P<Pbfa_17>[a-zA-Záâãçéêíóôú]+)([aeiou])nça(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + m.group(4) + "nças"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pbfa_17") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_18>[0-9]+) (?P<Pbfa_19>[a-zA-Záâãçéêíóôú]+)([aeiou])nças(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "nça"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pbfa_18") in "00000000001" and not excYnca.search(TEXT) and not m.group("Pbfa_19") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_20>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfa_21>[a-zA-Záâãçéêíóôú]+)([aeiou])nça(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfa_20").lower() in nuMfmoas and not m.group("Pbfa_21") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_22>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfa_23>[a-zA-Záâãçéêíóôú]+)([aeiou])nças(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfa_22").lower() in nuMfmoas and not m.group("Pbfa_23") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_g>[a-zA-Z]+) (?P<Pfa_h>[a-zA-Zç]+)([âêíôú])ncias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "ncia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_g") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_i>[a-zA-Z]+)s (?P<Pfa_j>[a-zA-Zç]+)([âêíôú])ncia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "ncia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_i") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_k>[a-zA-Z]+) (?P<Pfa_l>[a-zA-Zç]+)([âêíôú])ncia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "ncia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_k") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pfab_8>[a-zA-Záâãçéêíóôú]+[âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pfab_9>[a-zA-Záâãçéêíóôú]+[âêíôú])ncias(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitos (?P<Pfab_10>[a-zA-Záâãçéêíóôú]+[âêíôú])ncias(?![-\\w–\xad])', '= m.group(1) + "uitas " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uito (?P<Pfab_11>[a-zA-Záâãçéêíóôú]+[âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "ncia\\n" + m.group(1) + "uitas " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao] (?P<Pfab_12>[a-zA-Záâãçéêíóôú]+[âêíôú])ncias(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "ncia\\n" + m.group(1) + "uitas " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pfab_13>[a-zA-Záâãçéêíóôú]+[âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "ncia\\n" + m.group(1) + "uitas " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucos (?P<Pfab_14>[a-zA-Záâãçéêíóôú]+[âêíôú])ncias(?![-\\w–\xad])', '= m.group(1) + "oucas " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouco (?P<Pfab_15>[a-zA-Záâãçéêíóôú]+[âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "ncia\\n" + m.group(1) + "oucas " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pfab_16>[a-zA-Záâãçéêíóôú]+[âêíôú])ncias(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "ncia\\n" + m.group(1) + "oucas " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pfab_17>[a-zA-Záâãçéêíóôú]+[âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "ncia\\n" + m.group(1) + "oucas " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pfab_14>[a-zA-Záâãçéêíóôú]+[âêíôú])ncias(?![-\\w–\xad])', '= m.group(1) + "odas as " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pfab_15>[a-zA-Záâãçéêíóôú]+[âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "ncia\\n" + m.group(1) + "odas as " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pfab_16>[a-zA-Záâãçéêíóôú]+[âêíôú])ncias(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "ncia\\n" + m.group(1) + "odas as " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pfab_17>[a-zA-Záâãçéêíóôú]+[âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "ncia\\n" + m.group(1) + "odas as " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfab_18>[a-zA-Z]+)s mesmos (?P<Pfab_19>[a-zA-Záâãçéêíóôú]+[âêíôú])ncia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "ncia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfab_18") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfab_20>[a-zA-Z]+)s mesmas (?P<Pfab_21>[a-zA-Záâãçéêíóôú]+[âêíôú])ncia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "ncia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfab_20") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfab_22>[a-zA-Z]+) mesmo (?P<Pfab_23>[a-zA-Záâãçéêíóôú]+[âêíôú])ncias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "ncia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfab_22") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfab_24>[a-zA-Z]+) mesma (?P<Pfab_25>[a-zA-Záâãçéêíóôú]+[âêíôú])ncias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "ncia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfab_24") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfab_26>[a-zA-Z]+) mesmo (?P<Pfab_27>[a-zA-Záâãçéêíóôú]+[âêíôú])ncia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "ncia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfab_26") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfab_28>[a-zA-Z]+)s mesmos (?P<Pfab_29>[a-zA-Záâãçéêíóôú]+[âêíôú])ncias(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s mesmas " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfab_28") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Pfab_30>[a-zA-Záâãçéêíóôú]+[âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "ncia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Pcfa_a>[a-zA-Záâãéêíóôú]+)([âêíôú])ncias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "ncia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)mas (?P<Pcfa_b>[a-zA-Záâãéêíóôú]+)([âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "ncia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pcfa_c>[a-zA-Záâãéêíóôú]+)([âêíôú])ncias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "ncia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pcfa_d>[a-zA-Záâãéêíóôú]+)([âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "ncia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pcfa_e>[a-zA-Záâãéêíóôú]+)([âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "ncia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pcfa_f>[a-zA-Záâãéêíóôú]+)([âêíôú])ncias(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Pcfa_g>[a-zA-Záâãéêíóôú]+)([âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pcfa_h>[a-zA-Záâãéêíóôú]+)([âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pcfa_0>[a-zA-Záâãéêíóôú]+)([âêíôú])ncias(?![-\\w–\xad])', '= "Uma " + m.group(2) + m.group(3) + "ncia\\nUmas " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) uma (?P<Pcfa_1>[a-zA-Záâãçéêíóôú]+)([âêíôú])ncias(?![-\\w–\xad])', '= ", uma " + m.group(2) + m.group(3) + "ncia\\n, umas " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pcfa_0>[a-zA-Záâãçéêíóôú]+)([âêíôú])ncias(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + m.group(3) + "ncia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pcfa_0>[a-zA-Záâãçéêíóôú]+)([âêíôú])ncias(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + m.group(3) + "ncia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pcfa_2>[a-zA-Záâãçéêíóôú]+) uma (?P<Pcfa_3>[a-zA-Záâãçéêíóôú]+)([âêíôú])ncias(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + m.group(3) + "ncia\\n" + m.group(1) + " umas " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pcfa_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pcfa_4>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pcfa_5>[a-zA-Záâãçéêíóôú]+)([âêíôú])ncias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "ncia\\n" + m.group(1) + " e umas " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pcfa_4") in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pcfa_6>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pcfa_7>[a-zA-Záâãçéêíóôú]+)([âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pcfa_6").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pcfa_8>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pcfa_9>[a-zA-Záâãçéêíóôú]+)([âêíôú])ncias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pcfa_8").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pcfa_10>[a-zA-Záâãçéêíóôú]+) (?P<Pcfa_11>[a-zA-Záâãçéêíóôú]+)([âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pcfa_10").lower() in numFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pcfa_12>[0-9]+) (?P<Pcfa_13>[a-záâãçéêíóôú]+)([âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pcfa_12") in "00000000001" and not excYncia.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pcfa_14>[0-9][0-9][0-9]) (?P<Pcfa_15>[a-záâãçéêíóôú]+)([âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + m.group(4) + "ncias"', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pcfa_16>[0-9]+) (?P<Pcfa_17>[a-záâãçéêíóôú]+)([âêíôú])ncias(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "ncia"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pcfa_16") in "00000000001" and not excYncia.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pcfa_17>[a-zA-Záâãçéêíóôú]+)os (?P<Pcfa_18>[a-zA-Záâãçéêíóôú]+)([âêíôú])ncia(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pcfa_17").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pcfa_19>[a-zA-Záâãçéêíóôú]+)os (?P<Pcfa_20>[a-zA-Záâãçéêíóôú]+)([âêíôú])ncias(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pcfa_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_m>[a-zA-Z]+) (?P<Pfa_n>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "grafia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_m") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_o>[a-zA-Z]+)s (?P<Pfa_p>[a-zA-Záâãçéêíóôú]+)garfia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "grafia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_o") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_q>[a-zA-Z]+) (?P<Pfa_r>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "grafia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_q") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pfac_8>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pfac_9>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitos (?P<Pfac_10>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= m.group(1) + "uitas " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uito (?P<Pfac_11>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "grafia\\n" + m.group(1) + "uitas " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao] (?P<Pfac_12>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "grafia\\n" + m.group(1) + "uitas " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pfac_13>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "grafia\\n" + m.group(1) + "uitas " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucos (?P<Pfac_14>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= m.group(1) + "oucas " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouco (?P<Pfac_15>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "grafia\\n" + m.group(1) + "oucas " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pfac_16>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "grafia\\n" + m.group(1) + "oucas " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pfac_17>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "grafia\\n" + m.group(1) + "oucas " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pfac_14>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= m.group(1) + "odas as " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pfac_15>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "grafia\\n" + m.group(1) + "odas as " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pfac_16>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "grafia\\n" + m.group(1) + "odas as " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pfac_17>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "grafia\\n" + m.group(1) + "odas as " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfac_18>[a-zA-Z]+)s mesmos (?P<Pfac_19>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "grafia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', 'm.group("Pfac_18") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfac_20>[a-zA-Z]+)s mesmas (?P<Pfac_21>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "grafia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', 'm.group("Pfac_20") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfac_22>[a-zA-Z]+) mesmo (?P<Pfac_23>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "grafia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', 'm.group("Pfac_22") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfac_24>[a-zA-Z]+) mesma (?P<Pfac_25>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "grafia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', 'm.group("Pfac_24") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfac_26>[a-zA-Z]+) mesmo (?P<Pfac_27>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "grafia"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', 'm.group("Pfac_26") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfac_28>[a-zA-Z]+)s mesmos (?P<Pfac_29>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s mesmas " + m.group(2) + "grafias"', 'Não há concordâgrafia entre as palavras. Você quis dizer:', 'm.group("Pfac_28") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Pfac_30>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "grafia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Pfac_a>[a-zA-Záâãéêíóôú]+)grafias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "grafia\\n" + m.group(1) + "mas " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)mas (?P<Pfac_b>[a-zA-Záâãéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "grafia\\n" + m.group(1) + "mas " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfac_c>[a-zA-Záâãéêíóôú]+)grafias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "grafia\\n" + m.group(1) + "mas " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfac_d>[a-zA-Záâãéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "grafia\\n" + m.group(1) + "mas " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfac_e>[a-zA-Záâãéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "grafia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfac_f>[a-zA-Záâãéêíóôú]+)grafias(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Pfac_g>[a-zA-Záâãéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pfac_h>[a-zA-Záâãéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pgfa_0>[a-zA-Záâãéêíóôú]+)grafias(?![-\\w–\xad])', '= "Uma " + m.group(2) + "grafia\\nUmas " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) uma (?P<Pgfa_1>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= ", uma " + m.group(2) + "grafia\\n, umas " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pgfa_0>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + "grafia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pgfa_0>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + "grafia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pgfa_2>[a-zA-Záâãçéêíóôú]+) uma (?P<Pgfa_3>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "grafia\\n" + m.group(1) + " umas " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pgfa_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pgfa_4>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pgfa_5>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "grafia\\n" + m.group(1) + " e umas " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pgfa_4") in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pgfa_6>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pgfa_7>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pgfa_6").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pgfa_8>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pgfa_9>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pgfa_8").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pgfa_10>[a-zA-Záâãçéêíóôú]+) (?P<Pgfa_11>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pgfa_10").lower() in numFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pgfa_12>[0-9]+) (?P<Pgfa_13>[a-záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "grafias"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pgfa_12") in "00000000001" and not excYgrafia.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pgfa_14>[0-9][0-9][0-9]) (?P<Pgfa_15>[a-záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(4) + "nças"', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pgfa_16>[0-9]+) (?P<Pgfa_17>[a-záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "grafia"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pgfa_16") in "00000000001" and not excYgrafia.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pgfa_17>[a-zA-Záâãçéêíóôú]+)os (?P<Pgfa_18>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pgfa_17").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pgfa_19>[a-zA-Záâãçéêíóôú]+)os (?P<Pgfa_20>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "grafias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pgfa_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_s>[a-zA-Z]+) (?P<Pfa_t>[a-zA-Záâãçéêíóôú]+)([gl])ogias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "ogia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_s") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_u>[a-zA-Z]+)s (?P<Pfa_v>[a-zA-Záâãçéêíóôú]+)([gl])ogia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "ogia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_u") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_w>[a-zA-Z]+) (?P<Pfa_x>[a-zA-Záâãçéêíóôú]+)([gl])ogia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "ogia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_w") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pfad_8>[a-zA-Záâãçéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pfad_9>[a-zA-Záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitos (?P<Pfad_10>[a-zA-Záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= m.group(1) + "uitas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uito (?P<Pfad_11>[a-zA-Záâãçéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "ogia\\n" + m.group(1) + "uitas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao] (?P<Pfad_12>[a-zA-Záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "ogia\\n" + m.group(1) + "uitas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pfad_13>[a-zA-Záâãçéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "ogia\\n" + m.group(1) + "uitas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucos (?P<Pfad_14>[a-zA-Záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= m.group(1) + "oucas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouco (?P<Pfad_15>[a-zA-Záâãçéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "ogia\\n" + m.group(1) + "oucas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pfad_16>[a-zA-Záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "ogia\\n" + m.group(1) + "oucas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pfad_17>[a-zA-Záâãçéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "ogia\\n" + m.group(1) + "oucas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pfad_14>[a-zA-Záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= m.group(1) + "odas as " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pfad_15>[a-zA-Záâãçéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "ogia\\n" + m.group(1) + "odas as " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pfad_16>[a-zA-Záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "ogia\\n" + m.group(1) + "odas as " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pfad_17>[a-zA-Záâãçéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "ogia\\n" + m.group(1) + "odas as " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfad_18>[a-zA-Z]+)s mesmos (?P<Pfad_19>[a-zA-Záâãçéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "ogia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfad_18") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfad_20>[a-zA-Z]+)s mesmas (?P<Pfad_21>[a-zA-Záâãçéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "ogia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfad_20") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfad_22>[a-zA-Z]+) mesmo (?P<Pfad_23>[a-zA-Záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "ogia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfad_22") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfad_24>[a-zA-Z]+) mesma (?P<Pfad_25>[a-zA-Záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "ogia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfad_24") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfad_26>[a-zA-Z]+) mesmo (?P<Pfad_27>[a-zA-Záâãçéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "ogia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfad_26") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfad_28>[a-zA-Z]+)s mesmos (?P<Pfad_29>[a-zA-Záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s mesmas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfad_28") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Pfad_30>[a-zA-Záâãçéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "ogia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Pfad_a>[a-zA-Záâãéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ogia\\n" + m.group(1) + "mas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)mas (?P<Pfad_b>[a-zA-Záâãéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ogia\\n" + m.group(1) + "mas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfad_c>[a-zA-Záâãéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ogia\\n" + m.group(1) + "mas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfad_d>[a-zA-Záâãéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ogia\\n" + m.group(1) + "mas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfad_e>[a-zA-Záâãéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ogia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfad_f>[a-zA-Záâãéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Pfad_g>[a-zA-Záâãéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pfad_h>[a-zA-Záâãéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Plfa_0>[a-zA-Záâãéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= "Uma " + m.group(2) + "ogia\\nUmas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) uma (?P<Plfa_1>[a-zA-Záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= ", uma " + m.group(2) + "ogia\\n, umas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Plfa_0>[a-zA-Záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + "ogia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Plfa_0>[a-zA-Záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + "ogia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plfa_2>[a-zA-Záâãçéêíóôú]+) uma (?P<Plfa_3>[a-zA-Záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "ogia\\n" + m.group(1) + " umas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Plfa_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plfa_4>[a-zA-Záâãçéêíóôú]+) e uma (?P<Plfa_5>[a-zA-Záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "ogia\\n" + m.group(1) + " e umas " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Plfa_4") in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plfa_6>[a-zA-Záâãçéêíóôú]+) e uma (?P<Plfa_7>[a-zA-Záâãçéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plfa_6").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plfa_8>[a-zA-Záâãçéêíóôú]+) e umas (?P<Plfa_9>[a-zA-Záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plfa_8").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plfa_10>[a-zA-Záâãçéêíóôú]+) (?P<Plfa_11>[a-zA-Záâãçéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plfa_10").lower() in numFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plfa_12>[0-9]+) (?P<Plfa_13>[a-záâãçéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ogias"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Plfa_12") in "00000000001" and not excYogia.search(TEXT)'],
 ['(?u)\\b([.])(?P<Plfa_14>[0-9][0-9][0-9]) (?P<Plfa_15>[a-záâãçéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(4) + "nças"', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plfa_16>[0-9]+) (?P<Plfa_17>[a-záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ogia"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Plfa_16") in "00000000001" and not excYogia.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plfa_17>[a-zA-Záâãçéêíóôú]+)os (?P<Plfa_18>[a-zA-Záâãçéêíóôú]+[gl])ogia(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plfa_17").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plfa_19>[a-zA-Záâãçéêíóôú]+)os (?P<Plfa_20>[a-zA-Záâãçéêíóôú]+[gl])ogias(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plfa_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_1>[a-zA-Z]+) (?P<Pfb_2>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "rgia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_1") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_3>[a-zA-Z]+)s (?P<Pfb_4>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "rgia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_3") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_5>[a-zA-Z]+) (?P<Pfb_6>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "rgia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_5") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pfae_8>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pfae_9>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitos (?P<Pfae_10>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= m.group(1) + "uitas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uito (?P<Pfae_11>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "rgia\\n" + m.group(1) + "uitas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao] (?P<Pfae_12>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "rgia\\n" + m.group(1) + "uitas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pfae_13>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "rgia\\n" + m.group(1) + "uitas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucos (?P<Pfae_14>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= m.group(1) + "oucas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouco (?P<Pfae_15>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "rgia\\n" + m.group(1) + "oucas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pfae_16>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "rgia\\n" + m.group(1) + "oucas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pfae_17>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "rgia\\n" + m.group(1) + "oucas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pfae_14>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= m.group(1) + "odas as " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pfae_15>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "rgia\\n" + m.group(1) + "odas as " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pfae_16>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "rgia\\n" + m.group(1) + "odas as " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pfae_17>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "rgia\\n" + m.group(1) + "odas as " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfae_18>[a-zA-Z]+)s mesmos (?P<Pfae_19>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "rgia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfae_18") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfae_20>[a-zA-Z]+)s mesmas (?P<Pfae_21>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "rgia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfae_20") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfae_22>[a-zA-Z]+) mesmo (?P<Pfae_23>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "rgia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfae_22") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfae_24>[a-zA-Z]+) mesma (?P<Pfae_25>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "rgia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfae_24") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfae_26>[a-zA-Z]+) mesmo (?P<Pfae_27>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "rgia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfae_26") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfae_28>[a-zA-Z]+)s mesmos (?P<Pfae_29>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s mesmas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfae_28") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Pfae_30>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "rgia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Pfae_a>[a-zA-Záâãéêíóôú]+)rgias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "rgia\\n" + m.group(1) + "mas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)mas (?P<Pfae_b>[a-zA-Záâãéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "rgia\\n" + m.group(1) + "mas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfae_c>[a-zA-Záâãéêíóôú]+)rgias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "rgia\\n" + m.group(1) + "mas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfae_d>[a-zA-Záâãéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "rgia\\n" + m.group(1) + "mas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfae_e>[a-zA-Záâãéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "rgia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfae_f>[a-zA-Záâãéêíóôú]+)rgias(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Pfae_g>[a-zA-Záâãéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pfae_h>[a-zA-Záâãéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pbfa_0>[a-zA-Záâãéêíóôú]+)rgias(?![-\\w–\xad])', '= "Uma " + m.group(2) + "rgia\\nUmas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) uma (?P<Pbfa_1>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= ", uma " + m.group(2) + "rgia\\n, umas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pbfa_0>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + "rgia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pbfa_0>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + "rgia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_2>[a-zA-Záâãçéêíóôú]+) uma (?P<Pbfa_3>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "rgia\\n" + m.group(1) + " umas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfa_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_4>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfa_5>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "rgia\\n" + m.group(1) + " e umas " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfa_4") in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_6>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfa_7>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfa_6").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_8>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pbfa_9>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfa_8").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_10>[a-zA-Záâãçéêíóôú]+) (?P<Pbfa_11>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfa_10").lower() in numFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_12>[0-9]+) (?P<Pbfa_13>[a-záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "rgias"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pbfa_12") in "00000000001" and not excYrgia.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pbfa_14>[0-9][0-9][0-9]) (?P<Pbfa_15>[a-záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(4) + "nças"', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_16>[0-9]+) (?P<Pbfa_17>[a-záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "rgia"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pbfa_16") in "00000000001" and not excYrgia.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_17>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfa_18>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfa_17").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_19>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfa_20>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfa_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_7>[a-zA-Z]+) (?P<Pfb_8>[a-zA-Zç]+)([áéíóú])lias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "lia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_7") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_9>[a-zA-Z]+)s (?P<Pfb_0>[a-zA-Zç]+)([áéíóú])lia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "lia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_9") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfa_y>[a-zA-Z]+) (?P<Pfa_z>[a-zA-Zç]+)([áéíóú])lia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "lia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfa_y") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pfaf_8>[a-zA-Záâãçéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pfaf_9>[a-zA-Záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitos (?P<Pfaf_10>[a-zA-Záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= m.group(1) + "uitas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uito (?P<Pfaf_11>[a-zA-Záâãçéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "lia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao] (?P<Pfaf_12>[a-zA-Záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "lia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pfaf_13>[a-zA-Záâãçéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "lia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucos (?P<Pfaf_14>[a-zA-Záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= m.group(1) + "oucas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouco (?P<Pfaf_15>[a-zA-Záâãçéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "lia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pfaf_16>[a-zA-Záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "lia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pfaf_17>[a-zA-Záâãçéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "lia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pfaf_14>[a-zA-Záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= m.group(1) + "odas as " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pfaf_15>[a-zA-Záâãçéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "lia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pfaf_16>[a-zA-Záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "lia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pfaf_17>[a-zA-Záâãçéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "lia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaf_18>[a-zA-Z]+)s mesmos (?P<Pfaf_19>[a-zA-Záâãçéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "lia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaf_18") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaf_20>[a-zA-Z]+)s mesmas (?P<Pfaf_21>[a-zA-Záâãçéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "lia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaf_20") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaf_22>[a-zA-Z]+) mesmo (?P<Pfaf_23>[a-zA-Záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "lia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaf_22") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaf_24>[a-zA-Z]+) mesma (?P<Pfaf_25>[a-zA-Záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "lia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaf_24") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaf_26>[a-zA-Z]+) mesmo (?P<Pfaf_27>[a-zA-Záâãçéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "lia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaf_26") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaf_28>[a-zA-Z]+)s mesmos (?P<Pfaf_29>[a-zA-Záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaf_28") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Pfaf_30>[a-zA-Záâãçéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + m.group(3) + "lia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Pfaf_a>[a-zA-Záâãéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "lia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)mas (?P<Pfaf_b>[a-zA-Záâãéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "lia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfaf_c>[a-zA-Záâãéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "lia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfaf_d>[a-zA-Záâãéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "lia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfaf_e>[a-zA-Záâãéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "lia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfaf_f>[a-zA-Záâãéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Pfaf_g>[a-zA-Záâãéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pfaf_h>[a-zA-Záâãéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pbfb_0>[a-zA-Záâãéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= "Uma " + m.group(2) + m.group(3) + "lia\\nUmas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) uma (?P<Pbfb_1>[a-zA-Záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= ", uma " + m.group(2) + m.group(3) + "lia\\n, umas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pbfb_0>[a-zA-Záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + m.group(3) + "lia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pbfb_0>[a-zA-Záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + m.group(3) + "lia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_2>[a-zA-Záâãçéêíóôú]+) uma (?P<Pbfb_3>[a-zA-Záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + m.group(3) + "lia\\n" + m.group(1) + " umas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfb_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_4>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfb_5>[a-zA-Záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "lia\\n" + m.group(1) + " e umas " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfb_4") in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_6>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfb_7>[a-zA-Záâãçéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfb_6").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_8>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pbfb_9>[a-zA-Záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfb_8").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_10>[a-zA-Záâãçéêíóôú]+) (?P<Pbfb_11>[a-zA-Záâãçéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfb_10").lower() in numFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_12>[0-9]+) (?P<Pbfb_13>[a-záâãçéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pbfb_12") in "00000000001" and not excYlia.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pbfb_14>[0-9][0-9][0-9]) (?P<Pbfb_15>[a-záâãçéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(4) + "nças"', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_16>[0-9]+) (?P<Pbfb_17>[a-záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "lia"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pbfb_16") in "00000000001" and not excYlia.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_17>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfb_18>[a-zA-Záâãçéêíóôú]+)([áéíóú])lia(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfb_17").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_19>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfb_20>[a-zA-Záâãçéêíóôú]+)([áéíóú])lias(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfb_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_a>[a-zA-Z]+) (?P<Pfb_b>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "erapia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_a") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_c>[a-zA-Z]+)s (?P<Pfb_d>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "erapia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_c") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_e>[a-zA-Z]+) (?P<Pfb_f>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "erapia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_e") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pfag_8>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pfag_9>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitos (?P<Pfag_10>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= m.group(1) + "uitas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uito (?P<Pfag_11>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "erapia\\n" + m.group(1) + "uitas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao] (?P<Pfag_12>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "erapia\\n" + m.group(1) + "uitas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pfag_13>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + "erapia\\n" + m.group(1) + "uitas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucos (?P<Pfag_14>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= m.group(1) + "oucas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouco (?P<Pfag_15>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "erapia\\n" + m.group(1) + "oucas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pfag_16>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "erapia\\n" + m.group(1) + "oucas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pfag_17>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "erapia\\n" + m.group(1) + "oucas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pfag_14>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= m.group(1) + "odas as " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pfag_15>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "erapia\\n" + m.group(1) + "odas as " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pfag_16>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "erapia\\n" + m.group(1) + "odas as " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pfag_17>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "erapia\\n" + m.group(1) + "odas as " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfag_18>[a-zA-Z]+)s mesmos (?P<Pfag_19>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "erapia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfag_18") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfag_20>[a-zA-Z]+)s mesmas (?P<Pfag_21>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "erapia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfag_20") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfag_22>[a-zA-Z]+) mesmo (?P<Pfag_23>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "erapia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfag_22") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfag_24>[a-zA-Z]+) mesma (?P<Pfag_25>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "erapia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfag_24") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfag_26>[a-zA-Z]+) mesmo (?P<Pfag_27>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "erapia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfag_26") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfag_28>[a-zA-Z]+)s mesmos (?P<Pfag_29>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s mesmas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfag_28") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Pfag_30>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "erapia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Pfag_a>[a-zA-Záâãéêíóôú]+)erapias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "erapia\\n" + m.group(1) + "mas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)mas (?P<Pfag_b>[a-zA-Záâãéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "erapia\\n" + m.group(1) + "mas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfag_c>[a-zA-Záâãéêíóôú]+)erapias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "erapia\\n" + m.group(1) + "mas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfag_d>[a-zA-Záâãéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "erapia\\n" + m.group(1) + "mas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfag_e>[a-zA-Záâãéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "erapia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfag_f>[a-zA-Záâãéêíóôú]+)erapias(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Pfag_g>[a-zA-Záâãéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pfag_h>[a-zA-Záâãéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pbfa_0>[a-zA-Záâãéêíóôú]+)erapias(?![-\\w–\xad])', '= "Uma " + m.group(2) + "erapia\\nUmas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) uma (?P<Pbfa_1>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= ", uma " + m.group(2) + "erapia\\n, umas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pbfa_0>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + "erapia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pbfa_0>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + "erapia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_2>[a-zA-Záâãçéêíóôú]+) uma (?P<Pbfa_3>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "erapia\\n" + m.group(1) + " umas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfa_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_4>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfa_5>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "erapia\\n" + m.group(1) + " e umas " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfa_4") in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_6>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfa_7>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfa_6").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_8>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pbfa_9>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfa_8").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_10>[a-zA-Záâãçéêíóôú]+) (?P<Pbfa_11>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfa_10").lower() in numFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_12>[0-9]+) (?P<Pbfa_13>[a-záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "erapias"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pbfa_12") in "00000000001" and not excYapia.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pbfa_14>[0-9][0-9][0-9]) (?P<Pbfa_15>[a-záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(4) + "nças"', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_16>[0-9]+) (?P<Pbfa_17>[a-záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "erapia"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pbfa_16") in "00000000001" and not excYapia.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_17>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfa_18>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfa_17").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfa_19>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfa_20>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfa_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_g>[a-zA-Z]+) (?P<Pfb_h>[a-zA-Zç]+)([áéíóú])rias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "ria\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_g") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_i>[a-zA-Z]+)s (?P<Pfb_j>[a-zç]+)([áéíóú])ria(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "ria\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_i") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_k>[a-zA-Z]+) (?P<Pfb_l>[a-zç]+)([áéíóú])ria(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "ria"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_k") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pfah_8>[a-zA-Záâãçéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pfah_9>[a-zA-Záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitos (?P<Pfah_10>[a-zA-Záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= m.group(1) + "uitas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[a] (?P<Pfah_12>[a-zA-Záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + m.group(3) + "rias\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pfah_13>[a-zA-Záâãçéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + m.group(3) + "ria\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucos (?P<Pfah_14>[a-zA-Záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= m.group(1) + "oucas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouco (?P<Pfah_15>[a-zA-Záâãçéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "ria\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pfah_16>[a-zA-Záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "ria\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pfah_17>[a-zA-Záâãçéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "ria\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pfah_14>[a-zA-Záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= m.group(1) + "odas as " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pfah_15>[a-zA-Záâãçéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "ria\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pfah_16>[a-zA-Záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "ria\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pfah_17>[a-zA-Záâãçéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "ria\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfah_18>[a-zA-Z]+)s mesmos (?P<Pfah_19>[a-zA-Záâãçéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "ria\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfah_18") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfah_20>[a-zA-Z]+)s mesmas (?P<Pfah_21>[a-zA-Záâãçéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "ria\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfah_20") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfah_22>[a-zA-Z]+) mesmo (?P<Pfah_23>[a-zA-Záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "ria\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfah_22") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfah_24>[a-zA-Z]+) mesma (?P<Pfah_25>[a-zA-Záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "ria\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfah_24") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfah_26>[a-zA-Z]+) mesmo (?P<Pfah_27>[a-zA-Záâãçéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "ria"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfah_26") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfah_28>[a-zA-Z]+)s mesmos (?P<Pfah_29>[a-zA-Záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfah_28") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Pfah_30>[a-zA-Záâãçéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + m.group(3) + "ria\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Pfah_a>[a-zA-Záâãéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "ria\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)mas (?P<Pfah_b>[a-zA-Záâãéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "ria\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfah_c>[a-zA-Záâãéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "ria\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfah_d>[a-zA-Záâãéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "ria\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfah_e>[a-zA-Záâãéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "ria"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfah_f>[a-zA-Záâãéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Pfah_g>[a-zA-Záâãéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pfah_h>[a-zA-Záâãéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pbfb_0>[a-zA-Záâãéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= "Uma " + m.group(2) + m.group(3) + "ria\\nUmas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) uma (?P<Pbfb_1>[a-zA-Záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= ", uma " + m.group(2) + m.group(3) + "ria\\n, umas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pbfb_0>[a-zA-Záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + m.group(3) + "ria"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pbfb_0>[a-zA-Záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + m.group(3) + "ria"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_2>[a-zA-Záâãçéêíóôú]+) uma (?P<Pbfb_3>[a-zA-Záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + m.group(3) + "ria\\n" + m.group(1) + " umas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfb_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_4>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfb_5>[a-zA-Záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "ria\\n" + m.group(1) + " e umas " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfb_4") in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_6>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfb_7>[a-zA-Záâãçéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfb_6").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_8>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pbfb_9>[a-zA-Záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfb_8").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_10>[a-zA-Záâãçéêíóôú]+) (?P<Pbfb_11>[a-zA-Záâãçéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfb_10").lower() in numFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_12>[0-9]+) (?P<Pbfb_13>[a-záâãçéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pbfb_12") in "00000000001" and not excYria.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pbfb_14>[0-9][0-9][0-9]) (?P<Pbfb_15>[a-záâãçéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(4) + "nças"', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_16>[0-9]+) (?P<Pbfb_17>[a-záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "ria"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pbfb_16") in "00000000001" and not excYria.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_17>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfb_18>[a-zA-Záâãçéêíóôú]+)([áéíóú])ria(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfb_17").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfb_19>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfb_20>[a-zA-Záâãçéêíóôú]+)([áéíóú])rias(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfb_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_m>[a-zA-Z]+) (?P<Pfb_n>[a-zA-Zç]+)([áéíú])sias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "sia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_m") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_o>[a-zA-Z]+)s (?P<Pfb_p>[a-zA-Zç]+)([áéíú])sia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "sia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_o") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_q>[a-zA-Z]+) (?P<Pfb_r>[a-zA-Zç]+)([áéíú])sia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "sia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_q") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pfai_8>[a-zA-Záâãçéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pfai_9>[a-zA-Záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitos (?P<Pfai_10>[a-zA-Záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= m.group(1) + "uitas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uito (?P<Pfai_11>[a-zA-Záâãçéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "sia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao] (?P<Pfai_12>[a-zA-Záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "sia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pfai_13>[a-zA-Záâãçéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "sia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucos (?P<Pfai_14>[a-zA-Záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= m.group(1) + "oucas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouco (?P<Pfai_15>[a-zA-Záâãçéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "sia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pfai_16>[a-zA-Záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "sia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pfai_17>[a-zA-Záâãçéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "sia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pfai_14>[a-zA-Záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= m.group(1) + "odas as " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pfai_15>[a-zA-Záâãçéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "sia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pfai_16>[a-zA-Záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "sia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pfai_17>[a-zA-Záâãçéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "sia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfai_18>[a-zA-Z]+)s mesmos (?P<Pfai_19>[a-zA-Záâãçéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "sia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfai_18") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfai_20>[a-zA-Z]+)s mesmas (?P<Pfai_21>[a-zA-Záâãçéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "sia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfai_20") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfai_22>[a-zA-Z]+) mesmo (?P<Pfai_23>[a-zA-Záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "sia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfai_22") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfai_24>[a-zA-Z]+) mesma (?P<Pfai_25>[a-zA-Záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "sia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfai_24") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfai_26>[a-zA-Z]+) mesmo (?P<Pfai_27>[a-zA-Záâãçéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "sia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfai_26") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfai_28>[a-zA-Z]+)s mesmos (?P<Pfai_29>[a-zA-Záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfai_28") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Pfai_30>[a-zA-Záâãçéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + m.group(3) + "sia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Pfai_a>[a-zA-Záâãéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "sia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)mas (?P<Pfai_b>[a-zA-Záâãéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "sia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfai_c>[a-zA-Záâãéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "sia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfai_d>[a-zA-Záâãéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "sia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfai_e>[a-zA-Záâãéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "sia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfai_f>[a-zA-Záâãéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Pfai_g>[a-zA-Záâãéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pfai_h>[a-zA-Záâãéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pbfc_0>[a-zA-Záâãéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= "Uma " + m.group(2) + m.group(3) + "sia\\nUmas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) uma (?P<Pbfc_1>[a-zA-Záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= ", uma " + m.group(2) + m.group(3) + "sia\\n, umas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pbfc_0>[a-zA-Záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + m.group(3) + "sia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pbfc_0>[a-zA-Záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + m.group(3) + "sia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfc_2>[a-zA-Záâãçéêíóôú]+) uma (?P<Pbfc_3>[a-zA-Záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + m.group(3) + "sia\\n" + m.group(1) + " umas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfc_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfc_4>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfc_5>[a-zA-Záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "sia\\n" + m.group(1) + " e umas " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfc_4") in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfc_6>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfc_7>[a-zA-Záâãçéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfc_6").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfc_8>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pbfc_9>[a-zA-Záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfc_8").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfc_10>[a-zA-Záâãçéêíóôú]+) (?P<Pbfc_11>[a-zA-Záâãçéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfc_10").lower() in numFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfc_12>[0-9]+) (?P<Pbfc_13>[a-záâãçéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pbfc_12") in "00000000001" and not excYsia.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pbfc_14>[0-9][0-9][0-9]) (?P<Pbfc_15>[a-záâãçéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(4) + "nças"', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfc_16>[0-9]+) (?P<Pbfc_17>[a-záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "sia"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pbfc_16") in "00000000001" and not excYsia.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfc_17>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfc_18>[a-zA-Záâãçéêíóôú]+)([áéíú])sia(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfc_17").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfc_19>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfc_20>[a-zA-Záâãçéêíóôú]+)([áéíú])sias(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfc_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_s>[a-zA-Z]+) (?P<Pfb_t>[a-zA-Zç]+)([áéíóú])rsias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "rsia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_s") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_u>[a-zA-Z]+)s (?P<Pfb_v>[a-zA-Zç]+)([áéíóú])rsia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "rsia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_u") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_w>[a-zA-Z]+) (?P<Pfb_x>[a-zA-Zç]+)([áéíóú])rsia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "rsia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_w") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pfaj_8>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pfaj_9>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitos (?P<Pfaj_10>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= m.group(1) + "uitas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uito (?P<Pfaj_11>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "rsia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao] (?P<Pfaj_12>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "rsia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pfaj_13>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "rsia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucos (?P<Pfaj_14>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= m.group(1) + "oucas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouco (?P<Pfaj_15>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "rsia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pfaj_16>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "rsia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pfaj_17>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "rsia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pfaj_14>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= m.group(1) + "odas as " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pfaj_15>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "rsia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pfaj_16>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "rsia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pfaj_17>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "rsia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaj_18>[a-zA-Z]+)s mesmos (?P<Pfaj_19>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "rsia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaj_18") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaj_20>[a-zA-Z]+)s mesmas (?P<Pfaj_21>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "rsia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaj_20") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaj_22>[a-zA-Z]+) mesmo (?P<Pfaj_23>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "rsia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaj_22") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaj_24>[a-zA-Z]+) mesma (?P<Pfaj_25>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "rsia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaj_24") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaj_26>[a-zA-Z]+) mesmo (?P<Pfaj_27>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "rsia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaj_26") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfaj_28>[a-zA-Z]+)s mesmos (?P<Pfaj_29>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfaj_28") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Pfaj_30>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + m.group(3) + "rsia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Pfaj_a>[a-zA-Záâãéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "rsia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)mas (?P<Pfaj_b>[a-zA-Záâãéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "rsia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfaj_c>[a-zA-Záâãéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "rsia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfaj_d>[a-zA-Záâãéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "rsia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfaj_e>[a-zA-Záâãéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "rsia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfaj_f>[a-zA-Záâãéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Pfaj_g>[a-zA-Záâãéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pfaj_h>[a-zA-Záâãéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pbfd_0>[a-zA-Záâãéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= "Uma " + m.group(2) + m.group(3) + "rsia\\nUmas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) uma (?P<Pbfd_1>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= ", uma " + m.group(2) + m.group(3) + "rsia\\n, umas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pbfd_0>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + m.group(3) + "rsia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pbfd_0>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + m.group(3) + "rsia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfd_2>[a-zA-Záâãçéêíóôú]+) uma (?P<Pbfd_3>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + m.group(3) + "rsia\\n" + m.group(1) + " umas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfd_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfd_4>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfd_5>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "rsia\\n" + m.group(1) + " e umas " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfd_4") in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfd_6>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfd_7>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfd_6").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfd_8>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pbfd_9>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfd_8").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfd_10>[a-zA-Záâãçéêíóôú]+) (?P<Pbfd_11>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfd_10").lower() in numFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfd_12>[0-9]+) (?P<Pbfd_13>[a-záâãçéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pbfd_12") in "00000000001" and not excYrsia.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pbfd_14>[0-9][0-9][0-9]) (?P<Pbfd_15>[a-záâãçéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(4) + "nças"', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfd_16>[0-9]+) (?P<Pbfd_17>[a-záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "rsia"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pbfd_16") in "00000000001" and not excYrsia.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfd_17>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfd_18>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsia(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfd_17").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfd_19>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfd_20>[a-zA-Záâãçéêíóôú]+)([áéíóú])rsias(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfd_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfb_y>[a-zA-Z]+) (?P<Pfb_z>[a-zA-Zç]+)([áéíóú])ssias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "ssia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfb_y") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfc_a>[a-zA-Z]+)s (?P<Pfc_b>[a-zA-Zç]+)([áéíóú])ssia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "ssia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfc_a") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfc_c>[a-zA-Z]+) (?P<Pfc_d>[a-zA-Zç]+)([áéíóú])ssia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "ssia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfc_c") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pfak_8>[a-zA-Záâãçéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pfak_9>[a-zA-Záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitos (?P<Pfak_10>[a-zA-Záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= m.group(1) + "uitas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uito (?P<Pfak_11>[a-zA-Záâãçéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "ssia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao] (?P<Pfak_12>[a-zA-Záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "ssia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pfak_13>[a-zA-Záâãçéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "ssia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucos (?P<Pfak_14>[a-zA-Záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= m.group(1) + "oucas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouco (?P<Pfak_15>[a-zA-Záâãçéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "ssia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pfak_16>[a-zA-Záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "ssia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pfak_17>[a-zA-Záâãçéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "ssia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pfak_14>[a-zA-Záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= m.group(1) + "odas as " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pfak_15>[a-zA-Záâãçéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "ssia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pfak_16>[a-zA-Záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "ssia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pfak_17>[a-zA-Záâãçéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "ssia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfak_18>[a-zA-Z]+)s mesmos (?P<Pfak_19>[a-zA-Záâãçéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "ssia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfak_18") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfak_20>[a-zA-Z]+)s mesmas (?P<Pfak_21>[a-zA-Záâãçéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "ssia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfak_20") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfak_22>[a-zA-Z]+) mesmo (?P<Pfak_23>[a-zA-Záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "ssia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfak_22") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfak_24>[a-zA-Z]+) mesma (?P<Pfak_25>[a-zA-Záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "ssia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfak_24") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfak_26>[a-zA-Z]+) mesmo (?P<Pfak_27>[a-zA-Záâãçéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "ssia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfak_26") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfak_28>[a-zA-Z]+)s mesmos (?P<Pfak_29>[a-zA-Záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfak_28") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Pfak_30>[a-zA-Záâãçéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + m.group(3) + "ssia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Pfak_a>[a-zA-Záâãéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "ssia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)mas (?P<Pfak_b>[a-zA-Záâãéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "ssia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfak_c>[a-zA-Záâãéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "ssia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfak_d>[a-zA-Záâãéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "ssia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfak_e>[a-zA-Záâãéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "ssia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfak_f>[a-zA-Záâãéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Pfak_g>[a-zA-Záâãéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pbfe_0>[a-zA-Záâãéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= "Uma " + m.group(2) + m.group(3) + "ssia\\nUmas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) uma (?P<Pbfe_1>[a-zA-Záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= ", uma " + m.group(2) + m.group(3) + "ssia\\n, umas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pbfe_0>[a-zA-Záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + m.group(3) + "ssia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pbfe_0>[a-zA-Záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + m.group(3) + "ssia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfe_2>[a-zA-Záâãçéêíóôú]+) uma (?P<Pbfe_3>[a-zA-Záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + m.group(3) + "ssia\\n" + m.group(1) + " umas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfe_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfe_4>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfe_5>[a-zA-Záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "ssia\\n" + m.group(1) + " e umas " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfe_4") in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfe_6>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfe_7>[a-zA-Záâãçéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfe_6").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfe_8>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pbfe_9>[a-zA-Záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfe_8").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfe_10>[a-zA-Záâãçéêíóôú]+) (?P<Pbfe_11>[a-zA-Záâãçéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfe_10").lower() in numFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfe_12>[0-9]+) (?P<Pbfe_13>[a-záâãçéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pbfe_12") in "00000000001" and not excYssia.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pbfe_14>[0-9][0-9][0-9]) (?P<Pbfe_15>[a-záâãçéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(4) + "nças"', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfe_16>[0-9]+) (?P<Pbfe_17>[a-záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "ssia"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pbfe_16") in "00000000001" and not excYssia.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfe_17>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfe_18>[a-zA-Záâãçéêíóôú]+)([áéíú])ssia(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfe_17").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfe_19>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfe_20>[a-zA-Záâãçéêíóôú]+)([áéíú])ssias(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfe_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfc_e>[a-zA-Z]+) (?P<Pfc_f>[a-zA-Zç]+)([áéíóú])rnias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "rnia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfc_e") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfc_g>[a-zA-Z]+)s (?P<Pfc_h>[a-zA-Zç]+)([áéíóú])rnia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "rnia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfc_g") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfc_i>[a-zA-Z]+) (?P<Pfc_j>[a-zA-Zç]+)([áéíóú])rnia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "rnia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfc_i") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pfal_8>[a-zA-Záâãçéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pfal_9>[a-zA-Záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitos (?P<Pfal_10>[a-zA-Záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= m.group(1) + "uitas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uito (?P<Pfal_11>[a-zA-Záâãçéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "rnia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao] (?P<Pfal_12>[a-zA-Záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "rnia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pfal_13>[a-zA-Záâãçéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "rnia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucos (?P<Pfal_14>[a-zA-Záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= m.group(1) + "oucas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouco (?P<Pfal_15>[a-zA-Záâãçéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "rnia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pfal_16>[a-zA-Záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "rnia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pfal_17>[a-zA-Záâãçéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "rnia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pfal_14>[a-zA-Záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= m.group(1) + "odas as " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pfal_15>[a-zA-Záâãçéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "rnia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pfal_16>[a-zA-Záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "rnia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pfal_17>[a-zA-Záâãçéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "rnia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfal_18>[a-zA-Z]+)s mesmos (?P<Pfal_19>[a-zA-Záâãçéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "rnia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfal_18") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfal_20>[a-zA-Z]+)s mesmas (?P<Pfal_21>[a-zA-Záâãçéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "rnia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfal_20") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfal_22>[a-zA-Z]+) mesmo (?P<Pfal_23>[a-zA-Záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "rnia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfal_22") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfal_24>[a-zA-Z]+) mesma (?P<Pfal_25>[a-zA-Záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "rnia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfal_24") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfal_26>[a-zA-Z]+) mesmo (?P<Pfal_27>[a-zA-Záâãçéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "rnia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfal_26") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfal_28>[a-zA-Z]+)s mesmos (?P<Pfal_29>[a-zA-Záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfal_28") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Pfal_30>[a-zA-Záâãçéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + m.group(3) + "rnia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Pfal_a>[a-zA-Záâãéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "rnia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)mas (?P<Pfal_b>[a-zA-Záâãéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "rnia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfal_c>[a-zA-Záâãéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "rnia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfal_d>[a-zA-Záâãéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "rnia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfal_e>[a-zA-Záâãéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "rnia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfal_f>[a-zA-Záâãéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Pfal_g>[a-zA-Záâãéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pbff_0>[a-zA-Záâãéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= "Uma " + m.group(2) + m.group(3) + "rnia\\nUmas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) uma (?P<Pbff_1>[a-zA-Záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= ", uma " + m.group(2) + m.group(3) + "rnia\\n, umas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pbff_0>[a-zA-Záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + m.group(3) + "rnia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pbff_0>[a-zA-Záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + m.group(3) + "rnia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbff_2>[a-zA-Záâãçéêíóôú]+) uma (?P<Pbff_3>[a-zA-Záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + m.group(3) + "rnia\\n" + m.group(1) + " umas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbff_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbff_4>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbff_5>[a-zA-Záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "rnia\\n" + m.group(1) + " e umas " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbff_4") in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbff_6>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbff_7>[a-zA-Záâãçéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbff_6").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbff_8>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pbff_9>[a-zA-Záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbff_8").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbff_10>[a-zA-Záâãçéêíóôú]+) (?P<Pbff_11>[a-zA-Záâãçéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbff_10").lower() in numFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbff_12>[0-9]+) (?P<Pbff_13>[a-záâãçéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pbff_12") in "00000000001" and not excYrnia.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pbff_14>[0-9][0-9][0-9]) (?P<Pbff_15>[a-záâãçéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(4) + "nças"', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbff_16>[0-9]+) (?P<Pbff_17>[a-záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "rnia"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pbff_16") in "00000000001" and not excYrnia.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbff_17>[a-zA-Záâãçéêíóôú]+)os (?P<Pbff_18>[a-zA-Záâãçéêíóôú]+)([áéíú])rnia(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbff_17").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbff_19>[a-zA-Záâãçéêíóôú]+)os (?P<Pbff_20>[a-zA-Záâãçéêíóôú]+)([áéíú])rnias(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbff_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfc_k>[a-zA-Z]+) (?P<Pfc_l>[a-zA-Zç]+)([âêíôú])nias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "nia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfc_k") in aaSingular and not m.group("Pfc_l") in "-Qu-qu-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfc_m>[a-zA-Z]+)s (?P<Pfc_n>[a-zA-Zç]+)([âêíôú])nia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "nia\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfc_m") in aaSingular and not m.group("Pfc_n") in "-Qu-qu-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfc_o>[a-zA-Z]+) (?P<Pfc_p>[a-zA-Zç]+)([âêíôú])nia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "nia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfc_o") in abSingular and not m.group("Pfc_p") in "-Qu-qu-"'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pfam_8>[a-zA-Záâãçéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pfam_9>[a-zA-Záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitos (?P<Pfam_10>[a-zA-Záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= m.group(1) + "uitas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uito (?P<Pfam_11>[a-zA-Záâãçéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "nia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao] (?P<Pfam_12>[a-zA-Záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "nia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pfam_13>[a-zA-Záâãçéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + "uita " + m.group(2) + m.group(3) + "nia\\n" + m.group(1) + "uitas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucos (?P<Pfam_14>[a-zA-Záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= m.group(1) + "oucas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouco (?P<Pfam_15>[a-zA-Záâãçéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "nia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pfam_16>[a-zA-Záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "nia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pfam_17>[a-zA-Záâãçéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + m.group(3) + "nia\\n" + m.group(1) + "oucas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pfam_14>[a-zA-Záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= m.group(1) + "odas as " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pfam_15>[a-zA-Záâãçéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "nia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pfam_16>[a-zA-Záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "nia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pfam_17>[a-zA-Záâãçéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + m.group(3) + "nia\\n" + m.group(1) + "odas as " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfam_18>[a-zA-Z]+)s mesmos (?P<Pfam_19>[a-zA-Záâãçéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "nia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfam_18") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfam_20>[a-zA-Z]+)s mesmas (?P<Pfam_21>[a-zA-Záâãçéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "nia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfam_20") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfam_22>[a-zA-Z]+) mesmo (?P<Pfam_23>[a-zA-Záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "nia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfam_22") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfam_24>[a-zA-Z]+) mesma (?P<Pfam_25>[a-zA-Záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "nia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfam_24") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfam_26>[a-zA-Z]+) mesmo (?P<Pfam_27>[a-zA-Záâãçéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + m.group(3) + "nia"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfam_26") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfam_28>[a-zA-Z]+)s mesmos (?P<Pfam_29>[a-zA-Záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfam_28") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Pfam_30>[a-zA-Záâãçéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + m.group(3) + "nia\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Pfam_a>[a-zA-Záâãéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "nia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)mas (?P<Pfam_b>[a-zA-Záâãéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "nia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfam_c>[a-zA-Záâãéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "nia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfam_d>[a-zA-Záâãéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "nia\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pfam_e>[a-zA-Záâãéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "nia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pfam_f>[a-zA-Záâãéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Pfam_g>[a-zA-Záâãéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pfam_h>[a-zA-Záâãéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pbfg_0>[a-zA-Záâãéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= "Uma " + m.group(2) + m.group(3) + "nia\\nUmas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) uma (?P<Pbfg_1>[a-zA-Záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= ", uma " + m.group(2) + m.group(3) + "nia\\n, umas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pbfg_0>[a-zA-Záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + m.group(3) + "nia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pbfg_0>[a-zA-Záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + m.group(3) + "nia"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfg_2>[a-zA-Záâãçéêíóôú]+) uma (?P<Pbfg_3>[a-zA-Záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + m.group(3) + "nia\\n" + m.group(1) + " umas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfg_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfg_4>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfg_5>[a-zA-Záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "nia\\n" + m.group(1) + " e umas " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pbfg_4") in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfg_6>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pbfg_7>[a-zA-Záâãçéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfg_6").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfg_8>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pbfg_9>[a-zA-Záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfg_8").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfg_10>[a-zA-Záâãçéêíóôú]+) (?P<Pbfg_11>[a-zA-Záâãçéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfg_10").lower() in numFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfg_12>[0-9]+) (?P<Pbfg_13>[a-záâãçéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pbfg_12") in "00000000001" and not excYnia.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pbfg_14>[0-9][0-9][0-9]) (?P<Pbfg_15>[a-záâãçéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(4) + "nças"', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfg_16>[0-9]+) (?P<Pbfg_17>[a-záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "nia"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pbfg_16") in "00000000001" and not excYnia.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfg_17>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfg_18>[a-zA-Záâãçéêíóôú]+)([âêíôú])nia(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfg_17").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pbfg_19>[a-zA-Záâãçéêíóôú]+)os (?P<Pbfg_20>[a-zA-Záâãçéêíóôú]+)([âêíôú])nias(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pbfg_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Puf_a>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_a") in plvrFema and not m.group("Puf_a") in excplVirg'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Puf_b>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_b") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Puf_c>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_c") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Puf_d>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_d") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Puf_e>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_e") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Puf_f>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_f") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Puf_g>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_g") in plvrFema and not m.group("Puf_g") in excplVirg'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Puf_h>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_h") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([U])ma (?P<Puf_i>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "\\n" + m.group(1) + "mas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_i") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Puf_j>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_j") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Puf_k>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_k") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Puf_l>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_l") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Puf_m>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_m") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Puf_n>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_n") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Puf_o>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "\\n" + m.group(1) + "lgumas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_o") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Puf_p>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_p") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Puf_q>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_q") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Puf_r>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_r") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Puf_s>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_s") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Puf_t>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_t") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Puf_u>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "\\n" + m.group(1) + "enhumas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_u") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Puf_v>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(2) + " " + m.group(3) + "\\n" + m.group(2) + "s " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_v") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Puf_w>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "\\n" + m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Puf_w") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pauf_0>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= "Uma " + m.group(2) + "\\nUmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_0") in plvrFema'],
 ['(?u)\\b([,]) uma (?P<Pauf_1>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= ", uma " + m.group(2) + "\\n, umas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_1") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pauf_0>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_0") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pauf_0>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_0") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_2>[a-zA-Záâãçéêíóôú]+) uma (?P<Pauf_3>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "\\n" + m.group(1) + " umas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_3") in plvrFema and not m.group("Pauf_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_4>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pauf_5>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "\\n" + m.group(1) + " e umas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_5") in plvrFema and not m.group("Pauf_4") in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_6>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pauf_7>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_7") in plvrFema and m.group("Pauf_6").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_8>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pauf_9>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_9") in plvrFema and m.group("Pauf_8").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_10>[a-zA-Záâãçéêíóôú]+) (?P<Pauf_11>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_11") in plvrFema and m.group("Pauf_10").lower() in numFem and not m.group("Pauf_11") in excplVirg'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_12>[0-9]+) (?P<Pauf_13>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pauf_13") in plvrFema and not m.group("Pauf_12") in "00000000001" and not excYfema.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pauf_14>[0-9][0-9][0-9]) (?P<Pauf_15>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "s"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pauf_15") in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_16>[0-9]+) (?P<Pauf_17>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2)', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pauf_17") in plvrFema and m.group("Pauf_16") in "00000000001" and not excYfema.search(TEXT) and not exchora.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_17>[a-zA-Záâãçéêíóôú]+)os (?P<Pauf_18>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_18") in plvrFema and m.group("Pauf_17").lower() in nuMfmoas and not m.group("Pauf_18") in excplVirg'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_19>[a-zA-Záâãçéêíóôú]+)os (?P<Pauf_20>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_20") in plvrFema and m.group("Pauf_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pst_0>[a-zA-Z]+) (?P<Pst_1>[a-zA-Z]+ista)s(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "\\n" + m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pst_0") in aaSingular and not m.group("Pst_1") in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pst_2>[a-zA-Z]+)s (?P<Pst_3>[a-zA-Zç]+ista)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "\\n" + m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pst_2") in aaSingular and not m.group("Pst_3") in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pst_4>[a-zA-Z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "\\n" + m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pst_4") in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pst_5>[a-zA-Zç]+ista)(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "\\n" + m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pst_5") in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pst_6>[a-zA-Z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "\\n" + m.group(1) + "mas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pst_6") in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pst_7>[a-zA-Zç]+ista)(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "\\n" + m.group(1) + "mas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pst_7") in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])(a|Doi|doi|Dua|dua)s (?P<Pst_8>[a-zA-Zç]+ista)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pst_8") in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Piv_0>[a-zA-Z]+) (?P<Piv_1>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "\\n" + m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Piv_0") in aaSingular and m.group("Piv_1") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Piv_2>[a-zA-Z]+)s (?P<Piv_3>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "\\n" + m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Piv_2") in aaSingular and m.group("Piv_3") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Piv_4>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "\\n" + m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Piv_4") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Piv_5>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "\\n" + m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Piv_5") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Piv_6>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "\\n" + m.group(1) + "mas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Piv_6") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Piv_7>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "\\n" + m.group(1) + "mas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Piv_7") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(a|Doi|doi|Dua|dua)s (?P<Piv_8>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Piv_8") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Àà])s (?P<Piv_9>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Você quis dizer:', 'm.group("Piv_9") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Piv_10>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Você quis dizer:', 'm.group("Piv_10") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári([ao])s (?P<Pivv_9>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + "ári" + m.group(2) + "s " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_9") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uita (?P<Pivv_10>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_10") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pivv_11>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_11") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao]) (?P<Pivv_12>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_12") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao])s (?P<Pivv_13>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_13") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pivv_14>[a-zA-Z]+)s mesmos (?P<Pivv_15>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "\\n" + m.group(1) + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_14") in abSingular and m.group("Pivv_15") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pivv_16>[a-zA-Z]+)s mesmas (?P<Pivv_17>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "\\n" + m.group(1) + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_16") in acSingular and m.group("Pivv_17") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pivv_18>[a-zA-Z]+)s mesmo (?P<Pivv_19>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "\\n" + m.group(1) + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_18") in abSingular and m.group("Pivv_19") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pivv_20>[a-zA-Z]+)s mesma (?P<Pivv_21>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "\\n" + m.group(1) + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_20") in acSingular and m.group("Pivv_21") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Pivv_22>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "\\n" + m.group(1) + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_22") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Pivv_23>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_23") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pivv_24>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= "Uma " + m.group(2) + "\\nUmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_24") in plvrInva'],
 ['(?u)\\b([,]) uma (?P<Pivv_25>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= ", uma " + m.group(2) + "\\n, umas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_25") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Pivv_24>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= "Um " + m.group(2) + "\\nUns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_26") in plvrInva'],
 ['(?u)\\b([,]) um (?P<Pivv_27>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= ", um " + m.group(2) + "\\n, uns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_27") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Pivv_28>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_28") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pivv_29>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_29") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Pivv_30>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_30") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pivv_31>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_31") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pivv_32>[a-zA-Záâãçéêíóôú]+) um (?P<Pivv_33>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) + "\\n" + m.group(1) + " uns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pivv_32") in "-E-e-" and m.group("Pivv_33") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pivv_34>[a-zA-Záâãçéêíóôú]+) uma (?P<Pivv_35>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "\\n" + m.group(1) + " umas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pivv_34") in "-E-e-" and m.group("Pivv_35") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pivv_36>[a-zA-Záâãçéêíóôú]+) e um (?P<Pivv_37>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "\\n" + m.group(1) + " e uns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pivv_36") in numEfem and m.group("Pivv_37") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pivv_38>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pivv_39>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "\\n" + m.group(1) + " e umas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pivv_38") in numEfem and m.group("Pivv_39") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pivv_40>[a-zA-Záâãçéêíóôú]+) e um (?P<Pivv_41>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_40").lower() in numEmasc and m.group("Pivv_41") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pivv_42>[a-zA-Záâãçéêíóôú]+) e uns (?P<Pivv_43>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_42").lower() in numEmasc and m.group("Pivv_43") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pivv_44>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pivv_45>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_44").lower() in numEfem and m.group("Pivv_45") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pivv_46>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pivv_47>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_46").lower() in numEfem and m.group("Pivv_47") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pivv_48>[a-zA-Záâãçéêíóôú]+) (?P<Pivv_49>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pivv_48").lower() in numFem and m.group("Pivv_49") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pivv_50>[0-9]+) (?P<Pivv_51>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pivv_50") in "00000000001" and not excYinvaz.search(TEXT) and m.group("Pivv_51") in plvrInva'],
 ['(?u)\\b([.])(?P<Pivv_52>[0-9][0-9][0-9]) (?P<Pivv_53>[a-zA-Záâãçéêíóôú]+a)(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "s"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("m.group("Pivv_53") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pivv_54>[0-9]+) (?P<Pivv_55>[a-zA-Záâãçéêíóôú]+a)s(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2)', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pivv_55") in "00000000001" and not excYinvaz.search(TEXT) and m.group("Pivv_55") in plvrInva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdo_0>[a-zA-Z]+) (?P<Pdo_1>[a-zA-Z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "do\\n" + m.group(1) + "s " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdo_0") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdo_2>[a-zA-Z]+)s (?P<Pdo_3>[a-zA-Z]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "do\\n" + m.group(1) + "s " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdo_2") in adSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdo_4>[a-zA-Z]+) (?P<Pdo_5>[a-zA-Z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "da\\n" + m.group(1) + "s " + m.group(2) + m.group(3) + "das\\n" + varGenero[m.group(1)] + " " + m.group(2) + m.group(3) + "do\\n" + varGenero[m.group(1)] + "s " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdo_4") in aeSingular and not m.group("Pdo_5") in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdo_6>[a-zA-Z]+)s (?P<Pdo_7>[a-zA-Z]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "da\\n" + m.group(1) + "s " + m.group(2) + m.group(3) + "das\\n" + varGenero[m.group(1)] + " " + m.group(2) + m.group(3) + "do\\n" + varGenero[m.group(1)] + "s " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdo_6") in aeSingular and not m.group("Pdo_7") in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdo_8>[a-zA-Z]+) (?P<Pdo_9>[a-zA-Z]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "da\\n" + varGenero[m.group(1)] + " " + m.group(2) + m.group(3) + "do"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdo_8") in aeSingular and not m.group("Pdo_9") in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdo_a>[a-zA-Z]+)s (?P<Pdo_b>[a-zA-Z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "das\\n" + varGenero[m.group(1)] + "s " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdo_a") in aeSingular and not m.group("Pdo_b") in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pda_0>[a-zA-Z]+) (?P<Pda_1>[a-zA-Z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "da\\n" + m.group(1) + "s " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pda_0") in acSingular and not m.group("Pda_1") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pda_2>[a-zA-Z]+)s (?P<Pda_3>[a-zA-Z]+)([aí])da(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "da\\n" + m.group(1) + "s " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pda_2") in acSingular and not m.group("Pda_3") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pda_4>[a-zA-Z]+) (?P<Pda_5>[a-zA-Z]+)([aí])das(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "da\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pda_4") in abSingular and not m.group("Pda_5") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pda_6>[a-zA-Z]+)s (?P<Pda_7>[a-zA-Z]+)([aí])da(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "da\\n" + varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pda_6") in abSingular and not m.group("Pda_7") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pda_8>[a-zA-Z]+) (?P<Pda_9>[a-zA-Z]+)([aí])da(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + m.group(3) + "da"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pda_8") in abSingular and not m.group("Pda_9") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pda_a>[a-zA-Z]+)s (?P<Pda_b>[a-zA-Z]+)([aí])das(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pda_a") in abSingular and not m.group("Pda_b") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pds_0>[a-zA-Z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + m.group(3) + "do\\n" + m.group(1) + "ns " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pds_1>[a-zA-Zç]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + m.group(3) + "do\\n" + m.group(1) + "ns " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pds_2>[a-zA-Z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "da\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pds_2") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pds_3>[a-zA-Zç]+)([aí])da(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "da\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pds_3") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pds_4>[a-zA-Z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pds_4") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pds_5>[a-zA-Zç]+)([aí])da(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "da"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pds_5") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pds_6>[a-zA-Z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "da\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pds_6") in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pds_7>[a-zA-Zç]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "da\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pds_7") in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pds_8>[a-zA-Zç]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pds_9>[a-zA-Zç]+)([aí])da(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pds_9") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pds_a>[a-zA-Zç]+)([aí])da(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pds_a") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pds_b>[a-zA-Zç]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pds_b") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pds_c>[a-zA-Zç]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pds_d>[a-zA-Zç]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pds_e>[a-zA-Zç]+)([aí])da(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "da\\n" + m.group(1) + "s " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pds_e") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pds_f>[a-zA-Zç]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pds_g>[a-zA-Zç]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pds_h>[a-zA-Z]+)([aí])da(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "da"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pds_h") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pds_i>[a-zA-Z]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + m.group(3) + "da\\n" + m.group(1) + "m " + m.group(2) + m.group(3) + "do"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pds_j>[a-zA-Z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + m.group(3) + "dos\\n" + m.group(1) + "mas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pds_j") in excpLvrada'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pds_k>[a-zA-Z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + m.group(3) + "das\\n" + m.group(1) + "ns " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pido_0>[a-zA-Z]+) (?P<Pido_1>[a-zA-Zç]+)idos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ido\\n" + m.group(1) + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pido_0") in abSingular and not m.group("Pido_1") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pido_2>[a-zA-Z]+)s (?P<Pido_3>[a-zA-Zç]+)ido(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ido\\n" + m.group(1) + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pido_2") in adSingular and not m.group("Pido_3") in "lib-Lib-dev"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pido_4>[a-zA-Z]+) (?P<Pido_5>[a-zA-Zç]+)idos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ida\\n" + m.group(1) + "s " + m.group(2) + "idas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ido\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pido_4") in aeSingular and not m.group("Pido_5") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pido_6>[a-zA-Z]+)s (?P<Pido_7>[a-zA-Zç]+)ido(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ida\\n" + m.group(1) + "s " + m.group(2) + "idas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ido\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pido_6") in acSingular and not m.group("Pido_7") in "lib-Lib-dev"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pido_8>[a-zA-Z]+) (?P<Pido_9>[a-zA-Zç]+)ido(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ida\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ido"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pido_8") in aeSingular and not excfido.search(TEXT) and not m.group("Pido_9") in "lib-Lib-dev"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pido_a>[a-zA-Z]+)s (?P<Pido_b>[a-zA-Zç]+)idos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idas\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pido_a") in acSingular and not m.group("Pido_b") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pida_0>[a-zA-Z]+) (?P<Pida_1>[a-zA-Zç]+)idas(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ida\\n" + m.group(1) + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pida_0") in acSingular and not m.group("Pida_1") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pida_2>[a-zA-Z]+)s (?P<Pida_3>[a-zA-Zç]+)ida(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ida\\n" + m.group(1) + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pida_2") in acSingular and not m.group("Pida_3") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pida_4>[a-zA-Z]+) (?P<Pida_5>[a-zA-Zç]+)idas(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ida\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pida_4") in abSingular and not m.group("Pida_5") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pida_6>[a-zA-Z]+)s (?P<Pida_7>[a-zA-Zç]+)ida(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ida\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pida_6") in abSingular and not m.group("Pida_7") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pida_8>[a-zA-Z]+) (?P<Pida_9>[a-zA-Zç]+)ida(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ida"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pida_8") in abSingular and not m.group("Pida_9") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pida_a>[a-zA-Z]+)s (?P<Pida_b>[a-zA-Zç]+)idas(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pida_a") in abSingular and not m.group("Pida_b") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pids_0>[a-zA-Zç]+)idos(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ido\\n" + m.group(1) + "ns " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_0") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pids_1>[a-zA-Zç]+)ido(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ido\\n" + m.group(1) + "ns " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_1") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pids_2>[a-zA-Zç]+)idas(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ida\\n" + m.group(1) + "mas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_2") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pids_3>[a-zA-Zç]+)ida(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ida\\n" + m.group(1) + "mas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_3") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pids_4>[a-zA-Zç]+)idas(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_4") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pids_5>[a-zA-Zç]+)ida(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ida"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_5") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pids_6>[a-zA-Zç]+)idos(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ida\\n" + m.group(1) + "mas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_6") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pids_7>[a-zA-Zç]+)ido(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ida\\n" + m.group(1) + "mas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_7") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pids_8>[a-zA-Zç]+)ido(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_8") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pids_9>[a-zA-Zç]+)ida(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_9") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pids_a>[a-zA-Zç]+)ida(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_a") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pids_b>[a-zA-Zç]+)idas(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_b") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pids_c>[a-zA-Zç]+)ido(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_c") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pids_d>[a-zA-Zç]+)idos(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_d") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pids_e>[a-zA-Zç]+)ida(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ida\\n" + m.group(1) + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_e") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pids_f>[a-zA-Zç]+)ido(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_f") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pids_g>[a-zA-Zç]+)idos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_g") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pids_h>[a-zA-Zç]+)ida(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ida"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_h") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pids_i>[a-zA-Zç]+)ido(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ida\\n" + m.group(1) + "m " + m.group(2) + "ido"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_i") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pids_j>[a-zA-Zç]+)idas(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "idos\\n" + m.group(1) + "mas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_j") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pids_k>[a-zA-Zç]+)idos(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "idas\\n" + m.group(1) + "ns " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pids_k") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pso_0>[a-zA-Z]+) (?P<Pso_1>[a-zA-Zç]+)osos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "oso\\n" + m.group(1) + "s " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pso_0") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pso_2>[a-zA-Z]+)s (?P<Pso_3>[a-zA-Zç]+)oso(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "oso\\n" + m.group(1) + "s " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pso_2") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pso_4>[a-zA-Z]+) (?P<Pso_5>[a-zA-Zç]+)osos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "osa\\n" + m.group(1) + "s " + m.group(2) + "osas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "oso\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pso_4") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pso_6>[a-zA-Z]+)s (?P<Pso_7>[a-zA-Zç]+)oso(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "osa\\n" + m.group(1) + "s " + m.group(2) + "osas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "oso\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pso_6") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pso_8>[a-zA-Z]+) (?P<Pso_9>[a-zA-Zç]+)oso(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "osa\\n" + varGenero[m.group(1)] + " " + m.group(2) + "oso"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pso_8") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pso_a>[a-zA-Z]+)s (?P<Pso_b>[a-zA-Zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "osas\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pso_a") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psa_0>[a-zA-Z]+) (?P<Psa_1>[a-zA-Zç]+)osas(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "osa\\n" + m.group(1) + "s " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psa_0") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psa_2>[a-zA-Z]+)s (?P<Psa_3>[a-zA-Zç]+)osa(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "osa\\n" + m.group(1) + "s " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psa_2") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psa_4>[a-zA-Z]+) (?P<Psa_5>[a-zA-Zç]+)osas(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "osa\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psa_4") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psa_6>[a-zA-Z]+)s (?P<Psa_7>[a-zA-Zç]+)osa(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "osa\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psa_6") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psa_8>[a-zA-Z]+) (?P<Psa_9>[a-zA-Zç]+)osa(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "osa"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psa_8") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psa_a>[a-zA-Z]+)s (?P<Psa_b>[a-zA-Zç]+)osas(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psa_a") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pss_0>[a-zA-Zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "oso\\n" + m.group(1) + "ns " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pss_1>[a-zA-Zç]+)oso(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "oso\\n" + m.group(1) + "ns " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pss_2>[a-zA-Zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "osa\\n" + m.group(1) + "mas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pss_3>[a-zA-Zç]+)osa(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "osa\\n" + m.group(1) + "mas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pss_4>[a-zA-Zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pss_5>[a-zA-Zç]+)osa(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "osa"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pss_6>[a-zA-Zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "osa\\n" + m.group(1) + "mas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pss_6") in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pss_7>[a-zA-Zç]+)oso(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "osa\\n" + m.group(1) + "mas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pss_7") in excAdo'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pss_8>[a-zA-Zç]+)oso(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pss_9>[a-zA-Zç]+)osa(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pss_a>[a-zA-Zç]+)osa(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pss_b>[a-zA-Zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pss_c>[a-zA-Zç]+)oso(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pss_d>[a-zA-Zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pss_e>[a-zA-Zç]+)osa(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "osa\\n" + m.group(1) + "s " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pss_f>[a-zA-Zç]+)oso(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pss_g>[a-zA-Zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pss_h>[a-zA-Zç]+)osa(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "osa"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pss_i>[a-zA-Zç]+)oso(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "osa\\n" + m.group(1) + "m " + m.group(2) + "oso"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pss_j>[a-zA-Zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "osos\\n" + m.group(1) + "mas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pss_k>[a-zA-Zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "osas\\n" + m.group(1) + "ns " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvo_0>[a-zA-Z]+) (?P<Pvo_1>[a-zA-Zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ivo\\n" + m.group(1) + "s " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvo_0") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvo_2>[a-zA-Z]+)s (?P<Pvo_3>[a-zA-Zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ivo\\n" + m.group(1) + "s " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvo_2") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvo_4>[a-zA-Z]+) (?P<Pvo_5>[a-zA-Zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "iva\\n" + m.group(1) + "s " + m.group(2) + "ivas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ivo\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvo_4") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvo_6>[a-zA-Z]+)s (?P<Pvo_7>[a-zA-Zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "iva\\n" + m.group(1) + "s " + m.group(2) + "ivas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ivo\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvo_6") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvo_8>[a-zA-Z]+) (?P<Pvo_9>[a-zA-Zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "iva\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ivo"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvo_8") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvo_a>[a-zA-Z]+)s (?P<Pvo_b>[a-zA-Zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ivas\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvo_a") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pva_0>[a-zA-Z]+) (?P<Pva_1>[a-zA-Zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "iva\\n" + m.group(1) + "s " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pva_0") in acSingular and not m.group("Pva_1") in excpLvriva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pva_2>[a-zA-Z]+)s (?P<Pva_3>[a-zA-Zç]+)iva(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "iva\\n" + m.group(1) + "s " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pva_2") in acSingular and not m.group("Pva_3") in excpLvriva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pva_4>[a-zA-Z]+) (?P<Pva_5>[a-zA-Zç]+)ivas(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "iva\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pva_4") in abSingular and not m.group("Pva_5") in excpLvriva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pva_6>[a-zA-Z]+)s (?P<Pva_7>[a-zA-Zç]+)iva(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "iva\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pva_6") in abSingular and not m.group("Pva_7") in excpLvriva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pva_8>[a-zA-Z]+) (?P<Pva_9>[a-zA-Zç]+)iva(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "iva"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pva_8") in abSingular and not m.group("Pva_9") in excpLvriva'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pva_a>[a-zA-Z]+)s (?P<Pva_b>[a-zA-Zç]+)ivas(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pva_a") in abSingular and not m.group("Pva_b") in excpLvriva'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pvs_0>[a-zA-Zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ivo\\n" + m.group(1) + "ns " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pvs_1>[a-zA-Zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ivo\\n" + m.group(1) + "ns " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pvs_2>[a-zA-Zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "iva\\n" + m.group(1) + "mas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pvs_2") in excpLvriva'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pvs_3>[a-zA-Zç]+)iva(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "iva\\n" + m.group(1) + "mas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pvs_3") in excpLvriva'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pvs_4>[a-zA-Zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pvs_4") in excpLvriva'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pvs_5>[a-zA-Zç]+)iva(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "iva"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pvs_5") in excpLvriva'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pvs_6>[a-zA-Zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "iva\\n" + m.group(1) + "mas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pvs_7>[a-zA-Zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "iva\\n" + m.group(1) + "mas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pvs_8>[a-zA-Zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pvs_9>[a-zA-Zç]+)iva(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pvs_9") in excpLvriva'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pvs_a>[a-zA-Zç]+)iva(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pvs_a") in excpLvriva'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pvs_b>[a-zA-Zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pvs_b") in excpLvriva'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pvs_c>[a-zA-Zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pvs_d>[a-zA-Zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pvs_e>[a-zA-Zç]+)iva(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "iva\\n" + m.group(1) + "s " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pvs_e") in excpLvriva'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pvs_f>[a-zA-Zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pvs_g>[a-zA-Zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pvs_h>[a-zA-Zç]+)iva(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "iva"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pvs_h") in excpLvriva'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pvs_i>[a-zA-Zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "iva\\n" + m.group(1) + "m " + m.group(2) + "ivo"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pvs_j>[a-zA-Zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "ivos\\n" + m.group(1) + "mas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pvs_j") in excpLvriva'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pvs_k>[a-zA-Zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "ivas\\n" + m.group(1) + "ns " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pto_0>[a-zA-Z]+) (?P<Pto_1>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "mento\\n" + m.group(1) + "s " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pto_0") in abSingular and not m.group("Pto_1") in excMento'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pto_2>[a-zA-Z]+)s (?P<Pto_3>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "mento\\n" + m.group(1) + "s " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pto_2") in abSingular and not m.group("Pto_3") in excMento'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pto_4>[a-zA-Z]+) (?P<Pto_5>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "mento\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pto_4") in acSingular and not m.group("Pto_5") in excMento'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pto_6>[a-zA-Z]+)s (?P<Pto_7>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "mento\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pto_6") in acSingular and not m.group("Pto_7") in excMento'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pto_8>[a-zA-Z]+) (?P<Pto_9>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "mento"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pto_8") in acSingular and not m.group("Pto_9") in excMento'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pto_a>[a-zA-Z]+)s (?P<Pto_b>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pto_a") in acSingular and not m.group("Pto_b") in excMento'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pta_0>[a-zA-Z]+) (?P<Pta_1>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "menta\\n" + m.group(1) + "s " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pta_0") in acSingular and m.group("Pta_1") in plvrFmenta'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pta_2>[a-zA-Z]+)s (?P<Pta_3>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "menta\\n" + m.group(1) + "s " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pta_2") in acSingular and m.group("Pta_3") in plvrFmenta'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pta_4>[a-zA-Z]+) (?P<Pta_5>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "menta\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pta_4") in abSingular and m.group("Pta_5") in plvrFmenta'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pta_6>[a-zA-Z]+)s (?P<Pta_7>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "menta\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pta_6") in abSingular and m.group("Pta_7") in plvrFmenta'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pta_8>[a-zA-Z]+) (?P<Pta_9>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "menta"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pta_8") in abSingular and m.group("Pta_9") in plvrFmenta'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pta_a>[a-zA-Z]+)s (?P<Pta_b>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pta_a") in abSingular and m.group("Pta_b") in plvrFmenta'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pts_0>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "mento\\n" + m.group(1) + "ns " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pts_1>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "mento\\n" + m.group(1) + "ns " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pts_2>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "menta\\n" + m.group(1) + "mas " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pts_2") in plvrFmenta'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pts_3>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "menta\\n" + m.group(1) + "mas " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pts_3") in plvrFmenta'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pts_4>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pts_4") in plvrFmenta'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pts_5>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "menta"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pts_5") in plvrFmenta'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pts_6>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "menta\\n" + m.group(1) + "mas " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pts_7>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "menta\\n" + m.group(1) + "mas " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pts_8>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pts_9>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pts_9") in plvrFmenta'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pts_a>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pts_a") in plvrFmenta'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pts_b>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pts_b") in plvrFmenta'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pts_c>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pts_d>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pts_e>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "menta\\n" + m.group(1) + "s " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pts_e") in plvrFmenta'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pts_f>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pts_g>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pts_h>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "menta"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pts_h") in plvrFmenta'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pts_i>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "mento"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pts_j>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pts_j") in plvrFmenta'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pts_k>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pts_10>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '\\1odo \\2mento\\n\\1odos os \\2mentos', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pts_11>[a-zA-Zç]+)mento(?![-\\w–\xad])', '\\1odos os \\2mentos', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])oda (?P<Pts_12>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '\\1odo \\2mento\\n\\1odos os \\2mentos', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odas (?P<Pts_13>[a-zA-Zç]+)mento(?![-\\w–\xad])', '\\1odos os \\2mentos', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pts_14>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '\\1oda \\2menta\\n\\1odas as \\2mentas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pts_15>[a-zA-Zç]+)menta(?![-\\w–\xad])', '\\1odas as \\2mentas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])oda (?P<Pts_16>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '\\1oda \\2menta\\n\\1odas as \\2mentas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odas (?P<Pts_17>[a-zA-Zç]+)menta(?![-\\w–\xad])', '\\1odas as \\2mentas', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_40>[a-zA-Záâãçéêíóôú]+) um (?P<Ptos_50>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) + "mento\\n" + m.group(1) + " uns " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptos_40") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_41>[a-zA-Záâãçéêíóôú]+) uma (?P<Ptos_51>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "menta\\n" + m.group(1) + " umas " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptos_41") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_42>[a-zA-Záâãçéêíóôú]+) uma (?P<Ptos_52>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) + "mento\\n" + m.group(1) + " uma " + m.group(2) + "menta"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptos_42") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_43>[a-zA-Záâãçéêíóôú]+) um (?P<Ptos_53>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "menta\\n" + m.group(1) + " um " + m.group(2) + "mento"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptos_43") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_44>[a-zA-Záâãçéêíóôú]+) uma (?P<Ptos_54>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "menta\\n" + m.group(1) + " uns " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptos_44") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_45>[a-zA-Záâãçéêíóôú]+) um (?P<Ptos_55>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= m.group(1) + " umas " + m.group(2) + "mentas\\n" + m.group(1) + " um " + m.group(2) + "mento"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptos_45") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_46>[a-zA-Záâãçéêíóôú]+) uns (?P<Ptos_56>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + " uns " + m.group(2) + "mentos\\n" uma " + m.group(2) + "menta"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptos_46") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_47>[a-zA-Záâãçéêíóôú]+) uns (?P<Ptos_57>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= m.group(1) + " uns " + m.group(2) + "mentos\\n" + m.group(1) + " umas " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptos_47") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_48>[a-zA-Záâãçéêíóôú]+) umas (?P<Ptos_58>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + " umas " + m.group(2) + "mentas\\n" + m.group(1) + " um " + m.group(2) + "mento"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptos_48") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_49>[a-zA-Záâãçéêíóôú]+) umas (?P<Ptos_59>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) + " umas " + m.group(2) + "mentas\\n" + m.group(1) + " uns " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptos_49") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_60>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptos_70>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "mento\\n" + m.group(1) + " e uns " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptos_60") in numEmfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_61>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptos_71>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "menta\\n" + m.group(1) + " e umas " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptos_61") in numEmfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_62>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptos_72>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "menta\\n" + m.group(1) + " e uns " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptos_62") in numEmfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_63>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptos_73>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= m.group(1) + " e umas " + m.group(2) + "mentas\\n" + m.group(1) + " e um " + m.group(2) + "mento"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptos_63") in numEmfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_64>[a-zA-Záâãçéêíóôú]+) e uns (?P<Ptos_74>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= m.group(1) + " e uns " + m.group(2) + "mentos\\n" + m.group(1) + " e umas " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptos_64") in numEmfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_65>[a-zA-Záâãçéêíóôú]+) e umas (?P<Ptos_75>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) + " e umas " + m.group(2) + "mentas\\n" + m.group(1) + " e uns " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptos_65") in numEmfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_80>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptos_90>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_80").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_81>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptos_91>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_81").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_82>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptos_92>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "mentos\\n" + m.group(1) + " e uma " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_82").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_83>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptos_93>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "mentas\\n" + m.group(1) + " e um " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_83").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_84>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptos_94>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "mentas\\n" + m.group(1) + " e um " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_84").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_85>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptos_95>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "mentas\\n" + m.group(1) + " e um " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_85").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_86>[a-zA-Záâãçéêíóôú]+) e uns (?P<Ptos_96>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "mentos\\n" + m.group(1) + " e uma " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_86").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_87>[a-zA-Záâãçéêíóôú]+) e uns (?P<Ptos_97>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "mentos\\n" + m.group(1) + " e uma " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_87").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_88>[a-zA-Záâãçéêíóôú]+) e umas (?P<Ptos_98>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "mentas\\n" + m.group(1) + " e um " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_88").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_89>[a-zA-Záâãçéêíóôú]+) e umas (?P<Ptos_99>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "mentas\\n" + m.group(1) + " e um " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_89").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_100>[a-zA-Záâãçéêíóôú]+) (?P<Ptos_101>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_100").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_102>[a-zA-Záâãçéêíóôú]+) (?P<Ptos_103>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_102").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_104>[0-9]+) (?P<Ptos_105>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "mentos"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Ptos_104") in "00000000001" and not excYmfoa.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_106>[0-9]+) (?P<Ptos_107>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "mentas"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Ptos_106") in "00000000001" and not excYmfoa.search(TEXT)'],
 ['(?u)\\b([.])(?P<Ptos__108>[0-9][0-9][0-9]) (?P<Ptos_109>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "mentos"', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)\\b([.])(?P<Ptos__110>[0-9][0-9][0-9]) (?P<Ptos_111>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "mentas"', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_112>[0-1]+) (?P<Ptos_113>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"o"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptos_112") in "00000000001" and not excYmfoa.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_114>[0-1]+) (?P<Ptos_115>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"a"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptos_114") in "00000000001" and not excYmfoa.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_116>[a-zA-Záâãçéêíóôú]+)as (?P<Ptos_117>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_116").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_118>[a-zA-Záâãçéêíóôú]+)as (?P<Ptos_119>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_118").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_120>[a-zA-Záâãçéêíóôú]+)os (?P<Ptos_121>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_120").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_122>[a-zA-Záâãçéêíóôú]+)os (?P<Ptos_123>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_122").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_124>[a-zA-Záâãçéêíóôú]+)os (?P<Ptos_125>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_100").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_126>[a-zA-Záâãçéêíóôú]+)as (?P<Ptos_127>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_102").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_180>[a-zA-Záâãçéêíóôú]+)[ao]s e uma (?P<Ptos_190>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + "as e uma " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_180").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_181>[a-zA-Záâãçéêíóôú]+)[ao]s e um (?P<Ptos_191>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + "os e um " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_181").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_182>[a-zA-Záâãçéêíóôú]+)[ao]s e uma (?P<Ptos_192>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + "os e um " + m.group(2) + "mentos\\n" + m.group(1) + "as e uma " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_182").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_183>[a-zA-Záâãçéêíóôú]+)[ao]s e um (?P<Ptos_193>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + "as e uma " + m.group(2) + "mentas\\n" + m.group(1) + "os e um " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_183").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_184>[a-zA-Záâãçéêíóôú]+)[ao]s e uma (?P<Ptos_194>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) +os " e uma " + m.group(2) + "mentas\\n" + m.group(1) + "os e um " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_184").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_185>[a-zA-Záâãçéêíóôú]+)[ao]s e um (?P<Ptos_195>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= m.group(1) + "as e uma " + m.group(2) + "mentas\\n" + m.group(1) + "os e um " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_185").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_186>[a-zA-Záâãçéêíóôú]+)[ao]s e uns (?P<Ptos_196>[a-zA-Zç]+)menta(?![-\\w–\xad])', '= m.group(1) + "os e um " + m.group(2) + "mentos\\n" + m.group(1) + "as e uma " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_186").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_187>[a-zA-Záâãçéêíóôú]+)[ao]s e uns (?P<Ptos_197>[a-zA-Zç]+)mentas(?![-\\w–\xad])', '= m.group(1) + "os e um " + m.group(2) + "mentos\\n" + m.group(1) + "as e uma " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_187").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_188>[a-zA-Záâãçéêíóôú]+)[ao]s e umas (?P<Ptos_198>[a-zA-Zç]+)mento(?![-\\w–\xad])', '= m.group(1) + "as e uma " + m.group(2) + "mentas\\n" + m.group(1) + "os e um " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_188").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptos_189>[a-zA-Záâãçéêíóôú]+)[ao]s e umas (?P<Ptos_199>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '= m.group(1) + "as e uma " + m.group(2) + "mentas\\n" + m.group(1) + "os e um " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptos_189").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pico_0>[a-zA-Z]+) (?P<Pico_1>[a-zA-Zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ico\\n" + m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pico_0") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pico_2>[a-zA-Z]+)s (?P<Pico_3>[a-zA-Zç]+[âêô][mn])ico(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ico\\n" + m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pico_2") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pico_4>[a-zA-Z]+) (?P<Pico_5>[a-zA-Zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + m.group(1) + "s " + m.group(2) + "icas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ico\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pico_4") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pico_6>[a-zA-Z]+)s (?P<Pico_7>[a-zA-Zç]+[âêô][mn])ico(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + m.group(1) + "s " + m.group(2) + "icas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ico\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pico_6") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pico_8>[a-zA-Z]+) (?P<Pico_9>[a-zA-Zç]+[âêô][mn])ico(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ico"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pico_8") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pico_a>[a-zA-Z]+)s (?P<Pico_b>[a-zA-Zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pico_a") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pica_0>[a-zA-Z]+) (?P<Pica_1>[a-zA-Zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pica_0") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pica_2>[a-zA-Z]+)s (?P<Pica_3>[a-zA-Zç]+[âêô][mn])ica(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pica_2") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pica_4>[a-zA-Z]+) (?P<Pica_5>[a-zA-Zç]+[âêô][mn])icas(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ica\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pica_4") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pica_6>[a-zA-Z]+)s (?P<Pica_7>[a-zA-Zç]+[âêô][mn])ica(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ica\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pica_6") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pica_8>[a-zA-Z]+) (?P<Pica_9>[a-zA-Zç]+[âêô][mn])ica(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ica"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pica_8") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pica_a>[a-zA-Z]+)s (?P<Pica_b>[a-zA-Zç]+[âêô][mn])icas(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pica_a") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pics_0>[a-zA-Zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ico\\n" + m.group(1) + "ns " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pics_1>[a-zA-Zç]+[âêô][mn])ico(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ico\\n" + m.group(1) + "ns " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pics_2>[a-zA-Zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica\\n" + m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pics_3>[a-zA-Zç]+[âêô][mn])ica(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica\\n" + m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pics_4>[a-zA-Zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pics_5>[a-zA-Zç]+[âêô][mn])ica(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pics_6>[a-zA-Zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica\\n" + m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pics_7>[a-zA-Zç]+[âêô][mn])ico(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica\\n" + m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pics_8>[a-zA-Zç]+[âêô][mn])ico(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pics_9>[a-zA-Zç]+[âêô][mn])ica(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pics_a>[a-zA-Zç]+[âêô][mn])ica(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pics_b>[a-zA-Zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pics_c>[a-zA-Zç]+[âêô][mn])ico(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pics_d>[a-zA-Zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pics_e>[a-zA-Zç]+[âêô][mn])ica(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pics_f>[a-zA-Zç]+[âêô][mn])ico(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pics_g>[a-zA-Zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pics_h>[a-zA-Zç]+[âêô][mn])ica(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pics_i>[a-zA-Zç]+[âêô][mn])ico(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica\\n" + m.group(1) + "m " + m.group(2) + "ico"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pics_j>[a-zA-Zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "icos\\n" + m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pics_k>[a-zA-Zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "icas\\n" + m.group(1) + "ns " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pnco_0>[a-zA-Z]+) (?P<Pnco_1>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ico\\n" + m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pnco_0") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pnco_2>[a-zA-Z]+)s (?P<Pnco_3>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ico\\n" + m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pnco_2") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pnco_4>[a-zA-Z]+) (?P<Pnco_5>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + m.group(1) + "s " + m.group(2) + "icas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ico\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pnco_4") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pnco_6>[a-zA-Z]+)s (?P<Pnco_7>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + m.group(1) + "s " + m.group(2) + "icas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ico\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pnco_6") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pnco_8>[a-zA-Z]+) (?P<Pnco_9>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ico"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pnco_8") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pnco_a>[a-zA-Z]+)s (?P<Pnco_b>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pnco_a") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pnca_0>[a-zA-Z]+) (?P<Pnca_1>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pnca_0") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pnca_2>[a-zA-Z]+)s (?P<Pnca_3>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pnca_2") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pnca_4>[a-zA-Z]+) (?P<Pnca_5>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ica\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pnca_4") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pnca_6>[a-zA-Z]+)s (?P<Pnca_7>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ica\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pnca_6") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pnca_8>[a-zA-Z]+) (?P<Pnca_9>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ica"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pnca_8") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pnca_a>[a-zA-Z]+)s (?P<Pnca_b>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pnca_a") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pncs_0>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ico\\n" + m.group(1) + "ns " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pncs_1>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ico\\n" + m.group(1) + "ns " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pncs_2>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica\\n" + m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pncs_3>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica\\n" + m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pncs_4>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pncs_5>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pncs_6>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica\\n" + m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pncs_7>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica\\n" + m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pncs_8>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pncs_9>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pncs_a>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pncs_b>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pncs_c>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pncs_d>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pncs_e>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pncs_f>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pncs_g>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pncs_h>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pncs_i>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica\\n" + m.group(1) + "m " + m.group(2) + "ico"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pncs_j>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "icos\\n" + m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pncs_k>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "icas\\n" + m.group(1) + "ns " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psco_0>[a-zA-Z]+) (?P<Psco_1>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ico\\n" + m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psco_0") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psco_2>[a-zA-Z]+)s (?P<Psco_3>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ico\\n" + m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psco_2") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psco_4>[a-zA-Z]+) (?P<Psco_5>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + m.group(1) + "s " + m.group(2) + "icas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ico\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psco_4") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psco_6>[a-zA-Z]+)s (?P<Psco_7>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + m.group(1) + "s " + m.group(2) + "icas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ico\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psco_6") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psco_8>[a-zA-Z]+) (?P<Psco_9>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ico"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psco_8") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psco_a>[a-zA-Z]+)s (?P<Psco_b>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psco_a") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psca_0>[a-zA-Z]+) (?P<Psca_1>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psca_0") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psca_2>[a-zA-Z]+)s (?P<Psca_3>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psca_2") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psca_4>[a-zA-Z]+) (?P<Psca_5>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ica\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psca_4") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psca_6>[a-zA-Z]+)s (?P<Psca_7>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ica\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psca_6") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psca_8>[a-zA-Z]+) (?P<Psca_9>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ica"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psca_8") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psca_a>[a-zA-Z]+)s (?P<Psca_b>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psca_a") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pscs_0>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ico\\n" + m.group(1) + "ns " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pscs_1>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ico\\n" + m.group(1) + "ns " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pscs_2>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica\\n" + m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pscs_3>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica\\n" + m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pscs_4>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pscs_5>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pscs_6>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica\\n" + m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pscs_7>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica\\n" + m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pscs_8>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pscs_9>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pscs_a>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pscs_b>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pscs_c>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pscs_d>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pscs_e>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ica\\n" + m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pscs_f>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pscs_g>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pscs_h>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pscs_i>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ica\\n" + m.group(1) + "m " + m.group(2) + "ico"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pscs_j>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "icos\\n" + m.group(1) + "mas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pscs_k>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "icas\\n" + m.group(1) + "ns " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Peso_0>[a-zA-Z]+) (?P<Peso_1>[a-zA-Zç]+)escos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "esco\\n" + m.group(1) + "s " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Peso_0") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Peso_2>[a-zA-Z]+)s (?P<Peso_3>[a-zA-Zç]+)esco(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "esco\\n" + m.group(1) + "s " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Peso_2") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Peso_4>[a-zA-Z]+) (?P<Peso_5>[a-zA-Zç]+)escos(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "esco\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Peso_4") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Peso_6>[a-zA-Z]+)s (?P<Peso_7>[a-zA-Zç]+)esco(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "esco\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Peso_6") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Peso_8>[a-zA-Z]+) (?P<Peso_9>[a-zA-Zç]+)esco(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "esco"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Peso_8") in acSingular and not m.group("Peso_9") in "-un-Un-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Peso_a>[a-zA-Z]+)s (?P<Peso_b>[a-zA-Zç]+)escos(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Peso_a") in acSingular and not m.group("Peso_b") in "-un-Un-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pesa_0>[a-zA-Z]+) (?P<Pesa_1>[a-zA-Zç]+)escas(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "esca\\n" + m.group(1) + "s " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pesa_0") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pesa_2>[a-zA-Z]+)s (?P<Pesa_3>[a-zA-Zç]+)esca(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "esca\\n" + m.group(1) + "s " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pesa_2") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pesa_4>[a-zA-Z]+) (?P<Pesa_5>[a-zA-Zç]+)escas(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "esca\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pesa_4") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pesa_6>[a-zA-Z]+)s (?P<Pesa_7>[a-zA-Zç]+)esca(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "esca\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pesa_6") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pesa_8>[a-zA-Z]+) (?P<Pesa_9>[a-zA-Zç]+)esca(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "esca"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pesa_8") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pesa_a>[a-zA-Z]+)s (?P<Pesa_b>[a-zA-Zç]+)escas(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pesa_a") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pess_0>[a-zA-Zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "esco\\n" + m.group(1) + "ns " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pess_1>[a-zA-Zç]+)esco(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "esco\\n" + m.group(1) + "ns " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pess_2>[a-zA-Zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "esca\\n" + m.group(1) + "mas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pess_3>[a-zA-Zç]+)esca(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "esca\\n" + m.group(1) + "mas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pess_4>[a-zA-Zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pess_5>[a-zA-Zç]+)esca(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "esca"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pess_6>[a-zA-Zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "esca\\n" + m.group(1) + "mas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pess_6") in "-un-Un-"'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pess_7>[a-zA-Zç]+)esco(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "esca\\n" + m.group(1) + "mas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pess_7") in "-un-Un-"'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pess_8>[a-zA-Zç]+)esco(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pess_9>[a-zA-Zç]+)esca(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pess_a>[a-zA-Zç]+)esca(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pess_b>[a-zA-Zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pess_c>[a-zA-Zç]+)esco(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pess_d>[a-zA-Zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pess_e>[a-zA-Zç]+)esca(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "esca\\n" + m.group(1) + "s " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pess_f>[a-zA-Zç]+)esco(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pess_g>[a-zA-Zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pess_h>[a-zA-Zç]+)esca(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "esca"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pess_i>[a-zA-Zç]+)esco(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "esca\\n" + m.group(1) + "m " + m.group(2) + "esco"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pess_j>[a-zA-Zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "escos\\n" + m.group(1) + "mas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pess_k>[a-zA-Zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "escas\\n" + m.group(1) + "ns " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pldo_0>[a-zA-Z]+) (?P<Pldo_1>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ido\\n" + m.group(1) + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pldo_0") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pldo_2>[a-zA-Z]+)s (?P<Pldo_3>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ido(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ido\\n" + m.group(1) + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pldo_2") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pldo_4>[a-zA-Z]+) (?P<Pldo_5>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ida\\n" + m.group(1) + "s " + m.group(2) + "idas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ido\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pldo_4") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pldo_6>[a-zA-Z]+)s (?P<Pldo_7>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ido(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ida\\n" + m.group(1) + "s " + m.group(2) + "idas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ido\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pldo_6") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pldo_8>[a-zA-Z]+) (?P<Pldo_9>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ido(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ida\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ido"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pldo_8") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pldo_a>[a-zA-Z]+)s (?P<Pldo_b>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idas\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pldo_a") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plda_0>[a-zA-Z]+) (?P<Plda_1>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ida\\n" + m.group(1) + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plda_0") in acSingular and not m.group("Plda_1") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plda_2>[a-zA-Z]+)s (?P<Plda_3>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ida\\n" + m.group(1) + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plda_2") in acSingular and not m.group("Plda_3") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plda_4>[a-zA-Z]+) (?P<Plda_5>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ida\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plda_4") in abSingular and not m.group("Plda_5") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plda_6>[a-zA-Z]+)s (?P<Plda_7>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ida\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plda_6") in abSingular and not m.group("Plda_7") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plda_8>[a-zA-Z]+) (?P<Plda_9>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ida"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plda_8") in abSingular and not m.group("Plda_9") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plda_a>[a-zA-Z]+)s (?P<Plda_b>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plda_a") in abSingular and not m.group("Plda_b") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Plds_0>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ido\\n" + m.group(1) + "ns " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Plds_1>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ido(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ido\\n" + m.group(1) + "ns " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Plds_2>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ida\\n" + m.group(1) + "mas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Plds_2") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Plds_3>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ida\\n" + m.group(1) + "mas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Plds_3") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Plds_4>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Plds_4") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Plds_5>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ida"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Plds_5") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Plds_6>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ida\\n" + m.group(1) + "mas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Plds_7>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ido(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ida\\n" + m.group(1) + "mas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Plds_8>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ido(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Plds_9>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Plds_9") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Plds_a>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Plds_a") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Plds_b>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Plds_b") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Plds_c>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ido(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Plds_d>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Plds_e>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ida\\n" + m.group(1) + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Plds_e") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Plds_f>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ido(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Plds_g>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Plds_h>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ida"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Plds_h") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Plds_i>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ido(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ida\\n" + m.group(1) + "m " + m.group(2) + "ido"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Plds_j>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "idos\\n" + m.group(1) + "mas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Plds_j") in excplvrIda'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Plds_k>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "idas\\n" + m.group(1) + "ns " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plgo_0>[a-zA-Z]+) (?P<Plgo_1>[a-zA-Zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "logo\\n" + m.group(1) + "s " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plgo_0") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plgo_2>[a-zA-Z]+)s (?P<Plgo_3>[a-zA-Zç]+[ó])logo(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "logo\\n" + m.group(1) + "s " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plgo_2") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plgo_4>[a-zA-Z]+) (?P<Plgo_5>[a-zA-Zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "loga\\n" + m.group(1) + "s " + m.group(2) + "logas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "logo\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plgo_4") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plgo_6>[a-zA-Z]+)s (?P<Plgo_7>[a-zA-Zç]+[ó])logo(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "loga\\n" + m.group(1) + "s " + m.group(2) + "logas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "logo\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plgo_6") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plgo_8>[a-zA-Z]+) (?P<Plgo_9>[a-zA-Zç]+[ó])logo(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "loga\\n" + varGenero[m.group(1)] + " " + m.group(2) + "logo"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plgo_8") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plgo_a>[a-zA-Z]+)s (?P<Plgo_b>[a-zA-Zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "logas\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plgo_a") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plga_0>[a-zA-Z]+) (?P<Plga_1>[a-zA-Zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "loga\\n" + m.group(1) + "s " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plga_0") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plga_2>[a-zA-Z]+)s (?P<Plga_3>[a-zA-Zç]+[ó])loga(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "loga\\n" + m.group(1) + "s " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plga_2") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plga_4>[a-zA-Z]+) (?P<Plga_5>[a-zA-Zç]+[ó])logas(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "loga\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plga_4") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plga_6>[a-zA-Z]+)s (?P<Plga_7>[a-zA-Zç]+[ó])loga(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "loga\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plga_6") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plga_8>[a-zA-Z]+) (?P<Plga_9>[a-zA-Zç]+[ó])loga(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "loga"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plga_8") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Plga_a>[a-zA-Z]+)s (?P<Plga_b>[a-zA-Zç]+[ó])logas(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Plga_a") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Plgs_0>[a-zA-Zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "logo\\n" + m.group(1) + "ns " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Plgs_1>[a-zA-Zç]+[ó])logo(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "logo\\n" + m.group(1) + "ns " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Plgs_2>[a-zA-Zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "loga\\n" + m.group(1) + "mas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Plgs_3>[a-zA-Zç]+[ó])loga(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "loga\\n" + m.group(1) + "mas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Plgs_4>[a-zA-Zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Plgs_5>[a-zA-Zç]+[ó])loga(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "loga"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Plgs_6>[a-zA-Zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "loga\\n" + m.group(1) + "mas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Plgs_7>[a-zA-Zç]+[ó])logo(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "loga\\n" + m.group(1) + "mas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Plgs_8>[a-zA-Zç]+[ó])logo(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Plgs_9>[a-zA-Zç]+[ó])loga(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Plgs_a>[a-zA-Zç]+[ó])loga(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Plgs_b>[a-zA-Zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Plgs_c>[a-zA-Zç]+[ó])logo(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Plgs_d>[a-zA-Zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Plgs_e>[a-zA-Zç]+[ó])loga(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "loga\\n" + m.group(1) + "s " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Plgs_f>[a-zA-Zç]+[ó])logo(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Plgs_g>[a-zA-Zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Plgs_h>[a-zA-Zç]+[ó])loga(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "loga"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Plgs_i>[a-zA-Zç]+[ó])logo(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "loga\\n" + m.group(1) + "m " + m.group(2) + "logo"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Plgs_j>[a-zA-Zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "logos\\n" + m.group(1) + "mas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Plgs_k>[a-zA-Zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "logas\\n" + m.group(1) + "ns " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prio_0>[a-zA-Z]+) (?P<Prio_1>[a-zA-Zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "rio\\n" + m.group(1) + "s " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prio_0") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prio_2>[a-zA-Z]+)s (?P<Prio_3>[a-zA-Zç]+[áéíóúâêô])rio(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "rio\\n" + m.group(1) + "s " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prio_2") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prio_4>[a-zA-Z]+) (?P<Prio_5>[a-zA-Zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prio_4") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prio_6>[a-zA-Z]+)s (?P<Prio_7>[a-zA-Zç]+[áéíóúâêô])rio(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "rio\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prio_6") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prio_8>[a-zA-Z]+) (?P<Prio_9>[a-zA-Zç]+[áéíóúâêô])rio(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "rio"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prio_8") in agSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prio_a>[a-zA-Z]+)s (?P<Prio_b>[a-zA-Zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prio_a") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])A (?P<Prio_c>[a-zA-Zç]+[áéíóúâêô])rio(?![-\\w–\xad])', '= "O " + m.group(1) + "rio"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prio_c") in excPlvrio'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pria_0>[a-zA-Z]+) (?P<Pria_1>[a-zA-Zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ria\\n" + m.group(1) + "s " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pria_0") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pria_2>[a-zA-Z]+)s (?P<Pria_3>[a-zA-Zç]+[áéíóúâêô])ria(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ria\\n" + m.group(1) + "s " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pria_2") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pria_4>[a-zA-Z]+) (?P<Pria_5>[a-zA-Zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ria\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pria_4") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pria_6>[a-zA-Z]+)s (?P<Pria_7>[a-zA-Zç]+[áéíóúâêô])ria(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ria\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pria_6") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pria_8>[a-zA-Z]+) (?P<Pria_9>[a-zç]+[áéíóúâêô])ria(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ria"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pria_8") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pria_a>[a-zA-Z]+)s (?P<Pria_b>[a-zA-Zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pria_a") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pris_0>[a-zA-Zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "rio\\n" + m.group(1) + "ns " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pris_1>[a-zA-Zç]+[áéíóúâêô])rio(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "rio\\n" + m.group(1) + "ns " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pris_2>[a-zA-Zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ria\\n" + m.group(1) + "mas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pris_3>[a-zA-Zç]+[áéíóúâêô])ria(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ria\\n" + m.group(1) + "mas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pris_4>[a-zA-Zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pris_5>[a-zA-Zç]+[áéíóúâêô])ria(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ria"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pris_6>[a-zA-Zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ria\\n" + m.group(1) + "mas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pris_7>[a-zA-Zç]+[áéíóúâêô])rio(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ria\\n" + m.group(1) + "mas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pris_8>[a-zA-Zç]+[áéíóúâêô])rio(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pris_9>[a-zA-Zç]+[áéíóúâêô])ria(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pris_a>[a-zA-Zç]+[áéíóúâêô])ria(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pris_b>[a-zA-Zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pris_c>[a-zA-Zç]+[áéíóúâêô])rio(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pris_d>[a-zA-Zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pris_e>[a-zA-Zç]+[áéíóúâêô])ria(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ria\\n" + m.group(1) + "s " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pris_f>[a-zA-Zç]+[áéíóúâêô])rio(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pris_g>[a-zA-Zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pris_h>[a-zA-Zç]+[áéíóúâêô])ria(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ria"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pris_i>[a-zA-Zç]+[áéíóúâêô])rio(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ria\\n" + m.group(1) + "m " + m.group(2) + "rio"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pris_j>[a-zA-Zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "rios\\n" + m.group(1) + "mas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pris_k>[a-zA-Zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "rias\\n" + m.group(1) + "ns " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psso_0>[a-zA-Z]+) (?P<Psso_1>[a-zA-Zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ssimo\\n" + m.group(1) + "s " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psso_0") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psso_2>[a-zA-Z]+)s (?P<Psso_3>[a-zA-Zç]+[í])ssimo(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ssimo\\n" + m.group(1) + "s " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psso_2") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psso_4>[a-zA-Z]+) (?P<Psso_5>[a-zA-Zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ssima\\n" + m.group(1) + "s " + m.group(2) + "ssimas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ssimo\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psso_4") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psso_6>[a-zA-Z]+)s (?P<Psso_7>[a-zA-Zç]+[í])ssimo(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ssima\\n" + m.group(1) + "s " + m.group(2) + "ssimas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ssimo\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psso_6") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psso_8>[a-zA-Z]+) (?P<Psso_9>[a-zA-Zç]+[í])ssimo(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ssima\\n" + varGenero[m.group(1)] + " " + m.group(2) + "ssimo"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psso_8") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psso_a>[a-zA-Z]+)s (?P<Psso_b>[a-zA-Zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ssimas\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psso_a") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pssa_0>[a-zA-Z]+) (?P<Pssa_1>[a-zA-Zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ssima\\n" + m.group(1) + "s " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pssa_0") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pssa_2>[a-zA-Z]+)s (?P<Pssa_3>[a-zA-Zç]+[í])ssima(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ssima\\n" + m.group(1) + "s " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pssa_2") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pssa_4>[a-zA-Z]+) (?P<Pssa_5>[a-zA-Zç]+[í])ssimas(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ssima\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pssa_4") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pssa_6>[a-zA-Z]+)s (?P<Pssa_7>[a-zA-Zç]+[í])ssima(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ssima\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pssa_6") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pssa_8>[a-zA-Z]+) (?P<Pssa_9>[a-zA-Zç]+[í])ssima(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ssima"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pssa_8") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pssa_a>[a-zA-Z]+)s (?P<Pssa_b>[a-zA-Zç]+[í])ssimas(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pssa_a") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Psss_0>[a-zA-Zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ssimo\\n" + m.group(1) + "ns " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Psss_1>[a-zA-Zç]+[í])ssimo(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ssimo\\n" + m.group(1) + "ns " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Psss_2>[a-zA-Zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ssima\\n" + m.group(1) + "mas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Psss_3>[a-zA-Zç]+[í])ssima(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ssima\\n" + m.group(1) + "mas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Psss_4>[a-zA-Zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Psss_5>[a-zA-Zç]+[í])ssima(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ssima"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Psss_6>[a-zA-Zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ssima\\n" + m.group(1) + "mas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Psss_7>[a-zA-Zç]+[í])ssimo(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ssima\\n" + m.group(1) + "mas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Psss_8>[a-zA-Zç]+[í])ssimo(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Psss_9>[a-zA-Zç]+[í])ssima(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Psss_a>[a-zA-Zç]+[í])ssima(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Psss_b>[a-zA-Zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Psss_c>[a-zA-Zç]+[í])ssimo(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Psss_d>[a-zA-Zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Psss_e>[a-zA-Zç]+[í])ssima(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ssima\\n" + m.group(1) + "s " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Psss_f>[a-zA-Zç]+[í])ssimo(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Psss_g>[a-zA-Zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Psss_h>[a-zA-Zç]+[í])ssima(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ssima"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Psss_i>[a-zA-Zç]+[í])ssimo(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ssima\\n" + m.group(1) + "m " + m.group(2) + "ssimo"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Psss_j>[a-zA-Zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "ssimos\\n" + m.group(1) + "mas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Psss_k>[a-zA-Zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "ssimas\\n" + m.group(1) + "ns " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psmo_0>[a-zA-Z]+) (?P<Psmo_1>[a-zA-Zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "simo\\n" + m.group(1) + "s " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psmo_0") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psmo_2>[a-zA-Z]+)s (?P<Psmo_3>[a-zA-Zç]+[é])simo(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "simo\\n" + m.group(1) + "s " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psmo_2") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psmo_4>[a-zA-Z]+) (?P<Psmo_5>[a-zA-Zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "sima\\n" + m.group(1) + "s " + m.group(2) + "simas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "simo\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psmo_4") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psmo_6>[a-zA-Z]+)s (?P<Psmo_7>[a-zA-Zç]+[é])simo(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "sima\\n" + m.group(1) + "s " + m.group(2) + "simas\\n" + varGenero[m.group(1)] + " " + m.group(2) + "simo\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psmo_6") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psmo_8>[a-zA-Z]+) (?P<Psmo_9>[a-zA-Zç]+[é])simo(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "sima\\n" + varGenero[m.group(1)] + " " + m.group(2) + "simo"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psmo_8") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psmo_a>[a-zA-Z]+)s (?P<Psmo_b>[a-zA-Zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "simas\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psmo_a") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psma_0>[a-zA-Z]+) (?P<Psma_1>[a-zA-Zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "sima\\n" + m.group(1) + "s " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psma_0") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psma_2>[a-zA-Z]+)s (?P<Psma_3>[a-zA-Zç]+[é])sima(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "sima\\n" + m.group(1) + "s " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psma_2") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psma_4>[a-zA-Z]+) (?P<Psma_5>[a-zA-Zç]+[é])simas(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "sima\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psma_4") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psma_6>[a-zA-Z]+)s (?P<Psma_7>[a-zA-Zç]+[é])sima(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "sima\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psma_6") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psma_8>[a-zA-Z]+) (?P<Psma_9>[a-zA-Zç]+[é])sima(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "sima"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psma_8") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Psma_a>[a-zA-Z]+)s (?P<Psma_b>[a-zA-Zç]+[é])simas(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Psma_a") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Psms_0>[a-zA-Zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "simo\\n" + m.group(1) + "ns " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Psms_1>[a-zA-Zç]+[é])simo(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "simo\\n" + m.group(1) + "ns " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Psms_2>[a-zA-Zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "sima\\n" + m.group(1) + "mas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Psms_3>[a-zA-Zç]+[é])sima(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "sima\\n" + m.group(1) + "mas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Psms_4>[a-zA-Zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Psms_5>[a-zA-Zç]+[é])sima(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "sima"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Psms_6>[a-zA-Zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "sima\\n" + m.group(1) + "mas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Psms_7>[a-zA-Zç]+[é])simo(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "sima\\n" + m.group(1) + "mas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Psms_8>[a-zA-Zç]+[é])simo(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Psms_9>[a-zA-Zç]+[é])sima(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Psms_a>[a-zA-Zç]+[é])sima(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Psms_b>[a-zA-Zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Psms_c>[a-zA-Zç]+[é])simo(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Psms_d>[a-zA-Zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Psms_e>[a-zA-Zç]+[é])sima(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "sima\\n" + m.group(1) + "s " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Psms_f>[a-zA-Zç]+[é])simo(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Psms_g>[a-zA-Zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Psms_h>[a-zA-Zç]+[é])sima(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "sima"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Psms_i>[a-zA-Zç]+[é])simo(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "sima\\n" + m.group(1) + "m " + m.group(2) + "simo" ', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Psms_j>[a-zA-Zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "simos\\n" + m.group(1) + "mas " + m.group(2) + "simas" ', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Psms_k>[a-zA-Zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "simas\\n" + m.group(1) + "ns " + m.group(2) + "simos" ', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgo_0>[a-zA-Z]+) (?P<Pdgo_1>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "o\\n" + m.group(1) + "s " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgo_0") in abSingular and m.group("Pdgo_1") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgo_2>[a-zA-Z]+)s (?P<Pdgo_3>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "o\\n" + m.group(1) + "s " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgo_2") in abSingular and m.group("Pdgo_3") in plvrMfoa and not m.group("Pdgo_3") + "o e " in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgo_4>[a-zA-Z]+) (?P<Pdgo_5>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "a\\n" + m.group(1) + "s " + m.group(2) + "as\\n" + varGenero[m.group(1)] + " " + m.group(2) + "o\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgo_4") in acSingular and m.group("Pdgo_5") in plvrMfoa and not (m.group("Pdgo_4") in "-A-" and m.group("Pdgo_5") in excplMfoa)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgo_6>[a-zA-Z]+)s (?P<Pdgo_7>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "a\\n" + m.group(1) + "s " + m.group(2) + "as\\n" + varGenero[m.group(1)] + " " + m.group(2) + "o\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgo_6") in acSingular and m.group("Pdgo_7") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgo_8>[a-zA-Z]+) (?P<Pdgo_9>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "a\\n" + varGenero[m.group(1)] + " " + m.group(2) + "o"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgo_8") in acSingular and m.group("Pdgo_9") in plvrMfoa and not (m.group("Pdgo_8") in "-A-" and m.group("Pdgo_9") in excplMfoa)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgo_a>[a-zA-Z]+)s (?P<Pdgo_b>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "as\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgo_a") in acSingular and m.group("Pdgo_b") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdga_0>[a-zA-Z]+) (?P<Pdga_1>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "a\\n" + m.group(1) + "s " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdga_0") in acSingular and m.group("Pdga_1") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdga_2>[a-zA-Z]+)s (?P<Pdga_3>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "a\\n" + m.group(1) + "s " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdga_2") in acSingular and m.group("Pdga_3") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdga_4>[a-zA-Z]+) (?P<Pdga_5>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "a\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "as\\n" + m.group(1) + " " + m.group(2) + "o\\n" + m.group(1) + "s " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdga_4") in abSingular and m.group("Pdga_5") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdga_6>[a-zA-Z]+)s (?P<Pdga_7>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "a\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "as\\n" + m.group(1) + " " + m.group(2) + "o\\n" + m.group(1) + "s " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdga_6") in abSingular and m.group("Pdga_7") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdga_8>[a-zA-Z]+) (?P<Pdga_9>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "o\\n" + varGenera[m.group(1)] + " " + m.group(2) + "a"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdga_8") in abSingular and m.group("Pdga_9") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdga_a>[a-zA-Z]+)s (?P<Pdga_b>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "os\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdga_a") in abSingular and m.group("Pdga_b") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pdgs_0>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "o\\n" + m.group(1) + "ns " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_0") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pdgs_1>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "o\\n" + m.group(1) + "ns " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_1") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pdgs_2>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "a\\n" + m.group(1) + "mas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_2") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pdgs_3>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "a\\n" + m.group(1) + "mas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_3") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pdgs_4>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_4") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pdgs_5>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "a"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_5") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pdgs_6>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "a\\n" + m.group(1) + "ns " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_6") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pdgs_7>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "o\\n" + m.group(1) + "mas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_7") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pdgs_8>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_8") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pdgs_9>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_9") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pdgs_a>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_a") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pdgs_b>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_b") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pdgs_c>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_c") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pdgs_d>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_d") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pdgs_e>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "a\\n" + m.group(1) + "s " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_e") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pdgs_f>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_f") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pdgs_g>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_g") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pdgs_h>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "a"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_h") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pdgs_i>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "a\\n" + m.group(1) + "m " + m.group(2) + "o"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_i") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pdgs_j>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "os\\n" + m.group(1) + "mas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_j") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pdgs_k>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "as\\n" + m.group(1) + "ns " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_k") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári([ao])s (?P<Pdgs_m>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "ários " + m.group(3) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_m") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári([ao])s (?P<Pdgs_n>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(3) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_n") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])árias (?P<Pdgs_o>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "ários " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_o") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pdgs_p>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_p") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Pdgs_10>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= "Um " + m.group(2) + "o\\nUns " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_10") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pdgs_11>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= "Uma " + m.group(2) + "a\\nUmas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_11") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pdgs_12>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= "Um " + m.group(2) + "o\\nUma " + m.group(2) + "a"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_12") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Pdgs_13>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= "Uma " + m.group(2) + "a\\nUm " + m.group(2) + "o"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_13") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pdgs_14>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= "Uma " + m.group(2) + "a\\nUns " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_14") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Pdgs_15>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= "Umas " + m.group(2) + "as\\nUm " + m.group(2) + "o"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_15") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(^)uns (?P<Pdgs_16>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= "Uns " + m.group(2) + "os\\nUma " + m.group(2) + "a"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_16") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(^)uns (?P<Pdgs_17>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= "Uns " + m.group(2) + "os\\nUmas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_17") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(^)umas (?P<Pdgs_18>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= "Umas " + m.group(2) + "as\\nUm " + m.group(2) + "o"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_18") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(^)umas (?P<Pdgs_19>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= "Umas " + m.group(2) + "as\\nUns " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_19") in plvrMfoa'],
 ['(?u)\\b([,]) um (?P<Pdgs_20>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= ", um " + m.group(2) + "o\\n, uns " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_20") in plvrMfoa'],
 ['(?u)\\b([,]) uma (?P<Pdgs_21>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= ", uma " + m.group(2) + "a\\n, umas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_21") in plvrMfoa'],
 ['(?u)\\b([,]) uma (?P<Pdgs_22>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= ", um " + m.group(2) + "o\\n, uma " + m.group(2) + "a"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_22") in plvrMfoa'],
 ['(?u)\\b([,]) um (?P<Pdgs_23>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= ", uma " + m.group(2) + "a\\n, um " + m.group(2) + "o"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_23") in plvrMfoa'],
 ['(?u)\\b([,]) uma (?P<Pdgs_24>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= ", uma " + m.group(2) + "a\\n, uns " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_24") in plvrMfoa'],
 ['(?u)\\b([,]) um (?P<Pdgs_25>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= ", umas " + m.group(2) + "as\\n, um " + m.group(2) + "o"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_25") in plvrMfoa'],
 ['(?u)\\b([,]) uns (?P<Pdgs_26>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= ", uns " + m.group(2) + "os\\n, uma " + m.group(2) + "a"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_26") in plvrMfoa'],
 ['(?u)\\b([,]) uns (?P<Pdgs_27>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= ", uns " + m.group(2) + "os\\n, umas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_27") in plvrMfoa'],
 ['(?u)\\b([,]) umas (?P<Pdgs_28>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= ", umas " + m.group(2) + "as\\n, um " + m.group(2) + "o"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_28") in plvrMfoa'],
 ['(?u)\\b([,]) umas (?P<Pdgs_29>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= ", umas " + m.group(2) + "as\\n, uns " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_29") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (só|simples) (?P<Pdgs_30>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) +" "+ m.group(3) + "o\\n" + m.group(1) + "ns " + m.group(2) +" "+ m.group(3) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_30") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (só|simples) (?P<Pdgs_31>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) +" "+ m.group(3) + "a\\n" + m.group(1) + "mas " + m.group(2) +" "+ m.group(3) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_31") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (só|simples) (?P<Pdgs_32>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) +" "+ m.group(3) + "o\\n" + m.group(1) + "ma " + m.group(2) +" "+ m.group(3) + "a"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_32") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (só|simples) (?P<Pdgs_33>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) +" "+ m.group(3) + "a\\n" + m.group(1) + "m " + m.group(2) +" "+ m.group(3) + "o"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_33") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (só|simples) (?P<Pdgs_34>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) +" "+ m.group(3) + "a\\n" + m.group(1) + "ns " + m.group(2) +" "+ m.group(3) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_34") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (só|simples) (?P<Pdgs_35>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) +" "+ m.group(3) + "as\\n" + m.group(1) + "m " + m.group(2) +" "+ m.group(3) + "o"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_35") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (só|simples) (?P<Pdgs_36>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) +" "+ m.group(3) + "os\\n" + m.group(1) + "ma " + m.group(2) +" "+ m.group(3) + "a"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_36") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (só|simples) (?P<Pdgs_37>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) +" "+ m.group(3) + "os\\n" + m.group(1) + "mas " + m.group(2) +" "+ m.group(3) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_37") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (só|simples) (?P<Pdgs_38>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) +" "+ m.group(3) + "as\\n" + m.group(1) + "m " + m.group(2) +" "+ m.group(3) + "o"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_38") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (só|simples) (?P<Pdgs_39>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) +" "+ m.group(3) + "as\\n" + m.group(1) + "ns " + m.group(2) +" "+ m.group(3) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_39") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_40>[a-zA-Záâãçéêíóôú]+) um (?P<Pdgs_50>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) + "o\\n" + m.group(1) + " uns " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_50") in plvrMfoa and not m.group("Pdgs_40") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_41>[a-zA-Záâãçéêíóôú]+) uma (?P<Pdgs_51>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "a\\n" + m.group(1) + " umas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_51") in plvrMfoa and not m.group("Pdgs_41") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_42>[a-zA-Záâãçéêíóôú]+) uma (?P<Pdgs_52>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) + "o\\n" + m.group(1) + " uma " + m.group(2) + "a"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_52") in plvrMfoa and not m.group("Pdgs_42") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_43>[a-zA-Záâãçéêíóôú]+) um (?P<Pdgs_53>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "a\\n" + m.group(1) + " um " + m.group(2) + "o"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_53") in plvrMfoa and not m.group("Pdgs_43") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_44>[a-zA-Záâãçéêíóôú]+) uma (?P<Pdgs_54>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "a\\n" + m.group(1) + " uns " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_54") in plvrMfoa and not m.group("Pdgs_44") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_45>[a-zA-Záâãçéêíóôú]+) um (?P<Pdgs_55>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + " umas " + m.group(2) + "as\\n" + m.group(1) + " um " + m.group(2) + "o"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_55") in plvrMfoa and not m.group("Pdgs_45") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_46>[a-zA-Záâãçéêíóôú]+) uns (?P<Pdgs_56>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + " uns " + m.group(2) + "os\\n" uma " + m.group(2) + "a"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_56") in plvrMfoa and not m.group("Pdgs_46") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_47>[a-zA-Záâãçéêíóôú]+) uns (?P<Pdgs_57>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + " uns " + m.group(2) + "os\\n" + m.group(1) + " umas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_57") in plvrMfoa and not m.group("Pdgs_47") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_48>[a-zA-Záâãçéêíóôú]+) umas (?P<Pdgs_58>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + " umas " + m.group(2) + "as\\n" + m.group(1) + " um " + m.group(2) + "o"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_58") in plvrMfoa and not m.group("Pdgs_48") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_49>[a-zA-Záâãçéêíóôú]+) umas (?P<Pdgs_59>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + " umas " + m.group(2) + "as\\n" + m.group(1) + " uns " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_59") in plvrMfoa and not m.group("Pdgs_49") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_60>[a-zA-Záâãçéêíóôú]+) e um (?P<Pdgs_70>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "o\\n" + m.group(1) + " e uns " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_70") in plvrMfoa and not m.group("Pdgs_60") in numEmfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_61>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pdgs_71>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "a\\n" + m.group(1) + " e umas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_71") in plvrMfoa and not m.group("Pdgs_61") in numEmfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_62>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pdgs_72>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "a\\n" + m.group(1) + " e uns " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_72") in plvrMfoa and not m.group("Pdgs_62") in numEmfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_63>[a-zA-Záâãçéêíóôú]+) e um (?P<Pdgs_73>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + " e umas " + m.group(2) + "as\\n" + m.group(1) + " e um " + m.group(2) + "o"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_73) in plvrMfoa and not m.group("Pdgs_63") in numEmfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_64>[a-zA-Záâãçéêíóôú]+) e uns (?P<Pdgs_74>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + " e uns " + m.group(2) + "os\\n" + m.group(1) + " e umas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_74") in plvrMfoa and not m.group("Pdgs_64") in numEmfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_65>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pdgs_75>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + " e umas " + m.group(2) + "as\\n" + m.group(1) + " e uns " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_75") in plvrMfoa and not m.group("Pdgs_65") in numEmfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_80>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pdgs_90>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_90") in plvrMfoa and m.group("Pdgs_80").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_81>[a-zA-Záâãçéêíóôú]+) e um (?P<Pdgs_91>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_91") in plvrMfoa and m.group("Pdgs_81").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_82>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pdgs_92>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "os\\n" + m.group(1) + " e uma " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_92") in plvrMfoa and m.group("Pdgs_82").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_83>[a-zA-Záâãçéêíóôú]+) e um (?P<Pdgs_93>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "as\\n" + m.group(1) + " e um " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_93") in plvrMfoa and m.group("Pdgs_83").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_84>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pdgs_94>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "as\\n" + m.group(1) + " e um " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_94") in plvrMfoa and m.group("Pdgs_84").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_85>[a-zA-Záâãçéêíóôú]+) e um (?P<Pdgs_95>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "as\\n" + m.group(1) + " e um " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_95") in plvrMfoa and m.group("Pdgs_85").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_86>[a-zA-Záâãçéêíóôú]+) e uns (?P<Pdgs_96>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "os\\n" + m.group(1) + " e uma " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_96") in plvrMfoa and m.group("Pdgs_86").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_87>[a-zA-Záâãçéêíóôú]+) e uns (?P<Pdgs_97>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "os\\n" + m.group(1) + " e uma " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_97") in plvrMfoa and m.group("Pdgs_87").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_88>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pdgs_98>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "as\\n" + m.group(1) + " e um " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_98") in plvrMfoa and m.group("Pdgs_88").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_89>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pdgs_99>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "as\\n" + m.group(1) + " e um " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_99") in plvrMfoa and m.group("Pdgs_89").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_100>[a-zA-Záâãçéêíóôú]+) (?P<Pdgs_101>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_101") in plvrMfoa and m.group("Pdgs_100").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_102>[a-zA-Záâãçéêíóôú]+) (?P<Pdgs_103>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_103") in plvrMfoa and m.group("Pdgs_102").lower() in numMfmoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_104>[0-9]+) (?P<Pdgs_105>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "os"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pdgs_105") in plvrMfoa and not m.group("Pdgs_104") in "00000000001" and not excYmfoa.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_106>[0-9]+) (?P<Pdgs_107>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "as"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pdgs_107") in plvrMfoa and not m.group("Pdgs_106") in "00000000001" and not excYmfoa.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pdgs__108>[0-9][0-9][0-9]) (?P<Pdgs_109>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "os"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pdgs_109") in plvrMfoa'],
 ['(?u)\\b([.])(?P<Pdgs__110>[0-9][0-9][0-9]) (?P<Pdgs_111>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "as"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pdgs_111") in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_112>[0-1]+) (?P<Pdgs_113>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"o"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pdgs_113") in plvrMfoa and m.group("Pdgs_112") in "00000000001" and not excYmfoa.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_114>[0-1]+) (?P<Pdgs_115>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"a"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pdgs_115") in plvrMfoa and m.group("Pdgs_114") in "00000000001" and not excYmfoa.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_116>[a-zA-Záâãçéêíóôú]+)as (?P<Pdgs_117>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_117") in plvrMfoa and m.group("Pdgs_116").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_118>[a-zA-Záâãçéêíóôú]+)as (?P<Pdgs_119>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_119") in plvrMfoa and m.group("Pdgs_118").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_120>[a-zA-Záâãçéêíóôú]+)os (?P<Pdgs_121>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_121") in plvrMfoa and m.group("Pdgs_120").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_122>[a-zA-Záâãçéêíóôú]+)os (?P<Pdgs_123>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_123") in plvrMfoa and m.group("Pdgs_122").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_124>[a-zA-Záâãçéêíóôú]+)os (?P<Pdgs_125>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_125") in plvrMfoa and m.group("Pdgs_124").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_126>[a-zA-Záâãçéêíóôú]+)as (?P<Pdgs_127>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_127") in plvrMfoa and m.group("Pdgs_126").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_180>[a-zA-Záâãçéêíóôú]+)[ao]s e uma (?P<Pdgs_190>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "as e uma " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_190") in plvrMfoa and m.group("Pdgs_180").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_181>[a-zA-Záâãçéêíóôú]+)[ao]s e um (?P<Pdgs_191>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "os e um " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_191") in plvrMfoa and m.group("Pdgs_181").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_182>[a-zA-Záâãçéêíóôú]+)[ao]s e uma (?P<Pdgs_192>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "os e um " + m.group(2) + "os\\n" + m.group(1) + "as e uma " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_192") in plvrMfoa and m.group("Pdgs_182").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_183>[a-zA-Záâãçéêíóôú]+)[ao]s e um (?P<Pdgs_193>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "as e uma " + m.group(2) + "as\\n" + m.group(1) + "os e um " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_193") in plvrMfoa and m.group("Pdgs_183").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_184>[a-zA-Záâãçéêíóôú]+)[ao]s e uma (?P<Pdgs_194>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) +os " e uma " + m.group(2) + "as\\n" + m.group(1) + "os e um " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_194") in plvrMfoa and m.group("Pdgs_184").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_185>[a-zA-Záâãçéêíóôú]+)[ao]s e um (?P<Pdgs_195>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "as e uma " + m.group(2) + "as\\n" + m.group(1) + "os e um " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_195") in plvrMfoa and m.group("Pdgs_185").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_186>[a-zA-Záâãçéêíóôú]+)[ao]s e uns (?P<Pdgs_196>[a-zA-Zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "os e um " + m.group(2) + "os\\n" + m.group(1) + "as e uma " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_196") in plvrMfoa and m.group("Pdgs_186").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_187>[a-zA-Záâãçéêíóôú]+)[ao]s e uns (?P<Pdgs_197>[a-zA-Zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "os e um " + m.group(2) + "os\\n" + m.group(1) + "as e uma " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_197") in plvrMfoa and m.group("Pdgs_187").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_188>[a-zA-Záâãçéêíóôú]+)[ao]s e umas (?P<Pdgs_198>[a-zA-Zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "as e uma " + m.group(2) + "as\\n" + m.group(1) + "os e um " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_198") in plvrMfoa and m.group("Pdgs_188").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgs_189>[a-zA-Záâãçéêíóôú]+)[ao]s e umas (?P<Pdgs_199>[a-zA-Zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "as e uma " + m.group(2) + "as\\n" + m.group(1) + "os e um " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgs_199") in plvrMfoa and m.group("Pdgs_189").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prto_0>[a-zA-Z]+) (?P<Prto_1>[a-zA-Zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "or\\n" + m.group(1) + "s " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prto_0") in abSingular and not m.group("Prto_1") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prto_2>[a-zA-Z]+)s (?P<Prto_3>[a-zA-Zçáéíóúâêô]+[dst])or(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "or\\n" + m.group(1) + "s " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prto_2") in abSingular and not m.group("Prto_3") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prto_4>[a-zA-Z]+) (?P<Prto_5>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ora\\n" + m.group(1) + "s " + m.group(2) + "oras\\n" + varGenero[m.group(1)] + " " + m.group(2) + "or\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prto_4") in acSingular and not m.group("Prto_5") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prto_6>[a-zA-Z]+)s (?P<Prto_7>[a-zA-Zçáéíóúâêô]+[dst])or(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ora\\n" + m.group(1) + "s " + m.group(2) + "oras\\n" + varGenero[m.group(1)] + " " + m.group(2) + "or\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prto_6") in acSingular and not m.group("Prto_7") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prto_8>[a-zA-Z]+) (?P<Prto_9>[a-zA-Zçáéíóúâêô]+[dst])or(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ora\\n" + varGenero[m.group(1)] + " " + m.group(2) + "or"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prto_8") in acSingular and not m.group("Prto_9") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prto_a>[a-zA-Z]+)s (?P<Prto_b>[a-zA-Zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "oras\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prto_a") in acSingular and not m.group("Prto_b") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prta_0>[a-zA-Z]+) (?P<Prta_1>[a-zA-Zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ora\\n" + m.group(1) + "s " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prta_0") in acSingular and not m.group("Prta_1") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prta_2>[a-zA-Z]+)s (?P<Prta_3>[a-zA-Zçáéíóúâêô]+[dst])ora(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ora\\n" + m.group(1) + "s " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prta_2") in acSingular and not m.group("Prta_3") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prta_4>[a-zA-Z]+) (?P<Prta_5>[a-zA-Zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ora\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "oras\\n" + m.group(1) + " " + m.group(2) + "or\\n" + m.group(1) + "s " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prta_4") in abSingular and not m.group("Prta_5") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prta_6>[a-zA-Z]+)s (?P<Prta_7>[a-zA-Zçáéíóúâêô]+[dst])ora(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ora\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "oras\\n" + m.group(1) + " " + m.group(2) + "or\\n" + m.group(1) + "s " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prta_6") in abSingular and not m.group("Prta_7") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prta_8>[a-zA-Z]+) (?P<Prta_9>[a-zA-Zçáéíóúâêô]+[dst])ora(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ora"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prta_8") in abSingular and not m.group("Prta_9") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Prta_a>[a-zA-Z]+)s (?P<Prta_b>[a-zA-Zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prta_a") in abSingular and not m.group("Prta_b") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Prts_0>[a-zA-Zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "or\\n" + m.group(1) + "ns " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_0") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Prts_1>[a-zA-Zçáéíóúâêô]+[dst])or(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "or\\n" + m.group(1) + "ns " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_1") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Prts_2>[a-zA-Zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ora\\n" + m.group(1) + "mas " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_2") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Prts_3>[a-zA-Zçáéíóúâêô]+[dst])ora(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ora\\n" + m.group(1) + "mas " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_3") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Prts_4>[a-zA-Zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prts_4") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Prts_5>[a-zA-Zçáéíóúâêô]+[dst])ora(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ora"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Prts_5") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Prts_6>[a-zA-Zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ora\\n" + m.group(1) + "ns " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_6") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Prts_7>[a-zA-Zçáéíóúâêô]+[dst])or(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "oras\\n" + m.group(1) + "m " + m.group(2) + "or"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_7") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Prts_10>[a-zA-Zçáéíóúâêô]+[dst])or(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ora\\n" + m.group(1) + "m " + m.group(2) + "or"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_10") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Prts_11>[a-zA-Zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "oras\\n" + m.group(1) + "ns " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_11") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Prts_8>[a-zA-Zçáéíóúâêô]+[dst])or(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_8") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Prts_9>[a-zA-Zçáéíóúâêô]+[dst])ra(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_9") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Prts_a>[a-zA-Zçáéíóúâêô]+[dst])ora(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_a") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Prts_b>[a-zA-Zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_b") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Prts_c>[a-zA-Zçáéíóúâêô]+[dst])or(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_c") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Prts_d>[a-zA-Zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_d") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Prts_e>[a-zA-Zçáéíóúâêô]+[dst])ora(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ora\\n" + m.group(1) + "s " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_e") in "D-d-ad-Ad"'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Prts_f>[a-zA-Zçáéíóúâêô]+[dst])or(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_f") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Prts_g>[a-zA-Zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_g") in "D-d-"'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Prts_h>[a-zA-Zçáéíóúâêô]+[dst])ora(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ora"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Prts_h") in "D-d-ad-Ad"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pflr_0>[a-zA-Z]+)s (d|c|fl)or(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "or\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pflr_0") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pflr_1>[a-zA-Z]+) (d|c|fl)ores(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "or\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pflr_1") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pflr_2>[a-zA-Z]+) (d|c|fl)or(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "or"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pflr_2") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (d|c|fl)or(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "or"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (d|c|fl)ores(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (d|c|fl)or(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "or"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (d|c|fl)ores(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (d|c|fl)or(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (d|c|fl)or(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (d|c|fl)or(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (d|c|fl)ores(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (d|c|fl)ores(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "or\\n" + m.group(1) + "mas " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (d|c|fl)or(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "or"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (d|c|fl)ores(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (d|c|fl)or(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "or"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (d|c|fl)ores(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (d|c|fl)or(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (d|c|fl)ores(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "or\\n" + m.group(1) + "lgumas " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (d|c|fl)or(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "or"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (d|c|fl)ores(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (d|c|fl)or(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "or"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (d|c|fl)ores(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (d|c|fl)or(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (d|c|fl)ores(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "or\\n" + m.group(1) + "enhumas " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (d|c|fl)ores(?![-\\w–\xad])', '= m.group(2) + " " + m.group(3) + "or\\n" + m.group(2) + "s " + m.group(3) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (d|c|fl)or(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "or\\n" + m.group(1) + "s " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pter_0>[a-zA-Z]+) (?P<Pter_1>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "\\n" + m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pter_0") in aaSingular and m.group("Pter_1") in plvrMfr'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pter_2>[a-zA-Z]+)s (?P<Pter_3>[a-zA-Zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "\\n" + m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pter_2") in aaSingular and m.group("Pter_3") in plvrMfr'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pter_4>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "\\n" + m.group(1) + "ns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pter_4") in plvrMfr'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pter_5>[a-zA-Zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "\\n" + m.group(1) + "ns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pter_5") in plvrMfr'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pter_6>[a-zA-Zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "\\n" + m.group(1) + "mas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pter_6") in plvrMfr'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pter_7>[a-zA-Zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "\\n" + m.group(1) + "mas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pter_7") in plvrMfr'],
 ['(?u)(?<![-\\w–.,\xad])(a|Doi|doi|Dua|dua)s (?P<Pter_8>[a-zA-Zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pter_8") in plvrMfr'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptrm_0>[a-zA-Z]+)s (?P<Ptrm_1>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_0") in aaSingular and m.group("Ptrm_1") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptrm_2>[a-zA-Z]+) (?P<Ptrm_3>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_2") in aaSingular and m.group("Ptrm_3") in plvrMascr and not (m.group("Ptrm_2") in "-A-" and m.group("Ptrm_3") in excPlvrmr)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptrm_4>[a-zA-Z]+) (?P<Ptrm_5>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_4") in acSingular and m.group("Ptrm_5") in plvrMascr and not (m.group("Ptrm_4") in "-A-" and m.group("Ptrm_5") in excPlvrmr)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptrm_6>[a-zA-Z]+)s (?P<Ptrm_7>[a-zA-Záâãçéêíóôú]+[r])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2)s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_6") in acSingular and m.group("Ptrm_7") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Ptrm_a>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_a") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Ptrm_b>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_b") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Ptrm_c>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_c") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Ptrm_d>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_d") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Ptrm_e>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_e") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Ptrm_f>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_f") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Ptrm_g>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_g") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Ptrm_h>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_h") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Ptrm_i>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "\\n" + m.group(1) + "ns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_i") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Ptrm_j>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_j") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Ptrm_k>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_k") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Ptrm_l>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_l") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Ptrm_m>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_m") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Ptrm_n>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_n") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Ptrm_o>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "\\n" + m.group(1) + "lguns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_o") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Ptrm_p>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_p") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Ptrm_q>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_q") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Ptrm_r>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_r") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Ptrm_s>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_s") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Ptrm_t>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_t") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Ptrm_u>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "\\n" + m.group(1) + "enhuns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_u") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Ptrm_v>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_v") in plvrMascr and not m.group("Ptrm_v") in excPlvrmr'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Ptrm_w>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_w") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Ptrm_x>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_x") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Ptrm_y>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrm_y") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptrf_0>[a-zA-Z]+)s (?P<Ptrf_1>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_0") in aaSingular and m.group("Ptrf_1") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptrf_2>[a-zA-Z]+) (?P<Ptrf_3>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_2") in aaSingular and m.group("Ptrf_3") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptrf_4>[a-zA-Z]+) (?P<Ptrf_5>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_4") in abSingular and m.group("Ptrf_5") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptrf_6>[a-zA-Z]+)s (?P<Ptrf_7>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_6") in abSingular and m.group("Ptrf_7") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Ptrf_a>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_a") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Ptrf_b>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_b") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Ptrf_c>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_c") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Ptrf_d>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_d") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Ptrf_e>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_e") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Ptrf_f>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_f") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Ptrf_g>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_g") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Ptrf_h>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_h") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Ptrf_i>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "\\n" + m.group(1) + "mas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_i") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Ptrf_j>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_j") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Ptrf_k>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_k") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Ptrf_l>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_l") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Ptrf_m>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_m") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Ptrf_n>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_n") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Ptrf_o>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "\\n" + m.group(1) + "lgumas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_o") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Ptrf_p>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_p") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Ptrf_q>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_q") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Ptrf_r>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_r") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Ptrf_s>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_s") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Ptrf_t>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_t") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Ptrf_u>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "\\n" + m.group(1) + "enhumas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_u") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Ptrf_v>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '= m.group(2) + " " + m.group(3) + "\\n" + m.group(2) + "s " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_v") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Ptrf_w>[a-zA-Záâãçéêíóôú]+[r])(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "\\n" + m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptrf_w") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptuu_0>[a-zA-Z]+) (?P<Ptuu_1>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "u\\n" + m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_0") in aaSingular and m.group("Ptuu_1") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptuu_2>[a-zA-Z]+)s (?P<Ptuu_3>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "u\\n" + m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_2") in aaSingular and m.group("Ptuu_3") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)m (?P<Ptuu_4>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "u\\n" + m.group(1) + "ns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_4") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Ptuu_5>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "u\\n" + m.group(1) + "ns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_5") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Ptuu_6>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "u\\n" + m.group(1) + "mas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_6") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Ptuu_7>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "u\\n" + m.group(1) + "mas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_7") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(a|Doi|doi|Dua|dua)s (?P<Ptuu_8>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_8") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári([ao])s (?P<Ptuu_9>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "ári" + m.group(2) + "s " + m.group(3) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_9") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uita (?P<Ptuu_10>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_10") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Ptuu_11>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_11") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao]) (?P<Ptuu_12>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "u\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_12") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao])s (?P<Ptuu_13>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "u\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_13") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptuu_14>[a-zA-Z]+)s mesmos (?P<Ptuu_15>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "u\\n" + m.group(1) + "s mesmos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_14") in abSingular and m.group("Ptuu_15") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptuu_16>[a-zA-Z]+)s mesmas (?P<Ptuu_17>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "u\\n" + m.group(1) + "s mesmas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_16") in acSingular and m.group("Ptuu_17") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptuu_18>[a-zA-Z]+)s mesmo (?P<Ptuu_19>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "u\\n" + m.group(1) + "s mesmos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_18") in abSingular and m.group("Ptuu_19") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptuu_20>[a-zA-Z]+)s mesma (?P<Ptuu_21>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "u\\n" + m.group(1) + "s mesmas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_20") in acSingular and m.group("Ptuu_21") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Ptuu_22>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "u\\n" + m.group(1) + "s mesmas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_22") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Ptuu_23>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_23") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Ptuu_24>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= "Uma " + m.group(2) + "u\\nUmas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_24") in plvrMfe'],
 ['(?u)\\b([,]) uma (?P<Ptuu_25>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= ", uma " + m.group(2) + "u\\n, umas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_25") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Ptuu_24>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= "Um " + m.group(2) + "u\\nUns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_26") in plvrMfe'],
 ['(?u)\\b([,]) um (?P<Ptuu_27>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= ", um " + m.group(2) + "u\\n, uns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_27") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Ptuu_28>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_28") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Ptuu_29>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_29") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Ptuu_30>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_30") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Ptuu_31>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_31") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptuu_32>[a-zA-Záâãçéêíóôú]+) um (?P<Ptuu_33>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) + "u\\n" + m.group(1) + " uns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptuu_32") in "-E-e-" and m.group("Ptuu_33") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptuu_34>[a-zA-Záâãçéêíóôú]+) uma (?P<Ptuu_35>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "u\\n" + m.group(1) + " umas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptuu_34") in "-E-e-" and m.group("Ptuu_35") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptuu_36>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptuu_37>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "u\\n" + m.group(1) + " e uns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptuu_36") in numEfem and m.group("Ptuu_37") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptuu_38>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptuu_39>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "u\\n" + m.group(1) + " e umas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptuu_38") in numEfem and m.group("Ptuu_39") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptuu_40>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptuu_41>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_40").lower() in numEmasc and m.group("Ptuu_41") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptuu_42>[a-zA-Záâãçéêíóôú]+) e uns (?P<Ptuu_43>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_42").lower() in numEmasc and m.group("Ptuu_43") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptuu_44>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptuu_45>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_44").lower() in numEfem and m.group("Ptuu_45") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptuu_46>[a-zA-Záâãçéêíóôú]+) e umas (?P<Ptuu_47>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_46").lower() in numEfem and m.group("Ptuu_47") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptuu_48>[a-zA-Záâãçéêíóôú]+) (?P<Ptuu_49>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptuu_48").lower() in numFem and m.group("Ptuu_49") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptuu_50>[0-9]+) (?P<Ptuu_51>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "us"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Ptuu_50") in "00000000001" and not excYmfeu.search(TEXT) and m.group("Ptuu_51") in plvrMfe'],
 ['(?u)\\b([.])(?P<Ptuu_52>[0-9][0-9][0-9]) (?P<Ptuu_53>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "us"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptuu_53") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptuu_54>[0-9]+) (?P<Ptuu_55>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "u"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptuu_55") in "00000000001" and not excYmfeu.search(TEXT) and m.group("Ptuu_55") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptum_0>[a-zA-Z]+)s (?P<Ptum_1>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "u\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_0") in aaSingular and m.group("Ptum_1") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptum_2>[a-zA-Z]+) (?P<Ptum_3>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "u\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_2") in aaSingular and m.group("Ptum_3") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptum_4>[a-zA-Z]+) (?P<Ptum_5>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_4") in acSingular and m.group("Ptum_5") in plvrMascu and not (m.group("Ptum_4") in "-A-" and m.group("Ptum_5") in excplMascu)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptum_6>[a-zA-Z]+)s (?P<Ptum_7>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_6") in acSingular and m.group("Ptum_7") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Ptum_a>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_a") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Ptum_b>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_b") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Ptum_c>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_c") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Ptum_d>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_d") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Ptum_e>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_e") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Ptum_f>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_f") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Ptum_g>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_g") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Ptum_h>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_h") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([U])m (?P<Ptum_i>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "u\\n" + m.group(1) + "ns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_i") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Ptum_j>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "ugum " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_j") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Ptum_k>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "uguns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_k") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Ptum_l>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "ugum " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_l") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Ptum_m>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "uguns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_m") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Ptum_n>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "uguns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_n") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Ptum_o>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "ugum " + m.group(2) + "u\\n" + m.group(1) + "uguns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_o") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Ptum_p>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_p") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Ptum_q>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_q") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Ptum_r>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_r") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Ptum_s>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_s") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Ptum_t>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_t") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Ptum_u>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "u\\n" + m.group(1) + "enhuns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_u") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Ptum_v>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_v") in plvrMascu and not m.group("Ptum_v") in excplMasc'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Ptum_w>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "u\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_w") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Ptum_x>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "u\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_x") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Ptum_y>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "u\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_y") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Ptum_10>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= "Um " + m.group(2) + "u\\nUns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_10") in plvrMasc'],
 ['(?u)\\b([,]) um (?P<Ptum_11>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= ", um " + m.group(2) + "u\\n, uns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_11") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Ptum_12>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) +"u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_12") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Ptum_13>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) +"u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_13") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptum_14>[a-zA-Záâãçéêíóôú]+) um (?P<Ptum_15>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) +"u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_15") in plvrMascu and not m.group("Ptum_14") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptum_16>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptum_17>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "u\\n" + m.group(1) + " e uns " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_17") in plvrMascu and not m.group("Ptum_16") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptum_18>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptum_19>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_19") in plvrMascu and m.group("Ptum_18").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptum_19>[a-zA-Záâãçéêíóôú]+) e uns (?P<Ptum_20>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_20") in plvrMascu and m.group("Ptum_19").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptum_21>[a-zA-Záâãçéêíóôú]+) (?P<Ptum_22>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_22") in plvrMascu and m.group("Ptum_21").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptum_23>[0-9]+) (?P<Ptum_24>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "us"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptum_24") in plvrMascu and not m.group("Ptum_23") in "00000000001" and not excYmascu.search(TEXT)'],
 ['(?u)\\b([.])(?P<Ptum_25>[0-9][0-9][0-9]) (?P<Ptum_26>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "us"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptum_26") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptum_27>[0-9]+) (?P<Ptum_28>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"u"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptum_28") in plvrMascu and m.group("Ptum_27") in "00000000001" and not excYmascu.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptum_29>[a-zA-Záâãçéêíóôú]+)as (?P<Ptum_30>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_30") in plvrMascu and m.group("Ptum_29").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptum_31>[a-zA-Záâãçéêíóôú]+)as (?P<Ptum_32>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptum_32") in plvrMascu and m.group("Ptum_31").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_0>[a-zA-Z]+)s (?P<Pauf_1>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "u\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_0") in aaSingular and m.group("Pauf_1") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_2>[a-zA-Z]+) (?P<Pauf_3>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "u\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_2") in aaSingular and m.group("Pauf_3") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_4>[a-zA-Z]+) (?P<Pauf_5>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_4") in abSingular and m.group("Pauf_5") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_6>[a-zA-Z]+)s (?P<Pauf_7>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_6") in abSingular and m.group("Pauf_7") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pauf_8>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_8") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pauf_9>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_9") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Pauf_a>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_a") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Pauf_b>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_b") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pauf_c>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_c") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pauf_d>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_d") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pauf_e>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_e") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pauf_f>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_f") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pauf_g>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_g") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pauf_h>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_h") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([U])ma (?P<Pauf_i>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "u\\n" + m.group(1) + "mas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_i") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pauf_j>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "uguma " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_j") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pauf_k>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "ugumas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_k") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pauf_l>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "uguma " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_l") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pauf_m>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "ugumas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_m") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pauf_n>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "ugumas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_n") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pauf_o>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "uguma " + m.group(2) + "u\\n" + m.group(1) + "ugumas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_o") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pauf_p>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_p") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pauf_q>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_q") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pauf_r>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_r") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pauf_s>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_s") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pauf_t>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_t") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pauf_u>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "u\\n" + m.group(1) + "enhumas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_u") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pauf_v>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(2) + " " + m.group(3) + "u\\n" + m.group(2) + "s " + m.group(3) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_v") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pauf_w>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "u\\n" + m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_w") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pauf_10>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= "Uma " + m.group(2) + "u\\nUmas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_10") in plvrFem'],
 ['(?u)\\b([,]) uma (?P<Pauf_11>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= ", uma " + m.group(2) + "u\\n, umas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_11") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pauf_12>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) +"u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_12") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pauf_13>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) +"u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_13") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_14>[a-zA-Záâãçéêíóôú]+) uma (?P<Pauf_15>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) +"u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_15") in plvrFemu and not m.group("Pauf_14") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_16>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pauf_17>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "u\\n" + m.group(1) + " e umas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_17") in plvrFemu and not m.group("Pauf_16") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_18>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pauf_19>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_19") in plvrFemu and m.group("Pauf_18").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_19>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pauf_20>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_20") in plvrFemu and m.group("Pauf_19").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_21>[a-zA-Záâãçéêíóôú]+) (?P<Pauf_22>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_22") in plvrFemu and m.group("Pauf_21").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_23>[0-9]+) (?P<Pauf_24>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "us"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pauf_24") in plvrFemu and not m.group("Pauf_23") in "00000000001" and not excYfemu.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pauf_25>[0-9][0-9][0-9]) (?P<Pauf_26>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "us"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pauf_26") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_27>[0-9]+) (?P<Pauf_28>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"u"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pauf_28") in plvrFemu and m.group("Pauf_27") in "00000000001" and not excYfemu.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_29>[a-zA-Záâãçéêíóôú]+)os (?P<Pauf_30>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_30") in plvrFemu and m.group("Pauf_29").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pauf_31>[a-zA-Záâãçéêíóôú]+)os (?P<Pauf_32>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pauf_32") in plvrFemu and m.group("Pauf_31").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptii_0>[a-zA-Z]+) (?P<Ptii_1>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "i\\n" + m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_0") in aaSingular and m.group("Ptii_1") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptii_2>[a-zA-Z]+)s (?P<Ptii_3>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "i\\n" + m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_2") in aaSingular and m.group("Ptii_3") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)m (?P<Ptii_4>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "i\\n" + m.group(1) + "ns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_4") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Ptii_5>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "i\\n" + m.group(1) + "ns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_5") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Ptii_6>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "i\\n" + m.group(1) + "mas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_6") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Ptii_7>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "i\\n" + m.group(1) + "mas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_7") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(a|Doi|doi|Dua|dua)s (?P<Ptii_8>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_8") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári([ao])s (?P<Ptii_9>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= m.group(1) + "ári" + m.group(2) + "s " + m.group(3) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_9") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uita (?P<Ptii_10>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_10") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Ptii_11>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "u"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_11") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao]) (?P<Ptii_12>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "i\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_12") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao])s (?P<Ptii_13>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "i\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_13") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptii_14>[a-zA-Z]+)s mesmos (?P<Ptii_15>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "i\\n" + m.group(1) + "s mesmos " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_14") in abSingular and m.group("Ptii_15") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptii_16>[a-zA-Z]+)s mesmas (?P<Ptii_17>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "i\\n" + m.group(1) + "s mesmas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_16") in acSingular and m.group("Ptii_17") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptii_18>[a-zA-Z]+)s mesmo (?P<Ptii_19>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "i\\n" + m.group(1) + "s mesmos " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_18") in abSingular and m.group("Ptii_19") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptii_20>[a-zA-Z]+)s mesma (?P<Ptii_21>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "i\\n" + m.group(1) + "s mesmas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_20") in acSingular and m.group("Ptii_21") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Ptii_22>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "i\\n" + m.group(1) + "s mesmas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_22") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Ptii_23>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_23") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Ptii_24>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= "Uma " + m.group(2) + "i\\nUmas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_24") in plvrMfei'],
 ['(?u)\\b([,]) uma (?P<Ptii_25>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= ", uma " + m.group(2) + "i\\n, umas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_25") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Ptii_24>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= "Um " + m.group(2) + "i\\nUns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_26") in plvrMfei'],
 ['(?u)\\b([,]) um (?P<Ptii_27>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= ", um " + m.group(2) + "i\\n, uns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_27") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Ptii_28>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_28") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Ptii_29>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_29") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Ptii_30>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_30") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Ptii_31>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_31") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptii_32>[a-zA-Záâãçéêíóôú]+) um (?P<Ptii_33>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) + "i\\n" + m.group(1) + " uns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptii_32") in "-E-e-" and m.group("Ptii_33") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptii_34>[a-zA-Záâãçéêíóôú]+) uma (?P<Ptii_35>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "i\\n" + m.group(1) + " umas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptii_34") in "-E-e-" and m.group("Ptii_35") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptii_36>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptii_37>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "i\\n" + m.group(1) + " e uns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptii_36") in numEfem and m.group("Ptii_37") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptii_38>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptii_39>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "i\\n" + m.group(1) + " e umas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptii_38") in numEfem and m.group("Ptii_39") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptii_40>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptii_41>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_40").lower() in numEmasc and m.group("Ptii_41") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptii_42>[a-zA-Záâãçéêíóôú]+) e uns (?P<Ptii_43>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_42").lower() in numEmasc and m.group("Ptii_43") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptii_44>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptii_45>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_44").lower() in numEfem and m.group("Ptii_45") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptii_46>[a-zA-Záâãçéêíóôú]+) e umas (?P<Ptii_47>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_46").lower() in numEfem and m.group("Ptii_47") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptii_48>[a-zA-Záâãçéêíóôú]+) (?P<Ptii_49>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptii_48").lower() in numFem and m.group("Ptii_49") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptii_50>[0-9]+) (?P<Ptii_51>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "is"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Ptii_50") in "00000000001" and not excYmfei.search(TEXT) and m.group("Ptii_51") in plvrMfei'],
 ['(?u)\\b([.])(?P<Ptii_52>[0-9][0-9][0-9]) (?P<Ptii_53>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "is"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptii_53") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptii_54>[0-9]+) (?P<Ptii_55>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "i"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptii_55") in "00000000001" and not excYmfei.search(TEXT) and m.group("Ptii_55") in plvrMfei'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptim_0>[a-zA-Z]+)s (?P<Ptim_1>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "i\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_0") in aaSingular and m.group("Ptim_1") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptim_2>[a-zA-Z]+) (?P<Ptim_3>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "i\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_2") in aaSingular and m.group("Ptim_3") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptim_4>[a-zA-Z]+) (?P<Ptim_5>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_4") in acSingular and m.group("Ptim_5") in plvrMasci and not m.group("Ptim_4") in "-A-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptim_6>[a-zA-Z]+)s (?P<Ptim_7>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_6") in acSingular and m.group("Ptim_7") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Ptim_a>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_a") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Ptim_b>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_b") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Ptim_c>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_c") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Ptim_d>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_d") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Ptim_e>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_e") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Ptim_f>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_f") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Ptim_g>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_g") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Ptim_h>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_h") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([U])m (?P<Ptim_i>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "i\\n" + m.group(1) + "ns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_i") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Ptim_j>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "ugum " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_j") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Ptim_k>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "uguns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_k") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Ptim_l>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "ugum " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_l") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Ptim_m>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "uguns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_m") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Ptim_n>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "uguns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_n") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Ptim_o>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "ugum " + m.group(2) + "i\\n" + m.group(1) + "uguns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_o") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Ptim_p>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_p") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Ptim_q>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_q") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Ptim_r>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_r") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Ptim_s>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_s") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Ptim_t>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_t") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Ptim_u>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "i\\n" + m.group(1) + "enhuns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_u") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Ptim_v>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_v") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Ptim_w>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "i\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_w") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Ptim_x>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "i\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_x") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Ptim_y>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "i\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_y") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Ptim_10>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= "Um " + m.group(2) + "i\\nUns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_10") in plvrMasci'],
 ['(?u)\\b([,]) um (?P<Ptim_11>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= ", um " + m.group(2) + "i\\n, uns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_11") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Ptim_12>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) +"i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_12") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Ptim_13>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) +"i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_13") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptim_14>[a-zA-Záâãçéêíóôú]+) um (?P<Ptim_15>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) +"i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_15") in plvrMasci and not m.group("Ptim_14") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptim_16>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptim_17>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "i\\n" + m.group(1) + " e uns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_17") in plvrMasci and not m.group("Ptim_16") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptim_18>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptim_19>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_19") in plvrMasci and m.group("Ptim_18").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptim_19>[a-zA-Záâãçéêíóôú]+) e uns (?P<Ptim_20>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_20") in plvrMasci and m.group("Ptim_19").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptim_21>[a-zA-Záâãçéêíóôú]+) (?P<Ptim_22>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_22") in plvrMasci and m.group("Ptim_21").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptim_23>[0-9]+) (?P<Ptim_24>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "is"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptim_24") in plvrMasci and not m.group("Ptim_23") in "00000000001" and not excYmasci.search(TEXT)'],
 ['(?u)\\b([.])(?P<Ptim_25>[0-9][0-9][0-9]) (?P<Ptim_26>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "is"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptim_26") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptim_27>[0-9]+) (?P<Ptim_28>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"i"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptim_28") in plvrMasci and m.group("Ptim_27") in "00000000001" and not excYmasci.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptim_29>[a-zA-Záâãçéêíóôú]+)as (?P<Ptim_30>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_30") in plvrMasci and m.group("Ptim_29").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptim_31>[a-zA-Záâãçéêíóôú]+)as (?P<Ptim_32>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptim_32") in plvrMasci and m.group("Ptim_31").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crci_10>[a-zA-Zçáéíóúâêô]+)i(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "i"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crci_10") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crci_11>[a-zA-Zçáéíóúâêô]+)is(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "is"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crci_11") in plvrMasci'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paif_0>[a-zA-Z]+)s (?P<Paif_1>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "i\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_0") in aaSingular and m.group("Paif_1") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paif_2>[a-zA-Z]+) (?P<Paif_3>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "i\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_2") in aaSingular and m.group("Paif_3") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paif_4>[a-zA-Z]+) (?P<Paif_5>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_4") in abSingular and m.group("Paif_5") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paif_6>[a-zA-Z]+)s (?P<Paif_7>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_6") in abSingular and m.group("Paif_7") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Paif_8>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_8") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Paif_9>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_9") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Paif_a>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_a") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Paif_b>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_b") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Paif_c>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_c") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Paif_d>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_d") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Paif_e>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_e") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Paif_f>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_f") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Paif_g>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_g") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Paif_h>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_h") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([U])ma (?P<Paif_i>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "i\\n" + m.group(1) + "mas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_i") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Paif_j>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "uguma " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_j") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Paif_k>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "ugumas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_k") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Paif_l>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "uguma " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_l") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Paif_m>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "ugumas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_m") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Paif_n>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "ugumas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_n") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Paif_o>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "uguma " + m.group(2) + "i\\n" + m.group(1) + "ugumas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_o") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Paif_p>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_p") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Paif_q>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_q") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Paif_r>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_r") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Paif_s>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_s") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Paif_t>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_t") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Paif_u>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "i\\n" + m.group(1) + "enhumas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_u") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Paif_v>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(2) + " " + m.group(3) + "i\\n" + m.group(2) + "s " + m.group(3) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_v") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Paif_w>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "i\\n" + m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_w") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Paif_10>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= "Uma " + m.group(2) + "i\\nUmas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_10") in plvrFemi'],
 ['(?u)\\b([,]) uma (?P<Paif_11>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= ", uma " + m.group(2) + "i\\n, umas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_11") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Paif_12>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) +"i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_12") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Paif_13>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) +"i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_13") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paif_14>[a-zA-Záâãçéêíóôú]+) uma (?P<Paif_15>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) +"i"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_15") in plvrFemi and not m.group("Paif_14") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paif_16>[a-zA-Záâãçéêíóôú]+) e uma (?P<Paif_17>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "i\\n" + m.group(1) + " e umas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_17") in plvrFemi and not m.group("Paif_16") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paif_18>[a-zA-Záâãçéêíóôú]+) e uma (?P<Paif_19>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_19") in plvrFemi and m.group("Paif_18").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paif_19>[a-zA-Záâãçéêíóôú]+) e umas (?P<Paif_20>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_20") in plvrFemi and m.group("Paif_19").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paif_21>[a-zA-Záâãçéêíóôú]+) (?P<Paif_22>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_22") in plvrFemi and m.group("Paif_21").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paif_23>[0-9]+) (?P<Paif_24>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "is"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Paif_24") in plvrFemi and not m.group("Paif_23") in "00000000001" and not excYfemi.search(TEXT)'],
 ['(?u)\\b([.])(?P<Paif_25>[0-9][0-9][0-9]) (?P<Paif_26>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "is"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Paif_26") in plvrFemi'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paif_27>[0-9]+) (?P<Paif_28>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"i"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Paif_28") in plvrFemi and m.group("Paif_27") in "00000000001" and not excYfemi.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paif_29>[a-zA-Záâãçéêíóôú]+)os (?P<Paif_30>[a-zA-Záâãçéêíóôú]+)i(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_30") in plvrFemi and m.group("Paif_29").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paif_31>[a-zA-Záâãçéêíóôú]+)os (?P<Paif_32>[a-zA-Záâãçéêíóôú]+)is(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paif_32") in plvrFemi and m.group("Paif_31").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptal_0>[a-zA-Z]+) (?P<Ptal_1>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "l\\n" + m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_0") in aaSingular and m.group("Ptal_1") in plvrMfal and not "certo quais" in TEXT and not m.group("Ptal_0") + " " + m.group("Ptal_1") in "A tais"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptal_2>[a-zA-Z]+)s (?P<Ptal_3>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "l\\n" + m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_2") in aaSingular and m.group("Ptal_3") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)m (?P<Ptal_4>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "l\\n" + m.group(1) + "ns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_4") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Ptal_5>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "l\\n" + m.group(1) + "ns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_5") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Ptal_6>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "l\\n" + m.group(1) + "mas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_6") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Ptal_7>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "l\\n" + m.group(1) + "mas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_7") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(a|Doi|doi|Dua|dua)s (?P<Ptal_8>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_8") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári([ao])s (?P<Ptal_9>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "ári" + m.group(2) + "s " + m.group(3) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_9") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uita (?P<Ptal_10>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_10") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Ptal_11>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_11") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao]) (?P<Ptal_12>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "l\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_12") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao])s (?P<Ptal_13>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "l\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_13") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptal_14>[a-zA-Z]+)s mesmos (?P<Ptal_15>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "l\\n" + m.group(1) + "s mesmos " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_14") in abSingular and m.group("Ptal_15") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptal_16>[a-zA-Z]+)s mesmas (?P<Ptal_17>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "l\\n" + m.group(1) + "s mesmas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_16") in acSingular and m.group("Ptal_17") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptal_18>[a-zA-Z]+)s mesmo (?P<Ptal_19>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "l\\n" + m.group(1) + "s mesmos " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_18") in abSingular and m.group("Ptal_19") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptal_20>[a-zA-Z]+)s mesma (?P<Ptal_21>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "l\\n" + m.group(1) + "s mesmas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_20") in acSingular and m.group("Ptal_21") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Ptal_22>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "l\\n" + m.group(1) + "s mesmas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_22") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Ptal_23>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_23") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Ptal_24>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= "Uma " + m.group(2) + "l\\nUmas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_24") in plvrMfal'],
 ['(?u)\\b([,]) uma (?P<Ptal_25>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= ", uma " + m.group(2) + "l\\n, umas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_25") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Ptal_24>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= "Um " + m.group(2) + "l\\nUns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_26") in plvrMfal'],
 ['(?u)\\b([,]) um (?P<Ptal_27>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= ", um " + m.group(2) + "l\\n, uns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_27") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Ptal_28>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_28") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Ptal_29>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_29") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Ptal_30>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_30") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Ptal_31>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_31") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptal_32>[a-zA-Záâãçéêíóôú]+) um (?P<Ptal_33>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) + "l\\n" + m.group(1) + " uns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptal_32") in "-E-e-" and m.group("Ptal_33") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptal_34>[a-zA-Záâãçéêíóôú]+) uma (?P<Ptal_35>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "l\\n" + m.group(1) + " umas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptal_34") in "-E-e-" and m.group("Ptal_35") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptal_36>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptal_37>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "l\\n" + m.group(1) + " e uns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptal_36") in numEmasc and not m.group("Ptal_36") in numEfem and m.group("Ptal_37") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptal_38>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptal_39>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "l\\n" + m.group(1) + " e umas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptal_38") in numEmasc and not m.group("Ptal_38") in numEfem and m.group("Ptal_39") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptal_40>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptal_41>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_40").lower() in numEmasc and m.group("Ptal_41") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptal_42>[a-zA-Záâãçéêíóôú]+) e uns (?P<Ptal_43>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_42").lower() in numEmasc and m.group("Ptal_43") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptal_44>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptal_45>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_44").lower() in numEfem and m.group("Ptal_45") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptal_46>[a-zA-Záâãçéêíóôú]+) e umas (?P<Ptal_47>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_46").lower() in numEfem and m.group("Ptal_47") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptal_48>[a-zA-Záâãçéêíóôú]+) (?P<Ptal_49>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptal_48").lower() in numFem and m.group("Ptal_49") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptal_50>[0-9]+) (?P<Ptal_51>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "is"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Ptal_50") in "00000000001" and not excYmfal.search(TEXT) and m.group("Ptal_51") in plvrMfal'],
 ['(?u)\\b([.])(?P<Ptal_52>[0-9][0-9][0-9]) (?P<Ptal_53>[a-zA-Zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "is"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptal_53") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptal_54>[0-9]+) (?P<Ptal_55>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "l"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptal_55") in "00000000001" and not excYmfal.search(TEXT) and m.group("Ptal_55") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palm_0>[a-zA-Z]+)s (?P<Palm_1>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "l\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_0") in aaSingular and m.group("Palm_1") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palm_2>[a-zA-Z]+) (?P<Palm_3>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "l\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_2") in aaSingular and m.group("Palm_3") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palm_4>[a-zA-Z]+) (?P<Palm_5>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_4") in acSingular and m.group("Palm_5") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palm_6>[a-zA-Z]+)s (?P<Palm_7>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_6") in acSingular and m.group("Palm_7") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Palm_a>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_a") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Palm_b>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_b") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Palm_c>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_c") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Palm_d>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_d") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Palm_e>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_e") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Palm_f>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_f") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Palm_g>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_g") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Palm_h>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_h") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([U])m (?P<Palm_i>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "l\\n" + m.group(1) + "ns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_i") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Palm_j>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_j") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Palm_k>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_k") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Palm_l>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_l") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Palm_m>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_m") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Palm_n>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_n") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Palm_o>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "l\\n" + m.group(1) + "lguns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_o") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Palm_p>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_p") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Palm_q>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_q") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Palm_r>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_r") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Palm_s>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_s") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Palm_t>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_t") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Palm_u>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "l\\n" + m.group(1) + "enhuns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_u") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Palm_v>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_v") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Palm_w>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "l\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_w") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Palm_x>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "l\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_x") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Palm_y>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "l\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_y") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Palm_10>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= "Um " + m.group(2) + "l\\nUns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_10") in plvrMascal'],
 ['(?u)\\b([,]) um (?P<Palm_11>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= ", um " + m.group(2) + "l\\n, uns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_11") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Palm_12>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) +"l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_12") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Palm_13>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) +"l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_13") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palm_14>[a-zA-Záâãçéêíóôú]+) um (?P<Palm_15>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) +"l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_15") in plvrMascal and not m.group("Palm_14") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palm_16>[a-zA-Záâãçéêíóôú]+) e um (?P<Palm_17>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "l\\n" + m.group(1) + " e uns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_17") in plvrMascal and not m.group("Palm_16") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palm_18>[a-zA-Záâãçéêíóôú]+) e um (?P<Palm_19>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_19") in plvrMascal and m.group("Palm_18").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palm_19>[a-zA-Záâãçéêíóôú]+) e uns (?P<Palm_20>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_20") in plvrMascal and m.group("Palm_19").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palm_21>[a-zA-Záâãçéêíóôú]+) (?P<Palm_22>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_22") in plvrMascal and m.group("Palm_21").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palm_23>[0-9]+) (?P<Palm_24>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "is"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Palm_24") in plvrMascal and not m.group("Palm_23") in "00000000001" and not excYmascal.search(TEXT)'],
 ['(?u)\\b([.])(?P<Palm_25>[0-9][0-9][0-9]) (?P<Palm_26>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "is"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Palm_26") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palm_27>[0-9]+) (?P<Palm_28>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"l"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Palm_28") in plvrMascal and m.group("Palm_27") in "00000000001" and not excYmascal.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palm_29>[a-zA-Záâãçéêíóôú]+)as (?P<Palm_30>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_30") in plvrMascal and m.group("Palm_29").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palm_31>[a-zA-Záâãçéêíóôú]+)as (?P<Palm_32>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palm_32") in plvrMascal and m.group("Palm_31").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palf_0>[a-zA-Z]+)s (?P<Palf_1>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "l\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_0") in aaSingular and m.group("Palf_1") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palf_2>[a-zA-Z]+) (?P<Palf_3>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "l\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_2") in aaSingular and m.group("Palf_3") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palf_4>[a-zA-Z]+) (?P<Palf_5>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_4") in abSingular and m.group("Palf_5") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palf_6>[a-zA-Z]+)s (?P<Palf_7>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_6") in abSingular and m.group("Palf_7") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Palf_8>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_8") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Palf_9>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_9") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Palf_a>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_a") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Palf_b>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_b") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Palf_c>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_c") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Palf_d>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_d") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Palf_e>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_e") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Palf_f>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_f") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Palf_g>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_g") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Palf_h>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_h") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([U])ma (?P<Palf_i>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "l\\n" + m.group(1) + "mas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_i") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Palf_j>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_j") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Palf_k>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_k") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Palf_l>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_l") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Palf_m>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_m") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Palf_n>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_n") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Palf_o>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "l\\n" + m.group(1) + "lgumas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_o") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Palf_p>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_p") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Palf_q>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_q") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Palf_r>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_r") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Palf_s>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_s") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Palf_t>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_t") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Palf_u>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "l\\n" + m.group(1) + "enhumas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_u") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Palf_v>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(2) + " " + m.group(3) + "l\\n" + m.group(2) + "s " + m.group(3) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_v") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Palf_w>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "l\\n" + m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_w") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Palf_10>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= "Uma " + m.group(2) + "l\\nUmas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_10") in plvrFemal'],
 ['(?u)\\b([,]) uma (?P<Palf_11>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= ", uma " + m.group(2) + "l\\n, umas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_11") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Palf_12>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) +"l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_12") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Palf_13>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) +"l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_13") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palf_14>[a-zA-Záâãçéêíóôú]+) uma (?P<Palf_15>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) +"l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_15") in plvrFemal and not m.group("Palf_14") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palf_16>[a-zA-Záâãçéêíóôú]+) e uma (?P<Palf_17>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "l\\n" + m.group(1) + " e umas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_17") in plvrFemal and not m.group("Palf_16") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palf_18>[a-zA-Záâãçéêíóôú]+) e uma (?P<Palf_19>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_19") in plvrFemal and m.group("Palf_18").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palf_19>[a-zA-Záâãçéêíóôú]+) e umas (?P<Palf_20>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_20") in plvrFemal and m.group("Palf_19").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palf_21>[a-zA-Záâãçéêíóôú]+) (?P<Palf_22>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_22") in plvrFemal and m.group("Palf_21").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palf_23>[0-9]+) (?P<Palf_24>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "is"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Palf_24") in plvrFemal and not m.group("Palf_23") in "00000000001" and not excYfemal.search(TEXT)'],
 ['(?u)\\b([.])(?P<Palf_25>[0-9][0-9][0-9]) (?P<Palf_26>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "is"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Palf_26") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palf_27>[0-9]+) (?P<Palf_28>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"l"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Palf_28") in plvrFemal and m.group("Palf_27") in "00000000001" and not excYfemal.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palf_29>[a-zA-Záâãçéêíóôú]+)os (?P<Palf_30>[a-zA-Záâãçéêíóôú]+[a])l(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_30") in plvrFemal and m.group("Palf_29").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Palf_31>[a-zA-Záâãçéêíóôú]+)os (?P<Palf_32>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Palf_32") in plvrFemal and m.group("Palf_31").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptel_0>[a-zA-Z]+) (?P<Ptel_1>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "el\\n" + m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_0") in aaSingular and m.group("Ptel_1") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptel_2>[a-zA-Z]+)s (?P<Ptel_3>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "el\\n" + m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_2") in aaSingular and m.group("Ptel_3") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)m (?P<Ptel_4>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "el\\n" + m.group(1) + "ns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_4") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Ptel_5>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "el\\n" + m.group(1) + "ns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_5") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Ptel_6>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "el\\n" + m.group(1) + "mas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_6") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Ptel_7>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "el\\n" + m.group(1) + "mas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_7") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(a|Doi|doi|Dua|dua)s (?P<Ptel_8>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_8") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári([ao])s (?P<Ptel_9>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + "ári" + m.group(2) + "s " + m.group(3) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_9") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uita (?P<Ptel_10>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_10") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Ptel_11>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_11") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao]) (?P<Ptel_12>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "el\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_12") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao])s (?P<Ptel_13>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "el\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_13") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptel_14>[a-zA-Z]+)s mesmos (?P<Ptel_15>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "el\\n" + m.group(1) + "s mesmos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_14") in abSingular and m.group("Ptel_15") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptel_16>[a-zA-Z]+)s mesmas (?P<Ptel_17>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "el\\n" + m.group(1) + "s mesmas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_16") in acSingular and m.group("Ptel_17") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptel_18>[a-zA-Z]+)s mesmo (?P<Ptel_19>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "el\\n" + m.group(1) + "s mesmos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_18") in abSingular and m.group("Ptel_19") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptel_20>[a-zA-Z]+)s mesma (?P<Ptel_21>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "el\\n" + m.group(1) + "s mesmas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_20") in acSingular and m.group("Ptel_21") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Ptel_22>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "el\\n" + m.group(1) + "s mesmas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_22") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Ptel_23>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_23") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Ptel_24>[a-zA-Z]+)éis(?![-\\w–\xad])', '= "Uma " + m.group(2) + "el\\nUmas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_24") in plvrMfel'],
 ['(?u)\\b([,]) uma (?P<Ptel_25>[a-zA-Z]+)éis(?![-\\w–\xad])', '= ", uma " + m.group(2) + "el\\n, umas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_25") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Ptel_24>[a-zA-Z]+)éis(?![-\\w–\xad])', '= "Um " + m.group(2) + "el\\nUns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_26") in plvrMfel'],
 ['(?u)\\b([,]) um (?P<Ptel_27>[a-zA-Z]+)éis(?![-\\w–\xad])', '= ", um " + m.group(2) + "el\\n, uns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_27") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Ptel_28>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_28") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Ptel_29>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_29") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Ptel_30>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_30") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Ptel_31>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_31") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptel_32>[a-zA-Záâãçéêíóôú]+) um (?P<Ptel_33>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) + "el\\n" + m.group(1) + " uns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptel_32") in "-E-e-" and m.group("Ptel_33") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptel_34>[a-zA-Záâãçéêíóôú]+) uma (?P<Ptel_35>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "el\\n" + m.group(1) + " umas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptel_34") in "-E-e-" and m.group("Ptel_35") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptel_36>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptel_37>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "el\\n" + m.group(1) + " e uns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptel_36") in numEfem and m.group("Ptel_37") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptel_38>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptel_39>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "el\\n" + m.group(1) + " e umas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptel_38") in numEfem and m.group("Ptel_39") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptel_40>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptel_41>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_40").lower() in numEmasc and m.group("Ptel_41") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptel_42>[a-zA-Záâãçéêíóôú]+) e uns (?P<Ptel_43>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_42").lower() in numEmasc and m.group("Ptel_43") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptel_44>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptel_45>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_44").lower() in numEfem and m.group("Ptel_45") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptel_46>[a-zA-Záâãçéêíóôú]+) e umas (?P<Ptel_47>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_46").lower() in numEfem and m.group("Ptel_47") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptel_48>[a-zA-Záâãçéêíóôú]+) (?P<Ptel_49>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptel_48").lower() in numFem and m.group("Ptel_49") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptel_50>[0-9]+) (?P<Ptel_51>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "éis"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Ptel_50") in "00000000001" and not excYmfel.search(TEXT) and m.group("Ptel_51") in plvrMfel'],
 ['(?u)\\b([.])(?P<Ptel_52>[0-9][0-9][0-9]) (?P<Ptel_53>[a-zA-Z]+)el(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "éis"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptel_53") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptel_54>[0-9]+) (?P<Ptel_55>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "el"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptel_55") in "00000000001" and not excYmfel.search(TEXT) and m.group("Ptel_55") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelm_0>[a-zA-Z]+)s (?P<Pelm_1>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "el\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_0") in aaSingular and m.group("Pelm_1") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelm_2>[a-zA-Z]+) (?P<Pelm_3>[a-zA-Z]+)éis(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "el\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_2") in aaSingular and m.group("Pelm_3") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelm_4>[a-zA-Z]+) (?P<Pelm_5>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_4") in acSingular and m.group("Pelm_5") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelm_6>[a-zA-Z]+)s (?P<Pelm_7>[a-zA-Z]+)éis(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_6") in acSingular and m.group("Pelm_7") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Pelm_a>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_a") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Pelm_b>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_b") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pelm_c>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_c") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pelm_d>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_d") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pelm_e>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_e") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pelm_f>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_f") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pelm_g>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_g") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pelm_h>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_h") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([U])m (?P<Pelm_i>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "el\\n" + m.group(1) + "ns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_i") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pelm_j>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "elgum " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_j") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pelm_k>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "elguns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_k") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pelm_l>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "elgum " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_l") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pelm_m>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "elguns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_m") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pelm_n>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "elguns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_n") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pelm_o>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "elgum " + m.group(2) + "el\\n" + m.group(1) + "elguns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_o") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pelm_p>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_p") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pelm_q>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_q") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pelm_r>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_r") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pelm_s>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_s") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pelm_t>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_t") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pelm_u>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "el\\n" + m.group(1) + "enhuns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_u") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pelm_v>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_v") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pelm_w>[a-zA-Z]+)éis(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "el\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_w") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pelm_x>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "el\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_x") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pelm_y>[a-zA-Z]+)éis(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "el\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_y") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Pelm_10>[a-zA-Z]+)éis(?![-\\w–\xad])', '= "Um " + m.group(2) + "el\\nUns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_10") in plvrMascel'],
 ['(?u)\\b([,]) um (?P<Pelm_11>[a-zA-Z]+)éis(?![-\\w–\xad])', '= ", um " + m.group(2) + "el\\n, uns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_11") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Pelm_12>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) +"el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_12") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Pelm_13>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) +"el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_13") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelm_14>[a-zA-Záâãçéêíóôú]+) um (?P<Pelm_15>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) +"el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_15") in plvrMascel and not m.group("Pelm_14") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelm_16>[a-zA-Záâãçéêíóôú]+) e um (?P<Pelm_17>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "el\\n" + m.group(1) + " e uns " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_17") in plvrMascel and not m.group("Pelm_16") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelm_18>[a-zA-Záâãçéêíóôú]+) e um (?P<Pelm_19>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_19") in plvrMascel and m.group("Pelm_18").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelm_19>[a-zA-Záâãçéêíóôú]+) e uns (?P<Pelm_20>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_20") in plvrMascel and m.group("Pelm_19").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelm_21>[a-zA-Záâãçéêíóôú]+) (?P<Pelm_22>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_22") in plvrMascel and m.group("Pelm_21").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelm_23>[0-9]+) (?P<Pelm_24>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "éis"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pelm_24") in plvrMascel and not m.group("Pelm_23") in "00000000001" and not excYmascel.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pelm_25>[0-9][0-9][0-9]) (?P<Pelm_26>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "éis"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pelm_26") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelm_27>[0-9]+) (?P<Pelm_28>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"el"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pelm_28") in plvrMascel and m.group("Pelm_27") in "00000000001" and not excYmascel.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelm_29>[a-zA-Záâãçéêíóôú]+)as (?P<Pelm_30>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_30") in plvrMascel and m.group("Pelm_29").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelm_31>[a-zA-Záâãçéêíóôú]+)as (?P<Pelm_32>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelm_32") in plvrMascel and m.group("Pelm_31").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelf_0>[a-zA-Z]+)s (?P<Pelf_1>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "el\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_0") in aaSingular and m.group("Pelf_1") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelf_2>[a-zA-Z]+) (?P<Pelf_3>[a-zA-Z]+)éis(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "el\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_2") in aaSingular and m.group("Pelf_3") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelf_4>[a-zA-Z]+) (?P<Pelf_5>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_4") in abSingular and m.group("Pelf_5") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelf_6>[a-zA-Z]+)s (?P<Pelf_7>[a-zA-Z]+)éis(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_6") in abSingular and m.group("Pelf_7") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pelf_8>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_8") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pelf_9>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_9") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Pelf_a>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_a") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Pelf_b>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_b") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pelf_c>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_c") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pelf_d>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_d") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pelf_e>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_e") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pelf_f>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_f") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pelf_g>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_g") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pelf_h>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_h") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([U])ma (?P<Pelf_i>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "el\\n" + m.group(1) + "mas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_i") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pelf_j>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "elguma " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_j") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pelf_k>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "elgumas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_k") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pelf_l>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "elguma " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_l") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pelf_m>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "elgumas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_m") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pelf_n>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "elgumas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_n") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pelf_o>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "elguma " + m.group(2) + "el\\n" + m.group(1) + "elgumas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_o") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pelf_p>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_p") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pelf_q>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_q") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pelf_r>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_r") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pelf_s>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_s") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pelf_t>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_t") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pelf_u>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "el\\n" + m.group(1) + "enhumas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_u") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pelf_v>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(2) + " " + m.group(3) + "el\\n" + m.group(2) + "s " + m.group(3) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_v") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pelf_w>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "el\\n" + m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_w") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pelf_10>[a-zA-Z]+)éis(?![-\\w–\xad])', '= "Uma " + m.group(2) + "el\\nUmas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_10") in plvrFemel'],
 ['(?u)\\b([,]) uma (?P<Pelf_11>[a-zA-Z]+)éis(?![-\\w–\xad])', '= ", uma " + m.group(2) + "el\\n, umas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_11") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pelf_12>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) +"el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_12") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pelf_13>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) +"el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_13") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelf_14>[a-zA-Záâãçéêíóôú]+) uma (?P<Pelf_15>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) +"el"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_15") in plvrFemel and not m.group("Pelf_14") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelf_16>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pelf_17>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "el\\n" + m.group(1) + " e umas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_17") in plvrFemel and not m.group("Pelf_16") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelf_18>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pelf_19>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_19") in plvrFemel and m.group("Pelf_18").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelf_19>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pelf_20>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_20") in plvrFemel and m.group("Pelf_19").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelf_21>[a-zA-Záâãçéêíóôú]+) (?P<Pelf_22>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_22") in plvrFemel and m.group("Pelf_21").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelf_23>[0-9]+) (?P<Pelf_24>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "éis"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pelf_24") in plvrFemel and not m.group("Pelf_23") in "00000000001" and not excYfemel.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pelf_25>[0-9][0-9][0-9]) (?P<Pelf_26>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "éis"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pelf_26") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelf_27>[0-9]+) (?P<Pelf_28>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"el"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pelf_28") in plvrFemel and m.group("Pelf_27") in "00000000001" and not excYfemel.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelf_29>[a-zA-Záâãçéêíóôú]+)os (?P<Pelf_30>[a-zA-Záâãçéêíóôú]+)el(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_30") in plvrFemel and m.group("Pelf_29").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelf_31>[a-zA-Záâãçéêíóôú]+)os (?P<Pelf_32>[a-zA-Z]+)éis(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelf_32") in plvrFemel and m.group("Pelf_31").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelw_0>[a-zA-Z]+)s (?P<Pelw_1>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "l\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_0") in aaSingular and m.group("Pelw_1") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelw_2>[a-zA-Z]+) (?P<Pelw_3>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "l\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_2") in aaSingular and m.group("Pelw_3") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelw_4>[a-zA-Z]+) (?P<Pelw_5>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_4") in acSingular and m.group("Pelw_5") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelw_6>[a-zA-Z]+)s (?P<Pelw_7>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_6") in acSingular and m.group("Pelw_7") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Pelw_a>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_a") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Pelw_b>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_b") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pelw_c>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_c") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pelw_d>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_d") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pelw_e>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_e") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pelw_f>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_f") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pelw_g>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_g") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pelw_h>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_h") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([U])m (?P<Pelw_i>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "l\\n" + m.group(1) + "ns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_i") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pelw_j>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_j") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pelw_k>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_k") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pelw_l>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_l") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pelw_m>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_m") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pelw_n>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_n") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pelw_o>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "l\\n" + m.group(1) + "lguns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_o") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pelw_p>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_p") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pelw_q>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_q") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pelw_r>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_r") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pelw_s>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_s") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pelw_t>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_t") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pelw_u>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "l\\n" + m.group(1) + "enhuns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_u") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pelw_v>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_v") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pelw_w>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "l\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_w") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pelw_x>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "l\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_x") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pelw_y>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "l\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_y") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Pelw_10>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= "Um " + m.group(2) + "l\\nUns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_10") in plvrAmascel'],
 ['(?u)\\b([,]) um (?P<Pelw_11>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= ", um " + m.group(2) + "l\\n, uns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_11") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Pelw_12>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) +"l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_12") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Pelw_13>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) +"l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_13") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelw_14>[a-zA-Záâãçéêíóôú]+) um (?P<Pelw_15>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) +"l"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_15") in plvrAmascel and not m.group("Pelw_14") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelw_16>[a-zA-Záâãçéêíóôú]+) e um (?P<Pelw_17>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "l\\n" + m.group(1) + " e uns " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_17") in plvrAmascel and not m.group("Pelw_16") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelw_18>[a-zA-Záâãçéêíóôú]+) e um (?P<Pelw_19>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_19") in plvrAmascel and m.group("Pelw_18").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelw_19>[a-zA-Záâãçéêíóôú]+) e uns (?P<Pelw_20>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_20") in plvrAmascel and m.group("Pelw_19").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelw_21>[a-zA-Záâãçéêíóôú]+) (?P<Pelw_22>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_22") in plvrAmascel and m.group("Pelw_21").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelw_23>[0-9]+) (?P<Pelw_24>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "is"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pelw_24") in plvrAmascel and not m.group("Pelw_23") in "00000000001" and not excYamscel.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pelw_25>[0-9][0-9][0-9]) (?P<Pelw_26>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "is"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pelw_26") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelw_27>[0-9]+) (?P<Pelw_28>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"l"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pelw_28") in plvrAmascel and m.group("Pelw_27") in "00000000001" and not excYamscel.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelw_29>[a-zA-Záâãçéêíóôú]+)as (?P<Pelw_30>[a-zA-Záâãçéêíóôú]+[e])l(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_30") in plvrAmascel and m.group("Pelw_29").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pelw_31>[a-zA-Záâãçéêíóôú]+)as (?P<Pelw_32>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pelw_32") in plvrAmascel and m.group("Pelw_31").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptesm_0>[a-zA-Z]+)s (?P<Ptesm_1>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ês\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_0") in aaSingular and m.group("Ptesm_1") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptesm_2>[a-zA-Z]+) (?P<Ptesm_3>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ês\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_2") in aaSingular and m.group("Ptesm_3") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptesm_4>[a-zA-Z]+) (?P<Ptesm_5>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ês"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_4") in acSingular and m.group("Ptesm_5") in plvrMasces and not m.group("Ptesm_4") in "-A-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptesm_6>[a-zA-Z]+)s (?P<Ptesm_7>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_6") in acSingular and m.group("Ptesm_7") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Ptesm_a>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ês"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_a") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Ptesm_b>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_b") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Ptesm_c>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ês"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_c") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Ptesm_d>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_d") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Ptesm_e>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_e") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Ptesm_f>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_f") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Ptesm_g>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_g") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Ptesm_h>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_h") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([U])m (?P<Ptesm_i>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ês\\n" + m.group(1) + "ns " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_i") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Ptesm_j>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= m.group(1) + "ugum " + m.group(2) + "ês"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_j") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Ptesm_k>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= m.group(1) + "uguns " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_k") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Ptesm_l>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= m.group(1) + "ugum " + m.group(2) + "ês"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_l") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Ptesm_m>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= m.group(1) + "uguns " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_m") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Ptesm_n>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= m.group(1) + "uguns " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_n") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Ptesm_o>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= m.group(1) + "ugum " + m.group(2) + "ês\\n" + m.group(1) + "uguns " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_o") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Ptesm_p>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "ês"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_p") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Ptesm_q>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_q") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Ptesm_r>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "ês"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_r") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Ptesm_s>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_s") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Ptesm_t>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_t") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Ptesm_u>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "ês\\n" + m.group(1) + "enhuns " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_u") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Ptesm_v>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "ês"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_v") in plvrMasces and not m.group("Ptesm_v") in excplMasc'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Ptesm_w>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "ês\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_w") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Ptesm_x>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "ês\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_x") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Ptesm_y>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "ês\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_y") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Ptesm_10>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= "Um " + m.group(2) + "ês\\nUns " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_10") in plvrMasces'],
 ['(?u)\\b([,]) um (?P<Ptesm_11>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= ", um " + m.group(2) + "ês\\n, uns " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_11") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Ptesm_12>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) +"ês"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_12") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Ptesm_13>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) +"ês"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_13") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptesm_14>[a-zA-Záâãçéêíóôú]+) um (?P<Ptesm_15>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) +"ês"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_15") in plvrMasces and not m.group("Ptesm_14") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptesm_16>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptesm_17>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "ês\\n" + m.group(1) + " e uns " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_17") in plvrMasces and not m.group("Ptesm_16") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptesm_18>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptesm_19>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_19") in plvrMasces and m.group("Ptesm_18").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptesm_19>[a-zA-Záâãçéêíóôú]+) e uns (?P<Ptesm_20>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_20") in plvrMasces and m.group("Ptesm_19").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptesm_21>[a-zA-Záâãçéêíóôú]+) (?P<Ptesm_22>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_22") in plvrMasces and m.group("Ptesm_21").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptesm_23>[0-9]+) (?P<Ptesm_24>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "eses"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptesm_24") in plvrMasces and not m.group("Ptesm_23") in "00000000001" and not excYmasces.search(TEXT)'],
 ['(?u)\\b([.])(?P<Ptesm_25>[0-9][0-9][0-9]) (?P<Ptesm_26>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "eses"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptesm_26") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptesm_27>[0-9]+) (?P<Ptesm_28>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"ês"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptesm_28") in plvrMasces and m.group("Ptesm_27") in "00000000001" and not excYmasces.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptesm_29>[a-zA-Záâãçéêíóôú]+)as (?P<Ptesm_30>[a-zA-Záâãçéêíóôú]+)ês(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_30") in plvrMasces and m.group("Ptesm_29").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptesm_31>[a-zA-Záâãçéêíóôú]+)as (?P<Ptesm_32>[a-zA-Záâãçéêíóôú]+)eses(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "eses"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptesm_32") in plvrMasces and m.group("Ptesm_31").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crces_10>[a-zA-Zçáéíóúâêô]+)ês(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "ês"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crces_10") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crces_11>[a-zA-Zçáéíóúâêô]+)eses(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2) + "eses"', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crces_11") in plvrMasces'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptism_0>[a-zA-Z]+)s (?P<Ptism_1>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s " + varpesse[m.group(2)]', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_0") in aaSingular and m.group("Ptism_1") in aapesse'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptism_2>[a-zA-Z]+) (?P<Ptism_3>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + varsesse[m.group(2)] + "\\n" + varGenero[m.group(1)] + "s " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_2") in aaSingular and m.group("Ptism_3") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptism_4>[a-zA-Z]+) (?P<Ptism_5>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_4") in acSingular and m.group("Ptism_5") in aapesse'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptism_6>[a-zA-Z]+)s (?P<Ptism_7>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_6") in acSingular and m.group("Ptism_7") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Ptism_a>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_a") in aapesse'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Ptism_b>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_b") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Ptism_c>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_c") in aapesse'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Ptism_d>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_d") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Ptism_e>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "ns " + varpesse[m.group(2)]', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_e") in aapesse'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Ptism_f>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "ois " + varpesse[m.group(2)]', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_f") in aapesse'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Ptism_g>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "ois " + varpesse[m.group(2)]', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_g") in aapesse'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Ptism_h>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_h") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])([U])m (?P<Ptism_i>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "m " + varsesse[m.group(2)] + "\\n" + m.group(1) + "ns " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_i") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Ptism_j>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "ugum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_j") in aapesse'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Ptism_k>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "uguns " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_k") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Ptism_l>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "ugum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_l") in aapesse'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Ptism_m>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "uguns " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_m") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Ptism_n>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "uguns " + varpesse[m.group(2)]', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_n") in aapesse'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Ptism_o>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "ugum " + varsesse[m.group(2)] + "\\n" + m.group(1) + "uguns " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_o") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Ptism_p>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_p") in aapesse'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Ptism_q>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_q") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Ptism_r>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_r") in aapesse'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Ptism_s>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_s") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Ptism_t>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "enhuns " + varpesse[m.group(2)]', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_t") in aapesse'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Ptism_u>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "enhum " + varsesse[m.group(2)] + "\\n" + m.group(1) + "enhuns " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_u") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Ptism_v>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_v") in aapesse'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Ptism_w>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + varsesse[m.group(3)] + "\\n" + aacCao[m.group(2)] + "s " + m.group(3)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_w") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Ptism_x>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "\\n" + aacCao[m.group(1)] + "s " + varpesse[m.group(2)]', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_x") in aapesse'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Ptism_y>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + varsesse[m.group(2)] + "\\n" + aacCao[m.group(1)] + "s " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_y") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Ptism_10>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= "Um " + varsesse[m.group(2)] + "\\nUns " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_10") in aasesse'],
 ['(?u)\\b([,]) um (?P<Ptism_11>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= ", um " + varsesse[m.group(2)] + "\\n, uns " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_11") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Ptism_12>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + varsesse[m.group(2)]', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_12") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Ptism_13>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "m simples " + varsesse[m.group(2)]', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_13") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptism_14>[a-zA-Záâãçéêíóôú]+) um (?P<Ptism_15>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + " um " + varsesse[m.group(2)]', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_15") in aasesse and not m.group("Ptism_14") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptism_16>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptism_17>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + " e um " + varsesse[m.group(2)] + "\\n" + m.group(1) + " e uns " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_17") in aasesse and not m.group("Ptism_16") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptism_18>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptism_19>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + " e um " + varpesse[m.group(2)]', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_19") in aapesse and m.group("Ptism_18").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptism_19>[a-zA-Záâãçéêíóôú]+) e uns (?P<Ptism_20>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + " e um " + varpesse[m.group(2)]', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_20") in aapesse and m.group("Ptism_19").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptism_21>[a-zA-Záâãçéêíóôú]+) (?P<Ptism_22>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + " " + varpesse[m.group(2)]', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_22") in aapesse and m.group("Ptism_21").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptism_23>[0-9]+) (?P<Ptism_24>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + " " + varpesse[m.group(2)]', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptism_24") in aapesse and not m.group("Ptism_23") in "00000000001" and not exckano.search(TEXT)'],
 ['(?u)\\b([.])(?P<Ptism_25>[0-9][0-9][0-9]) (?P<Ptism_26>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + varpesse[m.group(3)]', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptism_26") in aapesse'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptism_27>[0-9]+) (?P<Ptism_28>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + " " + varsesse[m.group(2)]', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptism_28") in aasesse and m.group("Ptism_27") in "00000000001" and not exckano.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptism_29>[a-zA-Záâãçéêíóôú]+)as (?P<Ptism_30>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "os " + varpesse[m.group(2)]', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_30") in aapesse and m.group("Ptism_29").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptism_31>[a-zA-Záâãçéêíóôú]+)as (?P<Ptism_32>[a-zA-Záâãçéêíóôú]+)(?![-\\w–\xad])', '= m.group(1) + "os " + varsesse[m.group(2)]', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptism_32") in aasesse and m.group("Ptism_31").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crcis_10>[a-zA-Zçáéíóúâêô]+)(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2)', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crcis_10") in aapesse'],
 ['(?u)(?<![-\\w–.,\xad])([Àà]) (?P<Crcis_11>[a-zA-Zçáéíóúâêô]+)(?![-\\w–\xad])', '= aacCrase[m.group(1)] + " " + m.group(2)', 'Não se usa crase antes de palavra masculina. Você quis dizer:', 'm.group("Crcis_11") in aasesse'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pcao_0>[a-zA-Z]+) (?P<Pcao_1>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ão\\n" + m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pcao_0") in aaSingular and m.group("Pcao_1") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pcao_2>[a-zA-Z]+)s (?P<Pcao_3>[a-zA-Zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ão\\n" + m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pcao_2") in aaSingular and m.group("Pcao_3") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)m (?P<Pcao_4>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ão\\n" + m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pcao_4") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pcao_5>[a-zA-Zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ão\\n" + m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pcao_5") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ma (?P<Pcao_6>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ão\\n" + m.group(1) + "mas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pcao_6") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pcao_7>[a-zA-Zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ão\\n" + m.group(1) + "mas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pcao_7") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])(a|Doi|doi|Dua|dua)s (?P<Pcao_8>[a-zA-Zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pcao_8") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Caom_0>[a-zA-Z]+)s (?P<Caom_1>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ão\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_0") in aaSingular and m.group("Caom_1") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Caom_2>[a-zA-Z]+) (?P<Caom_3>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ão\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_2") in aaSingular and m.group("Caom_3") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Caom_4>[a-zA-Z]+) (?P<Caom_5>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_4") in acSingular and m.group("Caom_5") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Caom_6>[a-zA-Z]+)s (?P<Caom_7>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_6") in acSingular and m.group("Caom_7") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Caom_a>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_a") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Caom_b>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_b") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Caom_c>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_c") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Caom_d>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_d") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Caom_e>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_e") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Caom_f>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_f") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Caom_g>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_g") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Caom_h>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_h") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Caom_i>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ão\\n" + m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_i") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Caom_j>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_j") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Caom_k>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_k") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Caom_l>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_l") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Caom_m>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_m") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Caom_n>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_n") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Caom_o>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "ão\\n" + m.group(1) + "lguns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_o") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Caom_p>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_p") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Caom_q>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_q") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Caom_r>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_r") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Caom_s>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_s") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Caom_t>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_t") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Caom_u>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "ão\\n" + m.group(1) + "enhuns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_u") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Caom_v>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_v") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Caom_w>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "ão\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_w") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Caom_x>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "ão\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_x") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Caom_y>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "ão\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caom_y") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Caof_0>[a-zA-Z]+)s (?P<Caof_1>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ão\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caof_0") in aaSingular and not m.group("Caof_1") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Caof_2>[a-zA-Z]+) (?P<Caof_3>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ão\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caof_2") in aaSingular and not m.group("Caof_3") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Caof_4>[a-zA-Z]+) (?P<Caof_5>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caof_4") in abSingular and not m.group("Caof_5") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Caof_6>[a-zA-Z]+)s (?P<Caof_7>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Caof_6") in abSingular and not m.group("Caof_7") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Caof_a>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_a") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Caof_b>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_b") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Caof_c>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_c") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Caof_d>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_d") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Caof_e>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_e") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Caof_f>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_f") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Caof_g>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_g") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Caof_h>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_h") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Caof_i>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ão\\n" + m.group(1) + "mas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_i") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Caof_j>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_j") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Caof_k>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_k") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Caof_l>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_l") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Caof_m>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_m") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Caof_n>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_n") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Caof_o>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "ão\\n" + m.group(1) + "lgumas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_o") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Caof_p>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_p") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Caof_q>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_q") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Caof_r>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_r") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Caof_s>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_s") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Caof_t>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_t") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Caof_u>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "ão\\n" + m.group(1) + "enhumas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_u") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Caof_v>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '= m.group(2) + " " + m.group(3) + "ão\\n" + m.group(2) + "s " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_v") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Caof_w>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ão\\n" + m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Caof_w") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paom_0>[a-zA-Z]+)s (?P<Paom_1>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ão\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paom_0") in aaSingular and not m.group("Paom_1") in plvrFemao and not m.group("Paom_1") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paom_2>[a-zA-Z]+) (?P<Paom_3>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ão\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paom_2") in aaSingular and not m.group("Paom_3") in plvrFemao and not m.group("Paom_3") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paom_4>[a-zA-Z]+) (?P<Paom_5>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paom_4") in acSingular and not m.group("Paom_5") in plvrFemao and not m.group("Paom_5") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paom_6>[a-zA-Z]+)s (?P<Paom_7>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paom_6") in acSingular and not m.group("Paom_7") in plvrFemao and not m.group("Paom_7") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Paom_a>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_a") in plvrFemao and not m.group("Paom_a") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Paom_b>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_b") in plvrFemao and not m.group("Paom_b") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Paom_c>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_c") in plvrFemao and not m.group("Paom_c") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Paom_d>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_d") in plvrFemao and not m.group("Paom_d") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Paom_e>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_e") in plvrFemao and not m.group("Paom_e") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Paom_f>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_f") in plvrFemao and not m.group("Paom_f") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Paom_g>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_g") in plvrFemao and not m.group("Paom_g") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Paom_h>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_h") in plvrFemao and not m.group("Paom_h") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Paom_i>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ão\\n" + m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_i") in plvrFemao and not m.group("Paom_i") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Paom_j>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_j") in plvrFemao and not m.group("Paom_j") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Paom_k>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_k") in plvrFemao and not m.group("Paom_k") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Paom_l>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_l") in plvrFemao and not m.group("Paom_l") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Paom_m>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_m") in plvrFemao and not m.group("Paom_m") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Paom_n>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_n") in plvrFemao and not m.group("Paom_n") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Paom_o>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "ão\\n" + m.group(1) + "lguns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_o") in plvrFemao and not m.group("Paom_o") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Paom_p>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_p") in plvrFemao and not m.group("Paom_p") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Paom_q>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_q") in plvrFemao and not m.group("Paom_q") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Paom_r>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_r") in plvrFemao and not m.group("Paom_r") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Paom_s>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_s") in plvrFemao and not m.group("Paom_s") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Paom_t>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_t") in plvrFemao and not m.group("Paom_t") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Paom_u>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "ão\\n" + m.group(1) + "enhuns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_u") in plvrFemao and not m.group("Paom_u") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Paom_v>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_v") in plvrFemao and not m.group("Paom_v") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Paom_w>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "ão\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_w") in plvrFemao and not m.group("Paom_w") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Paom_x>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "ão\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_x") in plvrFemao and not m.group("Paom_x") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Paom_y>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "ão\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paom_y") in plvrFemao and not m.group("Paom_y") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paor_0>[a-zA-Z]+)s (?P<Paor_1>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ão(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ão\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paor_0") in aaSingular and not m.group("Paor_1") in plvrFemao and not m.group("Paor_1") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paor_2>[a-zA-Z]+) (?P<Paor_3>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ões(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ão\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paor_2") in aaSingular and not m.group("Paor_3") in plvrFemao and not m.group("Paor_3") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paor_4>[a-zA-Z]+) (?P<Paor_5>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ão(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paor_4") in acSingular and not m.group("Paor_5") in plvrFemao and not m.group("Paor_5") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paor_6>[a-zA-Z]+)s (?P<Paor_7>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ões(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paor_6") in acSingular and not m.group("Paor_7") in plvrFemao and not m.group("Paor_7") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Paor_a>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ão(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_a") in plvrFemao and not m.group("Paor_a") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Paor_b>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ões(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_b") in plvrFemao and not m.group("Paor_b") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Paor_c>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ão(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_c") in plvrFemao and not m.group("Paor_c") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Paor_d>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ões(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_d") in plvrFemao and not m.group("Paor_d") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Paor_e>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ão(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_e") in plvrFemao and not m.group("Paor_e") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Paor_f>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ão(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_f") in plvrFemao and not m.group("Paor_f") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Paor_g>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ão(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_g") in plvrFemao and not m.group("Paor_g") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Paor_h>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ões(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_h") in plvrFemao and not m.group("Paor_h") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Paor_i>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ões(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ão\\n" + m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_i") in plvrFemao and not m.group("Paor_i") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Paor_j>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ão(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_j") in plvrFemao and not m.group("Paor_j") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Paor_k>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ões(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_k") in plvrFemao and not m.group("Paor_k") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Paor_l>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ão(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_l") in plvrFemao and not m.group("Paor_l") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Paor_m>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ões(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_m") in plvrFemao and not m.group("Paor_m") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Paor_n>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ão(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_n") in plvrFemao and not m.group("Paor_n") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Paor_o>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ões(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "ão\\n" + m.group(1) + "lguns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_o") in plvrFemao and not m.group("Paor_o") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Paor_p>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ão(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_p") in plvrFemao and not m.group("Paor_p") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Paor_q>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ões(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_q") in plvrFemao and not m.group("Paor_q") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Paor_r>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ão(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_r") in plvrFemao and not m.group("Paor_r") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Paor_s>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ões(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_s") in plvrFemao and not m.group("Paor_s") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Paor_t>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ão(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_t") in plvrFemao and not m.group("Paor_t") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Paor_u>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ões(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "ão\\n" + m.group(1) + "enhuns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_u") in plvrFemao and not m.group("Paor_u") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Paor_v>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ão(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_v") in plvrFemao and not m.group("Paor_v") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Paor_w>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ões(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "ão\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_w") in plvrFemao and not m.group("Paor_w") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Paor_x>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ão(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "ão\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_x") in plvrFemao and not m.group("Paor_x") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Paor_y>[a-zA-Záâãçéêíóôú]+[bcdfgprtv]r)ões(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "ão\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Paor_y") in plvrFemao and not m.group("Paor_y") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paot_0>[a-zA-Z]+)s (?P<Paot_1>[a-zA-Záâãçéêíóôú]+[aeiou]r)ão(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ão\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_0") in aaSingular and m.group("Paot_1") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paot_2>[a-zA-Z]+) (?P<Paot_3>[a-zA-Záâãçéêíóôú]+[aeiou]r)ões(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ão\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_2") in aaSingular and m.group("Paot_3") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paot_4>[a-zA-Z]+) (?P<Paot_5>[a-zA-Záâãçéêíóôú]+[aeiou]r)ão(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_4") in acSingular and m.group("Paot_5") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paot_6>[a-zA-Z]+)s (?P<Paot_7>[a-zA-Záâãçéêíóôú]+[aeiou]r)ões(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_6") in acSingular and m.group("Paot_7") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Paot_a>[a-zA-Záâãçéêíóôú]+[aeiou]r)ão(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_a") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Paot_b>[a-zA-Záâãçéêíóôú]+[aeiou]r)ões(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_b") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Paot_c>[a-zA-Záâãçéêíóôú]+[aeiou]r)ão(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_c") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Paot_d>[a-zA-Záâãçéêíóôú]+[aeiou]r)ões(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_d") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Paot_e>[a-zA-Záâãçéêíóôú]+[aeiou]r)ão(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_e") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Paot_f>[a-zA-Záâãçéêíóôú]+[aeiou]r)ão(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_f") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Paot_g>[a-zA-Záâãçéêíóôú]+[aeiou]r)ão(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_g") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Paot_h>[a-zA-Záâãçéêíóôú]+[aeiou]r)ões(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_h") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Paot_i>[a-zA-Záâãçéêíóôú]+[aeiou]r)ões(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ão\\n" + m.group(1) + "ns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_i") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Paot_j>[a-zA-Záâãçéêíóôú]+[aeiou]r)ão(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_j") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Paot_k>[a-zA-Záâãçéêíóôú]+[aeiou]r)ões(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_k") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Paot_l>[a-zA-Záâãçéêíóôú]+[aeiou]r)ão(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_l") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Paot_m>[a-zA-Záâãçéêíóôú]+[aeiou]r)ões(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_m") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Paot_n>[a-zA-Záâãçéêíóôú]+[aeiou]r)ão(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_n") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Paot_o>[a-zA-Záâãçéêíóôú]+[aeiou]r)ões(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "ão\\n" + m.group(1) + "lguns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_o") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Paot_p>[a-zA-Záâãçéêíóôú]+[aeiou]r)ão(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_p") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Paot_q>[a-zA-Záâãçéêíóôú]+[aeiou]r)ões(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_q") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Paot_r>[a-zA-Záâãçéêíóôú]+[aeiou]r)ão(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_r") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Paot_s>[a-zA-Záâãçéêíóôú]+[aeiou]r)ões(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_s") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Paot_t>[a-zA-Záâãçéêíóôú]+[aeiou]r)ão(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_t") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Paot_u>[a-zA-Záâãçéêíóôú]+[aeiou]r)ões(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "ão\\n" + m.group(1) + "enhuns " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_u") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Paot_v>[a-zA-Záâãçéêíóôú]+[aeiou]r)ão(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_v") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Paot_w>[a-zA-Záâãçéêíóôú]+[aeiou]r)ões(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "ão\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_w") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Paot_x>[a-zA-Záâãçéêíóôú]+[aeiou]r)ão(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "ão\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_x") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Paot_y>[a-zA-Záâãçéêíóôú]+[aeiou]r)ões(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "ão\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paot_y") in plvrMrao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paof_0>[a-zA-Z]+)s (?P<Paof_1>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ão\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_0") in aaSingular and m.group("Paof_1") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paof_2>[a-zA-Z]+) (?P<Paof_3>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ão\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_2") in aaSingular and m.group("Paof_3") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paof_4>[a-zA-Z]+) (?P<Paof_5>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_4") in abSingular and m.group("Paof_5") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Paof_6>[a-zA-Z]+)s (?P<Paof_7>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_6") in abSingular and m.group("Paof_7") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Paof_a>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_a") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Paof_b>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_b") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Paof_c>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_c") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Paof_d>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_d") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Paof_e>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_e") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Paof_f>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_f") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Paof_g>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_g") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Paof_h>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_h") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Paof_i>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ão\\n" + m.group(1) + "mas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_i") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Paof_j>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_j") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Paof_k>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_k") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Paof_l>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_l") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Paof_m>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_m") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Paof_n>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_n") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Paof_o>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "ão\\n" + m.group(1) + "lgumas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_o") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Paof_p>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_p") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Paof_q>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_q") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Paof_r>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "ão"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_r") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Paof_s>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_s") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Paof_t>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_t") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Paof_u>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "ão\\n" + m.group(1) + "enhumas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_u") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Paof_v>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(2) + " " + m.group(3) + "ão\\n" + m.group(2) + "s " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_v") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Paof_w>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ão\\n" + m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Paof_w") in plvrFemao'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdad_0>[a-zA-Z]+)s (?P<Pdad_1>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "dade\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdad_0") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdad_2>[a-zA-Z]+) (?P<Pdad_3>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "dade\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdad_2") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdad_4>[a-zA-Z]+) (?P<Pdad_5>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "dade"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdad_4") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdad_6>[a-zA-Z]+)s (?P<Pdad_7>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdad_6") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Pdad_a>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "dade"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Pdad_b>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pdad_c>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "dade"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pdad_d>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pdad_e>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pdad_f>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pdad_g>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pdad_h>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Pdad_i>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "dade\\n" + m.group(1) + "mas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pdad_j>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "dade"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pdad_k>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pdad_l>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "dade"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pdad_m>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pdad_n>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pdad_o>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "dade\\n" + m.group(1) + "lgumas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pdad_p>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "dade"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pdad_q>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pdad_r>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "dade"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pdad_s>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pdad_t>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pdad_u>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "dade\\n" + m.group(1) + "enhumas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pdad_v>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(2) + " " + m.group(3) + "dade\\n" + m.group(2) + "s " + m.group(3) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pdad_w>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "dade\\n" + m.group(1) + "s " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pdde_0>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= "Uma " + m.group(2) + "dade\\nUmas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) uma (?P<Pdde_1>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= ", uma " + m.group(2) + "dade\\n, umas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pdde_0>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + "dade"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pdde_0>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + "dade"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdde_2>[a-zA-Záâãçéêíóôú]+) uma (?P<Pdde_3>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "dade\\n" + m.group(1) + " umas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pdde_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdde_4>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pdde_5>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "dade\\n" + m.group(1) + " e umas " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pdde_4") in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdde_6>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pdde_7>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdde_6").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdde_8>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pdde_9>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdde_8").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdde_10>[a-zA-Záâãçéêíóôú]+) (?P<Pdde_11>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdde_10").lower() in numFem and not m.group("Pdde_11") in excplVirg'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdde_12>[0-9]+) (?P<Pdde_13>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "dades"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pdde_12") in "00000000001" and not excYfdade.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pdde_14>[0-9][0-9][0-9]) (?P<Pdde_15>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "dades"', 'Não há concordância entre os termos. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdde_16>[0-9]+) (?P<Pdde_17>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "dade"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pdde_16") in "00000000001" and not excYfdade.search(TEXT) and not exchora.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdde_17>[a-zA-Záâãçéêíóôú]+)os (?P<Pdde_18>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdde_17").lower() in nuMfmoas and not m.group("Pdde_18") in excplVirg'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdde_19>[a-zA-Záâãçéêíóôú]+)os (?P<Pdde_20>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdde_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvel_0>[a-zA-Z]+) (?P<Pvel_1>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "vel\\n" + m.group(1) + "s " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvel_0") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvel_2>[a-zA-Z]+)s (?P<Pvel_3>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "vel\\n" + m.group(1) + "s " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvel_2") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)m (?P<Pvel_4>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "vel\\n" + m.group(1) + "ns " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pvel_5>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "vel\\n" + m.group(1) + "ns " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Pvel_6>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "vel\\n" + m.group(1) + "mas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pvel_7>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "vel\\n" + m.group(1) + "mas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(a|Doi|doi|Dua|dua)s (?P<Pvel_8>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári([ao])s (?P<Pvel_9>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "ári" + m.group(2) + "s " + m.group(3) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uita (?P<Pvel_10>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "vel"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pvel_11>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "vel"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao]) (?P<Pvel_12>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "vel\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao])s (?P<Pvel_13>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "vel\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvel_14>[a-zA-Z]+)s mesmos (?P<Pvel_15>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "vel\\n" + m.group(1) + "s mesmos " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvel_14") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvel_16>[a-zA-Z]+)s mesmas (?P<Pvel_17>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "vel\\n" + m.group(1) + "s mesmas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvel_16") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvel_18>[a-zA-Z]+)s mesmo (?P<Pvel_19>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "vel\\n" + m.group(1) + "s mesmos " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvel_18") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvel_20>[a-zA-Z]+)s mesma (?P<Pvel_21>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "vel\\n" + m.group(1) + "s mesmas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvel_20") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Pvel_22>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "vel\\n" + m.group(1) + "s mesmas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Pvel_23>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pvel_24>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= "Uma " + m.group(2) + "vel\\nUmas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) uma (?P<Pvel_25>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= ", uma " + m.group(2) + "vel\\n, umas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Pvel_24>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= "Um " + m.group(2) + "vel\\nUns " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)\\b([,]) um (?P<Pvel_27>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= ", um " + m.group(2) + "vel\\n, uns " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Pvel_28>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) + "vel"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pvel_29>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + "vel"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Pvel_30>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) + "vel"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pvel_31>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + "vel"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvel_32>[a-zA-Záâãçéêíóôú]+) um (?P<Pvel_33>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) + "vel\\n" + m.group(1) + " uns " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pvel_32") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvel_34>[a-zA-Záâãçéêíóôú]+) uma (?P<Pvel_35>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "vel\\n" + m.group(1) + " umas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pvel_34") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvel_36>[a-zA-Záâãçéêíóôú]+) e um (?P<Pvel_37>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "vel\\n" + m.group(1) + " e uns " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pvel_36") in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvel_38>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pvel_39>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "vel\\n" + m.group(1) + " e umas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pvel_38") in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvel_40>[a-zA-Záâãçéêíóôú]+) e um (?P<Pvel_41>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvel_40").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvel_42>[a-zA-Záâãçéêíóôú]+) e uns (?P<Pvel_43>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvel_42").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvel_44>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pvel_45>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvel_44").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvel_46>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pvel_47>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvel_46").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvel_48>[a-zA-Záâãçéêíóôú]+) (?P<Pvel_49>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pvel_48").lower() in numFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvel_50>[0-9]+) (?P<Pvel_51>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "veis"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pvel_50") in "00000000001" and not excYvel.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pvel_52>[0-9][0-9][0-9]) (?P<Pvel_53>[a-zA-Zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "veis"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pvel_52").lower() in numFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvel_54>[0-9]+) (?P<Pvel_55>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "vel"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pvel_55") in "00000000001" and not excYvel.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptge_0>[a-zA-Z]+) (?P<Ptge_1>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "e\\n" + m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_0") in aaSingular and m.group("Ptge_1") in plvrMfe and not (m.group("Ptge_0") in "-A-" and m.group("Ptge_1") in excplMfe)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptge_2>[a-zA-Z]+)s (?P<Ptge_3>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "e\\n" + m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_2") in aaSingular and m.group("Ptge_3") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)m (?P<Ptge_4>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "e\\n" + m.group(1) + "ns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_4") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Ptge_5>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "e\\n" + m.group(1) + "ns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_5") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Ptge_6>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "e\\n" + m.group(1) + "mas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_6") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Ptge_7>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "e\\n" + m.group(1) + "mas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_7") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(a|Doi|doi|Dua|dua)s (?P<Ptge_8>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_8") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári([ao])s (?P<Ptge_9>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "ári" + m.group(2) + "s " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_9") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uita (?P<Ptge_10>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_10") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Ptge_11>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_11") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao]) (?P<Ptge_12>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "e\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_12") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao])s (?P<Ptge_13>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "e\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_13") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptge_14>[a-zA-Z]+)s mesmos (?P<Ptge_15>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "e\\n" + m.group(1) + "s mesmos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_14") in abSingular and m.group("Ptge_15") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptge_16>[a-zA-Z]+)s mesmas (?P<Ptge_17>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "e\\n" + m.group(1) + "s mesmas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_16") in acSingular and m.group("Ptge_17") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptge_18>[a-zA-Z]+)s mesmo (?P<Ptge_19>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "e\\n" + m.group(1) + "s mesmos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_18") in abSingular and m.group("Ptge_19") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptge_20>[a-zA-Z]+)s mesma (?P<Ptge_21>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "e\\n" + m.group(1) + "s mesmas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_20") in acSingular and m.group("Ptge_21") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Ptge_22>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "e\\n" + m.group(1) + "s mesmas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_22") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Ptge_23>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_23") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Ptge_24>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= "Uma " + m.group(2) + "e\\nUmas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_24") in plvrMfe'],
 ['(?u)\\b([,]) uma (?P<Ptge_25>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= ", uma " + m.group(2) + "e\\n, umas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_25") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Ptge_24>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= "Um " + m.group(2) + "e\\nUns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_26") in plvrMfe'],
 ['(?u)\\b([,]) um (?P<Ptge_27>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= ", um " + m.group(2) + "e\\n, uns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_27") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Ptge_28>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_28") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Ptge_29>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_29") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Ptge_30>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_30") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Ptge_31>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_31") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptge_32>[a-zA-Záâãçéêíóôú]+) um (?P<Ptge_33>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) + "e\\n" + m.group(1) + " uns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptge_32") in "-E-e-" and m.group("Ptge_33") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptge_34>[a-zA-Záâãçéêíóôú]+) uma (?P<Ptge_35>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "e\\n" + m.group(1) + " umas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptge_34") in "-E-e-" and m.group("Ptge_35") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptge_36>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptge_37>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "e\\n" + m.group(1) + " e uns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptge_36") in numEfem and m.group("Ptge_37") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptge_38>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptge_39>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "e\\n" + m.group(1) + " e umas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptge_38") in numEfem and m.group("Ptge_39") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptge_40>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptge_41>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_40").lower() in numEmasc and m.group("Ptge_41") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptge_42>[a-zA-Záâãçéêíóôú]+) e uns (?P<Ptge_43>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_42").lower() in numEmasc and m.group("Ptge_43") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptge_44>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptge_45>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_44").lower() in numEfem and m.group("Ptge_45") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptge_46>[a-zA-Záâãçéêíóôú]+) e umas (?P<Ptge_47>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_46").lower() in numEfem and m.group("Ptge_47") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptge_48>[a-zA-Záâãçéêíóôú]+) (?P<Ptge_49>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptge_48").lower() in numFem and m.group("Ptge_49") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptge_50>[0-9]+) (?P<Ptge_51>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "es"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Ptge_50") in "00000000001" and not excYmfe.search(TEXT) and m.group("Ptge_51") in plvrMfe'],
 ['(?u)\\b([.])(?P<Ptge_52>[0-9][0-9][0-9]) (?P<Ptge_53>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "es"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptge_53") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptge_54>[0-9]+) (?P<Ptge_55>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "e"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptge_54") in "00000000001" and not excYmfe.search(TEXT) and m.group("Ptge_55") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptfe_0>[a-zA-Z]+)s (?P<Ptfe_1>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "e\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_0") in aaSingular and m.group("Ptfe_1") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptfe_2>[a-zA-Z]+) (?P<Ptfe_3>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "e\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_2") in aaSingular and m.group("Ptfe_3") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptfe_4>[a-zA-Z]+) (?P<Ptfe_5>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_4") in agSingular and m.group("Ptfe_5") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])(A) (?P<Ptfe_a5>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_a5") in plvrMasce and not m.group("Ptfe_a5") in excPlvrnasce'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptfe_6>[a-zA-Z]+)s (?P<Ptfe_7>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_6") in acSingular and m.group("Ptfe_7") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári([ao])s (?P<Ptfe_8>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "ários " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_8") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])árias (?P<Ptfe_9>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "ários " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_9") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Ptfe_a>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_a") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Ptfe_b>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_b") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Ptfe_c>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_c") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Ptfe_d>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_d") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Ptfe_e>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_e") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Ptfe_f>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_f") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Ptfe_g>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_g") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Ptfe_h>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_h") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([U])m (?P<Ptfe_i>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "e\\n" + m.group(1) + "ns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_i") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Ptfe_j>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_j") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Ptfe_k>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_k") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Ptfe_l>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_l") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Ptfe_m>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_m") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Ptfe_n>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_n") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Ptfe_o>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "e\\n" + m.group(1) + "lguns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_o") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Ptfe_p>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_p") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Ptfe_q>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_q") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Ptfe_r>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_r") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Ptfe_s>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_s") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Ptfe_t>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_t") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Ptfe_u>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "e\\n" + m.group(1) + "enhuns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_u") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Ptfe_v>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_v") in plvrMasce and not m.group("Ptfe_v") in excPlvrnasce'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Ptfe_w>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "e\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_w") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Ptfe_x>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "e\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_x") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Ptfe_y>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "e\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_y") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Ptfe_10>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= "Um " + m.group(2) + "e\\nUns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_10") in plvrMasce'],
 ['(?u)\\b([,]) um (?P<Ptfe_11>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= ", um " + m.group(2) + "e\\n, uns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_11") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Ptfe_12>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) +"e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_12") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Ptfe_13>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) +"e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_13") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptfe_14>[a-zA-Záâãçéêíóôú]+) um (?P<Ptfe_15>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) +"e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_15") in plvrMasce and not m.group("Ptfe_14") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptfe_16>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptfe_17>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "e\\n" + m.group(1) + " e uns " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_17") in plvrMasce and not m.group("Ptfe_16") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptfe_18>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptfe_19>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_19") in plvrMasce and m.group("Ptfe_18").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptfe_19>[a-zA-Záâãçéêíóôú]+) e uns (?P<Ptfe_20>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_20") in plvrMasce and m.group("Ptfe_19").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptfe_21>[a-zA-Záâãçéêíóôú]+) (?P<Ptfe_22>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_22") in plvrMasce and m.group("Ptfe_21").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptfe_23>[0-9]+) (?P<Ptfe_24>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "es"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptfe_24") in plvrMasce and not m.group("Ptfe_23") in "00000000001" and not excYmasce.search(TEXT)'],
 ['(?u)\\b([.])(?P<Ptfe_25>[0-9][0-9][0-9]) (?P<Ptfe_26>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "es"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptfe_26") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptfe_27>[0-9]+) (?P<Ptfe_28>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"e"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptfe_28") in plvrMasce and m.group("Ptfe_27") in "00000000001" and not excYmasce.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptfe_29>[a-zA-Záâãçéêíóôú]+)as (?P<Ptfe_30>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_30") in plvrMasce and m.group("Ptfe_29").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptfe_31>[a-zA-Záâãçéêíóôú]+)as (?P<Ptfe_32>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptfe_32") in plvrMasce and m.group("Ptfe_31").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pffe_0>[a-zA-Z]+)s (?P<Pffe_1>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "e\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_0") in aaSingular and m.group("Pffe_1") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pffe_2>[a-zA-Z]+) (?P<Pffe_3>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "e\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_2") in aaSingular and m.group("Pffe_3") in plvrFeme and not m.group("Pffe_2") in "-Da-da-"'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])a (?P<Pffeb_0>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '\\1a \\2e\\n\\1as \\2es\\n\\1á \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffeb_0") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pffe_4>[a-zA-Z]+) (?P<Pffe_5>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_4") in abSingular and m.group("Pffe_5") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pffe_6>[a-zA-Z]+)s (?P<Pffe_7>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_6") in abSingular and m.group("Pffe_7") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pffe_8>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_8") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pffe_9>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_9") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Pffe_a>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_a") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Pffe_b>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_b") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pffe_c>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_c") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pffe_d>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_d") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pffe_e>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_e") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pffe_f>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_f") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pffe_g>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_g") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pffe_h>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_h") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([U])ma (?P<Pffe_i>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "e\\n" + m.group(1) + "mas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_i") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pffe_j>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_j") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pffe_k>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_k") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pffe_l>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_l") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pffe_m>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_m") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pffe_n>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_n") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pffe_o>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "e\\n" + m.group(1) + "lgumas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_o") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pffe_p>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_p") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pffe_q>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_q") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pffe_r>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_r") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pffe_s>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_s") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pffe_t>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_t") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pffe_u>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "e\\n" + m.group(1) + "enhumas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_u") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pffe_v>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(2) + " " + m.group(3) + "e\\n" + m.group(2) + "s " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_v") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pffe_w>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "e\\n" + m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_w") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pffe_10>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= "Uma " + m.group(2) + "e\\nUmas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_10") in plvrFeme'],
 ['(?u)\\b([,]) uma (?P<Pffe_11>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= ", uma " + m.group(2) + "e\\n, umas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_11") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pffe_12>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) +"e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_12") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pffe_13>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) +"e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_13") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pffe_14>[a-zA-Záâãçéêíóôú]+) uma (?P<Pffe_15>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) +"e"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_15") in plvrFeme and not m.group("Pffe_14") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pffe_16>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pffe_17>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "e\\n" + m.group(1) + " e umas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_17") in plvrFeme and not m.group("Pffe_16") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pffe_18>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pffe_19>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_19") in plvrFeme and m.group("Pffe_18").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pffe_19>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pffe_20>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_20") in plvrFeme and m.group("Pffe_19").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pffe_21>[a-zA-Záâãçéêíóôú]+) (?P<Pffe_22>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_22") in plvrFeme and m.group("Pffe_21").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pffe_23>[0-9]+) (?P<Pffe_24>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "es"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pffe_24") in plvrFeme and not m.group("Pffe_23") in "00000000001" and not excYfeme.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pffe_25>[0-9][0-9][0-9]) (?P<Pffe_26>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "es"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pffe_26") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pffe_27>[0-9]+) (?P<Pffe_28>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"e"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pffe_28") in plvrFeme and m.group("Pffe_27") in "00000000001" and not excYfeme.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pffe_29>[a-zA-Záâãçéêíóôú]+)os (?P<Pffe_30>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_30") in plvrFeme and m.group("Pffe_29").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pffe_31>[a-zA-Záâãçéêíóôú]+)os (?P<Pffe_32>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffe_32") in plvrFeme and m.group("Pffe_31").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Diab_2>[a-zA-Z]+)s ([Dd])iabete(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "iabete\\n" + m.group(1) + " " + m.group(2) + "iabetes\\n" + m.group(1) + "s " + m.group(2) + "iabetes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Diab_2") in aaSingular'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns ([Dd])iabete(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "iabete\\n" + m.group(1) + "m " + m.group(2) + "iabetes\\n" + m.group(1) + "ns " + m.group(2) + "iabetes"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas ([Dd])iabete(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "iabete\\n" + m.group(1) + "ma " + m.group(2) + "iabetes\\n" + m.group(1) + "mas " + m.group(2) + "iabetes"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári([ao])s ([Dd])iabete(?![-\\w–\xad])', '= m.group(1) + "ári" + m.group(2) + "s " + m.group(3) + "iabetes"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s ([Dd])iabete(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "iabete"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao])s ([Dd])iabete(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "iabete\\n" + m.group(1) + "od" + m.group(2) + " " + m.group(3) + "iabetes\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "iabetes"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Diab_14>[a-zA-Z]+)s mesmos ([Dd])iabete(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "iabete\\n" + m.group(1) + " mesmo " + m.group(2) + "iabetes\\n" + m.group(1) + "s mesmos " + m.group(2) + "iabetes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Diab_14") in abSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Diab_16>[a-zA-Z]+)s mesmas ([Dd])iabete(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "iabete\\n" + m.group(1) + " mesma " + m.group(2) + "iabetes\\n" + m.group(1) + "s mesmas " + m.group(2) + "iabetes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Diab_16") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas ([Dd])iabete(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "iabete\\n" + m.group(1) + " mesma " + m.group(2) + "iabetes\\n" + m.group(1) + "s mesmas " + m.group(2) + "iabetes"', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(a)s ([Dd])iabete(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "iabete\\n" + m.group(1) + " " + m.group(2) + "iabetes\\n" + m.group(1) + "s " + m.group(2) + "iabetes', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Diab_40>[a-zA-Záâãçéêíóôú]+) e um ([Dd])iabete(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "iabetes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Diab_40").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Diab_44>[a-zA-Záâãçéêíóôú]+) e uma ([Dd])iabete(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "iabetes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Diab_44").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Diab_48>[a-zA-Záâãçéêíóôú]+) ([Dd])iabete(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "iabetes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Diab_48").lower() in numFem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_0>[a-zA-Z]+) (?P<Ptaz_1>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "z\\n" + m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_0") in aaSingular and m.group("Ptaz_1") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_2>[a-zA-Z]+)s (?P<Ptaz_3>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "z\\n" + m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_2") in aaSingular and m.group("Ptaz_3") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)m (?P<Ptaz_4>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "z\\n" + m.group(1) + "ns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_4") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Ptaz_5>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "z\\n" + m.group(1) + "ns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_5") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Ptaz_6>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "z\\n" + m.group(1) + "mas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_6") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Ptaz_7>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "z\\n" + m.group(1) + "mas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_7") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(a|Doi|doi|Dua|dua)s (?P<Ptaz_8>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_8") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári([ao])s (?P<Ptaz_9>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "ári" + m.group(2) + "s " + m.group(3) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_9") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uita (?P<Ptaz_10>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_10") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Ptaz_11>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_11") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao]) (?P<Ptaz_12>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "z\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_12") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao])s (?P<Ptaz_13>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "z\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_13") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_14>[a-zA-Z]+)s mesmos (?P<Ptaz_15>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "z\\n" + m.group(1) + "s mesmos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_14") in abSingular and m.group("Ptaz_15") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_16>[a-zA-Z]+)s mesmas (?P<Ptaz_17>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "z\\n" + m.group(1) + "s mesmas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_16") in acSingular and m.group("Ptaz_17") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_18>[a-zA-Z]+)s mesmo (?P<Ptaz_19>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "z\\n" + m.group(1) + "s mesmos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_18") in abSingular and m.group("Ptaz_19") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_20>[a-zA-Z]+)s mesma (?P<Ptaz_21>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "z\\n" + m.group(1) + "s mesmas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_20") in acSingular and m.group("Ptaz_21") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Ptaz_22>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "z\\n" + m.group(1) + "s mesmas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_22") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Ptaz_23>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_23") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Ptaz_24>[a-zA-Z]+)zes(?![-\\w–\xad])', '= "Uma " + m.group(2) + "z\\nUmas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_24") in plvrInvaz'],
 ['(?u)\\b([,]) uma (?P<Ptaz_25>[a-zA-Z]+)zes(?![-\\w–\xad])', '= ", uma " + m.group(2) + "z\\n, umas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_25") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Ptaz_24>[a-zA-Z]+)zes(?![-\\w–\xad])', '= "Um " + m.group(2) + "z\\nUns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_26") in plvrInvaz'],
 ['(?u)\\b([,]) um (?P<Ptaz_27>[a-zA-Z]+)zes(?![-\\w–\xad])', '= ", um " + m.group(2) + "z\\n, uns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_27") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Ptaz_28>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_28") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Ptaz_29>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_29") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Ptaz_30>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_30") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Ptaz_31>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_31") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_32>[a-zA-Záâãçéêíóôú]+) um (?P<Ptaz_33>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) + "z\\n" + m.group(1) + " uns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptaz_32") in "-E-e-" and m.group("Ptaz_33") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_34>[a-zA-Záâãçéêíóôú]+) uma (?P<Ptaz_35>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "z\\n" + m.group(1) + " umas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptaz_34") in "-E-e-" and m.group("Ptaz_35") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_36>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptaz_37>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "z\\n" + m.group(1) + " e uns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptaz_36") in numEfem and m.group("Ptaz_37") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_38>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptaz_39>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "z\\n" + m.group(1) + " e umas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptaz_38") in numEfem and m.group("Ptaz_39") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_40>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptaz_41>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_40").lower() in numEmasc and m.group("Ptaz_41") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_42>[a-zA-Záâãçéêíóôú]+) e uns (?P<Ptaz_43>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_42").lower() in numEmasc and m.group("Ptaz_43") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_44>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptaz_45>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_44").lower() in numEfem and m.group("Ptaz_45") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_46>[a-zA-Záâãçéêíóôú]+) e umas (?P<Ptaz_47>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_46").lower() in numEfem and m.group("Ptaz_47") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_48>[a-zA-Záâãçéêíóôú]+) (?P<Ptaz_49>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_48").lower() in numFem and m.group("Ptaz_49") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_50>[0-9]+) (?P<Ptaz_51>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "zes"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Ptaz_50") in "00000000001" and not excYinvaz.search(TEXT) and m.group("Ptaz_51") in plvrInvaz'],
 ['(?u)\\b([.])(?P<Ptaz_52>[0-9][0-9][0-9]) (?P<Ptaz_53>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "zes"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("m.group("Ptaz_53") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_54>[0-9]+) (?P<Ptaz_55>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "z"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptaz_55") in "00000000001" and not excYinvaz.search(TEXT) and m.group("Ptaz_55") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazm_0>[a-zA-Z]+)s (?P<Pazm_1>[a-zA-Z]+)z(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "z\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_0") in aaSingular and m.group("Pazm_1") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazm_2>[a-zA-Z]+) (?P<Pazm_3>[a-zA-Z]+)zes(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "z\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_2") in aaSingular and m.group("Pazm_3") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazm_4>[a-zA-Z]+) (?P<Pazm_5>[a-zA-Z]+)z(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_4") in acSingular and m.group("Pazm_5") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazm_6>[a-zA-Z]+)s (?P<Pazm_7>[a-zA-Z]+)zes(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_6") in acSingular and m.group("Pazm_7") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Pazm_a>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_a") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Pazm_b>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_b") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pazm_c>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_c") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pazm_d>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_d") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pazm_e>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_e") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pazm_f>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_f") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pazm_g>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_g") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pazm_h>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_h") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([U])m (?P<Pazm_i>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "z\\n" + m.group(1) + "ns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_i") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pazm_j>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "zgum " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_j") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pazm_k>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "zguns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_k") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pazm_l>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "zgum " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_l") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pazm_m>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "zguns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_m") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pazm_n>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "zguns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_n") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pazm_o>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "zgum " + m.group(2) + "z\\n" + m.group(1) + "zguns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_o") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pazm_p>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_p") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pazm_q>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_q") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pazm_r>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_r") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pazm_s>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_s") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pazm_t>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_t") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pazm_u>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "z\\n" + m.group(1) + "enhuns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_u") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pazm_v>[a-zA-Z]+)z(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_v") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pazm_w>[a-zA-Z]+)zes(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "z\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_w") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pazm_x>[a-zA-Z]+)z(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "z\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_x") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pazm_y>[a-zA-Z]+)zes(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "z\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_y") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Pazm_10>[a-zA-Z]+)zes(?![-\\w–\xad])', '= "Um " + m.group(2) + "z\\nUns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_10") in plvrMascz'],
 ['(?u)\\b([,]) um (?P<Pazm_11>[a-zA-Z]+)zes(?![-\\w–\xad])', '= ", um " + m.group(2) + "z\\n, uns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_11") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Pazm_12>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) +"z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_12") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Pazm_13>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) +"z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_13") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazm_14>[a-zA-Záâãçéêíóôú]+) um (?P<Pazm_15>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) +"z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_15") in plvrMascz and not m.group("Pazm_14") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazm_16>[a-zA-Záâãçéêíóôú]+) e um (?P<Pazm_17>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "z\\n" + m.group(1) + " e uns " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_17") in plvrMascz and not m.group("Pazm_16") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazm_18>[a-zA-Záâãçéêíóôú]+) e um (?P<Pazm_19>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_19") in plvrMascz and m.group("Pazm_18").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazm_19>[a-zA-Záâãçéêíóôú]+) e uns (?P<Pazm_20>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_20") in plvrMascz and m.group("Pazm_19").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazm_21>[a-zA-Záâãçéêíóôú]+) (?P<Pazm_22>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_22") in plvrMascz and m.group("Pazm_21").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazm_23>[0-9]+) (?P<Pazm_24>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "zes"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pazm_24") in plvrMascz and not m.group("Pazm_23") in "00000000001" and not excYmascz.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pazm_25>[0-9][0-9][0-9]) (?P<Pazm_26>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "zes"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pazm_26") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazm_27>[0-9]+) (?P<Pazm_28>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"z"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pazm_28") in plvrMascz and m.group("Pazm_27") in "00000000001" and not excYmascz.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazm_29>[a-zA-Záâãçéêíóôú]+)as (?P<Pazm_30>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_30") in plvrMascz and m.group("Pazm_29").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazm_31>[a-zA-Záâãçéêíóôú]+)as (?P<Pazm_32>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazm_32") in plvrMascz and m.group("Pazm_31").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazf_0>[a-zA-Z]+)s (?P<Pazf_1>[a-zA-Z]+)z(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "z\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_0") in aaSingular and m.group("Pazf_1") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazf_2>[a-zA-Z]+) (?P<Pazf_3>[a-zA-Z]+)zes(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "z\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_2") in aaSingular and m.group("Pazf_3") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazf_4>[a-zA-Z]+) (?P<Pazf_5>[a-zA-Z]+)z(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_4") in abSingular and m.group("Pazf_5") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazf_6>[a-zA-Z]+)s (?P<Pazf_7>[a-zA-Z]+)zes(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_6") in abSingular and m.group("Pazf_7") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pazf_8>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_8") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pazf_9>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_9") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Pazf_a>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_a") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Pazf_b>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_b") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pazf_c>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_c") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pazf_d>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_d") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pazf_e>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_e") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pazf_f>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_f") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pazf_g>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_g") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pazf_h>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_h") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([U])ma (?P<Pazf_i>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "z\\n" + m.group(1) + "mas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_i") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pazf_j>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "zguma " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_j") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pazf_k>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "zgumas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_k") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pazf_l>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "zguma " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_l") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pazf_m>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "zgumas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_m") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pazf_n>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "zgumas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_n") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pazf_o>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "zguma " + m.group(2) + "z\\n" + m.group(1) + "zgumas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_o") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pazf_p>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_p") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pazf_q>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_q") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pazf_r>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_r") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pazf_s>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_s") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pazf_t>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_t") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pazf_u>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "z\\n" + m.group(1) + "enhumas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_u") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pazf_v>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(2) + " " + m.group(3) + "z\\n" + m.group(2) + "s " + m.group(3) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_v") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pazf_w>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "z\\n" + m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_w") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pazf_10>[a-zA-Z]+)zes(?![-\\w–\xad])', '= "Uma " + m.group(2) + "z\\nUmas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_10") in plvrFemz'],
 ['(?u)\\b([,]) uma (?P<Pazf_11>[a-zA-Z]+)zes(?![-\\w–\xad])', '= ", uma " + m.group(2) + "z\\n, umas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_11") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pazf_12>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) +"z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_12") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pazf_13>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) +"z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_13") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazf_14>[a-zA-Záâãçéêíóôú]+) uma (?P<Pazf_15>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) +"z"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_15") in plvrFemz and not m.group("Pazf_14") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazf_16>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pazf_17>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "z\\n" + m.group(1) + " e umas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_17") in plvrFemz and not m.group("Pazf_16") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazf_18>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pazf_19>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_19") in plvrFemz and m.group("Pazf_18").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazf_19>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pazf_20>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_20") in plvrFemz and m.group("Pazf_19").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazf_21>[a-zA-Záâãçéêíóôú]+) (?P<Pazf_22>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_22") in plvrFemz and m.group("Pazf_21").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazf_23>[0-9]+) (?P<Pazf_24>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "zes"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pazf_24") in plvrFemz and not m.group("Pazf_23") in "00000000001" and not excYfemz.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pazf_25>[0-9][0-9][0-9]) (?P<Pazf_26>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "zes"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pazf_26") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazf_27>[0-9]+) (?P<Pazf_28>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"z"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pazf_28") in plvrFemz and m.group("Pazf_27") in "00000000001" and not excYfemz.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazf_29>[a-zA-Záâãçéêíóôú]+)os (?P<Pazf_30>[a-zA-Z]+)z(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_30") in plvrFemz and m.group("Pazf_29").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pazf_31>[a-zA-Záâãçéêíóôú]+)os (?P<Pazf_32>[a-zA-Z]+)zes(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pazf_32") in plvrFemz and m.group("Pazf_31").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgm_0>[a-zA-Z]+) (?P<Pdgm_1>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "m\\n" + m.group(1) + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_0") in aaSingular and m.group("Pdgm_1") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgm_2>[a-zA-Z]+)s (?P<Pdgm_3>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "m\\n" + m.group(1) + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_2") in aaSingular and m.group("Pdgm_3") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)m (?P<Pdgm_4>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "m\\n" + m.group(1) + "ns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_4") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Pdgm_5>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "m\\n" + m.group(1) + "ns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_5") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Pdgm_6>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "m\\n" + m.group(1) + "mas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_6") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Pdgm_7>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "m\\n" + m.group(1) + "mas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_7") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(a|Doi|doi|Dua|dua)s (?P<Pdgm_8>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_8") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári([ao])s (?P<Pdgm_9>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= m.group(1) + "ári" + m.group(2) + "s " + m.group(3) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_9") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uita (?P<Pdgm_10>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_10") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pdgm_11>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_11") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao]) (?P<Pdgm_12>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "m\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_12") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao])s (?P<Pdgm_13>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "m\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_13") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgm_14>[a-zA-Z]+)s mesmos (?P<Pdgm_15>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "m\\n" + m.group(1) + "s mesmos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_14") in abSingular and m.group("Pdgm_15") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgm_16>[a-zA-Z]+)s mesmas (?P<Pdgm_17>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "m\\n" + m.group(1) + "s mesmas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_16") in acSingular and m.group("Pdgm_17") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgm_18>[a-zA-Z]+)s mesmo (?P<Pdgm_19>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "m\\n" + m.group(1) + "s mesmos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_18") in abSingular and m.group("Pdgm_19") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgm_20>[a-zA-Z]+)s mesma (?P<Pdgm_21>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "m\\n" + m.group(1) + "s mesmas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_20") in acSingular and m.group("Pdgm_21") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Pdgm_22>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "m\\n" + m.group(1) + "s mesmas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_22") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Pdgm_23>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_23") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pdgm_24>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= "Uma " + m.group(2) + "u\\nUmas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_24") in plvrMFm'],
 ['(?u)\\b([,]) uma (?P<Pdgm_25>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= ", uma " + m.group(2) + "u\\n, umas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_25") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Pdgm_24>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= "Um " + m.group(2) + "u\\nUns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_26") in plvrMFm'],
 ['(?u)\\b([,]) um (?P<Pdgm_27>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= ", um " + m.group(2) + "u\\n, uns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_27") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Pdgm_28>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_28") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pdgm_29>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_29") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Pdgm_30>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_30") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pdgm_31>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_31") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgm_32>[a-zA-Záâãçéêíóôú]+) um (?P<Pdgm_33>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) + "m\\n" + m.group(1) + " uns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pdgm_32") in "-E-e-" and m.group("Pdgm_33") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgm_34>[a-zA-Záâãçéêíóôú]+) uma (?P<Pdgm_35>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "m\\n" + m.group(1) + " umas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pdgm_34") in "-E-e-" and m.group("Pdgm_35") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgm_36>[a-zA-Záâãçéêíóôú]+) e um (?P<Pdgm_37>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "m\\n" + m.group(1) + " e uns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pdgm_36") in numEfem and m.group("Pdgm_37") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgm_38>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pdgm_39>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "m\\n" + m.group(1) + " e umas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Pdgm_38") in numEfem and m.group("Pdgm_39") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgm_40>[a-zA-Záâãçéêíóôú]+) e um (?P<Pdgm_41>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_40").lower() in numEmasc and m.group("Pdgm_41") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgm_42>[a-zA-Záâãçéêíóôú]+) e uns (?P<Pdgm_43>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_42").lower() in numEmasc and m.group("Pdgm_43") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgm_44>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pdgm_45>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_44").lower() in numEfem and m.group("Pdgm_45") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgm_46>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pdgm_47>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_46").lower() in numEfem and m.group("Pdgm_47") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgm_48>[a-zA-Záâãçéêíóôú]+) (?P<Pdgm_49>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pdgm_48").lower() in numFem and m.group("Pdgm_49") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgm_50>[0-9]+) (?P<Pdgm_51>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ns"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Pdgm_50") in "00000000001" and not excYmfm.search(TEXT) and m.group("Pdgm_51") in plvrMFm'],
 ['(?u)\\b([.])(?P<Pdgm_52>[0-9][0-9][0-9]) (?P<Pdgm_53>[a-zA-Zçáéíóúâêô]+)m(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "ns"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pdgm_53") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pdgm_54>[0-9]+) (?P<Pdgm_55>[a-zA-Zçáéíóúâêô]+)ns(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "m"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pdgm_55") in "00000000001" and not excYmfm.search(TEXT) and m.group("Pdgm_55") in plvrMFm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptmm_0>[a-zA-Z]+)s (?P<Ptmm_1>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "m\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_0") in aaSingular and m.group("Ptmm_1") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptmm_2>[a-zA-Z]+) (?P<Ptmm_3>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "m\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_2") in aaSingular and m.group("Ptmm_3") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptmm_4>[a-zA-Z]+) (?P<Ptmm_5>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_4") in acSingular and m.group("Ptmm_5") in plvrMascm and not (m.group("Ptmm_4") in "-A-" and m.group("Ptmm_5") in excplMascm)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptmm_6>[a-zA-Z]+)s (?P<Ptmm_7>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_6") in acSingular and m.group("Ptmm_7") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Ptmm_a>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_a") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Ptmm_b>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_b") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Ptmm_c>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_c") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Ptmm_d>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_d") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Ptmm_e>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_e") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Ptmm_f>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_f") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Ptmm_g>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_g") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Ptmm_h>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_h") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([U])m (?P<Ptmm_i>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "m\\n" + m.group(1) + "ns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_i") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Ptmm_j>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "ugum " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_j") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Ptmm_k>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "uguns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_k") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Ptmm_l>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "ugum " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_l") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Ptmm_m>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "uguns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_m") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Ptmm_n>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "uguns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_n") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Ptmm_o>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ugum " + m.group(2) + "m\\n" + m.group(1) + "uguns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_o") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Ptmm_p>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_p") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Ptmm_q>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_q") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Ptmm_r>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_r") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Ptmm_s>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_s") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Ptmm_t>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_t") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Ptmm_u>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "m\\n" + m.group(1) + "enhuns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_u") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Ptmm_v>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_v") in plvrMascm and not m.group("Ptmm_v") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Ptmm_w>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "m\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_w") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Ptmm_x>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "m\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_x") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Ptmm_y>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "m\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_y") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Ptmm_10>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= "Um " + m.group(2) + "u\\nUns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_10") in plvrMascm'],
 ['(?u)\\b([,]) um (?P<Ptmm_11>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= ", um " + m.group(2) + "u\\n, uns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_11") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Ptmm_12>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) +"m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_12") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Ptmm_13>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) +"m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_13") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptmm_14>[a-zA-Záâãçéêíóôú]+) um (?P<Ptmm_15>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) +"m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_15") in plvrMascm and not m.group("Ptmm_14") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptmm_16>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptmm_17>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "m\\n" + m.group(1) + " e uns " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_17") in plvrMascm and not m.group("Ptmm_16") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptmm_18>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptmm_19>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_19") in plvrMascm and m.group("Ptmm_18").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptmm_19>[a-zA-Záâãçéêíóôú]+) e uns (?P<Ptmm_20>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_20") in plvrMascm and m.group("Ptmm_19").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptmm_21>[a-zA-Záâãçéêíóôú]+) (?P<Ptmm_22>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_22") in plvrMascm and m.group("Ptmm_21").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptmm_23>[0-9]+) (?P<Ptmm_24>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ns"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptmm_24") in plvrMascm and not m.group("Ptmm_23") in "00000000001" and not excYmascm.search(TEXT)'],
 ['(?u)\\b([.])(?P<Ptmm_25>[0-9][0-9][0-9]) (?P<Ptmm_26>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "ns"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptmm_26") in plvrMascm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptmm_27>[0-9]+) (?P<Ptmm_28>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"m"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptmm_28") in plvrMascm and m.group("Ptmm_27") in "00000000001" and not excYmascm.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptmm_29>[a-zA-Záâãçéêíóôú]+)as (?P<Ptmm_30>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_30") in plvrMascm and m.group("Ptmm_29").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptmm_31>[a-zA-Záâãçéêíóôú]+)as (?P<Ptmm_32>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptmm_32") in plvrMascm and m.group("Ptmm_31").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamf_0>[a-zA-Z]+)s (?P<Pamf_1>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "m\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_0") in aaSingular and m.group("Pamf_1") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamf_2>[a-zA-Z]+) (?P<Pamf_3>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "m\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_2") in aaSingular and m.group("Pamf_3") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamf_4>[a-zA-Z]+) (?P<Pamf_5>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_4") in abSingular and m.group("Pamf_5") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamf_6>[a-zA-Z]+)s (?P<Pamf_7>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_6") in abSingular and m.group("Pamf_7") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pamf_8>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_8") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pamf_9>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_9") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Pamf_a>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_a") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Pamf_b>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_b") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pamf_c>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_c") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pamf_d>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_d") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pamf_e>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_e") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pamf_f>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_f") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pamf_g>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_g") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pamf_h>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_h") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([U])ma (?P<Pamf_i>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "m\\n" + m.group(1) + "mas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_i") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pamf_j>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "uguma " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_j") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pamf_k>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ugumas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_k") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pamf_l>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "uguma " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_l") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pamf_m>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ugumas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_m") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pamf_n>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "ugumas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_n") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pamf_o>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "uguma " + m.group(2) + "m\\n" + m.group(1) + "ugumas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_o") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pamf_p>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_p") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pamf_q>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_q") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pamf_r>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_r") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pamf_s>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_s") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pamf_t>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_t") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pamf_u>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "m\\n" + m.group(1) + "enhumas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_u") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pamf_v>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(2) + " " + m.group(3) + "m\\n" + m.group(2) + "s " + m.group(3) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_v") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pamf_w>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "m\\n" + m.group(1) + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_w") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pamf_10>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= "Uma " + m.group(2) + "u\\nUmas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_10") in plvrFemm'],
 ['(?u)\\b([,]) uma (?P<Pamf_11>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= ", uma " + m.group(2) + "u\\n, umas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_11") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pamf_12>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) +"m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_12") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pamf_13>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) +"m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_13") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamf_14>[a-zA-Záâãçéêíóôú]+) uma (?P<Pamf_15>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) +"m"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_15") in plvrFemm and not m.group("Pamf_14") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamf_16>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pamf_17>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "m\\n" + m.group(1) + " e umas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_17") in plvrFemm and not m.group("Pamf_16") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamf_18>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pamf_19>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_19") in plvrFemm and m.group("Pamf_18").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamf_19>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pamf_20>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_20") in plvrFemm and m.group("Pamf_19").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamf_21>[a-zA-Záâãçéêíóôú]+) (?P<Pamf_22>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_22") in plvrFemm and m.group("Pamf_21").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamf_23>[0-9]+) (?P<Pamf_24>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ns"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pamf_24") in plvrFemm and not m.group("Pamf_23") in "00000000001" and not excYfemm.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pamf_25>[0-9][0-9][0-9]) (?P<Pamf_26>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "ns"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pamf_26") in plvrFemm'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamf_27>[0-9]+) (?P<Pamf_28>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) +"m"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pamf_28") in plvrFemm and m.group("Pamf_27") in "00000000001" and not excYfemm.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamf_29>[a-zA-Záâãçéêíóôú]+)os (?P<Pamf_30>[a-zA-Záâãçéêíóôú]+)m(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_30") in plvrFemm and m.group("Pamf_29").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamf_31>[a-zA-Záâãçéêíóôú]+)os (?P<Pamf_32>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamf_32") in plvrFemm and m.group("Pamf_31").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfan_0>[a-zA-Z]+)s (?P<Pfan_1>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_0") in aaSingular and m.group("Pfan_1") in pvrFeman and not "estes sua" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfan_2>[a-zA-Z]+) (?P<Pfan_3>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_2") in aaSingular and m.group("Pfan_3") in pvrFeman and not "este sua" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfan_4>[a-zA-Z]+) (?P<Pfan_5>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= varGenera[m.group(1)] + " " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_4") in abSingular and m.group("Pfan_5") in pvrFeman and not (m.group("Pfan_4") in "Oo" and m.group("Pfan_5") in excplFema) and not "este sua" in TEXT and not "rimeiro minha" in TEXT and not (m.group("Pfan_5") == "camisa" and excamisa.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfan_6>[a-zA-Z]+)s (?P<Pfan_7>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_6") in abSingular and m.group("Pfan_7") in pvrFeman and not (m.group("Pfan_6") in "Oo" and m.group("Pfan_7") in excplFema)'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pfan_8>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_8") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ários (?P<Pfan_9>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "árias " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_9") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitos (?P<Pfan_10>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "s\\n" + m.group(1) + "uitas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_10") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uita (?P<Pfan_12>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "\\n" + m.group(1) + "uita " + m.group(2) + "\\n" + m.group(1) + "uitas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_12") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pfan_13>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "\\n" + m.group(1) + "uita " + m.group(2) + "\\n" + m.group(1) + "uitas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_13") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucos (?P<Pfan_14>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "oucas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_14") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pfan_16>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "\\n" + m.group(1) + "oucas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_16") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pfan_17>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "ouca " + m.group(2) + "\\n" + m.group(1) + "oucas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_17") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos (?P<Pfan_54>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "odas as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_54") in pvrFeman and not " a todos " + m.group("Pfan_54") in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odo (?P<Pfan_55>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "\\n" + m.group(1) + "odas as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_55") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pfan_56>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "\\n" + m.group(1) + "odas as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_56") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pfan_57>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "oda " + m.group(2) + "\\n" + m.group(1) + "odas as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_57") in pvrFeman and not " a todos " + m.group("Pfan_57") in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfan_18>[a-zA-Z]+)s mesmos (?P<Pfan_19>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_18") in abSingular and m.group("Pfan_19") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfan_20>[a-zA-Z]+)s mesmas (?P<Pfan_21>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_20") in acSingular and m.group("Pfan_21") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfan_22>[a-zA-Z]+) mesmo (?P<Pfan_23>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_22") in abSingular and m.group("Pfan_23") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfan_24>[a-zA-Z]+) mesma (?P<Pfan_25>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2) + "\\n" + varGenera[m.group(1)] + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_24") in acSingular and m.group("Pfan_25") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfan_26>[a-zA-Z]+) mesmo (?P<Pfan_27>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= varGenera[m.group(1)] + " mesma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_26") in abSingular and m.group("Pfan_27") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pfan_28>[a-zA-Z]+)s mesmos (?P<Pfan_29>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= varGenera[m.group(1)] + "s mesmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pfan_28") in abSingular and m.group("Pfan_29") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Pffn_a>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_a") in pvrFeman and not m.group("Pffn_a") in excplVirg'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m (?P<Pffn_b>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_b") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pffn_c>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_c") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pffn_d>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_d") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pffn_e>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "mas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_e") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pffn_f>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_f") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pffn_g>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_g") in pvrFeman and not m.group("Pffn_g") in excplVirg'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pffn_h>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "uas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_h") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([U])ma (?P<Pffn_i>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "\\n" + m.group(1) + "mas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_i") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pffn_j>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_j") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pffn_k>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_k") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pffn_l>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_l") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pffn_m>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_m") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pffn_n>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "lgumas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_n") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pffn_o>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "lguma " + m.group(2) + "\\n" + m.group(1) + "lgumas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_o") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pffn_p>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_p") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pffn_q>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_q") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pffn_r>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_r") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pffn_s>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_s") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pffn_t>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "enhumas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_t") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pffn_u>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "enhuma " + m.group(2) + "\\n" + m.group(1) + "enhumas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_u") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pffn_v>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(2) + " " + m.group(3) + "\\n" + m.group(2) + "s " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_v") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pffn_w>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "\\n" + m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pffn_w") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Pafn_0>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= "Uma " + m.group(2) + "\\nUmas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pafn_0") in pvrFeman'],
 ['(?u)\\b([,]) uma (?P<Pafn_1>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= ", uma " + m.group(2) + "\\n, umas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pafn_1") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Pafn_0>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pafn_0") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Pafn_0>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pafn_0") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pafn_2>[a-zA-Záâãçéêíóôú]+) uma (?P<Pafn_3>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "\\n" + m.group(1) + " umas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pafn_3") in pvrFeman and not m.group("Pafn_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pafn_4>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pafn_5>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "\\n" + m.group(1) + " e umas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pafn_5") in pvrFeman and not m.group("Pafn_4") in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pafn_6>[a-zA-Záâãçéêíóôú]+) e uma (?P<Pafn_7>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pafn_7") in pvrFeman and m.group("Pafn_6").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pafn_8>[a-zA-Záâãçéêíóôú]+) e umas (?P<Pafn_9>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pafn_9") in pvrFeman and m.group("Pafn_8").lower() in numEfem'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pafn_10>[a-zA-Záâãçéêíóôú]+) (?P<Pafn_11>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pafn_11") in pvrFeman and m.group("Pafn_10").lower() in numFem and not m.group("Pafn_11") in excplVirg'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pafn_12>[0-9]+) (?P<Pafn_13>[a-záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pafn_13") in pvrFeman and not m.group("Pafn_12") in "00000000001" and not excYfema.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pafn_14>[0-9][0-9][0-9]) (?P<Pafn_15>[a-záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "s"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pafn_15") in pvrFeman'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pafn_16>[0-9]+) (?P<Pafn_17>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2)', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pafn_17") in pvrFeman and m.group("Pafn_16") in "00000000001" and not excYfema.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pafn_17>[a-zA-Záâãçéêíóôú]+)os (?P<Pafn_18>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pafn_18") in pvrFeman and m.group("Pafn_17").lower() in nuMfmoas and not m.group("Pafn_18") in excplVirg'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pafn_19>[a-zA-Záâãçéêíóôú]+)os (?P<Pafn_20>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pafn_20") in pvrFeman and m.group("Pafn_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pman_0>[a-zA-Z]+)s (?P<Pman_1>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_0") in aaSingular and m.group("Pman_1") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pman_2>[a-zA-Z]+) (?P<Pman_3>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_2") in aaSingular and m.group("Pman_3") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pman_4>[a-zA-Z]+) (?P<Pman_5>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_4") in acSingular and m.group("Pman_5") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pman_6>[a-zA-Z]+)s (?P<Pman_7>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_6") in acSingular and m.group("Pman_7") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári[ao]s (?P<Pman_8>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "ários " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_8") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])árias (?P<Pman_9>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "ários " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_9") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uitas (?P<Pman_10>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "uitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_10") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uita (?P<Pman_11>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "\\n" + m.group(1) + "uitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_11") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao] (?P<Pman_12>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "\\n" + m.group(1) + "uitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_12") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Pman_13>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "\\n" + m.group(1) + "uitos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_13") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oucas (?P<Pman_14>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "oucos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_14") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouca (?P<Pman_15>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "ouco " + m.group(2) + "\\n" + m.group(1) + "oucos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_15") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao] (?P<Pman_16>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "ouco " + m.group(2) + "\\n" + m.group(1) + "oucos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_16") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ouc[ao]s (?P<Pman_17>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "ouco " + m.group(2) + "\\n" + m.group(1) + "oucos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_17") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odas (?P<Pman_14>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "odos os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_14") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])oda (?P<Pman_15>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "odo " + m.group(2) + "\\n" + m.group(1) + "odos os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_15") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao] (?P<Pman_16>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "odo " + m.group(2) + "\\n" + m.group(1) + "odos os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_16") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od[ao]s (?P<Pman_17>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "odo " + m.group(2) + "\\n" + m.group(1) + "odos os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_17") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pman_18>[a-zA-Z]+)s mesmos (?P<Pman_19>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_18") in abSingular and m.group("Pman_19") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pman_20>[a-zA-Z]+)s mesmas (?P<Pman_21>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_20") in acSingular and m.group("Pman_21") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pman_22>[a-zA-Z]+) mesmo (?P<Pman_23>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_22") in abSingular and m.group("Pman_23") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pman_24>[a-zA-Z]+) mesma (?P<Pman_25>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2) + "\\n" + varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_24") in acSingular and m.group("Pman_25") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pman_26>[a-zA-Z]+) mesma (?P<Pman_27>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= varGenero[m.group(1)] + " mesmo " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_26") in acSingular and m.group("Pman_27") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pman_28>[a-zA-Z]+)s mesmas (?P<Pman_29>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= varGenero[m.group(1)] + "s mesmos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pman_28") in acSingular and m.group("Pman_29") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Pmmn_a>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_a") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma (?P<Pmmn_b>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_b") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pmmn_c>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_c") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])mas (?P<Pmmn_d>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_d") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ns (?P<Pmmn_e>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_e") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])ois (?P<Pmmn_f>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_f") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pmmn_g>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_g") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])uas (?P<Pmmn_h>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "ois " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_h") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([U])m (?P<Pmmn_i>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "\\n" + m.group(1) + "ns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_i") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pmmn_j>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_j") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguma (?P<Pmmn_k>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_k") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pmmn_l>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_l") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgumas (?P<Pmmn_m>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_m") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lguns (?P<Pmmn_n>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "lguns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_n") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])lgum (?P<Pmmn_o>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "lgum " + m.group(2) + "\\n" + m.group(1) + "lguns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_o") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pmmn_p>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_p") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuma (?P<Pmmn_q>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_q") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pmmn_r>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_r") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhumas (?P<Pmmn_s>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_s") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhuns (?P<Pmmn_t>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "enhuns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_t") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Nn])enhum (?P<Pmmn_u>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "enhum " + m.group(2) + "\\n" + m.group(1) + "enhuns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_u") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pmmn_v>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_v") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])(^)([Aa]) (?P<Pmmn_w>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= aacCao[m.group(2)] + " " + m.group(3) + "\\n" + aacCao[m.group(2)] + "s " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_w") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pmmn_x>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_x") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s (?P<Pmmn_y>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= aacCao[m.group(1)] + " " + m.group(2) + "\\n" + aacCao[m.group(1)] + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pmmn_y") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Pamn_0>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= "Um " + m.group(2) + "\\nUns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamn_0") in pvrMascan'],
 ['(?u)\\b([,]) um (?P<Pamn_1>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= ", um " + m.group(2) + "\\n, uns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamn_1") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Pamn_0>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamn_0") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Pamn_0>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamn_0") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamn_2>[a-zA-Záâãçéêíóôú]+) um (?P<Pamn_3>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamn_3") in pvrMascan and not m.group("Pamn_2") in "-E-e-"'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamn_4>[a-zA-Záâãçéêíóôú]+) e um (?P<Pamn_5>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "\\n" + m.group(1) + " e uns " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamn_5") in pvrMascan and not m.group("Pamn_4") in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamn_6>[a-zA-Záâãçéêíóôú]+) e um (?P<Pamn_7>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamn_7") in pvrMascan and m.group("Pamn_6").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamn_8>[a-zA-Záâãçéêíóôú]+) e uns (?P<Pamn_9>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamn_9") in pvrMascan and m.group("Pamn_8").lower() in numEmasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamn_10>[a-zA-Záâãçéêíóôú]+) (?P<Pamn_11>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamn_11") in pvrMascan and m.group("Pamn_10").lower() in numMasc'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamn_12>[0-9]+) (?P<Pamn_13>[a-záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "s"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pamn_13") in pvrMascan and not m.group("Pamn_12") in "00000000001" and not excYmasca.search(TEXT)'],
 ['(?u)\\b([.])(?P<Pamn_14>[0-9][0-9][0-9]) (?P<Pamn_15>[a-záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "s"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pamn_15") in pvrMascan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamn_16>[0-9]+) (?P<Pamn_17>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2)', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Pamn_17") in pvrMascan and m.group("Pamn_16") in "00000000001" and not excYmasca.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamn_17>[a-zA-Záâãçéêíóôú]+)as (?P<Pamn_18>[a-zA-Záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamn_18") in pvrMascan and m.group("Pamn_17").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pamn_19>[a-zA-Záâãçéêíóôú]+)as (?P<Pamn_20>[a-zA-Záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Pamn_20") in pvrMascan and m.group("Pamn_19").lower() in nuMfmoas'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_0>[a-zA-Z]+) (?P<Ptaz_1>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ã\\n" + m.group(1) + "s " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_0") in aaSingular and m.group("Ptaz_1") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_2>[a-zA-Z]+)s (?P<Ptaz_3>[a-zA-Z]+)ã(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ã\\n" + m.group(1) + "s " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_2") in aaSingular and m.group("Ptaz_3") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)m (?P<Ptaz_4>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ã\\n" + m.group(1) + "ns " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_4") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)ns (?P<Ptaz_5>[a-zA-Z]+)ã(?![-\\w–\xad])', '= m.group(1) + "m " + m.group(2) + "ã\\n" + m.group(1) + "ns " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_5") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(U|Algu|algu|Nenhu|nenhu)ma (?P<Ptaz_6>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ã\\n" + m.group(1) + "mas " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_6") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(U|u|Algu|algu|Nenhu|nenhu)mas (?P<Ptaz_7>[a-zA-Z]+)ã(?![-\\w–\xad])', '= m.group(1) + "ma " + m.group(2) + "ã\\n" + m.group(1) + "mas " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_7") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(a|Doi|doi|Dua|dua)s (?P<Ptaz_8>[a-zA-Z]+)ã(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_8") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])([Vv])ári([ao])s (?P<Ptaz_9>[a-zA-Z]+)ã(?![-\\w–\xad])', '= m.group(1) + "ári" + m.group(2) + "s " + m.group(3) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_9") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uita (?P<Ptaz_10>[a-zA-Z]+)ã(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "ã"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_10") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])([Mm])uit[ao]s (?P<Ptaz_11>[a-zA-Z]+)ã(?![-\\w–\xad])', '= m.group(1) + "uito " + m.group(2) + "ã"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_11") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao]) (?P<Ptaz_12>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "ã\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_12") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])od([ao])s (?P<Ptaz_13>[a-zA-Z]+)ã(?![-\\w–\xad])', '= m.group(1) + "od" + m.group(2) + " " + m.group(3) + "ã\\n" + m.group(1) + "od" + m.group(2) + "s " + m.group(3) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_13") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_14>[a-zA-Z]+)s mesmos (?P<Ptaz_15>[a-zA-Z]+)ã(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "ã\\n" + m.group(1) + "s mesmos " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_14") in abSingular and m.group("Ptaz_15") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_16>[a-zA-Z]+)s mesmas (?P<Ptaz_17>[a-zA-Z]+)ã(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "ã\\n" + m.group(1) + "s mesmas " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_16") in acSingular and m.group("Ptaz_17") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_18>[a-zA-Z]+)s mesmo (?P<Ptaz_19>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= m.group(1) + " mesmo " + m.group(2) + "ã\\n" + m.group(1) + "s mesmos " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_18") in abSingular and m.group("Ptaz_19") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_20>[a-zA-Z]+)s mesma (?P<Ptaz_21>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "ã\\n" + m.group(1) + "s mesmas " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_20") in acSingular and m.group("Ptaz_21") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])([Aa])s mesmas (?P<Ptaz_22>[a-zA-Z]+)ã(?![-\\w–\xad])', '= m.group(1) + " mesma " + m.group(2) + "ã\\n" + m.group(1) + "s mesmas " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_22") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(a)s (?P<Ptaz_23>[a-zA-Z]+)ã(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_23") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(^)uma (?P<Ptaz_24>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= "Uma " + m.group(2) + "ã\\nUmas " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_24") in pvrInvan'],
 ['(?u)\\b([,]) uma (?P<Ptaz_25>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= ", uma " + m.group(2) + "ã\\n, umas " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_25") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(^)um (?P<Ptaz_24>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= "Um " + m.group(2) + "ã\\nUns " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_26") in pvrInvan'],
 ['(?u)\\b([,]) um (?P<Ptaz_27>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= ", um " + m.group(2) + "ã\\n, uns " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_27") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m só (?P<Ptaz_28>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= m.group(1) + "m só" +" " + m.group(2) + "ã"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_28") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma só (?P<Ptaz_29>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= m.group(1) + "ma só" +" " + m.group(2) + "ã"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_29") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])m simples (?P<Ptaz_30>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= m.group(1) + "m simples " + m.group(2) + "ã"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_30") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma simples (?P<Ptaz_31>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= m.group(1) + "ma simples " + m.group(2) + "ã"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_31") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_32>[a-zA-Záâãçéêíóôú]+) um (?P<Ptaz_33>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= m.group(1) + " um " + m.group(2) + "ã\\n" + m.group(1) + " uns " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptaz_32") in "-E-e-" and m.group("Ptaz_33") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_34>[a-zA-Záâãçéêíóôú]+) uma (?P<Ptaz_35>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= m.group(1) + " uma " + m.group(2) + "ã\\n" + m.group(1) + " umas " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptaz_34") in "-E-e-" and m.group("Ptaz_35") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_36>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptaz_37>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "ã\\n" + m.group(1) + " e uns " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptaz_36") in numEfem and m.group("Ptaz_37") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_38>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptaz_39>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "ã\\n" + m.group(1) + " e umas " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ptaz_38") in numEfem and m.group("Ptaz_39") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_40>[a-zA-Záâãçéêíóôú]+) e um (?P<Ptaz_41>[a-zA-Z]+)ã(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_40").lower() in numEmasc and m.group("Ptaz_41") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_42>[a-zA-Záâãçéêíóôú]+) e uns (?P<Ptaz_43>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= m.group(1) + " e um " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_42").lower() in numEmasc and m.group("Ptaz_43") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_44>[a-zA-Záâãçéêíóôú]+) e uma (?P<Ptaz_45>[a-zA-Z]+)ã(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_44").lower() in numEfem and m.group("Ptaz_45") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_46>[a-zA-Záâãçéêíóôú]+) e umas (?P<Ptaz_47>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= m.group(1) + " e uma " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_46").lower() in numEfem and m.group("Ptaz_47") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_48>[a-zA-Záâãçéêíóôú]+) (?P<Ptaz_49>[a-zA-Z]+)ã(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ãs"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ptaz_48").lower() in numFem and m.group("Ptaz_49") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_50>[0-9]+) (?P<Ptaz_51>[a-zA-Z]+)ã(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ãs"', 'Não há concordância entre os termos. Você quis dizer:', 'not m.group("Ptaz_50") in "00000000001" and not excYinvaz.search(TEXT) and m.group("Ptaz_51") in pvrInvan'],
 ['(?u)\\b([.])(?P<Ptaz_52>[0-9][0-9][0-9]) (?P<Ptaz_53>[a-zA-Z]+)ã(?![-\\w–\xad])', '= m.group(1) + m.group(2) + " " + m.group(3) + "ãs"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("m.group("Ptaz_53") in pvrInvan'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ptaz_54>[0-9]+) (?P<Ptaz_55>[a-zA-Z]+)ãs(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "ã"', 'Não há concordância entre os termos. Você quis dizer:', 'm.group("Ptaz_55") in "00000000001" and not excYinvaz.search(TEXT) and m.group("Ptaz_55") in pvrInvan'],
# CONCORDANCIA NOMINAL SINGULAR - PLURAL
# plvrFema
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_1>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_1").lower() in plvrFema and m.group("Msif_2").lower() in plvrFema and not " e " + m.group("Msif_1") + " " + m.group("Msif_2") +"s" in TEXT and not " ou " + m.group("Msif_1") + " " + m.group("Msif_2") + "s" in TEXT and not "s de " + m.group("Msif_1") + " " + m.group("Msif_2") + "s" in TEXT and not "s da " + m.group("Msif_1") + " " + m.group("Msif_2") + "s" in TEXT and not " a " + m.group("Msif_1") + " " + m.group("Msif_2") + "s" in TEXT and not m.group("Msif_1") + "-" + m.group("Msif_2") + "s" in tCompostops and not (m.group("Msif_1") in "maioria-maneira" and excMaioria.search(TEXT)) and not excsingpl.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_3>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_3").lower() in plvrFema and m.group("Msif_4").lower() in plvrMfoa and not " e " + m.group("Msif_3") + " " + m.group("Msif_4") + "as" in TEXT and not " ou " + m.group("Msif_3") + " " + m.group("Msif_4") + "as" in TEXT and not "s de " + m.group("Msif_3") + " " + m.group("Msif_4") + "as" in TEXT and not "s da " + m.group("Msif_3") + " " + m.group("Msif_4") + "as" in TEXT and not " a " + m.group("Msif_3") + " " + m.group("Msif_4") + "as" in TEXT and not m.group("Msif_3") + "-" + m.group("Msif_4") + "as" in tCompostops and not (m.group("Msif_3") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_5>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_5").lower() in plvrFema and not m.group("Msif_6").lower() in excAdo and not " e " + m.group("Msif_5") + " " + m.group("Msif_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msif_5") + " " + m.group("Msif_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msif_5") + " " + m.group("Msif_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Msif_5") + " " + m.group("Msif_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Msif_5") + " " + m.group("Msif_6") + m.group(3) + "dos" in TEXT and not m.group("Msif_5") + "-" + m.group("Msif_6") + m.group(3) + "dos" in tCompostops and not (m.group("Msif_5") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_7>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_7").lower() in plvrFema and not m.group("Msif_8").lower() in excIsta and not " e " + m.group("Msif_7") + " " + m.group("Msif_8") + "s" in TEXT and not " ou " + m.group("Msif_7") + " " + m.group("Msif_8") + "s" in TEXT and not "s de " + m.group("Msif_7") + " " + m.group("Msif_8") + "s" in TEXT and not "s da " + m.group("Msif_7") + " " + m.group("Msif_8") + "s" in TEXT and not " a " + m.group("Msif_7") + " " + m.group("Msif_8") + "s" in TEXT and not m.group("Msif_7") + "-" + m.group("Msif_8") + "s" in tCompostops and not (m.group("Msif_7") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_9>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_9").lower() in plvrFema and m.group("Msif_10").lower() in plvrInva and not " e " + m.group("Msif_9") + " " + m.group("Msif_10") + "s" in TEXT and not " ou " + m.group("Msif_9") + " " + m.group("Msif_10") + "s" in TEXT and not "s de " + m.group("Msif_9") + " " + m.group("Msif_10") + "s" in TEXT and not "s da " + m.group("Msif_9") + " " + m.group("Msif_10") + "s" in TEXT and not " a " + m.group("Msif_9") + " " + m.group("Msif_10") + "s" in TEXT and not m.group("Msif_9") + "-" + m.group("Msif_10") + "s" in tCompostops and not (m.group("Msif_9") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_11>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_11").lower() in plvrFema and not m.group("Msif_12").lower() in excAdo and not " e " + m.group("Msif_11") + " " + m.group("Msif_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msif_11") + " " + m.group("Msif_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msif_11") + " " + m.group("Msif_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Msif_11") + " " + m.group("Msif_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Msif_11") + " " + m.group("Msif_12") + m.group(3) + "das" in TEXT and not m.group("Msif_11") + "-" + m.group("Msif_12") + m.group(3) + "das" in tCompostops and not (m.group("Msif_11") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_13>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_13").lower() in plvrFema and not " e " + m.group("Msif_13") + " " + m.group("Msif_14") + "osos" in TEXT and not " ou " + m.group("Msif_13") + " " + m.group("Msif_14") + "osos" in TEXT and not "s de " + m.group("Msif_13") + " " + m.group("Msif_14") + "osos" in TEXT and not "s da " + m.group("Msif_13") + " " + m.group("Msif_14") + "osos" in TEXT and not " a " + m.group("Msif_13") + " " + m.group("Msif_14") + "osos" in TEXT and not m.group("Msif_13") + "-" + m.group("Msif_14") + "osos" in tCompostops and not (m.group("Msif_13") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_15>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_15").lower() in plvrFema and not " e " + m.group("Msif_15") + " " + m.group("Msif_16") + "osas" in TEXT and not " ou " + m.group("Msif_15") + " " + m.group("Msif_16") + "osas" in TEXT and not "s de " + m.group("Msif_15") + " " + m.group("Msif_16") + "osas" in TEXT and not "s da " + m.group("Msif_15") + " " + m.group("Msif_16") + "osas" in TEXT and not " a " + m.group("Msif_15") + " " + m.group("Msif_16") + "osas" in TEXT and not m.group("Msif_15") + "-" + m.group("Msif_16") + "osas" in tCompostops and not (m.group("Msif_15") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_17>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_17").lower() in plvrFema and not " e " + m.group("Msif_17") + " " + m.group("Msif_18") + "ivas" in TEXT and not " ou " + m.group("Msif_17") + " " + m.group("Msif_18") + "ivas" in TEXT and not "s de " + m.group("Msif_17") + " " + m.group("Msif_18") + "ivas" in TEXT and not "s da " + m.group("Msif_17") + " " + m.group("Msif_18") + "ivas" in TEXT and not " a " + m.group("Msif_17") + " " + m.group("Msif_18") + "ivas" in TEXT and not m.group("Msif_17") + "-" + m.group("Msif_18") + "ivas" in tCompostops and not (m.group("Msif_17") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_19>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_19").lower() in plvrFema and not " e " + m.group("Msif_19") + " " + m.group("Msif_20") + "ivas" in TEXT and not " ou " + m.group("Msif_19") + " " + m.group("Msif_20") + "ivas" in TEXT and not "s de " + m.group("Msif_19") + " " + m.group("Msif_20") + "ivas" in TEXT and not "s da " + m.group("Msif_19") + " " + m.group("Msif_20") + "ivas" in TEXT and not " a " + m.group("Msif_19") + " " + m.group("Msif_20") + "ivas" in TEXT and not m.group("Msif_19") + "-" + m.group("Msif_20") + "ivas" in tCompostops and not (m.group("Msif_19") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_21>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_21").lower() in plvrFema and not " e " + m.group("Msif_21") + " " + m.group("Msif_22") + "icas" in TEXT and not " ou " + m.group("Msif_21") + " " + m.group("Msif_22") + "icas" in TEXT and not "s de " + m.group("Msif_21") + " " + m.group("Msif_22") + "icas" in TEXT and not "s da " + m.group("Msif_21") + " " + m.group("Msif_22") + "icas" in TEXT and not " a " + m.group("Msif_21") + " " + m.group("Msif_22") + "icas" in TEXT and not m.group("Msif_21") + "-" + m.group("Msif_22") + "icas" in tCompostops and not (m.group("Msif_21") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_23>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_23").lower() in plvrFema and not " e " + m.group("Msif_23") + " " + m.group("Msif_24") + "icas" in TEXT and not " ou " + m.group("Msif_23") + " " + m.group("Msif_24") + "icas" in TEXT and not "s de " + m.group("Msif_23") + " " + m.group("Msif_24") + "icas" in TEXT and not "s da " + m.group("Msif_23") + " " + m.group("Msif_24") + "icas" in TEXT and not " a " + m.group("Msif_23") + " " + m.group("Msif_24") + "icas" in TEXT and not m.group("Msif_23") + "-" + m.group("Msif_24") + "icas" in tCompostops and not (m.group("Msif_23") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_25>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_25").lower() in plvrFema and not " e " + m.group("Msif_25") + " " + m.group("Msif_26") + "icas" in TEXT and not " ou " + m.group("Msif_25") + " " + m.group("Msif_26") + "icas" in TEXT and not "s de " + m.group("Msif_25") + " " + m.group("Msif_26") + "icas" in TEXT and not "s da " + m.group("Msif_25") + " " + m.group("Msif_26") + "icas" in TEXT and not " a " + m.group("Msif_25") + " " + m.group("Msif_26") + "icas" in TEXT and not m.group("Msif_25") + "-" + m.group("Msif_26") + "icas" in tCompostops and not (m.group("Msif_25") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_27>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_27").lower() in plvrFema and not " e " + m.group("Msif_27") + " " + m.group("Msif_28") + "escas" in TEXT and not " ou " + m.group("Msif_27") + " " + m.group("Msif_28") + "escas" in TEXT and not "s de " + m.group("Msif_27") + " " + m.group("Msif_28") + "escas" in TEXT and not "s da " + m.group("Msif_27") + " " + m.group("Msif_28") + "escas" in TEXT and not " a " + m.group("Msif_27") + " " + m.group("Msif_28") + "escas" in TEXT and not m.group("Msif_27") + "-" + m.group("Msif_28") + "escas" in tCompostops and not (m.group("Msif_27") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_29>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_29").lower() in plvrFema and not " e " + m.group("Msif_29") + " " + m.group("Msif_30") + "idas" in TEXT and not " ou " + m.group("Msif_29") + "s " + m.group("Msif_30") + "idas" in TEXT and not "s de " + m.group("Msif_29") + "s " + m.group("Msif_30") + "idas" in TEXT and not "s da " + m.group("Msif_29") + "s " + m.group("Msif_30") + "idas" in TEXT and not " a " + m.group("Msif_29") + "s " + m.group("Msif_30") + "idas" in TEXT and not m.group("Msif_29") + "-" + m.group("Msif_30") + "idas" in tCompostops and not (m.group("Msif_29") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_31>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_31").lower() in plvrFema and not " e " + m.group("Msif_31") + " " + m.group("Msif_32") + "logas" in TEXT and not " ou " + m.group("Msif_31") + " " + m.group("Msif_32") + "logas" in TEXT and not "s de " + m.group("Msif_31") + " " + m.group("Msif_32") + "logas" in TEXT and not "s da " + m.group("Msif_31") + " " + m.group("Msif_32") + "logas" in TEXT and not " a " + m.group("Msif_31") + " " + m.group("Msif_32") + "logas" in TEXT and not m.group("Msif_31") + "-" + m.group("Msif_32") + "logas" in tCompostops and not (m.group("Msif_31") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_33>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_33").lower() in plvrFema and not " e " + m.group("Msif_33") + " " + m.group("Msif_34") + "rias" in TEXT and not " ou " + m.group("Msif_33") + " " + m.group("Msif_34") + "rias" in TEXT and not "s de " + m.group("Msif_33") + " " + m.group("Msif_34") + "rias" in TEXT and not "s da " + m.group("Msif_33") + " " + m.group("Msif_34") + "rias" in TEXT and not " a " + m.group("Msif_33") + " " + m.group("Msif_34") + "rias" in TEXT and not m.group("Msif_33") + "-" + m.group("Msif_34") + "rias" in tCompostops and not (m.group("Msif_33") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_35>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_35").lower() in plvrFema and not " e " + m.group("Msif_35") + " " + m.group("Msif_36") + "ssimas" in TEXT and not " ou " + m.group("Msif_35") + " " + m.group("Msif_36") + "ssimas" in TEXT and not "s de " + m.group("Msif_35") + " " + m.group("Msif_36") + "ssimas" in TEXT and not "s da " + m.group("Msif_35") + " " + m.group("Msif_36") + "ssimas" in TEXT and not " a " + m.group("Msif_35") + " " + m.group("Msif_36") + "ssimas" in TEXT and not m.group("Msif_35") + "-" + m.group("Msif_36") + "ssimas" in tCompostops and not (m.group("Msif_35") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_37>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_37").lower() in plvrFema and not " e " + m.group("Msif_37") + " " + m.group("Msif_38") + "simas" in TEXT and not " ou " + m.group("Msif_37") + " " + m.group("Msif_38") + "simas" in TEXT and not "s de " + m.group("Msif_37") + " " + m.group("Msif_38") + "simas" in TEXT and not "s da " + m.group("Msif_37") + " " + m.group("Msif_38") + "simas" in TEXT and not " a " + m.group("Msif_37") + " " + m.group("Msif_38") + "simas" in TEXT and not m.group("Msif_37") + "-" + m.group("Msif_38") + "simas" in tCompostops and not (m.group("Msif_37") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_41>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_41").lower() in plvrFema and not m.group("Msif_42") in "D-d-" and not " e " + m.group("Msif_41") + " " + m.group("Msif_42") + "oras" in TEXT and not " ou " + m.group("Msif_41") + " " + m.group("Msif_42") + "oras" in TEXT and not "s de " + m.group("Msif_41") + " " + m.group("Msif_42") + "oras" in TEXT and not "s da " + m.group("Msif_41") + " " + m.group("Msif_42") + "oras" in TEXT and not " a " + m.group("Msif_41") + " " + m.group("Msif_42") + "oras" in TEXT and not m.group("Msif_41") + "-" + m.group("Msif_42") + "oras" in tCompostops and not (m.group("Msif_41") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_43>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_43").lower() in plvrFema and m.group("Msif_44") in plvrMfr and not " e " + m.group("Msif_43") + " " + m.group("Msif_44") + "es" in TEXT and not " ou " + m.group("Msif_43") + " " + m.group("Msif_44") + "es" in TEXT and not "s de " + m.group("Msif_43") + " " + m.group("Msif_44") + "es" in TEXT and not "s da " + m.group("Msif_43") + " " + m.group("Msif_44") + "es" in TEXT and not " a " + m.group("Msif_43") + " " + m.group("Msif_44") + "es" in TEXT and not m.group("Msif_43") + "-" + m.group("Msif_44") + "es" in tCompostops and not (m.group("Msif_43") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_45>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_45").lower() in plvrFema and m.group("Msif_46") in plvrFemr and not " e " + m.group("Msif_45") + " " + m.group("Msif_46") + "es" in TEXT and not " ou " + m.group("Msif_45") + " " + m.group("Msif_46") + "es" in TEXT and not "s de " + m.group("Msif_45") + " " + m.group("Msif_46") + "es" in TEXT and not "s da " + m.group("Msif_45") + " " + m.group("Msif_46") + "es" in TEXT and not " a " + m.group("Msif_45") + " " + m.group("Msif_46") + "es" in TEXT and not m.group("Msif_45") + "-" + m.group("Msif_46") + "es" in tCompostops and not (m.group("Msif_45") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_47>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_47").lower() in plvrFema and m.group("Msif_48") in plvrMfal and not " e " + m.group("Msif_47") + " " + m.group("Msif_48") + "is" in TEXT and not " ou " + m.group("Msif_47") + " " + m.group("Msif_48") + "is" in TEXT and not "s de " + m.group("Msif_47") + " " + m.group("Msif_48") + "is" in TEXT and not "s da " + m.group("Msif_47") + " " + m.group("Msif_48") + "is" in TEXT and not " a " + m.group("Msif_47") + " " + m.group("Msif_48") + "is" in TEXT and not m.group("Msif_47") + "-" + m.group("Msif_48") + "is" in tCompostops and not (m.group("Msif_47") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_49>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_49").lower() in plvrFema and m.group("Msif_50") in plvrMfcao and not " e " + m.group("Msif_49") + " " + m.group("Msif_50") + "ões" in TEXT and not + " ou " + m.group("Msif_49") + " " + m.group("Msif_50") + "ões" in TEXT and not + "s de " + m.group("Msif_49") + " " + m.group("Msif_50") + "ões" in TEXT and not + "s da " + m.group("Msif_49") + " " + m.group("Msif_50") + "ões" in TEXT and not + " a " + m.group("Msif_49") + " " + m.group("Msif_50") + "ões" in TEXT and not m.group("Msif_49") + "-" + m.group("Msif_50") + "ões" in tCompostops and not (m.group("Msif_49") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_51>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_51").lower() in plvrFema and not m.group("Msif_52") in plvrMascao and not " e " + m.group("Msif_51") + " " + m.group("Msif_52") + "ões" in TEXT and not " ou " + m.group("Msif_51") + " " + m.group("Msif_52") + "ões" in TEXT and not "s de " + m.group("Msif_51") + " " + m.group("Msif_52") + "ões" in TEXT and not "s da " + m.group("Msif_51") + " " + m.group("Msif_52") + "ões" in TEXT and not " a " + m.group("Msif_51") + " " + m.group("Msif_52") + "ões" in TEXT and not m.group("Msif_51") + "-" + m.group("Msif_52") + "ões" in tCompostops and not (m.group("Msif_51") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_53>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_53").lower() in plvrFema and m.group("Msif_54") in plvrFemao and not " e " + m.group("Msif_53") + " " + m.group("Msif_54") + "ões" in TEXT and not " ou " + m.group("Msif_53") + " " + m.group("Msif_54") + "ões" in TEXT and not "s de " + m.group("Msif_53") + " " + m.group("Msif_54") + "ões" in TEXT and not "s da " + m.group("Msif_53") + " " + m.group("Msif_54") + "ões" in TEXT and not " a " + m.group("Msif_53") + " " + m.group("Msif_54") + "ões" in TEXT and not (m.group("Msif_53") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_55>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_55").lower() in plvrFema and not " e " + m.group("Msif_55") + " " + m.group("Msif_56") + "veis" in TEXT and not " ou " + m.group("Msif_55") + " " + m.group("Msif_56") + "veis" in TEXT and not "s de " + m.group("Msif_55") + " " + m.group("Msif_56") + "veis" in TEXT and not "s da " + m.group("Msif_55") + " " + m.group("Msif_56") + "veis" in TEXT and not " a " + m.group("Msif_55") + " " + m.group("Msif_56") + "veis" in TEXT and not m.group("Msif_55") + "-" + m.group("Msif_56") + "veis" in tCompostops and not (m.group("Msif_55") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_57>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_57").lower() in plvrFema and m.group("Msif_58").lower() in plvrMfe and not " e " + m.group("Msif_57") + " " + m.group("Msif_58") + "es" in TEXT and not " ou " + m.group("Msif_57") + " " + m.group("Msif_58") + "es" in TEXT and not "s de " + m.group("Msif_57") + " " + m.group("Msif_58") + "es" in TEXT and not "s da " + m.group("Msif_57") + " " + m.group("Msif_58") + "es" in TEXT and not " a " + m.group("Msif_57") + " " + m.group("Msif_58") + "es" in TEXT and not m.group("Msif_57") + "-" + m.group("Msif_58") + "es" in tCompostops and not (m.group("Msif_57") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_59>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_59").lower() in plvrFema and m.group("Msif_60").lower() in plvrFeme and not " e " + m.group("Msif_59") + " " + m.group("Msif_60") + "es" in TEXT and not " ou " + m.group("Msif_59") + " " + m.group("Msif_60") + "es" in TEXT and not "s de " + m.group("Msif_59") + " " + m.group("Msif_60") + "es" in TEXT and not "s da " + m.group("Msif_59") + " " + m.group("Msif_60") + "es" in TEXT and not " a " + m.group("Msif_59") + " " + m.group("Msif_60") + "es" in TEXT and not m.group("Msif_59") + "-" + m.group("Msif_60") + "es" in tCompostops and not (m.group("Msif_59") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_61>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_61").lower() in plvrFema and m.group("Msif_62") in plvrMfel and not " e " + m.group("Msif_61") + " " + m.group("Msif_62") + "éis" in TEXT and not " ou " + m.group("Msif_61") + " " + m.group("Msif_62") + "éis" in TEXT and not "s de " + m.group("Msif_61") + " " + m.group("Msif_62") + "éis" in TEXT and not "s da " + m.group("Msif_61") + " " + m.group("Msif_62") + "éis" in TEXT and not " a " + m.group("Msif_61") + " " + m.group("Msif_62") + "éis" in TEXT and not m.group("Msif_61") + "-" + m.group("Msif_62") + "éis" in tCompostops and not (m.group("Msif_61") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_63>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_63").lower() in plvrFema and m.group("Msif_64") in plvrFemel and not " e " + m.group("Msif_63") + " " + m.group("Msif_64") + "éis" in TEXT and not " ou " + m.group("Msif_63") + " " + m.group("Msif_64") + "éis" in TEXT and not "s de " + m.group("Msif_63") + " " + m.group("Msif_64") + "éis" in TEXT and not "s da " + m.group("Msif_63") + " " + m.group("Msif_64") + "éis" in TEXT and not " a " + m.group("Msif_63") + " " + m.group("Msif_64") + "éis" in TEXT and not m.group("Msif_63") + "-" + m.group("Msif_64") + "éis" in tCompostops and not (m.group("Msif_63") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_65>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_65").lower() in plvrFema and m.group("Msif_66") in plvrMfeu and not " e " + m.group("Msif_65") + " " + m.group("Msif_66") + "us" in TEXT and not " ou " + m.group("Msif_65") + " " + m.group("Msif_66") + "us" in TEXT and not "s de " + m.group("Msif_65") + " " + m.group("Msif_66") + "us" in TEXT and not "s da " + m.group("Msif_65") + " " + m.group("Msif_66") + "us" in TEXT and not " a " + m.group("Msif_65") + " " + m.group("Msif_66") + "us" in TEXT and not m.group("Msif_65") + "-" + m.group("Msif_66") + "us" in tCompostops and not (m.group("Msif_65") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_67>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_67").lower() in plvrFema and m.group("Msif_68") in plvrFemu and not " e " + m.group("Msif_67") + " " + m.group("Msif_68") + "us" in TEXT and not " ou " + m.group("Msif_67") + " " + m.group("Msif_68") + "us" in TEXT and not "s de " + m.group("Msif_67") + " " + m.group("Msif_68") + "us" in TEXT and not "s da " + m.group("Msif_67") + " " + m.group("Msif_68") + "us" in TEXT and not " a " + m.group("Msif_67") + " " + m.group("Msif_68") + "us" in TEXT and not m.group("Msif_67") + "-" + m.group("Msif_68") + "us" in tCompostops and not (m.group("Msif_67") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_69>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_69").lower() in plvrFema and m.group("Msif_70") in plvrInvaz and not " e " + m.group("Msif_69") + " " + m.group("Msif_70") + "zes" in TEXT and not " ou " + m.group("Msif_69") + " " + m.group("Msif_70") + "zes" in TEXT and not "s de " + m.group("Msif_69") + " " + m.group("Msif_70") + "zes" in TEXT and not "s da " + m.group("Msif_69") + " " + m.group("Msif_70") + "zes" in TEXT and not " a " + m.group("Msif_69") + " " + m.group("Msif_70") + "zes" in TEXT and not m.group("Msif_69") + "-" + m.group("Msif_70") + "zes" in tCompostops and not (m.group("Msif_69") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_71>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_71").lower() in plvrFema and m.group("Msif_72") in plvrFemz and not " e " + m.group("Msif_71") + " " + m.group("Msif_72") + "zes" in TEXT and not " ou " + m.group("Msif_71") + " " + m.group("Msif_72") + "zes" in TEXT and not "s de " + m.group("Msif_71") + " " + m.group("Msif_72") + "zes" in TEXT and not "s da " + m.group("Msif_71") + " " + m.group("Msif_72") + "zes" in TEXT and not " a " + m.group("Msif_71") + " " + m.group("Msif_72") + "zes" in TEXT and not m.group("Msif_71") + "-" + m.group("Msif_72") + "zes" in tCompostops and not (m.group("Msif_71") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_73>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_73").lower() in plvrFema and m.group("Msif_74") in pvrFeman and not " e " + m.group("Msif_73") + " " + m.group("Msif_74") + "s" in TEXT and not " ou " + m.group("Msif_73") + " " + m.group("Msif_74") + "s" in TEXT and not "s de " + m.group("Msif_73") + " " + m.group("Msif_74") + "s" in TEXT and not "s da " + m.group("Msif_73") + " " + m.group("Msif_74") + "s" in TEXT and not " a " + m.group("Msif_73") + " " + m.group("Msif_74") + "s" in TEXT and not m.group("Msif_73") + "-" + m.group("Msif_74") + "s" in tCompostops and not (m.group("Msif_73") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_75>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_76>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_75").lower() in plvrFema and m.group("Msif_76") in plvrMFm and not " e " + m.group("Msif_75") + " " + m.group("Msif_76") + "ns" in TEXT and not " ou " + m.group("Msif_75") + " " + m.group("Msif_76") + "ns" in TEXT and not "s de " + m.group("Msif_75") + " " + m.group("Msif_76") + "ns" in TEXT and not "s da " + m.group("Msif_75") + " " + m.group("Msif_76") + "ns" in TEXT and not " a " + m.group("Msif_75") + " " + m.group("Msif_76") + "ns" in TEXT and not m.group("Msif_75") + "-" + m.group("Msif_76") + "ns" in tCompostops and not (m.group("Msif_75") in "maioria-maneira" and excMaioria.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msif_77>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msif_78>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msif_77").lower() in plvrFema and m.group("Msif_78") in plvrFemm and not " e " + m.group("Msif_77") + " " + m.group("Msif_78") + "ns" in TEXT and not " ou " + m.group("Msif_77") + " " + m.group("Msif_78") + "ns" in TEXT and not "s de " + m.group("Msif_77") + " " + m.group("Msif_78") + "ns" in TEXT and not "s da " + m.group("Msif_77") + " " + m.group("Msif_78") + "ns" in TEXT and not " a " + m.group("Msif_77") + " " + m.group("Msif_78") + "ns" in TEXT and not m.group("Msif_77") + "-" + m.group("Msif_78") + "ns" in tCompostops and not (m.group("Msif_77") in "maioria-maneira" and excMaioria.search(TEXT))'],
# dade
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_1>[a-zA-Z]+)dade (?P<Msdd_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_2").lower() in plvrFema and not " e " + m.group("Msdd_1") + "dade " + m.group("Msdd_2") +"s" in TEXT and not " de " + m.group("Msdd_1") + "dade " + m.group("Msdd_2") + "s" in TEXT and not " ou " + m.group("Msdd_1") + "dade " + m.group("Msdd_2") + "s" in TEXT and not m.group("Msdd_1") + "dade-" + m.group("Msdd_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_3>[a-zA-Z]+)dade (?P<Msdd_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_4").lower() in plvrMfoa and not " e " + m.group("Msdd_3") + "dade " + m.group("Msdd_4") + "as" in TEXT and not " ou " + m.group("Msdd_3") + "dade " + m.group("Msdd_4") + "as" in TEXT and not " de " + m.group("Msdd_3") + "dade " + m.group("Msdd_4") + "as" in TEXT and not m.group("Msdd_3") + "dade-" + m.group("Msdd_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_5>[a-zA-Z]+)dade (?P<Msdd_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msdd_6").lower() in excAdo and not " e " + m.group("Msdd_5") + "dade " + m.group("Msdd_6") + "dos" in TEXT and not " ou " + m.group("Msdd_5") + "dade " + m.group("Msdd_6") + "dos" in TEXT and not " de " + m.group("Msdd_5") + "dade " + m.group("Msdd_6") in TEXT and not m.group("Msdd_5") + "dade-" + m.group("Msdd_6") + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_7>[a-zA-Z]+)dade (?P<Msdd_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msdd_8").lower() in excIsta and not " e " + m.group("Msdd_7") + "dade " + m.group("Msdd_8") + "s" in TEXT and not " ou " + m.group("Msdd_7") + "dade " + m.group("Msdd_8") + "s" in TEXT and not " de " + m.group("Msdd_7") + "dade " + m.group("Msdd_8") + "s" in TEXT and not m.group("Msdd_7") + "dade-" + m.group("Msdd_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_9>[a-zA-Z]+)dade (?P<Msdd_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_10").lower() in plvrInva and not " e " + m.group("Msdd_9") + "dade " + m.group("Msdd_10") + "s" in TEXT and not " ou " + m.group("Msdd_9") + "dade " + m.group("Msdd_10") + "s" in TEXT and not " de " + m.group("Msdd_9") + "dade " + m.group("Msdd_10") + "s" in TEXT and not m.group("Msdd_9") + "dade-" + m.group("Msdd_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_11>[a-zA-Z]+)dade (?P<Msdd_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msdd_12").lower() in excAdo and not " e " + m.group("Msdd_11") + "dade " + m.group("Msdd_12") + "das" in TEXT and not " ou " + m.group("Msdd_11") + "dade " + m.group("Msdd_12") + "das" in TEXT and not " de " + m.group("Msdd_11") + "dade " + m.group("Msdd_12") + "s" in TEXT and not m.group("Msdd_11") + "dade-" + m.group("Msdd_12") + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_13>[a-zA-Z]+)dade (?P<Msdd_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msdd_13") + "dade " + m.group("Msdd_14") + "osos" in TEXT and not " ou " + m.group("Msdd_13") + "dade " + m.group("Msdd_14") + "osos" in TEXT and not " de " + m.group("Msdd_13") + "dade " + m.group("Msdd_14") + "s" in TEXT and not m.group("Msdd_13") + "dade-" + m.group("Msdd_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_15>[a-zA-Z]+)dade (?P<Msdd_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msdd_15") + "dade " + m.group("Msdd_16") + "osas" in TEXT and not " ou " + m.group("Msdd_15") + "dade " + m.group("Msdd_16") + "osas" in TEXT and not " de " + m.group("Msdd_15") + "dade " + m.group("Msdd_16") + "s" in TEXT and not m.group("Msdd_15") + "dade-" + m.group("Msdd_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_17>[a-zA-Z]+)dade (?P<Msdd_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msdd_17") + "dade " + m.group("Msdd_18") + "ivas" in TEXT and not " ou " + m.group("Msdd_17") + "dade " + m.group("Msdd_18") + "ivas" in TEXT and not " de " + m.group("Msdd_17") + "dade " + m.group("Msdd_18") + "s" in TEXT and not m.group("Msdd_17") + "dade-" + m.group("Msdd_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_19>[a-zA-Z]+)dade (?P<Msdd_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msdd_19") + "dade " + m.group("Msdd_20") + "ivas" in TEXT and not " ou " + m.group("Msdd_19") + "dade " + m.group("Msdd_20") + "ivas" in TEXT and not " de " + m.group("Msdd_19") + "dade " + m.group("Msdd_20") + "s" in TEXT and not m.group("Msdd_19") + "dade-" + m.group("Msdd_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_21>[a-zA-Z]+)dade (?P<Msdd_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msdd_21") + "dade " + m.group("Msdd_22") + "icas" in TEXT and not " ou " + m.group("Msdd_21") + "dade " + m.group("Msdd_22") + "icas" in TEXT and not " de " + m.group("Msdd_21") + "dade " + m.group("Msdd_22") + "s" in TEXT and not m.group("Msdd_21") + "dade-" + m.group("Msdd_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_23>[a-zA-Z]+)dade (?P<Msdd_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msdd_23") + "dade " + m.group("Msdd_24") + "icas" in TEXT and not " ou " + m.group("Msdd_23") + "dade " + m.group("Msdd_24") + "icas" in TEXT and not " de " + m.group("Msdd_23") + "dade " + m.group("Msdd_24") + "s" in TEXT and not m.group("Msdd_23") + "dade-" + m.group("Msdd_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_25>[a-zA-Z]+)dade (?P<Msdd_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msdd_25") + "dade " + m.group("Msdd_26") + "icas" in TEXT and not " ou " + m.group("Msdd_25") + "dade " + m.group("Msdd_26") + "icas" in TEXT and not " de " + m.group("Msdd_25") + "dade " + m.group("Msdd_26") + "s" in TEXT and not m.group("Msdd_25") + "dade-" + m.group("Msdd_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_27>[a-zA-Z]+)dade (?P<Msdd_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msdd_27") + "dade " + m.group("Msdd_28") + "escas" in TEXT and not " ou " + m.group("Msdd_27") + "dade " + m.group("Msdd_28") + "escas" in TEXT and not " de " + m.group("Msdd_27") + "dade " + m.group("Msdd_28") + "s" in TEXT and not m.group("Msdd_27") + "dade-" + m.group("Msdd_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_29>[a-zA-Z]+)dade (?P<Msdd_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msdd_29") + "dade " + m.group("Msdd_30") + "idas" in TEXT and not " ou " + m.group("Msdd_29") + "dades " + m.group("Msdd_30") + "idas" in TEXT and not " de " + m.group("Msdd_29") + "dade " + m.group("Msdd_30") + "s" in TEXT and not m.group("Msdd_29") + "dade-" + m.group("Msdd_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_31>[a-zA-Z]+)dade (?P<Msdd_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msdd_31") + "dade " + m.group("Msdd_32") + "logas" in TEXT and not " ou " + m.group("Msdd_31") + "dade " + m.group("Msdd_32") + "logas" in TEXT and not " de " + m.group("Msdd_31") + "dade " + m.group("Msdd_32") + "s" in TEXT and not m.group("Msdd_31") + "dade-" + m.group("Msdd_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_33>[a-zA-Z]+)dade (?P<Msdd_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msdd_33") + "dade " + m.group("Msdd_34") + "rias" in TEXT and not " ou " + m.group("Msdd_33") + "dade " + m.group("Msdd_34") + "rias" in TEXT and not " de " + m.group("Msdd_33") + "dade " + m.group("Msdd_34") +"s" in TEXT and not m.group("Msdd_33") + "dade-" + m.group("Msdd_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_35>[a-zA-Z]+)dade (?P<Msdd_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msdd_35") + "dade " + m.group("Msdd_36") + "ssimas" in TEXT and not " ou " + m.group("Msdd_35") + "dade " + m.group("Msdd_36") + "ssimas" in TEXT and not " de " + m.group("Msdd_35") + "dade " + m.group("Msdd_36") + "s" in TEXT and not m.group("Msdd_35") + "dade-" + m.group("Msdd_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_37>[a-zA-Z]+)dade (?P<Msdd_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msdd_37") + "dade " + m.group("Msdd_38") + "simas" in TEXT and not " ou " + m.group("Msdd_37") + "dade " + m.group("Msdd_38") + "simas" in TEXT and not " de " + m.group("Msdd_37") + "dade " + m.group("Msdd_38") + "s" in TEXT and not m.group("Msdd_37") + "dade-" + m.group("Msdd_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_41>[a-zA-Z]+)dade (?P<Msdd_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msdd_42") in "D-d-" and not " e " + m.group("Msdd_41") + "dade " + m.group("Msdd_42") + "oras" in TEXT and not " ou " + m.group("Msdd_41") + "dade " + m.group("Msdd_42") + "oras" in TEXT and not " de " + m.group("Msdd_41") + "dade " + m.group("Msdd_42") + "oras" in TEXT and not m.group("Msdd_41") + "dade-" + m.group("Msdd_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_43>[a-zA-Z]+)dade (?P<Msdd_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_44") in plvrMfr and not " e " + m.group("Msdd_43") + "dade " + m.group("Msdd_44") + "es" in TEXT and not " ou " + m.group("Msdd_43") + "dade " + m.group("Msdd_44") + "es" in TEXT and not " de " + m.group("Msdd_43") + "dade " + m.group("Msdd_44") + "es" in TEXT and not m.group("Msdd_43") + "dade-" + m.group("Msdd_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_45>[a-zA-Z]+)dade (?P<Msdd_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_46") in plvrFemr and not " e " + m.group("Msdd_45") + "dade " + m.group("Msdd_46") + "es" in TEXT and not " ou " + m.group("Msdd_45") + "dade " + m.group("Msdd_46") + "es" in TEXT and not " de " + m.group("Msdd_45") + "dade " + m.group("Msdd_46") + "es" in TEXT and not m.group("Msdd_45") + "dade-" + m.group("Msdd_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_47>[a-zA-Z]+)dade (?P<Msdd_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_48") in plvrMfal and not " e " + m.group("Msdd_47") + "dade " + m.group("Msdd_48") + "is" in TEXT and not " ou " + m.group("Msdd_47") + "dade " + m.group("Msdd_48") + "is" in TEXT and not " de " + m.group("Msdd_47") + "dade " + m.group("Msdd_48) + "is" in TEXT and not m.group("Msdd_47") + "dade-" + m.group("Msdd_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_49>[a-zA-Z]+)dade (?P<Msdd_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_50") in plvrMfcao and not " e " + m.group("Msdd_49") + "dade " + m.group("Msdd_50") + "ões" in TEXT and not + " ou " + m.group("Msdd_49") + "dade " + m.group("Msdd_50") + "ões" in TEXT and not " de " + m.group("Msdd_49") + "dade " + m.group("Msdd_50") in TEXT and not m.group("Msdd_49") + "dade-" + m.group("Msdd_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_51>[a-zA-Z]+)dade (?P<Msdd_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msdd_52") in plvrMascao and not " e " + m.group("Msdd_51") + "dade " + m.group("Msdd_52") + "ões" in TEXT and not " ou " + m.group("Msdd_51") + "dade " + m.group("Msdd_52") + "ões" in TEXT and not " de " + m.group("Msdd_51") + "dade " + m.group("Msdd_52") in TEXT and not m.group("Msdd_51") + "dade-" + m.group("Msdd_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_53>[a-zA-Z]+)dade (?P<Msdd_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_54") in plvrFemao and not " e " + m.group("Msdd_53") + "dade " + m.group("Msdd_54") + "ões" in TEXT and not " de " + m.group("Msdd_53") + "dade " + m.group("Msdd_54") in TEXT and not " ou " + m.group("Msdd_53") + "dade " + m.group("Msdd_54") + "ões" in TEXT and not m.group("Msdd_53") + "dade-" + m.group("Msdd_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_55>[a-zA-Z]+)dade (?P<Msdd_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msdd_55") + "dade " + m.group("Msdd_56") + "veis" in TEXT and " ou " + not m.group("Msdd_55") + "dade " + m.group("Msdd_56") + "veis" in TEXT and not " de " + m.group("Msdd_55") + "dade " + m.group("Msdd_56") in TEXT and not m.group("Msdd_55") + "dade-" + m.group("Msdd_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_57>[a-zA-Z]+)dade (?P<Msdd_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_58").lower() in plvrMfe and not " e " + m.group("Msdd_57") + "dade " + m.group("Msdd_58") + "es" in TEXT and not " ou " + m.group("Msdd_57") + "dade " + m.group("Msdd_58") + "es" in TEXT and not " de " + m.group("Msdd_57") + "dade " + m.group("Msdd_58") + "es" in TEXT and not m.group("Msdd_57") + "dade-" + m.group("Msdd_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_59>[a-zA-Z]+)dade (?P<Msdd_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_60").lower() in plvrFeme and not " e " + m.group("Msdd_59") + "dade " + m.group("Msdd_60") + "es" in TEXT and not " ou " + m.group("Msdd_59") + "dade " + m.group("Msdd_60") + "es" in TEXT and not " de " + m.group("Msdd_59") + "dade " + m.group("Msdd_60") + "es" in TEXT and not m.group("Msdd_59") + "dade-" + m.group("Msdd_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_61>[a-zA-Z]+)dade (?P<Msdd_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_62") in plvrMfel and not " e " + m.group("Msdd_61") + "dade " + m.group("Msdd_62") + "éis" in TEXT and not " ou " + m.group("Msdd_61") + "dade " + m.group("Msdd_62") + "éis" in TEXT and not " de " + m.group("Msdd_61") + "dade " + m.group("Msdd_62") in TEXT and not m.group("Msdd_61") + "dade-" + m.group("Msdd_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_63>[a-zA-Z]+)dade (?P<Msdd_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_64") in plvrFemel and not " e " + m.group("Msdd_63") + "dade " + m.group("Msdd_64") + "éis" in TEXT and not " ou " + m.group("Msdd_63") + "dade " + m.group("Msdd_64") + "éis" in TEXT and not " de " + m.group("Msdd_63") + "dade " + m.group("Msdd_64") in TEXT and not m.group("Msdd_63") + "dade-" + m.group("Msdd_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_65>[a-zA-Z]+)dade (?P<Msdd_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_66") in plvrMfeu and not " e " + m.group("Msdd_65") + "dade " + m.group("Msdd_66") + "us" in TEXT and not " ou " + m.group("Msdd_65") + "dade " + m.group("Msdd_66") + "us" in TEXT and not " de " + m.group("Msdd_65") + "dade " + m.group("Msdd_66") in TEXT and not m.group("Msdd_65") + "dade-" + m.group("Msdd_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_67>[a-zA-Z]+)dade (?P<Msdd_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_68") in plvrFemu and not " e " + m.group("Msdd_67") + "dade " + m.group("Msdd_68") + "us" in TEXT and not " ou " + m.group("Msdd_67") + "dade " + m.group("Msdd_68") + "us" in TEXT and not " de " + m.group("Msdd_67") + "dade " + m.group("Msdd_68") in TEXT and not m.group("Msdd_67") + "dade-" + m.group("Msdd_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_69>[a-zA-Z]+)dade (?P<Msdd_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_70") in plvrInvaz and not " e " + m.group("Msdd_69") + "dade " + m.group("Msdd_70") + "zes" in TEXT and not " ou " + m.group("Msdd_69") + "dade " + m.group("Msdd_70") + "zes" in TEXT and not " de " + m.group("Msdd_69") + "dade " + m.group("Msdd_70") in TEXT and not m.group("Msdd_69") + "dade-" + m.group("Msdd_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_71>[a-zA-Z]+)dade (?P<Msdd_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_72") in plvrFemz and not " e " + m.group("Msdd_71") + "dade " + m.group("Msdd_72") + "zes" in TEXT and not " ou " + m.group("Msdd_71") + "dade " + m.group("Msdd_72") + "zes" in TEXT and not " de " + m.group("Msdd_71") + "dade " + m.group("Msdd_72") in TEXT and not m.group("Msdd_71") + "dade-" + m.group("Msdd_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_75>[a-zA-Z]+)dade (?P<Msdd_76>[a-záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_76") in plvrMFm and not " e " + m.group("Msdd_75") + "dade " + m.group("Msdd_76") + "ns" in TEXT and not " ou " + m.group("Msdd_75") + "dade " + m.group("Msdd_76") + "ns" in TEXT and not " de " + m.group("Msdd_75") + "dade " + m.group("Msdd_76") in TEXT and not m.group("Msdd_75") + "dade-" + m.group("Msdd_76") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msdd_77>[a-zA-Z]+)dade (?P<Msdd_78>[a-záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msdd_78") in plvrFemm and not " e " + m.group("Msdd_77") + "dade " + m.group("Msdd_78") + "ns" in TEXT and not " ou " + m.group("Msdd_77") + "dade " + m.group("Msdd_78") + "ns" in TEXT and not " de " + m.group("Msdd_77") + "dade " + m.group("Msdd_78") in TEXT and not m.group("Msdd_77") + "dade-" + m.group("Msdd_78") + "ns" in tCompostops'],
# plvrMasca
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_1>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_1").lower() in plvrMasca and m.group("Msma_2").lower() in plvrMasca and not " e " + m.group("Msma_1") + " " + m.group("Msma_2") +"s" in TEXT and not " ou " + m.group("Msma_1") + " " + m.group("Msma_2") + "s" in TEXT and not "s de " + m.group("Msma_1") + " " + m.group("Msma_2") + "s" in TEXT and not "s do " + m.group("Msma_1") + " " + m.group("Msma_2") + "s" in TEXT and not " o " + m.group("Msma_1") + " " + m.group("Msma_2") + "s" in TEXT and not m.group("Msma_1") + "-" + m.group("Msma_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_3>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_3").lower() in plvrMasca and m.group("Msma_4").lower() in plvrMfoa and not " e " + m.group("Msma_3") + " " + m.group("Msma_4") + "os" in TEXT and not " ou " + m.group("Msma_3") + " " + m.group("Msma_4") + "os" in TEXT and not "s de " + m.group("Msma_3") + " " + m.group("Msma_4") + "os" in TEXT and not "s do " + m.group("Msma_3") + " " + m.group("Msma_4") + "os" in TEXT and not " o " + m.group("Msma_3") + " " + m.group("Msma_4") + "os" in TEXT and not m.group("Msma_3") + "-" + m.group("Msma_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_5>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_5").lower() in plvrMasca and not m.group("Msma_6").lower() in excAdo and not " e " + m.group("Msma_5") + " " + m.group("Msma_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msma_5") + " " + m.group("Msma_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msma_5") + " " + m.group("Msma_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msma_5") + " " + m.group("Msma_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msma_5") + " " + m.group("Msma_6") + m.group(3) + "dos" in TEXT and not m.group("Msma_5") + "-" + m.group("Msma_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_7>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_7").lower() in plvrMasca and not m.group("Msma_8").lower() in excIsta and not " e " + m.group("Msma_7") + " " + m.group("Msma_8") + "s" in TEXT and not " ou " + m.group("Msma_7") + " " + m.group("Msma_8") + "s" in TEXT and not "s de " + m.group("Msma_7") + " " + m.group("Msma_8") + "s" in TEXT and not "s do " + m.group("Msma_7") + " " + m.group("Msma_8") + "s" in TEXT and not " o " + m.group("Msma_7") + " " + m.group("Msma_8") + "s" in TEXT and not m.group("Msma_7") + "-" + m.group("Msma_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_9>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_9").lower() in plvrMasca and m.group("Msma_10").lower() in plvrInva and not " e " + m.group("Msma_9") + " " + m.group("Msma_10") + "s" in TEXT and not " ou " + m.group("Msma_9") + " " + m.group("Msma_10") + "s" in TEXT and not "s de " + m.group("Msma_9") + " " + m.group("Msma_10") + "s" in TEXT and not "s do " + m.group("Msma_9") + " " + m.group("Msma_10") + "s" in TEXT and not " a " + m.group("Msma_9") + " " + m.group("Msma_10") + "s" in TEXT and not m.group("Msma_9") + "-" + m.group("Msma_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_11>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_11").lower() in plvrMasca and not m.group("Msma_12").lower() in excAdo and not " e " + m.group("Msma_11") + " " + m.group("Msma_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msma_11") + " " + m.group("Msma_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msma_11") + " " + m.group("Msma_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Msma_11") + " " + m.group("Msma_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Msma_11") + " " + m.group("Msma_12") + m.group(3) + "das" in TEXT and not m.group("Msma_11") + "-" + m.group("Msma_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_13>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_13").lower() in plvrMasca and not " e " + m.group("Msma_13") + " " + m.group("Msma_14") + "osos" in TEXT and not " ou " + m.group("Msma_13") + " " + m.group("Msma_14") + "osos" in TEXT and not "s de " + m.group("Msma_13") + " " + m.group("Msma_14") + "osos" in TEXT and not "s do " + m.group("Msma_13") + " " + m.group("Msma_14") + "osos" in TEXT and not " o " + m.group("Msma_13") + " " + m.group("Msma_14") + "osos" in TEXT and not m.group("Msma_13") + "-" + m.group("Msma_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_15>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_15").lower() in plvrMasca and not " e " + m.group("Msma_15") + " " + m.group("Msma_16") + "osas" in TEXT and not " ou " + m.group("Msma_15") + " " + m.group("Msma_16") + "osas" in TEXT and not "s de " + m.group("Msma_15") + " " + m.group("Msma_16") + "osas" in TEXT and not "s do " + m.group("Msma_15") + " " + m.group("Msma_16") + "osas" in TEXT and not " o " + m.group("Msma_15") + " " + m.group("Msma_16") + "osas" in TEXT and not m.group("Msma_15") + "-" + m.group("Msma_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_17>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_17").lower() in plvrMasca and not " e " + m.group("Msma_17") + " " + m.group("Msma_18") + "ivas" in TEXT and not " ou " + m.group("Msma_17") + " " + m.group("Msma_18") + "ivas" in TEXT and not "s de " + m.group("Msma_17") + " " + m.group("Msma_18") + "ivas" in TEXT and not "s do " + m.group("Msma_17") + " " + m.group("Msma_18") + "ivas" in TEXT and not " o " + m.group("Msma_17") + " " + m.group("Msma_18") + "ivas" in TEXT and not m.group("Msma_17") + "-" + m.group("Msma_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_19>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_19").lower() in plvrMasca and not " e " + m.group("Msma_19") + " " + m.group("Msma_20") + "ivas" in TEXT and not " ou " + m.group("Msma_19") + " " + m.group("Msma_20") + "ivas" in TEXT and not "s de " + m.group("Msma_19") + " " + m.group("Msma_20") + "ivas" in TEXT and not "s do " + m.group("Msma_19") + " " + m.group("Msma_20") + "ivas" in TEXT and not " o " + m.group("Msma_19") + " " + m.group("Msma_20") + "ivas" in TEXT and not m.group("Msma_19") + "-" + m.group("Msma_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_21>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_21").lower() in plvrMasca and not " e " + m.group("Msma_21") + " " + m.group("Msma_22") + "icos" in TEXT and not " ou " + m.group("Msma_21") + " " + m.group("Msma_22") + "icos" in TEXT and not "s de " + m.group("Msma_21") + " " + m.group("Msma_22") + "icos" in TEXT and not "s do " + m.group("Msma_21") + " " + m.group("Msma_22") + "icos" in TEXT and not " o " + m.group("Msma_21") + " " + m.group("Msma_22") + "icos" in TEXT and not m.group("Msma_21") + "-" + m.group("Msma_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_23>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_23").lower() in plvrMasca and not " e " + m.group("Msma_23") + " " + m.group("Msma_24") + "icos" in TEXT and not " ou " + m.group("Msma_23") + " " + m.group("Msma_24") + "icos" in TEXT and not "s de " + m.group("Msma_23") + " " + m.group("Msma_24") + "icos" in TEXT and not "s do " + m.group("Msma_23") + " " + m.group("Msma_24") + "icos" in TEXT and not " o " + m.group("Msma_23") + " " + m.group("Msma_24") + "icos" in TEXT and not m.group("Msma_23") + "-" + m.group("Msma_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_25>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_25").lower() in plvrMasca and not " e " + m.group("Msma_25") + " " + m.group("Msma_26") + "icos" in TEXT and not " ou " + m.group("Msma_25") + " " + m.group("Msma_26") + "icos" in TEXT and not "s de " + m.group("Msma_25") + " " + m.group("Msma_26") + "icos" in TEXT and not "s do " + m.group("Msma_25") + " " + m.group("Msma_26") + "icos" in TEXT and not " o " + m.group("Msma_25") + " " + m.group("Msma_26") + "icos" in TEXT and not m.group("Msma_25") + "-" + m.group("Msma_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_27>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_27").lower() in plvrMasca and not " e " + m.group("Msma_27") + " " + m.group("Msma_28") + "escos" in TEXT and not " ou " + m.group("Msma_27") + " " + m.group("Msma_28") + "escos" in TEXT and not "s de " + m.group("Msma_27") + " " + m.group("Msma_28") + "escos" in TEXT and not "s do " + m.group("Msma_27") + " " + m.group("Msma_28") + "escos" in TEXT and not " o " + m.group("Msma_27") + " " + m.group("Msma_28") + "escos" in TEXT and not m.group("Msma_27") + "-" + m.group("Msma_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_29>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_29").lower() in plvrMasca and not " e " + m.group("Msma_29") + " " + m.group("Msma_30") + "idos" in TEXT and not " ou " + m.group("Msma_29") + "s " + m.group("Msma_30") + "idos" in TEXT and not "s de " + m.group("Msma_29") + "s " + m.group("Msma_30") + "idos" in TEXT and not "s do " + m.group("Msma_29") + "s " + m.group("Msma_30") + "idos" in TEXT and not " o " + m.group("Msma_29") + "s " + m.group("Msma_30") + "idos" in TEXT and not m.group("Msma_29") + "-" + m.group("Msma_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_31>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_31").lower() in plvrMasca and not " e " + m.group("Msma_31") + " " + m.group("Msma_32") + "logos" in TEXT and not " ou " + m.group("Msma_31") + " " + m.group("Msma_32") + "logos" in TEXT and not "s de " + m.group("Msma_31") + " " + m.group("Msma_32") + "logos" in TEXT and not "s do " + m.group("Msma_31") + " " + m.group("Msma_32") + "logos" in TEXT and not " o " + m.group("Msma_31") + " " + m.group("Msma_32") + "logos" in TEXT and not m.group("Msma_31") + "-" + m.group("Msma_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_33>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_33").lower() in plvrMasca and not " e " + m.group("Msma_33") + " " + m.group("Msma_34") + "rios" in TEXT and not " ou " + m.group("Msma_33") + " " + m.group("Msma_34") + "rios" in TEXT and not "s de " + m.group("Msma_33") + " " + m.group("Msma_34") + "rios" in TEXT and not "s do " + m.group("Msma_33") + " " + m.group("Msma_34") + "rios" in TEXT and not " o " + m.group("Msma_33") + " " + m.group("Msma_34") + "rios" in TEXT and not m.group("Msma_33") + "-" + m.group("Msma_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_35>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_35").lower() in plvrMasca and not " e " + m.group("Msma_35") + " " + m.group("Msma_36") + "ssimos" in TEXT and not " ou " + m.group("Msma_35") + " " + m.group("Msma_36") + "ssimos" in TEXT and not "s de " + m.group("Msma_35") + " " + m.group("Msma_36") + "ssimos" in TEXT and not "s do " + m.group("Msma_35") + " " + m.group("Msma_36") + "ssimos" in TEXT and not " o " + m.group("Msma_35") + " " + m.group("Msma_36") + "ssimos" in TEXT and not m.group("Msma_35") + "-" + m.group("Msma_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_37>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_37").lower() in plvrMasca and not " e " + m.group("Msma_37") + " " + m.group("Msma_38") + "simos" in TEXT and not " ou " + m.group("Msma_37") + " " + m.group("Msma_38") + "simos" in TEXT and not "s de " + m.group("Msma_37") + " " + m.group("Msma_38") + "simos" in TEXT and not "s do " + m.group("Msma_37") + " " + m.group("Msma_38") + "simos" in TEXT and not " o " + m.group("Msma_37") + " " + m.group("Msma_38") + "simos" in TEXT and not m.group("Msma_37") + "-" + m.group("Msma_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_41>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_41").lower() in plvrMasca and not m.group("Msma_42") in "D-d-" and not " e " + m.group("Msma_41") + " " + m.group("Msma_42") + "ores" in TEXT and not " ou " + m.group("Msma_41") + " " + m.group("Msma_42") + "ores" in TEXT and not "s de " + m.group("Msma_41") + " " + m.group("Msma_42") + "ores" in TEXT and not "s do " + m.group("Msma_41") + " " + m.group("Msma_42") + "ores" in TEXT and not " o " + m.group("Msma_41") + " " + m.group("Msma_42") + "ores" in TEXT and not m.group("Msma_41") + "-" + m.group("Msma_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_43>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_43").lower() in plvrMasca and m.group("Msma_44") in plvrMfr and not " e " + m.group("Msma_43") + " " + m.group("Msma_44") + "es" in TEXT and not " ou " + m.group("Msma_43") + " " + m.group("Msma_44") + "es" in TEXT and not "s de " + m.group("Msma_43") + " " + m.group("Msma_44") + "es" in TEXT and not "s do " + m.group("Msma_43") + " " + m.group("Msma_44") + "es" in TEXT and not " o " + m.group("Msma_43") + " " + m.group("Msma_44") + "es" in TEXT and not m.group("Msma_43") + "-" + m.group("Msma_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_45>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_45").lower() in plvrMasca and m.group("Msma_46") in plvrMascr and not " e " + m.group("Msma_45") + " " + m.group("Msma_46") + "es" in TEXT and not " ou " + m.group("Msma_45") + " " + m.group("Msma_46") + "es" in TEXT and not "s de " + m.group("Msma_45") + " " + m.group("Msma_46") + "es" in TEXT and not "s do " + m.group("Msma_45") + " " + m.group("Msma_46") + "es" in TEXT and not " o " + m.group("Msma_45") + " " + m.group("Msma_46") + "es" in TEXT and not m.group("Msma_45") + "-" + m.group("Msma_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_47>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_47").lower() in plvrMasca and m.group("Msma_48") in plvrMfal and not " e " + m.group("Msma_47") + " " + m.group("Msma_48") + "is" in TEXT and not " ou " + m.group("Msma_47") + " " + m.group("Msma_48") + "is" in TEXT and not "s de " + m.group("Msma_47") + " " + m.group("Msma_48") + "is" in TEXT and not "s do " + m.group("Msma_47") + " " + m.group("Msma_48") + "is" in TEXT and not " o " + m.group("Msma_47") + " " + m.group("Msma_48") + "is" in TEXT and not m.group("Msma_47") + "-" + m.group("Msma_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_49>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_49").lower() in plvrMasca and m.group("Msma_50") in plvrMfcao and not " e " + m.group("Msma_49") + " " + m.group("Msma_50") + "ões" in TEXT and not + " ou " + m.group("Msma_49") + " " + m.group("Msma_50") + "ões" in TEXT and not + "s de " + m.group("Msma_49") + " " + m.group("Msma_50") + "ões" in TEXT and not + "s do " + m.group("Msma_49") + " " + m.group("Msma_50") + "ões" in TEXT and not + " a " + m.group("Msma_49") + " " + m.group("Msma_50") + "ões" in TEXT and not m.group("Msma_49") + "-" + m.group("Msma_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_51>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_51").lower() in plvrMasca and m.group("Msma_52") in plvrNfemcao and not " e " + m.group("Msma_51") + " " + m.group("Msma_52") + "ões" in TEXT and not " ou " + m.group("Msma_51") + " " + m.group("Msma_52") + "ões" in TEXT and not "s de " + m.group("Msma_51") + " " + m.group("Msma_52") + "ões" in TEXT and not "s do " + m.group("Msma_51") + " " + m.group("Msma_52") + "ões" in TEXT and not " o " + m.group("Msma_51") + " " + m.group("Msma_52") + "ões" in TEXT and not m.group("Msma_51") + "-" + m.group("Msma_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_55>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_55").lower() in plvrMasca and not " e " + m.group("Msma_55") + " " + m.group("Msma_56") + "veis" in TEXT and not " ou " + m.group("Msma_55") + " " + m.group("Msma_56") + "veis" in TEXT and not "s de " + m.group("Msma_55") + " " + m.group("Msma_56") + "veis" in TEXT and not "s do " + m.group("Msma_55") + " " + m.group("Msma_56") + "veis" in TEXT and not " o " + m.group("Msma_55") + " " + m.group("Msma_56") + "veis" in TEXT and not m.group("Msma_55") + "-" + m.group("Msma_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_57>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_57").lower() in plvrMasca and m.group("Msma_58").lower() in plvrMfe and not " e " + m.group("Msma_57") + " " + m.group("Msma_58") + "es" in TEXT and not " ou " + m.group("Msma_57") + " " + m.group("Msma_58") + "es" in TEXT and not "s de " + m.group("Msma_57") + " " + m.group("Msma_58") + "es" in TEXT and not "s do " + m.group("Msma_57") + " " + m.group("Msma_58") + "es" in TEXT and not " o " + m.group("Msma_57") + " " + m.group("Msma_58") + "es" in TEXT and not m.group("Msma_57") + "-" + m.group("Msma_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_59>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_59").lower() in plvrMasca and m.group("Msma_60").lower() in plvrMasce and not " e " + m.group("Msma_59") + " " + m.group("Msma_60") + "es" in TEXT and not " ou " + m.group("Msma_59") + " " + m.group("Msma_60") + "es" in TEXT and not "s de " + m.group("Msma_59") + " " + m.group("Msma_60") + "es" in TEXT and not "s do " + m.group("Msma_59") + " " + m.group("Msma_60") + "es" in TEXT and not " o " + m.group("Msma_59") + " " + m.group("Msma_60") + "es" in TEXT and not m.group("Msma_59") + "-" + m.group("Msma_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_61>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_61").lower() in plvrMasca and m.group("Msma_62") in plvrMfel and not " e " + m.group("Msma_61") + " " + m.group("Msma_62") + "éis" in TEXT and not " ou " + m.group("Msma_61") + " " + m.group("Msma_62") + "éis" in TEXT and not "s de " + m.group("Msma_61") + " " + m.group("Msma_62") + "éis" in TEXT and not "s do " + m.group("Msma_61") + " " + m.group("Msma_62") + "éis" in TEXT and not " o " + m.group("Msma_61") + " " + m.group("Msma_62") + "éis" in TEXT and not m.group("Msma_61") + "-" + m.group("Msma_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_63>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_63").lower() in plvrMasca and m.group("Msma_64") in plvrMascel and not " e " + m.group("Msma_63") + " " + m.group("Msma_64") + "éis" in TEXT and not " ou " + m.group("Msma_63") + " " + m.group("Msma_64") + "éis" in TEXT and not "s de " + m.group("Msma_63") + " " + m.group("Msma_64") + "éis" in TEXT and not "s do " + m.group("Msma_63") + " " + m.group("Msma_64") + "éis" in TEXT and not " o " + m.group("Msma_63") + " " + m.group("Msma_64") + "éis" in TEXT and not m.group("Msma_63") + "-" + m.group("Msma_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_65>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_65").lower() in plvrMasca and m.group("Msma_66") in plvrMfeu and not " e " + m.group("Msma_65") + " " + m.group("Msma_66") + "us" in TEXT and not " ou " + m.group("Msma_65") + " " + m.group("Msma_66") + "us" in TEXT and not "s de " + m.group("Msma_65") + " " + m.group("Msma_66") + "us" in TEXT and not "s do " + m.group("Msma_65") + " " + m.group("Msma_66") + "us" in TEXT and not " o " + m.group("Msma_65") + " " + m.group("Msma_66") + "us" in TEXT and not m.group("Msma_65") + "-" + m.group("Msma_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_67>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_67").lower() in plvrMasca and m.group("Msma_68") in plvrMascu and not " e " + m.group("Msma_67") + " " + m.group("Msma_68") + "us" in TEXT and not " ou " + m.group("Msma_67") + " " + m.group("Msma_68") + "us" in TEXT and not "s de " + m.group("Msma_67") + " " + m.group("Msma_68") + "us" in TEXT and not "s do " + m.group("Msma_67") + " " + m.group("Msma_68") + "us" in TEXT and not " o " + m.group("Msma_67") + " " + m.group("Msma_68") + "us" in TEXT and not m.group("Msma_67") + "-" + m.group("Msma_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_69>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_69").lower() in plvrMasca and m.group("Msma_70") in plvrInvaz and not " e " + m.group("Msma_69") + " " + m.group("Msma_70") + "zes" in TEXT and not " ou " + m.group("Msma_69") + " " + m.group("Msma_70") + "zes" in TEXT and not "s de " + m.group("Msma_69") + " " + m.group("Msma_70") + "zes" in TEXT and not "s do " + m.group("Msma_69") + " " + m.group("Msma_70") + "zes" in TEXT and not " o " + m.group("Msma_69") + " " + m.group("Msma_70") + "zes" in TEXT and not m.group("Msma_69") + "-" + m.group("Msma_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_71>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_71").lower() in plvrMasca and m.group("Msma_72") in plvrMascz and not " e " + m.group("Msma_71") + " " + m.group("Msma_72") + "zes" in TEXT and not " ou " + m.group("Msma_71") + " " + m.group("Msma_72") + "zes" in TEXT and not "s de " + m.group("Msma_71") + " " + m.group("Msma_72") + "zes" in TEXT and not "s do " + m.group("Msma_71") + " " + m.group("Msma_72") + "zes" in TEXT and not " o " + m.group("Msma_71") + " " + m.group("Msma_72") + "zes" in TEXT and not m.group("Msma_71") + "-" + m.group("Msma_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_73>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_73").lower() in plvrMasca and m.group("Msma_74") in pvrMascan and not " e " + m.group("Msma_73") + " " + m.group("Msma_74") + "s" in TEXT and not " ou " + m.group("Msma_73") + " " + m.group("Msma_74") + "s" in TEXT and not "s de " + m.group("Msma_73") + " " + m.group("Msma_74") + "s" in TEXT and not "s do " + m.group("Msma_73") + " " + m.group("Msma_74") + "s" in TEXT and not " o " + m.group("Msma_73") + " " + m.group("Msma_74") + "s" in TEXT and not m.group("Msma_73") + "-" + m.group("Msma_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_75>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_75").lower() in plvrMasca and m.group("Msma_76").lower() in plvrMasco and not " e " + m.group("Msma_75") + " " + m.group("Msma_76") +"s" in TEXT and not " ou " + m.group("Msma_75") + " " + m.group("Msma_76") + "s" in TEXT and not "s de " + m.group("Msma_75") + " " + m.group("Msma_76") + "s" in TEXT and not "s do " + m.group("Msma_75") + " " + m.group("Msma_76") + "s" in TEXT and not " o " + m.group("Msma_75") + " " + m.group("Msma_76") + "s" in TEXT and not m.group("Msma_75") + "-" + m.group("Msma_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_77>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_77").lower() in plvrMasca and not " e " + m.group("Msma_77") + " " + m.group("Msma_78") + "inhos" in TEXT and not " ou " + m.group("Msma_77") + " " + m.group("Msma_78") + "inhos" in TEXT and not "s de " + m.group("Msma_77") + " " + m.group("Msma_78") + "inhos" in TEXT and not "s do " + m.group("Msma_77") + " " + m.group("Msma_78") + "inhos" in TEXT and not " o " + m.group("Msma_77") + " " + m.group("Msma_78") + "inhos" in TEXT and not m.group("Msma_77") + "-" + m.group("Msma_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_79>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_79").lower() in plvrMasca and not " e " + m.group("Msma_79") + " " + m.group("Msma_80") + "icas" in TEXT and not " ou " + m.group("Msma_79") + " " + m.group("Msma_80") + "icas" in TEXT and not "s de " + m.group("Msma_79") + " " + m.group("Msma_80") + "icas" in TEXT and not "s do " + m.group("Msma_79") + " " + m.group("Msma_80") + "icas" in TEXT and not " o " + m.group("Msma_79") + " " + m.group("Msma_80") + "icas" in TEXT and not m.group("Msma_79") + "-" + m.group("Msma_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_81>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_81").lower() in plvrMasca and not " e " + m.group("Msma_81") + " " + m.group("Msma_82") + "icas" in TEXT and not " ou " + m.group("Msma_81") + " " + m.group("Msma_82") + "icas" in TEXT and not "s de " + m.group("Msma_81") + " " + m.group("Msma_82") + "icas" in TEXT and not "s do " + m.group("Msma_81") + " " + m.group("Msma_82") + "icas" in TEXT and not " o " + m.group("Msma_81") + " " + m.group("Msma_82") + "icas" in TEXT and not m.group("Msma_81") + "-" + m.group("Msma_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_83>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_83").lower() in plvrMasca and not " e " + m.group("Msma_83") + " " + m.group("Msma_84") + "icas" in TEXT and not " ou " + m.group("Msma_83") + " " + m.group("Msma_84") + "icas" in TEXT and not "s de " + m.group("Msma_83") + " " + m.group("Msma_84") + "icas" in TEXT and not "s do " + m.group("Msma_83") + " " + m.group("Msma_84") + "icas" in TEXT and not " o " + m.group("Msma_83") + " " + m.group("Msma_84") + "icas" in TEXT and not m.group("Msma_83") + "-" + m.group("Msma_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_85>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_85").lower() in plvrMasca and not " e " + m.group("Msma_85") + " " + m.group("Msma_86") + "escas" in TEXT and not " ou " + m.group("Msma_85") + " " + m.group("Msma_86") + "escas" in TEXT and not "s de " + m.group("Msma_85") + " " + m.group("Msma_86") + "escas" in TEXT and not "s do " + m.group("Msma_85") + " " + m.group("Msma_86") + "escas" in TEXT and not " o " + m.group("Msma_85") + " " + m.group("Msma_86") + "escas" in TEXT and not m.group("Msma_85") + "-" + m.group("Msma_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_87>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_87").lower() in plvrMasca and not " e " + m.group("Msma_87") + " " + m.group("Msma_88") + "idas" in TEXT and not " ou " + m.group("Msma_87") + "s " + m.group("Msma_88") + "idas" in TEXT and not "s de " + m.group("Msma_87") + "s " + m.group("Msma_88") + "idas" in TEXT and not "s do " + m.group("Msma_87") + "s " + m.group("Msma_88") + "idas" in TEXT and not " o " + m.group("Msma_87") + "s " + m.group("Msma_88") + "idas" in TEXT and not m.group("Msma_87") + "-" + m.group("Msma_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_89>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_89").lower() in plvrMasca and not " e " + m.group("Msma_89") + " " + m.group("Msma_90") + "logas" in TEXT and not " ou " + m.group("Msma_89") + " " + m.group("Msma_90") + "logas" in TEXT and not "s de " + m.group("Msma_89") + " " + m.group("Msma_90") + "logas" in TEXT and not "s do " + m.group("Msma_89") + " " + m.group("Msma_90") + "logas" in TEXT and not " o " + m.group("Msma_89") + " " + m.group("Msma_90") + "logas" in TEXT and not m.group("Msma_89") + "-" + m.group("Msma_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_91>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_91").lower() in plvrMasca and not " e " + m.group("Msma_91") + " " + m.group("Msma_92") + "rias" in TEXT and not " ou " + m.group("Msma_91") + " " + m.group("Msma_92") + "rias" in TEXT and not "s de " + m.group("Msma_91") + " " + m.group("Msma_92") + "rias" in TEXT and not "s do " + m.group("Msma_91") + " " + m.group("Msma_92") + "rias" in TEXT and not " o " + m.group("Msma_91") + " " + m.group("Msma_92") + "rias" in TEXT and not m.group("Msma_91") + "-" + m.group("Msma_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_93>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_93").lower() in plvrMasca and not " e " + m.group("Msma_93") + " " + m.group("Msma_94") + "ssimas" in TEXT and not " ou " + m.group("Msma_93") + " " + m.group("Msma_94") + "ssimas" in TEXT and not "s de " + m.group("Msma_93") + " " + m.group("Msma_94") + "ssimas" in TEXT and not "s do " + m.group("Msma_93") + " " + m.group("Msma_94") + "ssimas" in TEXT and not " o " + m.group("Msma_93") + " " + m.group("Msma_94") + "ssimas" in TEXT and not m.group("Msma_93") + "-" + m.group("Msma_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_95>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_95").lower() in plvrMasca and not " e " + m.group("Msma_95") + " " + m.group("Msma_96") + "simas" in TEXT and not " ou " + m.group("Msma_95") + " " + m.group("Msma_96") + "simas" in TEXT and not "s de " + m.group("Msma_95") + " " + m.group("Msma_96") + "simas" in TEXT and not "s do " + m.group("Msma_95") + " " + m.group("Msma_96") + "simas" in TEXT and not " o " + m.group("Msma_95") + " " + m.group("Msma_96") + "simas" in TEXT and not m.group("Msma_95") + "-" + m.group("Msma_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_97>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_97").lower() in plvrMasca and m.group("Msma_98").lower() in plvrMfoa and not " e " + m.group("Msma_97") + " " + m.group("Msma_98") + "as" in TEXT and not " ou " + m.group("Msma_97") + " " + m.group("Msma_98") + "as" in TEXT and not "s de " + m.group("Msma_97") + " " + m.group("Msma_98") + "as" in TEXT and not "s do " + m.group("Msma_97") + " " + m.group("Msma_98") + "as" in TEXT and not " o " + m.group("Msma_97") + " " + m.group("Msma_98") + "as" in TEXT and not m.group("Msma_97") + "-" + m.group("Msma_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_99>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_99").lower() in plvrMasca and m.group("Msma_100") in plvrMFm and not " e " + m.group("Msma_99") + " " + m.group("Msma_100") + "ns" in TEXT and not " ou " + m.group("Msma_99") + " " + m.group("Msma_100") + "ns" in TEXT and not "s de " + m.group("Msma_99") + " " + m.group("Msma_100") + "ns" in TEXT and not "s do " + m.group("Msma_99") + " " + m.group("Msma_100") + "ns" in TEXT and not " o " + m.group("Msma_99") + " " + m.group("Msma_100") + "ns" in TEXT and not m.group("Msma_99") + "-" + m.group("Msma_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msma_101>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msma_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msma_101").lower() in plvrMasca and m.group("Msma_102") in plvrMascm and not " e " + m.group("Msma_101") + " " + m.group("Msma_102") + "ns" in TEXT and not " ou " + m.group("Msma_101") + " " + m.group("Msma_102") + "ns" in TEXT and not "s de " + m.group("Msma_101") + " " + m.group("Msma_102") + "ns" in TEXT and not "s do " + m.group("Msma_101") + " " + m.group("Msma_102") + "ns" in TEXT and not " o " + m.group("Msma_101") + " " + m.group("Msma_102") + "ns" in TEXT and not m.group("Msma_101") + "-" + m.group("Msma_102") + "ns" in tCompostops'],
# plvrMasco
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_1>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_1").lower() in plvrMasco and m.group("Msmo_2").lower() in plvrMasca and not " e " + m.group("Msmo_1") + " " + m.group("Msmo_2") +"s" in TEXT and not " ou " + m.group("Msmo_1") + " " + m.group("Msmo_2") + "s" in TEXT and not "s de " + m.group("Msmo_1") + " " + m.group("Msmo_2") + "s" in TEXT and not "s do " + m.group("Msmo_1") + " " + m.group("Msmo_2") + "s" in TEXT and not " o " + m.group("Msmo_1") + " " + m.group("Msmo_2") + "s" in TEXT and not m.group("Msmo_1") + "-" + m.group("Msmo_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_3>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_3").lower() in plvrMasco and m.group("Msmo_4").lower() in plvrMfoa and not " e " + m.group("Msmo_3") + " " + m.group("Msmo_4") + "os" in TEXT and not " ou " + m.group("Msmo_3") + " " + m.group("Msmo_4") + "os" in TEXT and not "s de " + m.group("Msmo_3") + " " + m.group("Msmo_4") + "os" in TEXT and not "s do " + m.group("Msmo_3") + " " + m.group("Msmo_4") + "os" in TEXT and not " o " + m.group("Msmo_3") + " " + m.group("Msmo_4") + "os" in TEXT and not m.group("Msmo_3") + "-" + m.group("Msmo_4") + "os" in tCompostops and not excsingpl.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_5>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_5").lower() in plvrMasco and not m.group("Msmo_6").lower() in excAdo and not " e " + m.group("Msmo_5") + " " + m.group("Msmo_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msmo_5") + " " + m.group("Msmo_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msmo_5") + " " + m.group("Msmo_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msmo_5") + " " + m.group("Msmo_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msmo_5") + " " + m.group("Msmo_6") + m.group(3) + "dos" in TEXT and not m.group("Msmo_5") + "-" + m.group("Msmo_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_7>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_7").lower() in plvrMasco and not m.group("Msmo_8").lower() in excIsta and not " e " + m.group("Msmo_7") + " " + m.group("Msmo_8") + "s" in TEXT and not " ou " + m.group("Msmo_7") + " " + m.group("Msmo_8") + "s" in TEXT and not "s de " + m.group("Msmo_7") + " " + m.group("Msmo_8") + "s" in TEXT and not "s do " + m.group("Msmo_7") + " " + m.group("Msmo_8") + "s" in TEXT and not " o " + m.group("Msmo_7") + " " + m.group("Msmo_8") + "s" in TEXT and not m.group("Msmo_7") + "-" + m.group("Msmo_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_9>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_9").lower() in plvrMasco and m.group("Msmo_10").lower() in plvrInva and not " e " + m.group("Msmo_9") + " " + m.group("Msmo_10") + "s" in TEXT and not " ou " + m.group("Msmo_9") + " " + m.group("Msmo_10") + "s" in TEXT and not "s de " + m.group("Msmo_9") + " " + m.group("Msmo_10") + "s" in TEXT and not "s do " + m.group("Msmo_9") + " " + m.group("Msmo_10") + "s" in TEXT and not " a " + m.group("Msmo_9") + " " + m.group("Msmo_10") + "s" in TEXT and not m.group("Msmo_9") + "-" + m.group("Msmo_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_11>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_11").lower() in plvrMasco and not m.group("Msmo_12").lower() in excAdo and not " e " + m.group("Msmo_11") + " " + m.group("Msmo_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msmo_11") + " " + m.group("Msmo_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msmo_11") + " " + m.group("Msmo_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Msmo_11") + " " + m.group("Msmo_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Msmo_11") + " " + m.group("Msmo_12") + m.group(3) + "das" in TEXT and not m.group("Msmo_11") + "-" + m.group("Msmo_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_13>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_13").lower() in plvrMasco and not " e " + m.group("Msmo_13") + " " + m.group("Msmo_14") + "osos" in TEXT and not " ou " + m.group("Msmo_13") + " " + m.group("Msmo_14") + "osos" in TEXT and not "s de " + m.group("Msmo_13") + " " + m.group("Msmo_14") + "osos" in TEXT and not "s do " + m.group("Msmo_13") + " " + m.group("Msmo_14") + "osos" in TEXT and not " o " + m.group("Msmo_13") + " " + m.group("Msmo_14") + "osos" in TEXT and not m.group("Msmo_13") + "-" + m.group("Msmo_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_15>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_15").lower() in plvrMasco and not " e " + m.group("Msmo_15") + " " + m.group("Msmo_16") + "osas" in TEXT and not " ou " + m.group("Msmo_15") + " " + m.group("Msmo_16") + "osas" in TEXT and not "s de " + m.group("Msmo_15") + " " + m.group("Msmo_16") + "osas" in TEXT and not "s do " + m.group("Msmo_15") + " " + m.group("Msmo_16") + "osas" in TEXT and not " o " + m.group("Msmo_15") + " " + m.group("Msmo_16") + "osas" in TEXT and not m.group("Msmo_15") + "-" + m.group("Msmo_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_17>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_17").lower() in plvrMasco and not " e " + m.group("Msmo_17") + " " + m.group("Msmo_18") + "ivas" in TEXT and not " ou " + m.group("Msmo_17") + " " + m.group("Msmo_18") + "ivas" in TEXT and not "s de " + m.group("Msmo_17") + " " + m.group("Msmo_18") + "ivas" in TEXT and not "s do " + m.group("Msmo_17") + " " + m.group("Msmo_18") + "ivas" in TEXT and not " o " + m.group("Msmo_17") + " " + m.group("Msmo_18") + "ivas" in TEXT and not m.group("Msmo_17") + "-" + m.group("Msmo_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_19>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_19").lower() in plvrMasco and not " e " + m.group("Msmo_19") + " " + m.group("Msmo_20") + "ivas" in TEXT and not " ou " + m.group("Msmo_19") + " " + m.group("Msmo_20") + "ivas" in TEXT and not "s de " + m.group("Msmo_19") + " " + m.group("Msmo_20") + "ivas" in TEXT and not "s do " + m.group("Msmo_19") + " " + m.group("Msmo_20") + "ivas" in TEXT and not " o " + m.group("Msmo_19") + " " + m.group("Msmo_20") + "ivas" in TEXT and not m.group("Msmo_19") + "-" + m.group("Msmo_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_21>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_21").lower() in plvrMasco and not " e " + m.group("Msmo_21") + " " + m.group("Msmo_22") + "icos" in TEXT and not " ou " + m.group("Msmo_21") + " " + m.group("Msmo_22") + "icos" in TEXT and not "s de " + m.group("Msmo_21") + " " + m.group("Msmo_22") + "icos" in TEXT and not "s do " + m.group("Msmo_21") + " " + m.group("Msmo_22") + "icos" in TEXT and not " o " + m.group("Msmo_21") + " " + m.group("Msmo_22") + "icos" in TEXT and not m.group("Msmo_21") + "-" + m.group("Msmo_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_23>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_23").lower() in plvrMasco and not " e " + m.group("Msmo_23") + " " + m.group("Msmo_24") + "icos" in TEXT and not " ou " + m.group("Msmo_23") + " " + m.group("Msmo_24") + "icos" in TEXT and not "s de " + m.group("Msmo_23") + " " + m.group("Msmo_24") + "icos" in TEXT and not "s do " + m.group("Msmo_23") + " " + m.group("Msmo_24") + "icos" in TEXT and not " o " + m.group("Msmo_23") + " " + m.group("Msmo_24") + "icos" in TEXT and not m.group("Msmo_23") + "-" + m.group("Msmo_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_25>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_25").lower() in plvrMasco and not " e " + m.group("Msmo_25") + " " + m.group("Msmo_26") + "icos" in TEXT and not " ou " + m.group("Msmo_25") + " " + m.group("Msmo_26") + "icos" in TEXT and not "s de " + m.group("Msmo_25") + " " + m.group("Msmo_26") + "icos" in TEXT and not "s do " + m.group("Msmo_25") + " " + m.group("Msmo_26") + "icos" in TEXT and not " o " + m.group("Msmo_25") + " " + m.group("Msmo_26") + "icos" in TEXT and not m.group("Msmo_25") + "-" + m.group("Msmo_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_27>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_27").lower() in plvrMasco and not " e " + m.group("Msmo_27") + " " + m.group("Msmo_28") + "escos" in TEXT and not " ou " + m.group("Msmo_27") + " " + m.group("Msmo_28") + "escos" in TEXT and not "s de " + m.group("Msmo_27") + " " + m.group("Msmo_28") + "escos" in TEXT and not "s do " + m.group("Msmo_27") + " " + m.group("Msmo_28") + "escos" in TEXT and not " o " + m.group("Msmo_27") + " " + m.group("Msmo_28") + "escos" in TEXT and not m.group("Msmo_27") + "-" + m.group("Msmo_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_29>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_29").lower() in plvrMasco and not " e " + m.group("Msmo_29") + " " + m.group("Msmo_30") + "idos" in TEXT and not " ou " + m.group("Msmo_29") + "s " + m.group("Msmo_30") + "idos" in TEXT and not "s de " + m.group("Msmo_29") + "s " + m.group("Msmo_30") + "idos" in TEXT and not "s do " + m.group("Msmo_29") + "s " + m.group("Msmo_30") + "idos" in TEXT and not " o " + m.group("Msmo_29") + "s " + m.group("Msmo_30") + "idos" in TEXT and not m.group("Msmo_29") + "-" + m.group("Msmo_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_31>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_31").lower() in plvrMasco and not " e " + m.group("Msmo_31") + " " + m.group("Msmo_32") + "logos" in TEXT and not " ou " + m.group("Msmo_31") + " " + m.group("Msmo_32") + "logos" in TEXT and not "s de " + m.group("Msmo_31") + " " + m.group("Msmo_32") + "logos" in TEXT and not "s do " + m.group("Msmo_31") + " " + m.group("Msmo_32") + "logos" in TEXT and not " o " + m.group("Msmo_31") + " " + m.group("Msmo_32") + "logos" in TEXT and not m.group("Msmo_31") + "-" + m.group("Msmo_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_33>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_33").lower() in plvrMasco and not " e " + m.group("Msmo_33") + " " + m.group("Msmo_34") + "rios" in TEXT and not " ou " + m.group("Msmo_33") + " " + m.group("Msmo_34") + "rios" in TEXT and not "s de " + m.group("Msmo_33") + " " + m.group("Msmo_34") + "rios" in TEXT and not "s do " + m.group("Msmo_33") + " " + m.group("Msmo_34") + "rios" in TEXT and not " o " + m.group("Msmo_33") + " " + m.group("Msmo_34") + "rios" in TEXT and not m.group("Msmo_33") + "-" + m.group("Msmo_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_35>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_35").lower() in plvrMasco and not " e " + m.group("Msmo_35") + " " + m.group("Msmo_36") + "ssimos" in TEXT and not " ou " + m.group("Msmo_35") + " " + m.group("Msmo_36") + "ssimos" in TEXT and not "s de " + m.group("Msmo_35") + " " + m.group("Msmo_36") + "ssimos" in TEXT and not "s do " + m.group("Msmo_35") + " " + m.group("Msmo_36") + "ssimos" in TEXT and not " o " + m.group("Msmo_35") + " " + m.group("Msmo_36") + "ssimos" in TEXT and not m.group("Msmo_35") + "-" + m.group("Msmo_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_37>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_37").lower() in plvrMasco and not " e " + m.group("Msmo_37") + " " + m.group("Msmo_38") + "simos" in TEXT and not " ou " + m.group("Msmo_37") + " " + m.group("Msmo_38") + "simos" in TEXT and not "s de " + m.group("Msmo_37") + " " + m.group("Msmo_38") + "simos" in TEXT and not "s do " + m.group("Msmo_37") + " " + m.group("Msmo_38") + "simos" in TEXT and not " o " + m.group("Msmo_37") + " " + m.group("Msmo_38") + "simos" in TEXT and not m.group("Msmo_37") + "-" + m.group("Msmo_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_41>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_41").lower() in plvrMasco and not m.group("Msmo_42") in "D-d-" and not " e " + m.group("Msmo_41") + " " + m.group("Msmo_42") + "ores" in TEXT and not " ou " + m.group("Msmo_41") + " " + m.group("Msmo_42") + "ores" in TEXT and not "s de " + m.group("Msmo_41") + " " + m.group("Msmo_42") + "ores" in TEXT and not "s do " + m.group("Msmo_41") + " " + m.group("Msmo_42") + "ores" in TEXT and not " o " + m.group("Msmo_41") + " " + m.group("Msmo_42") + "ores" in TEXT and not m.group("Msmo_41") + "-" + m.group("Msmo_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_43>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_43").lower() in plvrMasco and m.group("Msmo_44") in plvrMfr and not " e " + m.group("Msmo_43") + " " + m.group("Msmo_44") + "es" in TEXT and not " ou " + m.group("Msmo_43") + " " + m.group("Msmo_44") + "es" in TEXT and not "s de " + m.group("Msmo_43") + " " + m.group("Msmo_44") + "es" in TEXT and not "s do " + m.group("Msmo_43") + " " + m.group("Msmo_44") + "es" in TEXT and not " o " + m.group("Msmo_43") + " " + m.group("Msmo_44") + "es" in TEXT and not m.group("Msmo_43") + "-" + m.group("Msmo_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_45>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_45").lower() in plvrMasco and m.group("Msmo_46") in plvrMascr and not " e " + m.group("Msmo_45") + " " + m.group("Msmo_46") + "es" in TEXT and not " ou " + m.group("Msmo_45") + " " + m.group("Msmo_46") + "es" in TEXT and not "s de " + m.group("Msmo_45") + " " + m.group("Msmo_46") + "es" in TEXT and not "s do " + m.group("Msmo_45") + " " + m.group("Msmo_46") + "es" in TEXT and not " o " + m.group("Msmo_45") + " " + m.group("Msmo_46") + "es" in TEXT and not m.group("Msmo_45") + "-" + m.group("Msmo_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_47>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_47").lower() in plvrMasco and m.group("Msmo_48") in plvrMfal and not " e " + m.group("Msmo_47") + " " + m.group("Msmo_48") + "is" in TEXT and not " ou " + m.group("Msmo_47") + " " + m.group("Msmo_48") + "is" in TEXT and not "s de " + m.group("Msmo_47") + " " + m.group("Msmo_48") + "is" in TEXT and not "s do " + m.group("Msmo_47") + " " + m.group("Msmo_48") + "is" in TEXT and not " o " + m.group("Msmo_47") + " " + m.group("Msmo_48") + "is" in TEXT and not m.group("Msmo_47") + "-" + m.group("Msmo_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_49>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_49").lower() in plvrMasco and m.group("Msmo_50") in plvrMfcao and not " e " + m.group("Msmo_49") + " " + m.group("Msmo_50") + "ões" in TEXT and not + " ou " + m.group("Msmo_49") + " " + m.group("Msmo_50") + "ões" in TEXT and not + "s de " + m.group("Msmo_49") + " " + m.group("Msmo_50") + "ões" in TEXT and not + "s do " + m.group("Msmo_49") + " " + m.group("Msmo_50") + "ões" in TEXT and not + " a " + m.group("Msmo_49") + " " + m.group("Msmo_50") + "ões" in TEXT and not m.group("Msmo_49") + "-" + m.group("Msmo_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_51>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_51").lower() in plvrMasco and m.group("Msmo_52") in plvrNfemcao and not " e " + m.group("Msmo_51") + " " + m.group("Msmo_52") + "ões" in TEXT and not " ou " + m.group("Msmo_51") + " " + m.group("Msmo_52") + "ões" in TEXT and not "s de " + m.group("Msmo_51") + " " + m.group("Msmo_52") + "ões" in TEXT and not "s do " + m.group("Msmo_51") + " " + m.group("Msmo_52") + "ões" in TEXT and not " o " + m.group("Msmo_51") + " " + m.group("Msmo_52") + "ões" in TEXT and not m.group("Msmo_51") + "-" + m.group("Msmo_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_55>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_55").lower() in plvrMasco and not " e " + m.group("Msmo_55") + " " + m.group("Msmo_56") + "veis" in TEXT and not " ou " + m.group("Msmo_55") + " " + m.group("Msmo_56") + "veis" in TEXT and not "s de " + m.group("Msmo_55") + " " + m.group("Msmo_56") + "veis" in TEXT and not "s do " + m.group("Msmo_55") + " " + m.group("Msmo_56") + "veis" in TEXT and not " o " + m.group("Msmo_55") + " " + m.group("Msmo_56") + "veis" in TEXT and not m.group("Msmo_55") + "-" + m.group("Msmo_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_57>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_57").lower() in plvrMasco and m.group("Msmo_58").lower() in plvrMfe and not " e " + m.group("Msmo_57") + " " + m.group("Msmo_58") + "es" in TEXT and not " ou " + m.group("Msmo_57") + " " + m.group("Msmo_58") + "es" in TEXT and not "s de " + m.group("Msmo_57") + " " + m.group("Msmo_58") + "es" in TEXT and not "s do " + m.group("Msmo_57") + " " + m.group("Msmo_58") + "es" in TEXT and not " o " + m.group("Msmo_57") + " " + m.group("Msmo_58") + "es" in TEXT and not m.group("Msmo_57") + "-" + m.group("Msmo_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_59>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_59").lower() in plvrMasco and m.group("Msmo_60").lower() in plvrMasce and not " e " + m.group("Msmo_59") + " " + m.group("Msmo_60") + "es" in TEXT and not " ou " + m.group("Msmo_59") + " " + m.group("Msmo_60") + "es" in TEXT and not "s de " + m.group("Msmo_59") + " " + m.group("Msmo_60") + "es" in TEXT and not "s do " + m.group("Msmo_59") + " " + m.group("Msmo_60") + "es" in TEXT and not " o " + m.group("Msmo_59") + " " + m.group("Msmo_60") + "es" in TEXT and not m.group("Msmo_59") + "-" + m.group("Msmo_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_61>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_61").lower() in plvrMasco and m.group("Msmo_62") in plvrMfel and not " e " + m.group("Msmo_61") + " " + m.group("Msmo_62") + "éis" in TEXT and not " ou " + m.group("Msmo_61") + " " + m.group("Msmo_62") + "éis" in TEXT and not "s de " + m.group("Msmo_61") + " " + m.group("Msmo_62") + "éis" in TEXT and not "s do " + m.group("Msmo_61") + " " + m.group("Msmo_62") + "éis" in TEXT and not " o " + m.group("Msmo_61") + " " + m.group("Msmo_62") + "éis" in TEXT and not m.group("Msmo_61") + "-" + m.group("Msmo_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_63>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_63").lower() in plvrMasco and m.group("Msmo_64") in plvrMascel and not " e " + m.group("Msmo_63") + " " + m.group("Msmo_64") + "éis" in TEXT and not " ou " + m.group("Msmo_63") + " " + m.group("Msmo_64") + "éis" in TEXT and not "s de " + m.group("Msmo_63") + " " + m.group("Msmo_64") + "éis" in TEXT and not "s do " + m.group("Msmo_63") + " " + m.group("Msmo_64") + "éis" in TEXT and not " o " + m.group("Msmo_63") + " " + m.group("Msmo_64") + "éis" in TEXT and not m.group("Msmo_63") + "-" + m.group("Msmo_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_65>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_65").lower() in plvrMasco and m.group("Msmo_66") in plvrMfeu and not " e " + m.group("Msmo_65") + " " + m.group("Msmo_66") + "us" in TEXT and not " ou " + m.group("Msmo_65") + " " + m.group("Msmo_66") + "us" in TEXT and not "s de " + m.group("Msmo_65") + " " + m.group("Msmo_66") + "us" in TEXT and not "s do " + m.group("Msmo_65") + " " + m.group("Msmo_66") + "us" in TEXT and not " o " + m.group("Msmo_65") + " " + m.group("Msmo_66") + "us" in TEXT and not m.group("Msmo_65") + "-" + m.group("Msmo_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_67>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_67").lower() in plvrMasco and m.group("Msmo_68") in plvrMascu and not " e " + m.group("Msmo_67") + " " + m.group("Msmo_68") + "us" in TEXT and not " ou " + m.group("Msmo_67") + " " + m.group("Msmo_68") + "us" in TEXT and not "s de " + m.group("Msmo_67") + " " + m.group("Msmo_68") + "us" in TEXT and not "s do " + m.group("Msmo_67") + " " + m.group("Msmo_68") + "us" in TEXT and not " o " + m.group("Msmo_67") + " " + m.group("Msmo_68") + "us" in TEXT and not m.group("Msmo_67") + "-" + m.group("Msmo_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_69>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_69").lower() in plvrMasco and m.group("Msmo_70") in plvrInvaz and not " e " + m.group("Msmo_69") + " " + m.group("Msmo_70") + "zes" in TEXT and not " ou " + m.group("Msmo_69") + " " + m.group("Msmo_70") + "zes" in TEXT and not "s de " + m.group("Msmo_69") + " " + m.group("Msmo_70") + "zes" in TEXT and not "s do " + m.group("Msmo_69") + " " + m.group("Msmo_70") + "zes" in TEXT and not " o " + m.group("Msmo_69") + " " + m.group("Msmo_70") + "zes" in TEXT and not m.group("Msmo_69") + "-" + m.group("Msmo_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_71>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_71").lower() in plvrMasco and m.group("Msmo_72") in plvrMascz and not " e " + m.group("Msmo_71") + " " + m.group("Msmo_72") + "zes" in TEXT and not " ou " + m.group("Msmo_71") + " " + m.group("Msmo_72") + "zes" in TEXT and not "s de " + m.group("Msmo_71") + " " + m.group("Msmo_72") + "zes" in TEXT and not "s do " + m.group("Msmo_71") + " " + m.group("Msmo_72") + "zes" in TEXT and not " o " + m.group("Msmo_71") + " " + m.group("Msmo_72") + "zes" in TEXT and not m.group("Msmo_71") + "-" + m.group("Msmo_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_73>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_73").lower() in plvrMasco and m.group("Msmo_74") in pvrMascan and not " e " + m.group("Msmo_73") + " " + m.group("Msmo_74") + "s" in TEXT and not " ou " + m.group("Msmo_73") + " " + m.group("Msmo_74") + "s" in TEXT and not "s de " + m.group("Msmo_73") + " " + m.group("Msmo_74") + "s" in TEXT and not "s do " + m.group("Msmo_73") + " " + m.group("Msmo_74") + "s" in TEXT and not " o " + m.group("Msmo_73") + " " + m.group("Msmo_74") + "s" in TEXT and not m.group("Msmo_73") + "-" + m.group("Msmo_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_75>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_75").lower() in plvrMasco and m.group("Msmo_76").lower() in plvrMasco and not " e " + m.group("Msmo_75") + " " + m.group("Msmo_76") +"s" in TEXT and not " ou " + m.group("Msmo_75") + " " + m.group("Msmo_76") + "s" in TEXT and not "s de " + m.group("Msmo_75") + " " + m.group("Msmo_76") + "s" in TEXT and not "s do " + m.group("Msmo_75") + " " + m.group("Msmo_76") + "s" in TEXT and not " o " + m.group("Msmo_75") + " " + m.group("Msmo_76") + "s" in TEXT and not m.group("Msmo_75") + "-" + m.group("Msmo_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_77>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_77").lower() in plvrMasco and not " e " + m.group("Msmo_77") + " " + m.group("Msmo_78") + "inhos" in TEXT and not " ou " + m.group("Msmo_77") + " " + m.group("Msmo_78") + "inhos" in TEXT and not "s de " + m.group("Msmo_77") + " " + m.group("Msmo_78") + "inhos" in TEXT and not "s do " + m.group("Msmo_77") + " " + m.group("Msmo_78") + "inhos" in TEXT and not " o " + m.group("Msmo_77") + " " + m.group("Msmo_78") + "inhos" in TEXT and not m.group("Msmo_77") + "-" + m.group("Msmo_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_79>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_79").lower() in plvrMasco and not " e " + m.group("Msmo_79") + " " + m.group("Msmo_80") + "icas" in TEXT and not " ou " + m.group("Msmo_79") + " " + m.group("Msmo_80") + "icas" in TEXT and not "s de " + m.group("Msmo_79") + " " + m.group("Msmo_80") + "icas" in TEXT and not "s do " + m.group("Msmo_79") + " " + m.group("Msmo_80") + "icas" in TEXT and not " o " + m.group("Msmo_79") + " " + m.group("Msmo_80") + "icas" in TEXT and not m.group("Msmo_79") + "-" + m.group("Msmo_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_81>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_81").lower() in plvrMasco and not " e " + m.group("Msmo_81") + " " + m.group("Msmo_82") + "icas" in TEXT and not " ou " + m.group("Msmo_81") + " " + m.group("Msmo_82") + "icas" in TEXT and not "s de " + m.group("Msmo_81") + " " + m.group("Msmo_82") + "icas" in TEXT and not "s do " + m.group("Msmo_81") + " " + m.group("Msmo_82") + "icas" in TEXT and not " o " + m.group("Msmo_81") + " " + m.group("Msmo_82") + "icas" in TEXT and not m.group("Msmo_81") + "-" + m.group("Msmo_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_83>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_83").lower() in plvrMasco and not " e " + m.group("Msmo_83") + " " + m.group("Msmo_84") + "icas" in TEXT and not " ou " + m.group("Msmo_83") + " " + m.group("Msmo_84") + "icas" in TEXT and not "s de " + m.group("Msmo_83") + " " + m.group("Msmo_84") + "icas" in TEXT and not "s do " + m.group("Msmo_83") + " " + m.group("Msmo_84") + "icas" in TEXT and not " o " + m.group("Msmo_83") + " " + m.group("Msmo_84") + "icas" in TEXT and not m.group("Msmo_83") + "-" + m.group("Msmo_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_85>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_85").lower() in plvrMasco and not " e " + m.group("Msmo_85") + " " + m.group("Msmo_86") + "escas" in TEXT and not " ou " + m.group("Msmo_85") + " " + m.group("Msmo_86") + "escas" in TEXT and not "s de " + m.group("Msmo_85") + " " + m.group("Msmo_86") + "escas" in TEXT and not "s do " + m.group("Msmo_85") + " " + m.group("Msmo_86") + "escas" in TEXT and not " o " + m.group("Msmo_85") + " " + m.group("Msmo_86") + "escas" in TEXT and not m.group("Msmo_85") + "-" + m.group("Msmo_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_87>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_87").lower() in plvrMasco and not " e " + m.group("Msmo_87") + " " + m.group("Msmo_88") + "idas" in TEXT and not " ou " + m.group("Msmo_87") + "s " + m.group("Msmo_88") + "idas" in TEXT and not "s de " + m.group("Msmo_87") + "s " + m.group("Msmo_88") + "idas" in TEXT and not "s do " + m.group("Msmo_87") + "s " + m.group("Msmo_88") + "idas" in TEXT and not " o " + m.group("Msmo_87") + "s " + m.group("Msmo_88") + "idas" in TEXT and not m.group("Msmo_87") + "-" + m.group("Msmo_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_89>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_89").lower() in plvrMasco and not " e " + m.group("Msmo_89") + " " + m.group("Msmo_90") + "logas" in TEXT and not " ou " + m.group("Msmo_89") + " " + m.group("Msmo_90") + "logas" in TEXT and not "s de " + m.group("Msmo_89") + " " + m.group("Msmo_90") + "logas" in TEXT and not "s do " + m.group("Msmo_89") + " " + m.group("Msmo_90") + "logas" in TEXT and not " o " + m.group("Msmo_89") + " " + m.group("Msmo_90") + "logas" in TEXT and not m.group("Msmo_89") + "-" + m.group("Msmo_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_91>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_91").lower() in plvrMasco and not " e " + m.group("Msmo_91") + " " + m.group("Msmo_92") + "rias" in TEXT and not " ou " + m.group("Msmo_91") + " " + m.group("Msmo_92") + "rias" in TEXT and not "s de " + m.group("Msmo_91") + " " + m.group("Msmo_92") + "rias" in TEXT and not "s do " + m.group("Msmo_91") + " " + m.group("Msmo_92") + "rias" in TEXT and not " o " + m.group("Msmo_91") + " " + m.group("Msmo_92") + "rias" in TEXT and not m.group("Msmo_91") + "-" + m.group("Msmo_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_93>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_93").lower() in plvrMasco and not " e " + m.group("Msmo_93") + " " + m.group("Msmo_94") + "ssimas" in TEXT and not " ou " + m.group("Msmo_93") + " " + m.group("Msmo_94") + "ssimas" in TEXT and not "s de " + m.group("Msmo_93") + " " + m.group("Msmo_94") + "ssimas" in TEXT and not "s do " + m.group("Msmo_93") + " " + m.group("Msmo_94") + "ssimas" in TEXT and not " o " + m.group("Msmo_93") + " " + m.group("Msmo_94") + "ssimas" in TEXT and not m.group("Msmo_93") + "-" + m.group("Msmo_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_95>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_95").lower() in plvrMasco and not " e " + m.group("Msmo_95") + " " + m.group("Msmo_96") + "simas" in TEXT and not " ou " + m.group("Msmo_95") + " " + m.group("Msmo_96") + "simas" in TEXT and not "s de " + m.group("Msmo_95") + " " + m.group("Msmo_96") + "simas" in TEXT and not "s do " + m.group("Msmo_95") + " " + m.group("Msmo_96") + "simas" in TEXT and not " o " + m.group("Msmo_95") + " " + m.group("Msmo_96") + "simas" in TEXT and not m.group("Msmo_95") + "-" + m.group("Msmo_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_97>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_97").lower() in plvrMasco and m.group("Msmo_98").lower() in plvrMfoa and not " e " + m.group("Msmo_97") + " " + m.group("Msmo_98") + "as" in TEXT and not " ou " + m.group("Msmo_97") + " " + m.group("Msmo_98") + "as" in TEXT and not "s de " + m.group("Msmo_97") + " " + m.group("Msmo_98") + "as" in TEXT and not "s do " + m.group("Msmo_97") + " " + m.group("Msmo_98") + "as" in TEXT and not " o " + m.group("Msmo_97") + " " + m.group("Msmo_98") + "as" in TEXT and not m.group("Msmo_97") + "-" + m.group("Msmo_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_99>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_99").lower() in plvrMasco and m.group("Msmo_100") in plvrMFm and not " e " + m.group("Msmo_99") + " " + m.group("Msmo_100") + "ns" in TEXT and not " ou " + m.group("Msmo_99") + " " + m.group("Msmo_100") + "ns" in TEXT and not "s de " + m.group("Msmo_99") + " " + m.group("Msmo_100") + "ns" in TEXT and not "s do " + m.group("Msmo_99") + " " + m.group("Msmo_100") + "ns" in TEXT and not " o " + m.group("Msmo_99") + " " + m.group("Msmo_100") + "ns" in TEXT and not m.group("Msmo_99") + "-" + m.group("Msmo_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmo_101>[a-zA-Záâãçéêíóôú]+[o]) (?P<Msmo_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmo_101").lower() in plvrMasco and m.group("Msmo_102") in plvrMascm and not " e " + m.group("Msmo_101") + " " + m.group("Msmo_102") + "ns" in TEXT and not " ou " + m.group("Msmo_101") + " " + m.group("Msmo_102") + "ns" in TEXT and not "s de " + m.group("Msmo_101") + " " + m.group("Msmo_102") + "ns" in TEXT and not "s do " + m.group("Msmo_101") + " " + m.group("Msmo_102") + "ns" in TEXT and not " o " + m.group("Msmo_101") + " " + m.group("Msmo_102") + "ns" in TEXT and not m.group("Msmo_101") + "-" + m.group("Msmo_102") + "ns" in tCompostops'],
# plvrMfoa a
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_1>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_1").lower() in plvrMfoa and m.group("Msmfa_2").lower() in plvrFema and not " e " + m.group("Msmfa_1") + "a " + m.group("Msmfa_2") +"s" in TEXT and not " ou " + m.group("Msmfa_1") + "a " + m.group("Msmfa_2") + "s" in TEXT and not "s de " + m.group("Msmfa_1") + "a " + m.group("Msmfa_2") + "s" in TEXT and not "s da " + m.group("Msmfa_1") + "a " + m.group("Msmfa_2") + "s" in TEXT and not " a " + m.group("Msmfa_1") + "a " + m.group("Msmfa_2") + "s" in TEXT and not m.group("Msmfa_1") + "a-" + m.group("Msmfa_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_3>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_3").lower() in plvrMfoa and m.group("Msmfa_4").lower() in plvrMfoa and not " e " + m.group("Msmfa_3") + "a " + m.group("Msmfa_4") + "as" in TEXT and not " ou " + m.group("Msmfa_3") + "a " + m.group("Msmfa_4") + "as" in TEXT and not "s de " + m.group("Msmfa_3") + "a " + m.group("Msmfa_4") + "as" in TEXT and not "s da " + m.group("Msmfa_3") + "a " + m.group("Msmfa_4") + "as" in TEXT and not " a " + m.group("Msmfa_3") + "a " + m.group("Msmfa_4") + "as" in TEXT and not m.group("Msmfa_3") + "a-" + m.group("Msmfa_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_5>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_5").lower() in plvrMfoa and not m.group("Msmfa_6").lower() in excAdo and not " e " + m.group("Msmfa_5") + "a " + m.group("Msmfa_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msmfa_5") + "a " + m.group("Msmfa_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msmfa_5") + "a " + m.group("Msmfa_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Msmfa_5") + "a " + m.group("Msmfa_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Msmfa_5") + "a " + m.group("Msmfa_6") + m.group(3) + "dos" in TEXT and not m.group("Msmfa_5") + "a-" + m.group("Msmfa_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_7>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_7").lower() in plvrMfoa and not m.group("Msmfa_8").lower() in excIsta and not " e " + m.group("Msmfa_7") + "a " + m.group("Msmfa_8") + "s" in TEXT and not " ou " + m.group("Msmfa_7") + "a " + m.group("Msmfa_8") + "s" in TEXT and not "s de " + m.group("Msmfa_7") + "a " + m.group("Msmfa_8") + "s" in TEXT and not "s da " + m.group("Msmfa_7") + "a " + m.group("Msmfa_8") + "s" in TEXT and not " a " + m.group("Msmfa_7") + "a " + m.group("Msmfa_8") + "s" in TEXT and not m.group("Msmfa_7") + "a-" + m.group("Msmfa_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_9>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_9").lower() in plvrMfoa and m.group("Msmfa_10").lower() in plvrInva and not " e " + m.group("Msmfa_9") + "a " + m.group("Msmfa_10") + "s" in TEXT and not " ou " + m.group("Msmfa_9") + "a " + m.group("Msmfa_10") + "s" in TEXT and not "s de " + m.group("Msmfa_9") + "a " + m.group("Msmfa_10") + "s" in TEXT and not "s da " + m.group("Msmfa_9") + "a " + m.group("Msmfa_10") + "s" in TEXT and not " a " + m.group("Msmfa_9") + "a " + m.group("Msmfa_10") + "s" in TEXT and not m.group("Msmfa_9") + "a-" + m.group("Msmfa_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_11>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_11").lower() in plvrMfoa and not m.group("Msmfa_12").lower() in excAdo and not " e " + m.group("Msmfa_11") + "a " + m.group("Msmfa_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msmfa_11") + "a " + m.group("Msmfa_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msmfa_11") + "a " + m.group("Msmfa_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Msmfa_11") + "a " + m.group("Msmfa_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Msmfa_11") + "a " + m.group("Msmfa_12") + m.group(3) + "das" in TEXT and not m.group("Msmfa_11") + "a-" + m.group("Msmfa_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_13>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_13").lower() in plvrMfoa and not " e " + m.group("Msmfa_13") + "a " + m.group("Msmfa_14") + "osos" in TEXT and not " ou " + m.group("Msmfa_13") + "a " + m.group("Msmfa_14") + "osos" in TEXT and not "s de " + m.group("Msmfa_13") + "a " + m.group("Msmfa_14") + "osos" in TEXT and not "s da " + m.group("Msmfa_13") + "a " + m.group("Msmfa_14") + "osos" in TEXT and not " a " + m.group("Msmfa_13") + "a " + m.group("Msmfa_14") + "osos" in TEXT and not m.group("Msmfa_13") + "a-" + m.group("Msmfa_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_15>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_15").lower() in plvrMfoa and not " e " + m.group("Msmfa_15") + "a " + m.group("Msmfa_16") + "osas" in TEXT and not " ou " + m.group("Msmfa_15") + "a " + m.group("Msmfa_16") + "osas" in TEXT and not "s de " + m.group("Msmfa_15") + "a " + m.group("Msmfa_16") + "osas" in TEXT and not "s da " + m.group("Msmfa_15") + "a " + m.group("Msmfa_16") + "osas" in TEXT and not " a " + m.group("Msmfa_15") + "a " + m.group("Msmfa_16") + "osas" in TEXT and not m.group("Msmfa_15") + "a-" + m.group("Msmfa_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_17>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_17").lower() in plvrMfoa and not " e " + m.group("Msmfa_17") + "a " + m.group("Msmfa_18") + "ivas" in TEXT and not " ou " + m.group("Msmfa_17") + "a " + m.group("Msmfa_18") + "ivas" in TEXT and not "s de " + m.group("Msmfa_17") + "a " + m.group("Msmfa_18") + "ivas" in TEXT and not "s da " + m.group("Msmfa_17") + "a " + m.group("Msmfa_18") + "ivas" in TEXT and not " a " + m.group("Msmfa_17") + "a " + m.group("Msmfa_18") + "ivas" in TEXT and not m.group("Msmfa_17") + "a-" + m.group("Msmfa_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_19>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_19").lower() in plvrMfoa and not " e " + m.group("Msmfa_19") + "a " + m.group("Msmfa_20") + "ivas" in TEXT and not " ou " + m.group("Msmfa_19") + "a " + m.group("Msmfa_20") + "ivas" in TEXT and not "s de " + m.group("Msmfa_19") + "a " + m.group("Msmfa_20") + "ivas" in TEXT and not "s da " + m.group("Msmfa_19") + "a " + m.group("Msmfa_20") + "ivas" in TEXT and not " a " + m.group("Msmfa_19") + "a " + m.group("Msmfa_20") + "ivas" in TEXT and not m.group("Msmfa_19") + "a-" + m.group("Msmfa_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_21>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_21").lower() in plvrMfoa and not " e " + m.group("Msmfa_21") + "a " + m.group("Msmfa_22") + "icas" in TEXT and not " ou " + m.group("Msmfa_21") + "a " + m.group("Msmfa_22") + "icas" in TEXT and not "s de " + m.group("Msmfa_21") + "a " + m.group("Msmfa_22") + "icas" in TEXT and not "s da " + m.group("Msmfa_21") + "a " + m.group("Msmfa_22") + "icas" in TEXT and not " a " + m.group("Msmfa_21") + "a " + m.group("Msmfa_22") + "icas" in TEXT and not m.group("Msmfa_21") + "a-" + m.group("Msmfa_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_23>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_23").lower() in plvrMfoa and not " e " + m.group("Msmfa_23") + "a " + m.group("Msmfa_24") + "icas" in TEXT and not " ou " + m.group("Msmfa_23") + "a " + m.group("Msmfa_24") + "icas" in TEXT and not "s de " + m.group("Msmfa_23") + "a " + m.group("Msmfa_24") + "icas" in TEXT and not "s da " + m.group("Msmfa_23") + "a " + m.group("Msmfa_24") + "icas" in TEXT and not " a " + m.group("Msmfa_23") + "a " + m.group("Msmfa_24") + "icas" in TEXT and not m.group("Msmfa_23") + "a-" + m.group("Msmfa_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_25>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_25").lower() in plvrMfoa and not " e " + m.group("Msmfa_25") + "a " + m.group("Msmfa_26") + "icas" in TEXT and not " ou " + m.group("Msmfa_25") + "a " + m.group("Msmfa_26") + "icas" in TEXT and not "s de " + m.group("Msmfa_25") + "a " + m.group("Msmfa_26") + "icas" in TEXT and not "s da " + m.group("Msmfa_25") + "a " + m.group("Msmfa_26") + "icas" in TEXT and not " a " + m.group("Msmfa_25") + "a " + m.group("Msmfa_26") + "icas" in TEXT and not m.group("Msmfa_25") + "a-" + m.group("Msmfa_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_27>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_27").lower() in plvrMfoa and not " e " + m.group("Msmfa_27") + "a " + m.group("Msmfa_28") + "escas" in TEXT and not " ou " + m.group("Msmfa_27") + "a " + m.group("Msmfa_28") + "escas" in TEXT and not "s de " + m.group("Msmfa_27") + "a " + m.group("Msmfa_28") + "escas" in TEXT and not "s da " + m.group("Msmfa_27") + "a " + m.group("Msmfa_28") + "escas" in TEXT and not " a " + m.group("Msmfa_27") + "a " + m.group("Msmfa_28") + "escas" in TEXT and not m.group("Msmfa_27") + "a-" + m.group("Msmfa_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_29>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_29").lower() in plvrMfoa and not " e " + m.group("Msmfa_29") + "a " + m.group("Msmfa_30") + "idas" in TEXT and not " ou " + m.group("Msmfa_29") + "s " + m.group("Msmfa_30") + "idas" in TEXT and not "s de " + m.group("Msmfa_29") + "s " + m.group("Msmfa_30") + "idas" in TEXT and not "s da " + m.group("Msmfa_29") + "s " + m.group("Msmfa_30") + "idas" in TEXT and not " a " + m.group("Msmfa_29") + "s " + m.group("Msmfa_30") + "idas" in TEXT and not m.group("Msmfa_29") + "a-" + m.group("Msmfa_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_31>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_31").lower() in plvrMfoa and not " e " + m.group("Msmfa_31") + "a " + m.group("Msmfa_32") + "logas" in TEXT and not " ou " + m.group("Msmfa_31") + "a " + m.group("Msmfa_32") + "logas" in TEXT and not "s de " + m.group("Msmfa_31") + "a " + m.group("Msmfa_32") + "logas" in TEXT and not "s da " + m.group("Msmfa_31") + "a " + m.group("Msmfa_32") + "logas" in TEXT and not " a " + m.group("Msmfa_31") + "a " + m.group("Msmfa_32") + "logas" in TEXT and not m.group("Msmfa_31") + "a-" + m.group("Msmfa_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_33>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_33").lower() in plvrMfoa and not " e " + m.group("Msmfa_33") + "a " + m.group("Msmfa_34") + "rias" in TEXT and not " ou " + m.group("Msmfa_33") + "a " + m.group("Msmfa_34") + "rias" in TEXT and not "s de " + m.group("Msmfa_33") + "a " + m.group("Msmfa_34") + "rias" in TEXT and not "s da " + m.group("Msmfa_33") + "a " + m.group("Msmfa_34") + "rias" in TEXT and not " a " + m.group("Msmfa_33") + "a " + m.group("Msmfa_34") + "rias" in TEXT and not m.group("Msmfa_33") + "a-" + m.group("Msmfa_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_35>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_35").lower() in plvrMfoa and not " e " + m.group("Msmfa_35") + "a " + m.group("Msmfa_36") + "ssimas" in TEXT and not " ou " + m.group("Msmfa_35") + "a " + m.group("Msmfa_36") + "ssimas" in TEXT and not "s de " + m.group("Msmfa_35") + "a " + m.group("Msmfa_36") + "ssimas" in TEXT and not "s da " + m.group("Msmfa_35") + "a " + m.group("Msmfa_36") + "ssimas" in TEXT and not " a " + m.group("Msmfa_35") + "a " + m.group("Msmfa_36") + "ssimas" in TEXT and not m.group("Msmfa_35") + "a-" + m.group("Msmfa_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_37>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_37").lower() in plvrMfoa and not " e " + m.group("Msmfa_37") + "a " + m.group("Msmfa_38") + "simas" in TEXT and not " ou " + m.group("Msmfa_37") + "a " + m.group("Msmfa_38") + "simas" in TEXT and not "s de " + m.group("Msmfa_37") + "a " + m.group("Msmfa_38") + "simas" in TEXT and not "s da " + m.group("Msmfa_37") + "a " + m.group("Msmfa_38") + "simas" in TEXT and not " a " + m.group("Msmfa_37") + "a " + m.group("Msmfa_38") + "simas" in TEXT and not m.group("Msmfa_37") + "a-" + m.group("Msmfa_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_41>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_41").lower() in plvrMfoa and not m.group("Msmfa_42") in "D-d-" and not " e " + m.group("Msmfa_41") + "a " + m.group("Msmfa_42") + "oras" in TEXT and not " ou " + m.group("Msmfa_41") + "a " + m.group("Msmfa_42") + "oras" in TEXT and not "s de " + m.group("Msmfa_41") + "a " + m.group("Msmfa_42") + "oras" in TEXT and not "s da " + m.group("Msmfa_41") + "a " + m.group("Msmfa_42") + "oras" in TEXT and not " a " + m.group("Msmfa_41") + "a " + m.group("Msmfa_42") + "oras" in TEXT and not m.group("Msmfa_41") + "a-" + m.group("Msmfa_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_43>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_43").lower() in plvrMfoa and m.group("Msmfa_44") in plvrMfr and not " e " + m.group("Msmfa_43") + "a " + m.group("Msmfa_44") + "es" in TEXT and not " ou " + m.group("Msmfa_43") + "a " + m.group("Msmfa_44") + "es" in TEXT and not "s de " + m.group("Msmfa_43") + "a " + m.group("Msmfa_44") + "es" in TEXT and not "s da " + m.group("Msmfa_43") + "a " + m.group("Msmfa_44") + "es" in TEXT and not " a " + m.group("Msmfa_43") + "a " + m.group("Msmfa_44") + "es" in TEXT and not m.group("Msmfa_43") + "a-" + m.group("Msmfa_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_45>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_45").lower() in plvrMfoa and m.group("Msmfa_46") in plvrFemr and not " e " + m.group("Msmfa_45") + "a " + m.group("Msmfa_46") + "es" in TEXT and not " ou " + m.group("Msmfa_45") + "a " + m.group("Msmfa_46") + "es" in TEXT and not "s de " + m.group("Msmfa_45") + "a " + m.group("Msmfa_46") + "es" in TEXT and not "s da " + m.group("Msmfa_45") + "a " + m.group("Msmfa_46") + "es" in TEXT and not " a " + m.group("Msmfa_45") + "a " + m.group("Msmfa_46") + "es" in TEXT and not m.group("Msmfa_45") + "a-" + m.group("Msmfa_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_47>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_47").lower() in plvrMfoa and m.group("Msmfa_48") in plvrMfal and not " e " + m.group("Msmfa_47") + "a " + m.group("Msmfa_48") + "is" in TEXT and not " ou " + m.group("Msmfa_47") + "a " + m.group("Msmfa_48") + "is" in TEXT and not "s de " + m.group("Msmfa_47") + "a " + m.group("Msmfa_48") + "is" in TEXT and not "s da " + m.group("Msmfa_47") + "a " + m.group("Msmfa_48") + "is" in TEXT and not " a " + m.group("Msmfa_47") + "a " + m.group("Msmfa_48") + "is" in TEXT and not m.group("Msmfa_47") + "a-" + m.group("Msmfa_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_49>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_49").lower() in plvrMfoa and m.group("Msmfa_50") in plvrMfcao and not " e " + m.group("Msmfa_49") + "a " + m.group("Msmfa_50") + "ões" in TEXT and not + " ou " + m.group("Msmfa_49") + "a " + m.group("Msmfa_50") + "ões" in TEXT and not + "s de " + m.group("Msmfa_49") + "a " + m.group("Msmfa_50") + "ões" in TEXT and not + "s da " + m.group("Msmfa_49") + "a " + m.group("Msmfa_50") + "ões" in TEXT and not + " a " + m.group("Msmfa_49") + "a " + m.group("Msmfa_50") + "ões" in TEXT and not m.group("Msmfa_49") + "a-" + m.group("Msmfa_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_51>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_51").lower() in plvrMfoa and not m.group("Msmfa_52") in plvrMascao and not " e " + m.group("Msmfa_51") + "a " + m.group("Msmfa_52") + "ões" in TEXT and not " ou " + m.group("Msmfa_51") + "a " + m.group("Msmfa_52") + "ões" in TEXT and not "s de " + m.group("Msmfa_51") + "a " + m.group("Msmfa_52") + "ões" in TEXT and not "s da " + m.group("Msmfa_51") + "a " + m.group("Msmfa_52") + "ões" in TEXT and not " a " + m.group("Msmfa_51") + "a " + m.group("Msmfa_52") + "ões" in TEXT and not m.group("Msmfa_51") + "a-" + m.group("Msmfa_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_53>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_53").lower() in plvrMfoa and m.group("Msmfa_54") in plvrFemao and not " e " + m.group("Msmfa_53") + "a " + m.group("Msmfa_54") + "ões" in TEXT and not " ou " + m.group("Msmfa_53") + "a " + m.group("Msmfa_54") + "ões" in TEXT and not "s de " + m.group("Msmfa_53") + "a " + m.group("Msmfa_54") + "ões" in TEXT and not "s da " + m.group("Msmfa_53") + "a " + m.group("Msmfa_54") + "ões" in TEXT and not " a " + m.group("Msmfa_53") + "a " + m.group("Msmfa_54") + "ões" in TEXT and not m.group("Msmfa_53") + "a-" + m.group("Msmfa_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_55>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_55").lower() in plvrMfoa and not " e " + m.group("Msmfa_55") + "a " + m.group("Msmfa_56") + "veis" in TEXT and not " ou " + m.group("Msmfa_55") + "a " + m.group("Msmfa_56") + "veis" in TEXT and not "s de " + m.group("Msmfa_55") + "a " + m.group("Msmfa_56") + "veis" in TEXT and not "s da " + m.group("Msmfa_55") + "a " + m.group("Msmfa_56") + "veis" in TEXT and not " a " + m.group("Msmfa_55") + "a " + m.group("Msmfa_56") + "veis" in TEXT and not m.group("Msmfa_55") + "a-" + m.group("Msmfa_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_57>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_57").lower() in plvrMfoa and m.group("Msmfa_58").lower() in plvrMfe and not " e " + m.group("Msmfa_57") + "a " + m.group("Msmfa_58") + "es" in TEXT and not " ou " + m.group("Msmfa_57") + "a " + m.group("Msmfa_58") + "es" in TEXT and not "s de " + m.group("Msmfa_57") + "a " + m.group("Msmfa_58") + "es" in TEXT and not "s da " + m.group("Msmfa_57") + "a " + m.group("Msmfa_58") + "es" in TEXT and not " a " + m.group("Msmfa_57") + "a " + m.group("Msmfa_58") + "es" in TEXT and not m.group("Msmfa_57") + "a-" + m.group("Msmfa_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_59>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_59").lower() in plvrMfoa and m.group("Msmfa_60").lower() in plvrFeme and not " e " + m.group("Msmfa_59") + "a " + m.group("Msmfa_60") + "es" in TEXT and not " ou " + m.group("Msmfa_59") + "a " + m.group("Msmfa_60") + "es" in TEXT and not "s de " + m.group("Msmfa_59") + "a " + m.group("Msmfa_60") + "es" in TEXT and not "s da " + m.group("Msmfa_59") + "a " + m.group("Msmfa_60") + "es" in TEXT and not " a " + m.group("Msmfa_59") + "a " + m.group("Msmfa_60") + "es" in TEXT and not m.group("Msmfa_59") + "a-" + m.group("Msmfa_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_61>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_61").lower() in plvrMfoa and m.group("Msmfa_62") in plvrMfel and not " e " + m.group("Msmfa_61") + "a " + m.group("Msmfa_62") + "éis" in TEXT and not " ou " + m.group("Msmfa_61") + "a " + m.group("Msmfa_62") + "éis" in TEXT and not "s de " + m.group("Msmfa_61") + "a " + m.group("Msmfa_62") + "éis" in TEXT and not "s da " + m.group("Msmfa_61") + "a " + m.group("Msmfa_62") + "éis" in TEXT and not " a " + m.group("Msmfa_61") + "a " + m.group("Msmfa_62") + "éis" in TEXT and not m.group("Msmfa_61") + "a-" + m.group("Msmfa_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_63>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_63").lower() in plvrMfoa and m.group("Msmfa_64") in plvrFemel and not " e " + m.group("Msmfa_63") + "a " + m.group("Msmfa_64") + "éis" in TEXT and not " ou " + m.group("Msmfa_63") + "a " + m.group("Msmfa_64") + "éis" in TEXT and not "s de " + m.group("Msmfa_63") + "a " + m.group("Msmfa_64") + "éis" in TEXT and not "s da " + m.group("Msmfa_63") + "a " + m.group("Msmfa_64") + "éis" in TEXT and not " a " + m.group("Msmfa_63") + "a " + m.group("Msmfa_64") + "éis" in TEXT and not m.group("Msmfa_63") + "a-" + m.group("Msmfa_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_65>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_65").lower() in plvrMfoa and m.group("Msmfa_66") in plvrMfeu and not " e " + m.group("Msmfa_65") + "a " + m.group("Msmfa_66") + "us" in TEXT and not " ou " + m.group("Msmfa_65") + "a " + m.group("Msmfa_66") + "us" in TEXT and not "s de " + m.group("Msmfa_65") + "a " + m.group("Msmfa_66") + "us" in TEXT and not "s da " + m.group("Msmfa_65") + "a " + m.group("Msmfa_66") + "us" in TEXT and not " a " + m.group("Msmfa_65") + "a " + m.group("Msmfa_66") + "us" in TEXT and not m.group("Msmfa_65") + "a-" + m.group("Msmfa_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_67>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_67").lower() in plvrMfoa and m.group("Msmfa_68") in plvrFemu and not " e " + m.group("Msmfa_67") + "a " + m.group("Msmfa_68") + "us" in TEXT and not " ou " + m.group("Msmfa_67") + "a " + m.group("Msmfa_68") + "us" in TEXT and not "s de " + m.group("Msmfa_67") + "a " + m.group("Msmfa_68") + "us" in TEXT and not "s da " + m.group("Msmfa_67") + "a " + m.group("Msmfa_68") + "us" in TEXT and not " a " + m.group("Msmfa_67") + "a " + m.group("Msmfa_68") + "us" in TEXT and not m.group("Msmfa_67") + "a-" + m.group("Msmfa_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_69>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_69").lower() in plvrMfoa and m.group("Msmfa_70") in plvrInvaz and not " e " + m.group("Msmfa_69") + "a " + m.group("Msmfa_70") + "zes" in TEXT and not " ou " + m.group("Msmfa_69") + "a " + m.group("Msmfa_70") + "zes" in TEXT and not "s de " + m.group("Msmfa_69") + "a " + m.group("Msmfa_70") + "zes" in TEXT and not "s da " + m.group("Msmfa_69") + "a " + m.group("Msmfa_70") + "zes" in TEXT and not " a " + m.group("Msmfa_69") + "a " + m.group("Msmfa_70") + "zes" in TEXT and not m.group("Msmfa_69") + "a-" + m.group("Msmfa_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_71>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_71").lower() in plvrMfoa and m.group("Msmfa_72") in plvrFemz and not " e " + m.group("Msmfa_71") + "a " + m.group("Msmfa_72") + "zes" in TEXT and not " ou " + m.group("Msmfa_71") + "a " + m.group("Msmfa_72") + "zes" in TEXT and not "s de " + m.group("Msmfa_71") + "a " + m.group("Msmfa_72") + "zes" in TEXT and not "s da " + m.group("Msmfa_71") + "a " + m.group("Msmfa_72") + "zes" in TEXT and not " a " + m.group("Msmfa_71") + "a " + m.group("Msmfa_72") + "zes" in TEXT and not m.group("Msmfa_71") + "a-" + m.group("Msmfa_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_73>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_73").lower() in plvrMfoa and m.group("Msmfa_74") in pvrFeman and not " e " + m.group("Msmfa_73") + "a " + m.group("Msmfa_74") + "s" in TEXT and not " ou " + m.group("Msmfa_73") + "a " + m.group("Msmfa_74") + "s" in TEXT and not "s de " + m.group("Msmfa_73") + "a " + m.group("Msmfa_74") + "s" in TEXT and not "s da " + m.group("Msmfa_73") + "a " + m.group("Msmfa_74") + "s" in TEXT and not " a " + m.group("Msmfa_73") + "a " + m.group("Msmfa_74") + "s" in TEXT and not m.group("Msmfa_73") + "a-" + m.group("Msmfa_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_99>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_99").lower() in plvrMfoa and m.group("Msmfa_100") in plvrMFm and not " e " + m.group("Msmfa_99") + "a " + m.group("Msmfa_100") + "ns" in TEXT and not " ou " + m.group("Msmfa_99") + "a " + m.group("Msmfa_100") + "ns" in TEXT and not "s de " + m.group("Msmfa_99") + "a " + m.group("Msmfa_100") + "ns" in TEXT and not "s da " + m.group("Msmfa_99") + "a " + m.group("Msmfa_100") + "ns" in TEXT and not " a " + m.group("Msmfa_99") + "a " + m.group("Msmfa_100") + "ns" in TEXT and not m.group("Msmfa_99") + "a-" + m.group("Msmfa_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_101>[a-zA-Zçáéíóúâêô]+)a (?P<Msmfa_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_101").lower() in plvrMfoa and m.group("Msmfa_102") in plvrFemm and not " e " + m.group("Msmfa_101") + "a " + m.group("Msmfa_102") + "ns" in TEXT and not " ou " + m.group("Msmfa_101") + "a " + m.group("Msmfa_102") + "ns" in TEXT and not "s de " + m.group("Msmfa_101") + "a " + m.group("Msmfa_102") + "ns" in TEXT and not "s da " + m.group("Msmfa_101") + "a " + m.group("Msmfa_102") + "ns" in TEXT and not " a " + m.group("Msmfa_101") + "a " + m.group("Msmfa_102") + "ns" in TEXT and not m.group("Msmfa_101") + "a-" + m.group("Msmfa_102") + "ns" in tCompostops'],
# plvrMfoa o
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_1>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_1").lower() in plvrMfoa and m.group("Msmfo_2").lower() in plvrMasca and not " e " + m.group("Msmfo_1") + "o " + m.group("Msmfo_2") +"s" in TEXT and not " ou " + m.group("Msmfo_1") + "o " + m.group("Msmfo_2") + "s" in TEXT and not "s de " + m.group("Msmfo_1") + "o " + m.group("Msmfo_2") + "s" in TEXT and not "s do " + m.group("Msmfo_1") + "o " + m.group("Msmfo_2") + "s" in TEXT and not " o " + m.group("Msmfo_1") + "o " + m.group("Msmfo_2") + "s" in TEXT and not m.group("Msmfo_1") + "o-" + m.group("Msmfo_2") + "s" in tCompostops and not (m.group("Msmfo_1") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_3>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_3").lower() in plvrMfoa and m.group("Msmfo_4").lower() in plvrMfoa and not " e " + m.group("Msmfo_3") + "o " + m.group("Msmfo_4") + "os" in TEXT and not " ou " + m.group("Msmfo_3") + "o " + m.group("Msmfo_4") + "os" in TEXT and not "s de " + m.group("Msmfo_3") + "o " + m.group("Msmfo_4") + "os" in TEXT and not "s do " + m.group("Msmfo_3") + "o " + m.group("Msmfo_4") + "os" in TEXT and not " o " + m.group("Msmfo_3") + "o " + m.group("Msmfo_4") + "os" in TEXT and not m.group("Msmfo_3") + "o-" + m.group("Msmfo_4") + "os" in tCompostops and not (m.group("Msmfo_3") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_5>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_5").lower() in plvrMfoa and not m.group("Msmfo_6").lower() in excAdo and not " e " + m.group("Msmfo_5") + "o " + m.group("Msmfo_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msmfo_5") + "o " + m.group("Msmfo_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msmfo_5") + "o " + m.group("Msmfo_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msmfo_5") + "o " + m.group("Msmfo_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msmfo_5") + "o " + m.group("Msmfo_6") + m.group(3) + "dos" in TEXT and not m.group("Msmfo_5") + "o-" + m.group("Msmfo_6") + m.group(3) + "dos" in tCompostops and not (m.group("Msmfo_5") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_7>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_7").lower() in plvrMfoa and not m.group("Msmfo_8").lower() in excIsta and not " e " + m.group("Msmfo_7") + "o " + m.group("Msmfo_8") + "s" in TEXT and not " ou " + m.group("Msmfo_7") + "o " + m.group("Msmfo_8") + "s" in TEXT and not "s de " + m.group("Msmfo_7") + "o " + m.group("Msmfo_8") + "s" in TEXT and not "s do " + m.group("Msmfo_7") + "o " + m.group("Msmfo_8") + "s" in TEXT and not " o " + m.group("Msmfo_7") + "o " + m.group("Msmfo_8") + "s" in TEXT and not m.group("Msmfo_7") + "o-" + m.group("Msmfo_8") + "s" in tCompostops and not (m.group("Msmfo_7") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_9>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_9").lower() in plvrMfoa and m.group("Msmfo_10").lower() in plvrInva and not " e " + m.group("Msmfo_9") + "o " + m.group("Msmfo_10") + "s" in TEXT and not " ou " + m.group("Msmfo_9") + "o " + m.group("Msmfo_10") + "s" in TEXT and not "s de " + m.group("Msmfo_9") + "o " + m.group("Msmfo_10") + "s" in TEXT and not "s do " + m.group("Msmfo_9") + "o " + m.group("Msmfo_10") + "s" in TEXT and not " a " + m.group("Msmfo_9") + "o " + m.group("Msmfo_10") + "s" in TEXT and not m.group("Msmfo_9") + "o-" + m.group("Msmfo_10") + "s" in tCompostops and not (m.group("Msmfo_9") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_11>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_11").lower() in plvrMfoa and not m.group("Msmfo_12").lower() in excAdo and not " e " + m.group("Msmfo_11") + "o " + m.group("Msmfo_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msmfo_11") + "o " + m.group("Msmfo_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msmfo_11") + "o " + m.group("Msmfo_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Msmfo_11") + "o " + m.group("Msmfo_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Msmfo_11") + "o " + m.group("Msmfo_12") + m.group(3) + "das" in TEXT and not m.group("Msmfo_11") + "o-" + m.group("Msmfo_12") + m.group(3) + "das" in tCompostops and not (m.group("Msmfo_11") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_13>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_13").lower() in plvrMfoa and not " e " + m.group("Msmfo_13") + "o " + m.group("Msmfo_14") + "osos" in TEXT and not " ou " + m.group("Msmfo_13") + "o " + m.group("Msmfo_14") + "osos" in TEXT and not "s de " + m.group("Msmfo_13") + "o " + m.group("Msmfo_14") + "osos" in TEXT and not "s do " + m.group("Msmfo_13") + "o " + m.group("Msmfo_14") + "osos" in TEXT and not " o " + m.group("Msmfo_13") + "o " + m.group("Msmfo_14") + "osos" in TEXT and not m.group("Msmfo_13") + "o-" + m.group("Msmfo_14") + "osos" in tCompostops and not (m.group("Msmfo_13") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_15>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_15").lower() in plvrMfoa and not " e " + m.group("Msmfo_15") + "o " + m.group("Msmfo_16") + "osas" in TEXT and not " ou " + m.group("Msmfo_15") + "o " + m.group("Msmfo_16") + "osas" in TEXT and not "s de " + m.group("Msmfo_15") + "o " + m.group("Msmfo_16") + "osas" in TEXT and not "s do " + m.group("Msmfo_15") + "o " + m.group("Msmfo_16") + "osas" in TEXT and not " o " + m.group("Msmfo_15") + "o " + m.group("Msmfo_16") + "osas" in TEXT and not m.group("Msmfo_15") + "o-" + m.group("Msmfo_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_17>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_17").lower() in plvrMfoa and not " e " + m.group("Msmfo_17") + "o " + m.group("Msmfo_18") + "ivas" in TEXT and not " ou " + m.group("Msmfo_17") + "o " + m.group("Msmfo_18") + "ivas" in TEXT and not "s de " + m.group("Msmfo_17") + "o " + m.group("Msmfo_18") + "ivas" in TEXT and not "s do " + m.group("Msmfo_17") + "o " + m.group("Msmfo_18") + "ivas" in TEXT and not " o " + m.group("Msmfo_17") + "o " + m.group("Msmfo_18") + "ivas" in TEXT and not m.group("Msmfo_17") + "o-" + m.group("Msmfo_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_19>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_19").lower() in plvrMfoa and not " e " + m.group("Msmfo_19") + "o " + m.group("Msmfo_20") + "ivas" in TEXT and not " ou " + m.group("Msmfo_19") + "o " + m.group("Msmfo_20") + "ivas" in TEXT and not "s de " + m.group("Msmfo_19") + "o " + m.group("Msmfo_20") + "ivas" in TEXT and not "s do " + m.group("Msmfo_19") + "o " + m.group("Msmfo_20") + "ivas" in TEXT and not " o " + m.group("Msmfo_19") + "o " + m.group("Msmfo_20") + "ivas" in TEXT and not m.group("Msmfo_19") + "o-" + m.group("Msmfo_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_21>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_21").lower() in plvrMfoa and not " e " + m.group("Msmfo_21") + "o " + m.group("Msmfo_22") + "icos" in TEXT and not " ou " + m.group("Msmfo_21") + "o " + m.group("Msmfo_22") + "icos" in TEXT and not "s de " + m.group("Msmfo_21") + "o " + m.group("Msmfo_22") + "icos" in TEXT and not "s do " + m.group("Msmfo_21") + "o " + m.group("Msmfo_22") + "icos" in TEXT and not " o " + m.group("Msmfo_21") + "o " + m.group("Msmfo_22") + "icos" in TEXT and not m.group("Msmfo_21") + "o-" + m.group("Msmfo_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_23>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_23").lower() in plvrMfoa and not " e " + m.group("Msmfo_23") + "o " + m.group("Msmfo_24") + "icos" in TEXT and not " ou " + m.group("Msmfo_23") + "o " + m.group("Msmfo_24") + "icos" in TEXT and not "s de " + m.group("Msmfo_23") + "o " + m.group("Msmfo_24") + "icos" in TEXT and not "s do " + m.group("Msmfo_23") + "o " + m.group("Msmfo_24") + "icos" in TEXT and not " o " + m.group("Msmfo_23") + "o " + m.group("Msmfo_24") + "icos" in TEXT and not m.group("Msmfo_23") + "o-" + m.group("Msmfo_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_25>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_25").lower() in plvrMfoa and not " e " + m.group("Msmfo_25") + "o " + m.group("Msmfo_26") + "icos" in TEXT and not " ou " + m.group("Msmfo_25") + "o " + m.group("Msmfo_26") + "icos" in TEXT and not "s de " + m.group("Msmfo_25") + "o " + m.group("Msmfo_26") + "icos" in TEXT and not "s do " + m.group("Msmfo_25") + "o " + m.group("Msmfo_26") + "icos" in TEXT and not " o " + m.group("Msmfo_25") + "o " + m.group("Msmfo_26") + "icos" in TEXT and not m.group("Msmfo_25") + "o-" + m.group("Msmfo_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_27>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_27").lower() in plvrMfoa and not " e " + m.group("Msmfo_27") + "o " + m.group("Msmfo_28") + "escos" in TEXT and not " ou " + m.group("Msmfo_27") + "o " + m.group("Msmfo_28") + "escos" in TEXT and not "s de " + m.group("Msmfo_27") + "o " + m.group("Msmfo_28") + "escos" in TEXT and not "s do " + m.group("Msmfo_27") + "o " + m.group("Msmfo_28") + "escos" in TEXT and not " o " + m.group("Msmfo_27") + "o " + m.group("Msmfo_28") + "escos" in TEXT and not m.group("Msmfo_27") + "o-" + m.group("Msmfo_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_29>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_29").lower() in plvrMfoa and not " e " + m.group("Msmfo_29") + "o " + m.group("Msmfo_30") + "idos" in TEXT and not " ou " + m.group("Msmfo_29") + "s " + m.group("Msmfo_30") + "idos" in TEXT and not "s de " + m.group("Msmfo_29") + "s " + m.group("Msmfo_30") + "idos" in TEXT and not "s do " + m.group("Msmfo_29") + "s " + m.group("Msmfo_30") + "idos" in TEXT and not " o " + m.group("Msmfo_29") + "s " + m.group("Msmfo_30") + "idos" in TEXT and not m.group("Msmfo_29") + "o-" + m.group("Msmfo_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_31>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_31").lower() in plvrMfoa and not " e " + m.group("Msmfo_31") + "o " + m.group("Msmfo_32") + "logos" in TEXT and not " ou " + m.group("Msmfo_31") + "o " + m.group("Msmfo_32") + "logos" in TEXT and not "s de " + m.group("Msmfo_31") + "o " + m.group("Msmfo_32") + "logos" in TEXT and not "s do " + m.group("Msmfo_31") + "o " + m.group("Msmfo_32") + "logos" in TEXT and not " o " + m.group("Msmfo_31") + "o " + m.group("Msmfo_32") + "logos" in TEXT and not m.group("Msmfo_31") + "o-" + m.group("Msmfo_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_33>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_33").lower() in plvrMfoa and not " e " + m.group("Msmfo_33") + "o " + m.group("Msmfo_34") + "rios" in TEXT and not " ou " + m.group("Msmfo_33") + "o " + m.group("Msmfo_34") + "rios" in TEXT and not "s de " + m.group("Msmfo_33") + "o " + m.group("Msmfo_34") + "rios" in TEXT and not "s do " + m.group("Msmfo_33") + "o " + m.group("Msmfo_34") + "rios" in TEXT and not " o " + m.group("Msmfo_33") + "o " + m.group("Msmfo_34") + "rios" in TEXT and not m.group("Msmfo_33") + "o-" + m.group("Msmfo_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_35>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_35").lower() in plvrMfoa and not " e " + m.group("Msmfo_35") + "o " + m.group("Msmfo_36") + "ssimos" in TEXT and not " ou " + m.group("Msmfo_35") + "o " + m.group("Msmfo_36") + "ssimos" in TEXT and not "s de " + m.group("Msmfo_35") + "o " + m.group("Msmfo_36") + "ssimos" in TEXT and not "s do " + m.group("Msmfo_35") + "o " + m.group("Msmfo_36") + "ssimos" in TEXT and not " o " + m.group("Msmfo_35") + "o " + m.group("Msmfo_36") + "ssimos" in TEXT and not m.group("Msmfo_35") + "o-" + m.group("Msmfo_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_37>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_37").lower() in plvrMfoa and not " e " + m.group("Msmfo_37") + "o " + m.group("Msmfo_38") + "simos" in TEXT and not " ou " + m.group("Msmfo_37") + "o " + m.group("Msmfo_38") + "simos" in TEXT and not "s de " + m.group("Msmfo_37") + "o " + m.group("Msmfo_38") + "simos" in TEXT and not "s do " + m.group("Msmfo_37") + "o " + m.group("Msmfo_38") + "simos" in TEXT and not " o " + m.group("Msmfo_37") + "o " + m.group("Msmfo_38") + "simos" in TEXT and not m.group("Msmfo_37") + "o-" + m.group("Msmfo_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_41>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_41").lower() in plvrMfoa and not m.group("Msmfo_42") in "D-d-" and not " e " + m.group("Msmfo_41") + "o " + m.group("Msmfo_42") + "ores" in TEXT and not " ou " + m.group("Msmfo_41") + "o " + m.group("Msmfo_42") + "ores" in TEXT and not "s de " + m.group("Msmfo_41") + "o " + m.group("Msmfo_42") + "ores" in TEXT and not "s do " + m.group("Msmfo_41") + "o " + m.group("Msmfo_42") + "ores" in TEXT and not " o " + m.group("Msmfo_41") + "o " + m.group("Msmfo_42") + "ores" in TEXT and not m.group("Msmfo_41") + "o-" + m.group("Msmfo_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_43>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_43").lower() in plvrMfoa and m.group("Msmfo_44") in plvrMfr and not " e " + m.group("Msmfo_43") + "o " + m.group("Msmfo_44") + "es" in TEXT and not " ou " + m.group("Msmfo_43") + "o " + m.group("Msmfo_44") + "es" in TEXT and not "s de " + m.group("Msmfo_43") + "o " + m.group("Msmfo_44") + "es" in TEXT and not "s do " + m.group("Msmfo_43") + "o " + m.group("Msmfo_44") + "es" in TEXT and not " o " + m.group("Msmfo_43") + "o " + m.group("Msmfo_44") + "es" in TEXT and not m.group("Msmfo_43") + "o-" + m.group("Msmfo_44") + "es" in tCompostops and not (m.group("Msmfo_43") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_45>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_45").lower() in plvrMfoa and m.group("Msmfo_46") in plvrMascr and not " e " + m.group("Msmfo_45") + "o " + m.group("Msmfo_46") + "es" in TEXT and not " ou " + m.group("Msmfo_45") + "o " + m.group("Msmfo_46") + "es" in TEXT and not "s de " + m.group("Msmfo_45") + "o " + m.group("Msmfo_46") + "es" in TEXT and not "s do " + m.group("Msmfo_45") + "o " + m.group("Msmfo_46") + "es" in TEXT and not " o " + m.group("Msmfo_45") + "o " + m.group("Msmfo_46") + "es" in TEXT and not m.group("Msmfo_45") + "o-" + m.group("Msmfo_46") + "es" in tCompostops and not (m.group("Msmfo_45") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_47>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_47").lower() in plvrMfoa and m.group("Msmfo_48") in plvrMfal and not " e " + m.group("Msmfo_47") + "o " + m.group("Msmfo_48") + "is" in TEXT and not " ou " + m.group("Msmfo_47") + "o " + m.group("Msmfo_48") + "is" in TEXT and not "s de " + m.group("Msmfo_47") + "o " + m.group("Msmfo_48") + "is" in TEXT and not "s do " + m.group("Msmfo_47") + "o " + m.group("Msmfo_48") + "is" in TEXT and not " o " + m.group("Msmfo_47") + "o " + m.group("Msmfo_48") + "is" in TEXT and not m.group("Msmfo_47") + "o-" + m.group("Msmfo_48") + "is" in tCompostops and not (m.group("Msmfo_47") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_49>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_49").lower() in plvrMfoa and m.group("Msmfo_50") in plvrMfcao and not " e " + m.group("Msmfo_49") + "o " + m.group("Msmfo_50") + "ões" in TEXT and not + " ou " + m.group("Msmfo_49") + "o " + m.group("Msmfo_50") + "ões" in TEXT and not + "s de " + m.group("Msmfo_49") + "o " + m.group("Msmfo_50") + "ões" in TEXT and not + "s do " + m.group("Msmfo_49") + "o " + m.group("Msmfo_50") + "ões" in TEXT and not + " a " + m.group("Msmfo_49") + "o " + m.group("Msmfo_50") + "ões" in TEXT and not m.group("Msmfo_49") + "o-" + m.group("Msmfo_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_51>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_51").lower() in plvrMfoa and m.group("Msmfo_52") in plvrNfemcao and not " e " + m.group("Msmfo_51") + "o " + m.group("Msmfo_52") + "ões" in TEXT and not " ou " + m.group("Msmfo_51") + "o " + m.group("Msmfo_52") + "ões" in TEXT and not "s de " + m.group("Msmfo_51") + "o " + m.group("Msmfo_52") + "ões" in TEXT and not "s do " + m.group("Msmfo_51") + "o " + m.group("Msmfo_52") + "ões" in TEXT and not " o " + m.group("Msmfo_51") + "o " + m.group("Msmfo_52") + "ões" in TEXT and not m.group("Msmfo_51") + "o-" + m.group("Msmfo_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_55>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_55").lower() in plvrMfoa and not " e " + m.group("Msmfo_55") + "o " + m.group("Msmfo_56") + "veis" in TEXT and not " ou " + m.group("Msmfo_55") + "o " + m.group("Msmfo_56") + "veis" in TEXT and not "s de " + m.group("Msmfo_55") + "o " + m.group("Msmfo_56") + "veis" in TEXT and not "s do " + m.group("Msmfo_55") + "o " + m.group("Msmfo_56") + "veis" in TEXT and not " o " + m.group("Msmfo_55") + "o " + m.group("Msmfo_56") + "veis" in TEXT and not m.group("Msmfo_55") + "o-" + m.group("Msmfo_56") + "veis" in tCompostops and not (m.group("Msmfo_55") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_57>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_57").lower() in plvrMfoa and m.group("Msmfo_58").lower() in plvrMfe and not " e " + m.group("Msmfo_57") + "o " + m.group("Msmfo_58") + "es" in TEXT and not " ou " + m.group("Msmfo_57") + "o " + m.group("Msmfo_58") + "es" in TEXT and not "s de " + m.group("Msmfo_57") + "o " + m.group("Msmfo_58") + "es" in TEXT and not "s do " + m.group("Msmfo_57") + "o " + m.group("Msmfo_58") + "es" in TEXT and not " o " + m.group("Msmfo_57") + "o " + m.group("Msmfo_58") + "es" in TEXT and not m.group("Msmfo_57") + "o-" + m.group("Msmfo_58") + "es" in tCompostops and not (m.group("Msmfo_57") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_59>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_59").lower() in plvrMfoa and m.group("Msmfo_60").lower() in plvrMasce and not " e " + m.group("Msmfo_59") + "o " + m.group("Msmfo_60") + "es" in TEXT and not " ou " + m.group("Msmfo_59") + "o " + m.group("Msmfo_60") + "es" in TEXT and not "s de " + m.group("Msmfo_59") + "o " + m.group("Msmfo_60") + "es" in TEXT and not "s do " + m.group("Msmfo_59") + "o " + m.group("Msmfo_60") + "es" in TEXT and not " o " + m.group("Msmfo_59") + "o " + m.group("Msmfo_60") + "es" in TEXT and not m.group("Msmfo_59") + "o-" + m.group("Msmfo_60") + "es" in tCompostops and not (m.group("Msmfo_59") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_61>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_61").lower() in plvrMfoa and m.group("Msmfo_62") in plvrMfel and not " e " + m.group("Msmfo_61") + "o " + m.group("Msmfo_62") + "éis" in TEXT and not " ou " + m.group("Msmfo_61") + "o " + m.group("Msmfo_62") + "éis" in TEXT and not "s de " + m.group("Msmfo_61") + "o " + m.group("Msmfo_62") + "éis" in TEXT and not "s do " + m.group("Msmfo_61") + "o " + m.group("Msmfo_62") + "éis" in TEXT and not " o " + m.group("Msmfo_61") + "o " + m.group("Msmfo_62") + "éis" in TEXT and not m.group("Msmfo_61") + "o-" + m.group("Msmfo_62") + "éis" in tCompostops and not (m.group("Msmfo_61") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_63>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_63").lower() in plvrMfoa and m.group("Msmfo_64") in plvrMascel and not " e " + m.group("Msmfo_63") + "o " + m.group("Msmfo_64") + "éis" in TEXT and not " ou " + m.group("Msmfo_63") + "o " + m.group("Msmfo_64") + "éis" in TEXT and not "s de " + m.group("Msmfo_63") + "o " + m.group("Msmfo_64") + "éis" in TEXT and not "s do " + m.group("Msmfo_63") + "o " + m.group("Msmfo_64") + "éis" in TEXT and not " o " + m.group("Msmfo_63") + "o " + m.group("Msmfo_64") + "éis" in TEXT and not m.group("Msmfo_63") + "o-" + m.group("Msmfo_64") + "éis" in tCompostops and not (m.group("Msmfo_63") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_65>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_65").lower() in plvrMfoa and m.group("Msmfo_66") in plvrMfeu and not " e " + m.group("Msmfo_65") + "o " + m.group("Msmfo_66") + "us" in TEXT and not " ou " + m.group("Msmfo_65") + "o " + m.group("Msmfo_66") + "us" in TEXT and not "s de " + m.group("Msmfo_65") + "o " + m.group("Msmfo_66") + "us" in TEXT and not "s do " + m.group("Msmfo_65") + "o " + m.group("Msmfo_66") + "us" in TEXT and not " o " + m.group("Msmfo_65") + "o " + m.group("Msmfo_66") + "us" in TEXT and not m.group("Msmfo_65") + "o-" + m.group("Msmfo_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_67>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_67").lower() in plvrMfoa and m.group("Msmfo_68") in plvrMascu and not " e " + m.group("Msmfo_67") + "o " + m.group("Msmfo_68") + "us" in TEXT and not " ou " + m.group("Msmfo_67") + "o " + m.group("Msmfo_68") + "us" in TEXT and not "s de " + m.group("Msmfo_67") + "o " + m.group("Msmfo_68") + "us" in TEXT and not "s do " + m.group("Msmfo_67") + "o " + m.group("Msmfo_68") + "us" in TEXT and not " o " + m.group("Msmfo_67") + "o " + m.group("Msmfo_68") + "us" in TEXT and not m.group("Msmfo_67") + "o-" + m.group("Msmfo_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_69>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_69").lower() in plvrMfoa and m.group("Msmfo_70") in plvrInvaz and not " e " + m.group("Msmfo_69") + "o " + m.group("Msmfo_70") + "zes" in TEXT and not " ou " + m.group("Msmfo_69") + "o " + m.group("Msmfo_70") + "zes" in TEXT and not "s de " + m.group("Msmfo_69") + "o " + m.group("Msmfo_70") + "zes" in TEXT and not "s do " + m.group("Msmfo_69") + "o " + m.group("Msmfo_70") + "zes" in TEXT and not " o " + m.group("Msmfo_69") + "o " + m.group("Msmfo_70") + "zes" in TEXT and not m.group("Msmfo_69") + "o-" + m.group("Msmfo_70") + "zes" in tCompostops and not (m.group("Msmfo_69") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_71>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_71").lower() in plvrMfoa and m.group("Msmfo_72") in plvrMascz and not " e " + m.group("Msmfo_71") + "o " + m.group("Msmfo_72") + "zes" in TEXT and not " ou " + m.group("Msmfo_71") + "o " + m.group("Msmfo_72") + "zes" in TEXT and not "s de " + m.group("Msmfo_71") + "o " + m.group("Msmfo_72") + "zes" in TEXT and not "s do " + m.group("Msmfo_71") + "o " + m.group("Msmfo_72") + "zes" in TEXT and not " o " + m.group("Msmfo_71") + "o " + m.group("Msmfo_72") + "zes" in TEXT and not m.group("Msmfo_71") + "o-" + m.group("Msmfo_72") + "zes" in tCompostops and not (m.group("Msmfo_71") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_73>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_73").lower() in plvrMfoa and m.group("Msmfo_74") in pvrMascan and not " e " + m.group("Msmfo_73") + "o " + m.group("Msmfo_74") + "s" in TEXT and not " ou " + m.group("Msmfo_73") + "o " + m.group("Msmfo_74") + "s" in TEXT and not "s de " + m.group("Msmfo_73") + "o " + m.group("Msmfo_74") + "s" in TEXT and not "s do " + m.group("Msmfo_73") + "o " + m.group("Msmfo_74") + "s" in TEXT and not " o " + m.group("Msmfo_73") + "o " + m.group("Msmfo_74") + "s" in TEXT and not m.group("Msmfo_73") + "o-" + m.group("Msmfo_74") + "s" in tCompostops and not (m.group("Msmfo_73") in "modo" and excMmodo.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_75>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_75").lower() in plvrMfoa and m.group("Msmfo_76").lower() in plvrMasco and not " e " + m.group("Msmfo_75") + "o " + m.group("Msmfo_76") +"s" in TEXT and not " ou " + m.group("Msmfo_75") + "o " + m.group("Msmfo_76") + "s" in TEXT and not "s de " + m.group("Msmfo_75") + "o " + m.group("Msmfo_76") + "s" in TEXT and not "s do " + m.group("Msmfo_75") + "o " + m.group("Msmfo_76") + "s" in TEXT and not " o " + m.group("Msmfo_75") + "o " + m.group("Msmfo_76") + "s" in TEXT and not m.group("Msmfo_75") + "o-" + m.group("Msmfo_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_77>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_77").lower() in plvrMfoa and not " e " + m.group("Msmfo_77") + "o " + m.group("Msmfo_78") + "inhos" in TEXT and not " ou " + m.group("Msmfo_77") + "o " + m.group("Msmfo_78") + "inhos" in TEXT and not "s de " + m.group("Msmfo_77") + "o " + m.group("Msmfo_78") + "inhos" in TEXT and not "s do " + m.group("Msmfo_77") + "o " + m.group("Msmfo_78") + "inhos" in TEXT and not " o " + m.group("Msmfo_77") + "o " + m.group("Msmfo_78") + "inhos" in TEXT and not m.group("Msmfo_77") + "o-" + m.group("Msmfo_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_79>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_79").lower() in plvrMfoa and not " e " + m.group("Msmfo_79") + "o " + m.group("Msmfo_80") + "icas" in TEXT and not " ou " + m.group("Msmfo_79") + "o " + m.group("Msmfo_80") + "icas" in TEXT and not "s de " + m.group("Msmfo_79") + "o " + m.group("Msmfo_80") + "icas" in TEXT and not "s do " + m.group("Msmfo_79") + "o " + m.group("Msmfo_80") + "icas" in TEXT and not " o " + m.group("Msmfo_79") + "o " + m.group("Msmfo_80") + "icas" in TEXT and not m.group("Msmfo_79") + "o-" + m.group("Msmfo_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_81>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_81").lower() in plvrMfoa and not " e " + m.group("Msmfo_81") + "o " + m.group("Msmfo_82") + "icas" in TEXT and not " ou " + m.group("Msmfo_81") + "o " + m.group("Msmfo_82") + "icas" in TEXT and not "s de " + m.group("Msmfo_81") + "o " + m.group("Msmfo_82") + "icas" in TEXT and not "s do " + m.group("Msmfo_81") + "o " + m.group("Msmfo_82") + "icas" in TEXT and not " o " + m.group("Msmfo_81") + "o " + m.group("Msmfo_82") + "icas" in TEXT and not m.group("Msmfo_81") + "o-" + m.group("Msmfo_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_83>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_83").lower() in plvrMfoa and not " e " + m.group("Msmfo_83") + "o " + m.group("Msmfo_84") + "icas" in TEXT and not " ou " + m.group("Msmfo_83") + "o " + m.group("Msmfo_84") + "icas" in TEXT and not "s de " + m.group("Msmfo_83") + "o " + m.group("Msmfo_84") + "icas" in TEXT and not "s do " + m.group("Msmfo_83") + "o " + m.group("Msmfo_84") + "icas" in TEXT and not " o " + m.group("Msmfo_83") + "o " + m.group("Msmfo_84") + "icas" in TEXT and not m.group("Msmfo_83") + "o-" + m.group("Msmfo_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_85>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_85").lower() in plvrMfoa and not " e " + m.group("Msmfo_85") + "o " + m.group("Msmfo_86") + "escas" in TEXT and not " ou " + m.group("Msmfo_85") + "o " + m.group("Msmfo_86") + "escas" in TEXT and not "s de " + m.group("Msmfo_85") + "o " + m.group("Msmfo_86") + "escas" in TEXT and not "s do " + m.group("Msmfo_85") + "o " + m.group("Msmfo_86") + "escas" in TEXT and not " o " + m.group("Msmfo_85") + "o " + m.group("Msmfo_86") + "escas" in TEXT and not m.group("Msmfo_85") + "o-" + m.group("Msmfo_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_87>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_87").lower() in plvrMfoa and not " e " + m.group("Msmfo_87") + "o " + m.group("Msmfo_88") + "idas" in TEXT and not " ou " + m.group("Msmfo_87") + "s " + m.group("Msmfo_88") + "idas" in TEXT and not "s de " + m.group("Msmfo_87") + "s " + m.group("Msmfo_88") + "idas" in TEXT and not "s do " + m.group("Msmfo_87") + "s " + m.group("Msmfo_88") + "idas" in TEXT and not " o " + m.group("Msmfo_87") + "s " + m.group("Msmfo_88") + "idas" in TEXT and not m.group("Msmfo_87") + "o-" + m.group("Msmfo_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_89>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_89").lower() in plvrMfoa and not " e " + m.group("Msmfo_89") + "o " + m.group("Msmfo_90") + "logas" in TEXT and not " ou " + m.group("Msmfo_89") + "o " + m.group("Msmfo_90") + "logas" in TEXT and not "s de " + m.group("Msmfo_89") + "o " + m.group("Msmfo_90") + "logas" in TEXT and not "s do " + m.group("Msmfo_89") + "o " + m.group("Msmfo_90") + "logas" in TEXT and not " o " + m.group("Msmfo_89") + "o " + m.group("Msmfo_90") + "logas" in TEXT and not m.group("Msmfo_89") + "o-" + m.group("Msmfo_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_91>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_91").lower() in plvrMfoa and not " e " + m.group("Msmfo_91") + "o " + m.group("Msmfo_92") + "rias" in TEXT and not " ou " + m.group("Msmfo_91") + "o " + m.group("Msmfo_92") + "rias" in TEXT and not "s de " + m.group("Msmfo_91") + "o " + m.group("Msmfo_92") + "rias" in TEXT and not "s do " + m.group("Msmfo_91") + "o " + m.group("Msmfo_92") + "rias" in TEXT and not " o " + m.group("Msmfo_91") + "o " + m.group("Msmfo_92") + "rias" in TEXT and not m.group("Msmfo_91") + "o-" + m.group("Msmfo_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_93>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_93").lower() in plvrMfoa and not " e " + m.group("Msmfo_93") + "o " + m.group("Msmfo_94") + "ssimas" in TEXT and not " ou " + m.group("Msmfo_93") + "o " + m.group("Msmfo_94") + "ssimas" in TEXT and not "s de " + m.group("Msmfo_93") + "o " + m.group("Msmfo_94") + "ssimas" in TEXT and not "s do " + m.group("Msmfo_93") + "o " + m.group("Msmfo_94") + "ssimas" in TEXT and not " o " + m.group("Msmfo_93") + "o " + m.group("Msmfo_94") + "ssimas" in TEXT and not m.group("Msmfo_93") + "o-" + m.group("Msmfo_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_95>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_95").lower() in plvrMfoa and not " e " + m.group("Msmfo_95") + "o " + m.group("Msmfo_96") + "simas" in TEXT and not " ou " + m.group("Msmfo_95") + "o " + m.group("Msmfo_96") + "simas" in TEXT and not "s de " + m.group("Msmfo_95") + "o " + m.group("Msmfo_96") + "simas" in TEXT and not "s do " + m.group("Msmfo_95") + "o " + m.group("Msmfo_96") + "simas" in TEXT and not " o " + m.group("Msmfo_95") + "o " + m.group("Msmfo_96") + "simas" in TEXT and not m.group("Msmfo_95") + "o-" + m.group("Msmfo_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfo_97>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfo_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfo_97").lower() in plvrMfoa and m.group("Msmfo_98").lower() in plvrMfoa and not " e " + m.group("Msmfo_97") + "o " + m.group("Msmfo_98") + "as" in TEXT and not " ou " + m.group("Msmfo_97") + "o " + m.group("Msmfo_98") + "as" in TEXT and not "s de " + m.group("Msmfo_97") + "o " + m.group("Msmfo_98") + "as" in TEXT and not "s do " + m.group("Msmfo_97") + "o " + m.group("Msmfo_98") + "as" in TEXT and not " o " + m.group("Msmfo_97") + "o " + m.group("Msmfo_98") + "as" in TEXT and not m.group("Msmfo_97") + "o-" + m.group("Msmfo_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_99>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfa_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_99").lower() in plvrMfoa and m.group("Msmfa_100") in plvrMFm and not " e " + m.group("Msmfa_99") + "o " + m.group("Msmfa_100") + "ns" in TEXT and not " ou " + m.group("Msmfa_99") + "o " + m.group("Msmfa_100") + "ns" in TEXT and not "s de " + m.group("Msmfa_99") + "o " + m.group("Msmfa_100") + "ns" in TEXT and not "s da " + m.group("Msmfa_99") + "o " + m.group("Msmfa_100") + "ns" in TEXT and not " a " + m.group("Msmfa_99") + "o " + m.group("Msmfa_100") + "ns" in TEXT and not m.group("Msmfa_99") + "o-" + m.group("Msmfa_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfa_101>[a-zA-Zçáéíóúâêô]+)o (?P<Msmfa_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfa_101").lower() in plvrMfoa and m.group("Msmfa_102") in plvrMascm and not " e " + m.group("Msmfa_101") + "o " + m.group("Msmfa_102") + "ns" in TEXT and not " ou " + m.group("Msmfa_101") + "o " + m.group("Msmfa_102") + "ns" in TEXT and not "s de " + m.group("Msmfa_101") + "o " + m.group("Msmfa_102") + "ns" in TEXT and not "s da " + m.group("Msmfa_101") + "o " + m.group("Msmfa_102") + "ns" in TEXT and not " a " + m.group("Msmfa_101") + "o " + m.group("Msmfa_102") + "ns" in TEXT and not m.group("Msmfa_101") + "o-" + m.group("Msmfa_102") + "ns" in tCompostops'],
# plvrMasce
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_1>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_1").lower() in plvrMasce and m.group("Msmce_2").lower() in plvrMasca and not " e " + m.group("Msmce_1") + "e " + m.group("Msmce_2") +"s" in TEXT and not " ou " + m.group("Msmce_1") + "e " + m.group("Msmce_2") + "s" in TEXT and not "s de " + m.group("Msmce_1") + "e " + m.group("Msmce_2") + "s" in TEXT and not "s do " + m.group("Msmce_1") + "e " + m.group("Msmce_2") + "s" in TEXT and not " o " + m.group("Msmce_1") + "e " + m.group("Msmce_2") + "s" in TEXT and not m.group("Msmce_1") + "e-" + m.group("Msmce_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_3>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_3").lower() in plvrMasce and m.group("Msmce_4").lower() in plvrMasce and not " e " + m.group("Msmce_3") + "e " + m.group("Msmce_4") + "os" in TEXT and not " ou " + m.group("Msmce_3") + "e " + m.group("Msmce_4") + "os" in TEXT and not "s de " + m.group("Msmce_3") + "e " + m.group("Msmce_4") + "os" in TEXT and not "s do " + m.group("Msmce_3") + "e " + m.group("Msmce_4") + "os" in TEXT and not " o " + m.group("Msmce_3") + "e " + m.group("Msmce_4") + "os" in TEXT and not m.group("Msmce_3") + "e-" + m.group("Msmce_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_5>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_5").lower() in plvrMasce and not m.group("Msmce_6").lower() in excAdo and not " e " + m.group("Msmce_5") + "e " + m.group("Msmce_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msmce_5") + "e " + m.group("Msmce_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msmce_5") + "e " + m.group("Msmce_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msmce_5") + "e " + m.group("Msmce_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msmce_5") + "e " + m.group("Msmce_6") + m.group(3) + "dos" in TEXT and not m.group("Msmce_5") + "e-" + m.group("Msmce_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_7>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_7").lower() in plvrMasce and not m.group("Msmce_8").lower() in excIsta and not " e " + m.group("Msmce_7") + "e " + m.group("Msmce_8") + "s" in TEXT and not " ou " + m.group("Msmce_7") + "e " + m.group("Msmce_8") + "s" in TEXT and not "s de " + m.group("Msmce_7") + "e " + m.group("Msmce_8") + "s" in TEXT and not "s do " + m.group("Msmce_7") + "e " + m.group("Msmce_8") + "s" in TEXT and not " o " + m.group("Msmce_7") + "e " + m.group("Msmce_8") + "s" in TEXT and not m.group("Msmce_7") + "e-" + m.group("Msmce_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_9>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_9").lower() in plvrMasce and m.group("Msmce_10").lower() in plvrInva and not " e " + m.group("Msmce_9") + "e " + m.group("Msmce_10") + "s" in TEXT and not " ou " + m.group("Msmce_9") + "e " + m.group("Msmce_10") + "s" in TEXT and not "s de " + m.group("Msmce_9") + "e " + m.group("Msmce_10") + "s" in TEXT and not "s do " + m.group("Msmce_9") + "e " + m.group("Msmce_10") + "s" in TEXT and not " a " + m.group("Msmce_9") + "e " + m.group("Msmce_10") + "s" in TEXT and not m.group("Msmce_9") + "e-" + m.group("Msmce_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_11>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_11").lower() in plvrMasce and not m.group("Msmce_12").lower() in excAdo and not " e " + m.group("Msmce_11") + "e " + m.group("Msmce_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msmce_11") + "e " + m.group("Msmce_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msmce_11") + "e " + m.group("Msmce_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Msmce_11") + "e " + m.group("Msmce_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Msmce_11") + "e " + m.group("Msmce_12") + m.group(3) + "das" in TEXT and not m.group("Msmce_11") + "e-" + m.group("Msmce_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_13>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_13").lower() in plvrMasce and not " e " + m.group("Msmce_13") + "e " + m.group("Msmce_14") + "osos" in TEXT and not " ou " + m.group("Msmce_13") + "e " + m.group("Msmce_14") + "osos" in TEXT and not "s de " + m.group("Msmce_13") + "e " + m.group("Msmce_14") + "osos" in TEXT and not "s do " + m.group("Msmce_13") + "e " + m.group("Msmce_14") + "osos" in TEXT and not " o " + m.group("Msmce_13") + "e " + m.group("Msmce_14") + "osos" in TEXT and not m.group("Msmce_13") + "e-" + m.group("Msmce_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_15>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_15").lower() in plvrMasce and not " e " + m.group("Msmce_15") + "e " + m.group("Msmce_16") + "osas" in TEXT and not " ou " + m.group("Msmce_15") + "e " + m.group("Msmce_16") + "osas" in TEXT and not "s de " + m.group("Msmce_15") + "e " + m.group("Msmce_16") + "osas" in TEXT and not "s do " + m.group("Msmce_15") + "e " + m.group("Msmce_16") + "osas" in TEXT and not " o " + m.group("Msmce_15") + "e " + m.group("Msmce_16") + "osas" in TEXT and not m.group("Msmce_15") + "e-" + m.group("Msmce_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_17>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_17").lower() in plvrMasce and not " e " + m.group("Msmce_17") + "e " + m.group("Msmce_18") + "ivas" in TEXT and not " ou " + m.group("Msmce_17") + "e " + m.group("Msmce_18") + "ivas" in TEXT and not "s de " + m.group("Msmce_17") + "e " + m.group("Msmce_18") + "ivas" in TEXT and not "s do " + m.group("Msmce_17") + "e " + m.group("Msmce_18") + "ivas" in TEXT and not " o " + m.group("Msmce_17") + "e " + m.group("Msmce_18") + "ivas" in TEXT and not m.group("Msmce_17") + "e-" + m.group("Msmce_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_19>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_19").lower() in plvrMasce and not " e " + m.group("Msmce_19") + "e " + m.group("Msmce_20") + "ivas" in TEXT and not " ou " + m.group("Msmce_19") + "e " + m.group("Msmce_20") + "ivas" in TEXT and not "s de " + m.group("Msmce_19") + "e " + m.group("Msmce_20") + "ivas" in TEXT and not "s do " + m.group("Msmce_19") + "e " + m.group("Msmce_20") + "ivas" in TEXT and not " o " + m.group("Msmce_19") + "e " + m.group("Msmce_20") + "ivas" in TEXT and not m.group("Msmce_19") + "e-" + m.group("Msmce_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_21>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_21").lower() in plvrMasce and not " e " + m.group("Msmce_21") + "e " + m.group("Msmce_22") + "icos" in TEXT and not " ou " + m.group("Msmce_21") + "e " + m.group("Msmce_22") + "icos" in TEXT and not "s de " + m.group("Msmce_21") + "e " + m.group("Msmce_22") + "icos" in TEXT and not "s do " + m.group("Msmce_21") + "e " + m.group("Msmce_22") + "icos" in TEXT and not " o " + m.group("Msmce_21") + "e " + m.group("Msmce_22") + "icos" in TEXT and not m.group("Msmce_21") + "e-" + m.group("Msmce_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_23>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_23").lower() in plvrMasce and not " e " + m.group("Msmce_23") + "e " + m.group("Msmce_24") + "icos" in TEXT and not " ou " + m.group("Msmce_23") + "e " + m.group("Msmce_24") + "icos" in TEXT and not "s de " + m.group("Msmce_23") + "e " + m.group("Msmce_24") + "icos" in TEXT and not "s do " + m.group("Msmce_23") + "e " + m.group("Msmce_24") + "icos" in TEXT and not " o " + m.group("Msmce_23") + "e " + m.group("Msmce_24") + "icos" in TEXT and not m.group("Msmce_23") + "e-" + m.group("Msmce_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_25>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_25").lower() in plvrMasce and not " e " + m.group("Msmce_25") + "e " + m.group("Msmce_26") + "icos" in TEXT and not " ou " + m.group("Msmce_25") + "e " + m.group("Msmce_26") + "icos" in TEXT and not "s de " + m.group("Msmce_25") + "e " + m.group("Msmce_26") + "icos" in TEXT and not "s do " + m.group("Msmce_25") + "e " + m.group("Msmce_26") + "icos" in TEXT and not " o " + m.group("Msmce_25") + "e " + m.group("Msmce_26") + "icos" in TEXT and not m.group("Msmce_25") + "e-" + m.group("Msmce_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_27>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_27").lower() in plvrMasce and not " e " + m.group("Msmce_27") + "e " + m.group("Msmce_28") + "escos" in TEXT and not " ou " + m.group("Msmce_27") + "e " + m.group("Msmce_28") + "escos" in TEXT and not "s de " + m.group("Msmce_27") + "e " + m.group("Msmce_28") + "escos" in TEXT and not "s do " + m.group("Msmce_27") + "e " + m.group("Msmce_28") + "escos" in TEXT and not " o " + m.group("Msmce_27") + "e " + m.group("Msmce_28") + "escos" in TEXT and not m.group("Msmce_27") + "e-" + m.group("Msmce_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_29>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_29").lower() in plvrMasce and not " e " + m.group("Msmce_29") + "e " + m.group("Msmce_30") + "idos" in TEXT and not " ou " + m.group("Msmce_29") + "s " + m.group("Msmce_30") + "idos" in TEXT and not "s de " + m.group("Msmce_29") + "s " + m.group("Msmce_30") + "idos" in TEXT and not "s do " + m.group("Msmce_29") + "s " + m.group("Msmce_30") + "idos" in TEXT and not " o " + m.group("Msmce_29") + "s " + m.group("Msmce_30") + "idos" in TEXT and not m.group("Msmce_29") + "e-" + m.group("Msmce_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_31>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_31").lower() in plvrMasce and not " e " + m.group("Msmce_31") + "e " + m.group("Msmce_32") + "logos" in TEXT and not " ou " + m.group("Msmce_31") + "e " + m.group("Msmce_32") + "logos" in TEXT and not "s de " + m.group("Msmce_31") + "e " + m.group("Msmce_32") + "logos" in TEXT and not "s do " + m.group("Msmce_31") + "e " + m.group("Msmce_32") + "logos" in TEXT and not " o " + m.group("Msmce_31") + "e " + m.group("Msmce_32") + "logos" in TEXT and not m.group("Msmce_31") + "e-" + m.group("Msmce_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_33>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_33").lower() in plvrMasce and not " e " + m.group("Msmce_33") + "e " + m.group("Msmce_34") + "rios" in TEXT and not " ou " + m.group("Msmce_33") + "e " + m.group("Msmce_34") + "rios" in TEXT and not "s de " + m.group("Msmce_33") + "e " + m.group("Msmce_34") + "rios" in TEXT and not "s do " + m.group("Msmce_33") + "e " + m.group("Msmce_34") + "rios" in TEXT and not " o " + m.group("Msmce_33") + "e " + m.group("Msmce_34") + "rios" in TEXT and not m.group("Msmce_33") + "e-" + m.group("Msmce_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_35>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_35").lower() in plvrMasce and not " e " + m.group("Msmce_35") + "e " + m.group("Msmce_36") + "ssimos" in TEXT and not " ou " + m.group("Msmce_35") + "e " + m.group("Msmce_36") + "ssimos" in TEXT and not "s de " + m.group("Msmce_35") + "e " + m.group("Msmce_36") + "ssimos" in TEXT and not "s do " + m.group("Msmce_35") + "e " + m.group("Msmce_36") + "ssimos" in TEXT and not " o " + m.group("Msmce_35") + "e " + m.group("Msmce_36") + "ssimos" in TEXT and not m.group("Msmce_35") + "e-" + m.group("Msmce_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_37>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_37").lower() in plvrMasce and not " e " + m.group("Msmce_37") + "e " + m.group("Msmce_38") + "simos" in TEXT and not " ou " + m.group("Msmce_37") + "e " + m.group("Msmce_38") + "simos" in TEXT and not "s de " + m.group("Msmce_37") + "e " + m.group("Msmce_38") + "simos" in TEXT and not "s do " + m.group("Msmce_37") + "e " + m.group("Msmce_38") + "simos" in TEXT and not " o " + m.group("Msmce_37") + "e " + m.group("Msmce_38") + "simos" in TEXT and not m.group("Msmce_37") + "e-" + m.group("Msmce_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_41>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_41").lower() in plvrMasce and not m.group("Msmce_42") in "D-d-" and not " e " + m.group("Msmce_41") + "e " + m.group("Msmce_42") + "ores" in TEXT and not " ou " + m.group("Msmce_41") + "e " + m.group("Msmce_42") + "ores" in TEXT and not "s de " + m.group("Msmce_41") + "e " + m.group("Msmce_42") + "ores" in TEXT and not "s do " + m.group("Msmce_41") + "e " + m.group("Msmce_42") + "ores" in TEXT and not " o " + m.group("Msmce_41") + "e " + m.group("Msmce_42") + "ores" in TEXT and not m.group("Msmce_41") + "e-" + m.group("Msmce_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_43>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_43").lower() in plvrMasce and m.group("Msmce_44") in plvrMfr and not " e " + m.group("Msmce_43") + "e " + m.group("Msmce_44") + "es" in TEXT and not " ou " + m.group("Msmce_43") + "e " + m.group("Msmce_44") + "es" in TEXT and not "s de " + m.group("Msmce_43") + "e " + m.group("Msmce_44") + "es" in TEXT and not "s do " + m.group("Msmce_43") + "e " + m.group("Msmce_44") + "es" in TEXT and not " o " + m.group("Msmce_43") + "e " + m.group("Msmce_44") + "es" in TEXT and not m.group("Msmce_43") + "e-" + m.group("Msmce_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_45>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_45").lower() in plvrMasce and m.group("Msmce_46") in plvrMascr and not " e " + m.group("Msmce_45") + "e " + m.group("Msmce_46") + "es" in TEXT and not " ou " + m.group("Msmce_45") + "e " + m.group("Msmce_46") + "es" in TEXT and not "s de " + m.group("Msmce_45") + "e " + m.group("Msmce_46") + "es" in TEXT and not "s do " + m.group("Msmce_45") + "e " + m.group("Msmce_46") + "es" in TEXT and not " o " + m.group("Msmce_45") + "e " + m.group("Msmce_46") + "es" in TEXT and not m.group("Msmce_45") + "e-" + m.group("Msmce_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_47>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_47").lower() in plvrMasce and m.group("Msmce_48") in plvrMfal and not " e " + m.group("Msmce_47") + "e " + m.group("Msmce_48") + "is" in TEXT and not " ou " + m.group("Msmce_47") + "e " + m.group("Msmce_48") + "is" in TEXT and not "s de " + m.group("Msmce_47") + "e " + m.group("Msmce_48") + "is" in TEXT and not "s do " + m.group("Msmce_47") + "e " + m.group("Msmce_48") + "is" in TEXT and not " o " + m.group("Msmce_47") + "e " + m.group("Msmce_48") + "is" in TEXT and not m.group("Msmce_47") + "e-" + m.group("Msmce_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_49>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_49").lower() in plvrMasce and m.group("Msmce_50") in plvrMfcao and not " e " + m.group("Msmce_49") + "e " + m.group("Msmce_50") + "ões" in TEXT and not + " ou " + m.group("Msmce_49") + "e " + m.group("Msmce_50") + "ões" in TEXT and not + "s de " + m.group("Msmce_49") + "e " + m.group("Msmce_50") + "ões" in TEXT and not + "s do " + m.group("Msmce_49") + "e " + m.group("Msmce_50") + "ões" in TEXT and not + " a " + m.group("Msmce_49") + "e " + m.group("Msmce_50") + "ões" in TEXT and not m.group("Msmce_49") + "e-" + m.group("Msmce_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_51>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_51").lower() in plvrMasce and m.group("Msmce_52") in plvrNfemcao and not " e " + m.group("Msmce_51") + "e " + m.group("Msmce_52") + "ões" in TEXT and not " ou " + m.group("Msmce_51") + "e " + m.group("Msmce_52") + "ões" in TEXT and not "s de " + m.group("Msmce_51") + "e " + m.group("Msmce_52") + "ões" in TEXT and not "s do " + m.group("Msmce_51") + "e " + m.group("Msmce_52") + "ões" in TEXT and not " o " + m.group("Msmce_51") + "e " + m.group("Msmce_52") + "ões" in TEXT and not m.group("Msmce_51") + "e-" + m.group("Msmce_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_55>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_55").lower() in plvrMasce and not " e " + m.group("Msmce_55") + "e " + m.group("Msmce_56") + "veis" in TEXT and not " ou " + m.group("Msmce_55") + "e " + m.group("Msmce_56") + "veis" in TEXT and not "s de " + m.group("Msmce_55") + "e " + m.group("Msmce_56") + "veis" in TEXT and not "s do " + m.group("Msmce_55") + "e " + m.group("Msmce_56") + "veis" in TEXT and not " o " + m.group("Msmce_55") + "e " + m.group("Msmce_56") + "veis" in TEXT and not m.group("Msmce_55") + "e-" + m.group("Msmce_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_57>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_57").lower() in plvrMasce and m.group("Msmce_58").lower() in plvrMfe and not " e " + m.group("Msmce_57") + "e " + m.group("Msmce_58") + "es" in TEXT and not " ou " + m.group("Msmce_57") + "e " + m.group("Msmce_58") + "es" in TEXT and not "s de " + m.group("Msmce_57") + "e " + m.group("Msmce_58") + "es" in TEXT and not "s do " + m.group("Msmce_57") + "e " + m.group("Msmce_58") + "es" in TEXT and not " o " + m.group("Msmce_57") + "e " + m.group("Msmce_58") + "es" in TEXT and not m.group("Msmce_57") + "e-" + m.group("Msmce_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_59>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_59").lower() in plvrMasce and m.group("Msmce_60").lower() in plvrMasce and not " e " + m.group("Msmce_59") + "e " + m.group("Msmce_60") + "es" in TEXT and not " ou " + m.group("Msmce_59") + "e " + m.group("Msmce_60") + "es" in TEXT and not "s de " + m.group("Msmce_59") + "e " + m.group("Msmce_60") + "es" in TEXT and not "s do " + m.group("Msmce_59") + "e " + m.group("Msmce_60") + "es" in TEXT and not " o " + m.group("Msmce_59") + "e " + m.group("Msmce_60") + "es" in TEXT and not m.group("Msmce_59") + "e-" + m.group("Msmce_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_61>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_61").lower() in plvrMasce and m.group("Msmce_62") in plvrMfel and not " e " + m.group("Msmce_61") + "e " + m.group("Msmce_62") + "éis" in TEXT and not " ou " + m.group("Msmce_61") + "e " + m.group("Msmce_62") + "éis" in TEXT and not "s de " + m.group("Msmce_61") + "e " + m.group("Msmce_62") + "éis" in TEXT and not "s do " + m.group("Msmce_61") + "e " + m.group("Msmce_62") + "éis" in TEXT and not " o " + m.group("Msmce_61") + "e " + m.group("Msmce_62") + "éis" in TEXT and not m.group("Msmce_61") + "e-" + m.group("Msmce_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_63>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_63").lower() in plvrMasce and m.group("Msmce_64") in plvrMascel and not " e " + m.group("Msmce_63") + "e " + m.group("Msmce_64") + "éis" in TEXT and not " ou " + m.group("Msmce_63") + "e " + m.group("Msmce_64") + "éis" in TEXT and not "s de " + m.group("Msmce_63") + "e " + m.group("Msmce_64") + "éis" in TEXT and not "s do " + m.group("Msmce_63") + "e " + m.group("Msmce_64") + "éis" in TEXT and not " o " + m.group("Msmce_63") + "e " + m.group("Msmce_64") + "éis" in TEXT and not m.group("Msmce_63") + "e-" + m.group("Msmce_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_65>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_65").lower() in plvrMasce and m.group("Msmce_66") in plvrMfeu and not " e " + m.group("Msmce_65") + "e " + m.group("Msmce_66") + "us" in TEXT and not " ou " + m.group("Msmce_65") + "e " + m.group("Msmce_66") + "us" in TEXT and not "s de " + m.group("Msmce_65") + "e " + m.group("Msmce_66") + "us" in TEXT and not "s do " + m.group("Msmce_65") + "e " + m.group("Msmce_66") + "us" in TEXT and not " o " + m.group("Msmce_65") + "e " + m.group("Msmce_66") + "us" in TEXT and not m.group("Msmce_65") + "e-" + m.group("Msmce_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_67>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_67").lower() in plvrMasce and m.group("Msmce_68") in plvrMascu and not " e " + m.group("Msmce_67") + "e " + m.group("Msmce_68") + "us" in TEXT and not " ou " + m.group("Msmce_67") + "e " + m.group("Msmce_68") + "us" in TEXT and not "s de " + m.group("Msmce_67") + "e " + m.group("Msmce_68") + "us" in TEXT and not "s do " + m.group("Msmce_67") + "e " + m.group("Msmce_68") + "us" in TEXT and not " o " + m.group("Msmce_67") + "e " + m.group("Msmce_68") + "us" in TEXT and not m.group("Msmce_67") + "e-" + m.group("Msmce_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_69>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_69").lower() in plvrMasce and m.group("Msmce_70") in plvrInvaz and not " e " + m.group("Msmce_69") + "e " + m.group("Msmce_70") + "zes" in TEXT and not " ou " + m.group("Msmce_69") + "e " + m.group("Msmce_70") + "zes" in TEXT and not "s de " + m.group("Msmce_69") + "e " + m.group("Msmce_70") + "zes" in TEXT and not "s do " + m.group("Msmce_69") + "e " + m.group("Msmce_70") + "zes" in TEXT and not " o " + m.group("Msmce_69") + "e " + m.group("Msmce_70") + "zes" in TEXT and not m.group("Msmce_69") + "e-" + m.group("Msmce_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_71>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_71").lower() in plvrMasce and m.group("Msmce_72") in plvrMascz and not " e " + m.group("Msmce_71") + "e " + m.group("Msmce_72") + "zes" in TEXT and not " ou " + m.group("Msmce_71") + "e " + m.group("Msmce_72") + "zes" in TEXT and not "s de " + m.group("Msmce_71") + "e " + m.group("Msmce_72") + "zes" in TEXT and not "s do " + m.group("Msmce_71") + "e " + m.group("Msmce_72") + "zes" in TEXT and not " o " + m.group("Msmce_71") + "e " + m.group("Msmce_72") + "zes" in TEXT and not m.group("Msmce_71") + "e-" + m.group("Msmce_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_73>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_73").lower() in plvrMasce and m.group("Msmce_74") in pvrMascan and not " e " + m.group("Msmce_73") + "e " + m.group("Msmce_74") + "s" in TEXT and not " ou " + m.group("Msmce_73") + "e " + m.group("Msmce_74") + "s" in TEXT and not "s de " + m.group("Msmce_73") + "e " + m.group("Msmce_74") + "s" in TEXT and not "s do " + m.group("Msmce_73") + "e " + m.group("Msmce_74") + "s" in TEXT and not " o " + m.group("Msmce_73") + "e " + m.group("Msmce_74") + "s" in TEXT and not m.group("Msmce_73") + "e-" + m.group("Msmce_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_75>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_75").lower() in plvrMasce and m.group("Msmce_76").lower() in plvrMasco and not " e " + m.group("Msmce_75") + "e " + m.group("Msmce_76") +"s" in TEXT and not " ou " + m.group("Msmce_75") + "e " + m.group("Msmce_76") + "s" in TEXT and not "s de " + m.group("Msmce_75") + "e " + m.group("Msmce_76") + "s" in TEXT and not "s do " + m.group("Msmce_75") + "e " + m.group("Msmce_76") + "s" in TEXT and not " o " + m.group("Msmce_75") + "e " + m.group("Msmce_76") + "s" in TEXT and not m.group("Msmce_75") + "e-" + m.group("Msmce_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_77>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_77").lower() in plvrMasce and not " e " + m.group("Msmce_77") + "e " + m.group("Msmce_78") + "inhos" in TEXT and not " ou " + m.group("Msmce_77") + "e " + m.group("Msmce_78") + "inhos" in TEXT and not "s de " + m.group("Msmce_77") + "e " + m.group("Msmce_78") + "inhos" in TEXT and not "s do " + m.group("Msmce_77") + "e " + m.group("Msmce_78") + "inhos" in TEXT and not " o " + m.group("Msmce_77") + "e " + m.group("Msmce_78") + "inhos" in TEXT and not m.group("Msmce_77") + "e-" + m.group("Msmce_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_79>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_79").lower() in plvrMasce and not " e " + m.group("Msmce_79") + "e " + m.group("Msmce_80") + "icas" in TEXT and not " ou " + m.group("Msmce_79") + "e " + m.group("Msmce_80") + "icas" in TEXT and not "s de " + m.group("Msmce_79") + "e " + m.group("Msmce_80") + "icas" in TEXT and not "s do " + m.group("Msmce_79") + "e " + m.group("Msmce_80") + "icas" in TEXT and not " o " + m.group("Msmce_79") + "e " + m.group("Msmce_80") + "icas" in TEXT and not m.group("Msmce_79") + "e-" + m.group("Msmce_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_81>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_81").lower() in plvrMasce and not " e " + m.group("Msmce_81") + "e " + m.group("Msmce_82") + "icas" in TEXT and not " ou " + m.group("Msmce_81") + "e " + m.group("Msmce_82") + "icas" in TEXT and not "s de " + m.group("Msmce_81") + "e " + m.group("Msmce_82") + "icas" in TEXT and not "s do " + m.group("Msmce_81") + "e " + m.group("Msmce_82") + "icas" in TEXT and not " o " + m.group("Msmce_81") + "e " + m.group("Msmce_82") + "icas" in TEXT and not m.group("Msmce_81") + "e-" + m.group("Msmce_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_83>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_83").lower() in plvrMasce and not " e " + m.group("Msmce_83") + "e " + m.group("Msmce_84") + "icas" in TEXT and not " ou " + m.group("Msmce_83") + "e " + m.group("Msmce_84") + "icas" in TEXT and not "s de " + m.group("Msmce_83") + "e " + m.group("Msmce_84") + "icas" in TEXT and not "s do " + m.group("Msmce_83") + "e " + m.group("Msmce_84") + "icas" in TEXT and not " o " + m.group("Msmce_83") + "e " + m.group("Msmce_84") + "icas" in TEXT and not m.group("Msmce_83") + "e-" + m.group("Msmce_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_85>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_85").lower() in plvrMasce and not " e " + m.group("Msmce_85") + "e " + m.group("Msmce_86") + "escas" in TEXT and not " ou " + m.group("Msmce_85") + "e " + m.group("Msmce_86") + "escas" in TEXT and not "s de " + m.group("Msmce_85") + "e " + m.group("Msmce_86") + "escas" in TEXT and not "s do " + m.group("Msmce_85") + "e " + m.group("Msmce_86") + "escas" in TEXT and not " o " + m.group("Msmce_85") + "e " + m.group("Msmce_86") + "escas" in TEXT and not m.group("Msmce_85") + "e-" + m.group("Msmce_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_87>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_87").lower() in plvrMasce and not " e " + m.group("Msmce_87") + "e " + m.group("Msmce_88") + "idas" in TEXT and not " ou " + m.group("Msmce_87") + "s " + m.group("Msmce_88") + "idas" in TEXT and not "s de " + m.group("Msmce_87") + "s " + m.group("Msmce_88") + "idas" in TEXT and not "s do " + m.group("Msmce_87") + "s " + m.group("Msmce_88") + "idas" in TEXT and not " o " + m.group("Msmce_87") + "s " + m.group("Msmce_88") + "idas" in TEXT and not m.group("Msmce_87") + "e-" + m.group("Msmce_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_89>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_89").lower() in plvrMasce and not " e " + m.group("Msmce_89") + "e " + m.group("Msmce_90") + "logas" in TEXT and not " ou " + m.group("Msmce_89") + "e " + m.group("Msmce_90") + "logas" in TEXT and not "s de " + m.group("Msmce_89") + "e " + m.group("Msmce_90") + "logas" in TEXT and not "s do " + m.group("Msmce_89") + "e " + m.group("Msmce_90") + "logas" in TEXT and not " o " + m.group("Msmce_89") + "e " + m.group("Msmce_90") + "logas" in TEXT and not m.group("Msmce_89") + "e-" + m.group("Msmce_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_91>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_91").lower() in plvrMasce and not " e " + m.group("Msmce_91") + "e " + m.group("Msmce_92") + "rias" in TEXT and not " ou " + m.group("Msmce_91") + "e " + m.group("Msmce_92") + "rias" in TEXT and not "s de " + m.group("Msmce_91") + "e " + m.group("Msmce_92") + "rias" in TEXT and not "s do " + m.group("Msmce_91") + "e " + m.group("Msmce_92") + "rias" in TEXT and not " o " + m.group("Msmce_91") + "e " + m.group("Msmce_92") + "rias" in TEXT and not m.group("Msmce_91") + "e-" + m.group("Msmce_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_93>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_93").lower() in plvrMasce and not " e " + m.group("Msmce_93") + "e " + m.group("Msmce_94") + "ssimas" in TEXT and not " ou " + m.group("Msmce_93") + "e " + m.group("Msmce_94") + "ssimas" in TEXT and not "s de " + m.group("Msmce_93") + "e " + m.group("Msmce_94") + "ssimas" in TEXT and not "s do " + m.group("Msmce_93") + "e " + m.group("Msmce_94") + "ssimas" in TEXT and not " o " + m.group("Msmce_93") + "e " + m.group("Msmce_94") + "ssimas" in TEXT and not m.group("Msmce_93") + "e-" + m.group("Msmce_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_95>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_95").lower() in plvrMasce and not " e " + m.group("Msmce_95") + "e " + m.group("Msmce_96") + "simas" in TEXT and not " ou " + m.group("Msmce_95") + "e " + m.group("Msmce_96") + "simas" in TEXT and not "s de " + m.group("Msmce_95") + "e " + m.group("Msmce_96") + "simas" in TEXT and not "s do " + m.group("Msmce_95") + "e " + m.group("Msmce_96") + "simas" in TEXT and not " o " + m.group("Msmce_95") + "e " + m.group("Msmce_96") + "simas" in TEXT and not m.group("Msmce_95") + "e-" + m.group("Msmce_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_97>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_97").lower() in plvrMasce and m.group("Msmce_98").lower() in plvrMasce and not " e " + m.group("Msmce_97") + "e " + m.group("Msmce_98") + "as" in TEXT and not " ou " + m.group("Msmce_97") + "e " + m.group("Msmce_98") + "as" in TEXT and not "s de " + m.group("Msmce_97") + "e " + m.group("Msmce_98") + "as" in TEXT and not "s do " + m.group("Msmce_97") + "e " + m.group("Msmce_98") + "as" in TEXT and not " o " + m.group("Msmce_97") + "e " + m.group("Msmce_98") + "as" in TEXT and not m.group("Msmce_97") + "e-" + m.group("Msmce_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_99>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_99").lower() in plvrMasce and m.group("Msmce_100") in plvrMFm and not " e " + m.group("Msmce_99") + "e " + m.group("Msmce_100") + "ns" in TEXT and not " ou " + m.group("Msmce_99") + "e " + m.group("Msmce_100") + "ns" in TEXT and not "s de " + m.group("Msmce_99") + "e " + m.group("Msmce_100") + "ns" in TEXT and not "s do " + m.group("Msmce_99") + "e " + m.group("Msmce_100") + "ns" in TEXT and not " o " + m.group("Msmce_99") + "e " + m.group("Msmce_100") + "ns" in TEXT and not m.group("Msmce_99") + "e-" + m.group("Msmce_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmce_101>[a-zA-Zçáéíóúâêô]+)e (?P<Msmce_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmce_101").lower() in plvrMasce and m.group("Msmce_102") in plvrMascm and not " e " + m.group("Msmce_101") + "e " + m.group("Msmce_102") + "ns" in TEXT and not " ou " + m.group("Msmce_101") + "e " + m.group("Msmce_102") + "ns" in TEXT and not "s de " + m.group("Msmce_101") + "e " + m.group("Msmce_102") + "ns" in TEXT and not "s do " + m.group("Msmce_101") + "e " + m.group("Msmce_102") + "ns" in TEXT and not " o " + m.group("Msmce_101") + "e " + m.group("Msmce_102") + "ns" in TEXT and not m.group("Msmce_101") + "e-" + m.group("Msmce_102") + "ns" in tCompostops'],
# plvrFeme
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_1>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_1").lower() in plvrFeme and m.group("Msfme_2").lower() in plvrFema and not " e " + m.group("Msfme_1") + "e " + m.group("Msfme_2") +"s" in TEXT and not " ou " + m.group("Msfme_1") + "e " + m.group("Msfme_2") + "s" in TEXT and not "s de " + m.group("Msfme_1") + "e " + m.group("Msfme_2") + "s" in TEXT and not "s da " + m.group("Msfme_1") + "e " + m.group("Msfme_2") + "s" in TEXT and not " a " + m.group("Msfme_1") + "e " + m.group("Msfme_2") + "s" in TEXT and not m.group("Msfme_1") + "e-" + m.group("Msfme_2") + "s" in tCompostops and not (m.group("Msfme_1") in "parte" and excMparte.search(TEXT)) and not excsingpl.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_3>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_3").lower() in plvrFeme and m.group("Msfme_4").lower() in plvrFeme and not " e " + m.group("Msfme_3") + "e " + m.group("Msfme_4") + "as" in TEXT and not " ou " + m.group("Msfme_3") + "e " + m.group("Msfme_4") + "as" in TEXT and not "s de " + m.group("Msfme_3") + "e " + m.group("Msfme_4") + "as" in TEXT and not "s da " + m.group("Msfme_3") + "e " + m.group("Msfme_4") + "as" in TEXT and not " a " + m.group("Msfme_3") + "e " + m.group("Msfme_4") + "as" in TEXT and not m.group("Msfme_3") + "e-" + m.group("Msfme_4") + "as" in tCompostops and not (m.group("Msfme_3") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_5>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_5").lower() in plvrFeme and not m.group("Msfme_6").lower() in excAdo and not " e " + m.group("Msfme_5") + "e " + m.group("Msfme_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msfme_5") + "e " + m.group("Msfme_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msfme_5") + "e " + m.group("Msfme_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Msfme_5") + "e " + m.group("Msfme_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Msfme_5") + "e " + m.group("Msfme_6") + m.group(3) + "dos" in TEXT and not m.group("Msfme_5") + "e-" + m.group("Msfme_6") + m.group(3) + "dos" in tCompostops and not (m.group("Msfme_5") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_7>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_7").lower() in plvrFeme and not m.group("Msfme_8").lower() in excIsta and not " e " + m.group("Msfme_7") + "e " + m.group("Msfme_8") + "s" in TEXT and not " ou " + m.group("Msfme_7") + "e " + m.group("Msfme_8") + "s" in TEXT and not "s de " + m.group("Msfme_7") + "e " + m.group("Msfme_8") + "s" in TEXT and not "s da " + m.group("Msfme_7") + "e " + m.group("Msfme_8") + "s" in TEXT and not " a " + m.group("Msfme_7") + "e " + m.group("Msfme_8") + "s" in TEXT and not m.group("Msfme_7") + "e-" + m.group("Msfme_8") + "s" in tCompostops and not (m.group("Msfme_7") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_9>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_9").lower() in plvrFeme and m.group("Msfme_10").lower() in plvrInva and not " e " + m.group("Msfme_9") + "e " + m.group("Msfme_10") + "s" in TEXT and not " ou " + m.group("Msfme_9") + "e " + m.group("Msfme_10") + "s" in TEXT and not "s de " + m.group("Msfme_9") + "e " + m.group("Msfme_10") + "s" in TEXT and not "s da " + m.group("Msfme_9") + "e " + m.group("Msfme_10") + "s" in TEXT and not " a " + m.group("Msfme_9") + "e " + m.group("Msfme_10") + "s" in TEXT and not m.group("Msfme_9") + "e-" + m.group("Msfme_10") + "s" in tCompostops and not (m.group("Msfme_9") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_11>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_11").lower() in plvrFeme and not m.group("Msfme_12").lower() in excAdo and not " e " + m.group("Msfme_11") + "e " + m.group("Msfme_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msfme_11") + "e " + m.group("Msfme_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msfme_11") + "e " + m.group("Msfme_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Msfme_11") + "e " + m.group("Msfme_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Msfme_11") + "e " + m.group("Msfme_12") + m.group(3) + "das" in TEXT and not m.group("Msfme_11") + "e-" + m.group("Msfme_12") + m.group(3) + "das" in tCompostops and not (m.group("Msfme_11") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_15>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_15").lower() in plvrFeme and not " e " + m.group("Msfme_15") + "e " + m.group("Msfme_16") + "osas" in TEXT and not " ou " + m.group("Msfme_15") + "e " + m.group("Msfme_16") + "osas" in TEXT and not "s de " + m.group("Msfme_15") + "e " + m.group("Msfme_16") + "osas" in TEXT and not "s da " + m.group("Msfme_15") + "e " + m.group("Msfme_16") + "osas" in TEXT and not " a " + m.group("Msfme_15") + "e " + m.group("Msfme_16") + "osas" in TEXT and not m.group("Msfme_15") + "e-" + m.group("Msfme_16") + "osas" in tCompostops and not (m.group("Msfme_15") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_17>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_17").lower() in plvrFeme and not " e " + m.group("Msfme_17") + "e " + m.group("Msfme_18") + "ivas" in TEXT and not " ou " + m.group("Msfme_17") + "e " + m.group("Msfme_18") + "ivas" in TEXT and not "s de " + m.group("Msfme_17") + "e " + m.group("Msfme_18") + "ivas" in TEXT and not "s da " + m.group("Msfme_17") + "e " + m.group("Msfme_18") + "ivas" in TEXT and not " a " + m.group("Msfme_17") + "e " + m.group("Msfme_18") + "ivas" in TEXT and not m.group("Msfme_17") + "e-" + m.group("Msfme_18") + "ivas" in tCompostops and not (m.group("Msfme_17") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_21>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_21").lower() in plvrFeme and not " e " + m.group("Msfme_21") + "e " + m.group("Msfme_22") + "icas" in TEXT and not " ou " + m.group("Msfme_21") + "e " + m.group("Msfme_22") + "icas" in TEXT and not "s de " + m.group("Msfme_21") + "e " + m.group("Msfme_22") + "icas" in TEXT and not "s da " + m.group("Msfme_21") + "e " + m.group("Msfme_22") + "icas" in TEXT and not " a " + m.group("Msfme_21") + "e " + m.group("Msfme_22") + "icas" in TEXT and not m.group("Msfme_21") + "e-" + m.group("Msfme_22") + "icas" in tCompostops and not (m.group("Msfme_21") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_23>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_23").lower() in plvrFeme and not " e " + m.group("Msfme_23") + "e " + m.group("Msfme_24") + "icas" in TEXT and not " ou " + m.group("Msfme_23") + "e " + m.group("Msfme_24") + "icas" in TEXT and not "s de " + m.group("Msfme_23") + "e " + m.group("Msfme_24") + "icas" in TEXT and not "s da " + m.group("Msfme_23") + "e " + m.group("Msfme_24") + "icas" in TEXT and not " a " + m.group("Msfme_23") + "e " + m.group("Msfme_24") + "icas" in TEXT and not m.group("Msfme_23") + "e-" + m.group("Msfme_24") + "icas" in tCompostops and not (m.group("Msfme_23") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_25>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_25").lower() in plvrFeme and not " e " + m.group("Msfme_25") + "e " + m.group("Msfme_26") + "icas" in TEXT and not " ou " + m.group("Msfme_25") + "e " + m.group("Msfme_26") + "icas" in TEXT and not "s de " + m.group("Msfme_25") + "e " + m.group("Msfme_26") + "icas" in TEXT and not "s da " + m.group("Msfme_25") + "e " + m.group("Msfme_26") + "icas" in TEXT and not " a " + m.group("Msfme_25") + "e " + m.group("Msfme_26") + "icas" in TEXT and not m.group("Msfme_25") + "e-" + m.group("Msfme_26") + "icas" in tCompostops and not (m.group("Msfme_25") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_27>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_27").lower() in plvrFeme and not " e " + m.group("Msfme_27") + "e " + m.group("Msfme_28") + "escas" in TEXT and not " ou " + m.group("Msfme_27") + "e " + m.group("Msfme_28") + "escas" in TEXT and not "s de " + m.group("Msfme_27") + "e " + m.group("Msfme_28") + "escas" in TEXT and not "s da " + m.group("Msfme_27") + "e " + m.group("Msfme_28") + "escas" in TEXT and not " a " + m.group("Msfme_27") + "e " + m.group("Msfme_28") + "escas" in TEXT and not m.group("Msfme_27") + "e-" + m.group("Msfme_28") + "escas" in tCompostops and not (m.group("Msfme_27") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_29>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_29").lower() in plvrFeme and not " e " + m.group("Msfme_29") + "e " + m.group("Msfme_30") + "idas" in TEXT and not " ou " + m.group("Msfme_29") + "s " + m.group("Msfme_30") + "idas" in TEXT and not "s de " + m.group("Msfme_29") + "s " + m.group("Msfme_30") + "idas" in TEXT and not "s da " + m.group("Msfme_29") + "s " + m.group("Msfme_30") + "idas" in TEXT and not " a " + m.group("Msfme_29") + "s " + m.group("Msfme_30") + "idas" in TEXT and not m.group("Msfme_29") + "e-" + m.group("Msfme_30") + "idas" in tCompostops and not (m.group("Msfme_29") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_31>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_31").lower() in plvrFeme and not " e " + m.group("Msfme_31") + "e " + m.group("Msfme_32") + "logas" in TEXT and not " ou " + m.group("Msfme_31") + "e " + m.group("Msfme_32") + "logas" in TEXT and not "s de " + m.group("Msfme_31") + "e " + m.group("Msfme_32") + "logas" in TEXT and not "s da " + m.group("Msfme_31") + "e " + m.group("Msfme_32") + "logas" in TEXT and not " a " + m.group("Msfme_31") + "e " + m.group("Msfme_32") + "logas" in TEXT and not m.group("Msfme_31") + "e-" + m.group("Msfme_32") + "logas" in tCompostops and not (m.group("Msfme_31") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_33>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_33").lower() in plvrFeme and not " e " + m.group("Msfme_33") + "e " + m.group("Msfme_34") + "rias" in TEXT and not " ou " + m.group("Msfme_33") + "e " + m.group("Msfme_34") + "rias" in TEXT and not "s de " + m.group("Msfme_33") + "e " + m.group("Msfme_34") + "rias" in TEXT and not "s da " + m.group("Msfme_33") + "e " + m.group("Msfme_34") + "rias" in TEXT and not " a " + m.group("Msfme_33") + "e " + m.group("Msfme_34") + "rias" in TEXT and not m.group("Msfme_33") + "e-" + m.group("Msfme_34") + "rias" in tCompostops and not (m.group("Msfme_33") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_35>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_35").lower() in plvrFeme and not " e " + m.group("Msfme_35") + "e " + m.group("Msfme_36") + "ssimas" in TEXT and not " ou " + m.group("Msfme_35") + "e " + m.group("Msfme_36") + "ssimas" in TEXT and not "s de " + m.group("Msfme_35") + "e " + m.group("Msfme_36") + "ssimas" in TEXT and not "s da " + m.group("Msfme_35") + "e " + m.group("Msfme_36") + "ssimas" in TEXT and not " a " + m.group("Msfme_35") + "e " + m.group("Msfme_36") + "ssimas" in TEXT and not m.group("Msfme_35") + "e-" + m.group("Msfme_36") + "ssimas" in tCompostops and not (m.group("Msfme_35") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_37>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_37").lower() in plvrFeme and not " e " + m.group("Msfme_37") + "e " + m.group("Msfme_38") + "simas" in TEXT and not " ou " + m.group("Msfme_37") + "e " + m.group("Msfme_38") + "simas" in TEXT and not "s de " + m.group("Msfme_37") + "e " + m.group("Msfme_38") + "simas" in TEXT and not "s da " + m.group("Msfme_37") + "e " + m.group("Msfme_38") + "simas" in TEXT and not " a " + m.group("Msfme_37") + "e " + m.group("Msfme_38") + "simas" in TEXT and not m.group("Msfme_37") + "e-" + m.group("Msfme_38") + "simas" in tCompostops and not (m.group("Msfme_37") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_41>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_41").lower() in plvrFeme and not m.group("Msfme_42") in "D-d-" and not " e " + m.group("Msfme_41") + "e " + m.group("Msfme_42") + "oras" in TEXT and not " ou " + m.group("Msfme_41") + "e " + m.group("Msfme_42") + "oras" in TEXT and not "s de " + m.group("Msfme_41") + "e " + m.group("Msfme_42") + "oras" in TEXT and not "s da " + m.group("Msfme_41") + "e " + m.group("Msfme_42") + "oras" in TEXT and not " a " + m.group("Msfme_41") + "e " + m.group("Msfme_42") + "oras" in TEXT and not m.group("Msfme_41") + "e-" + m.group("Msfme_42") + "oras" in tCompostops and not (m.group("Msfme_41") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_43>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_43").lower() in plvrFeme and m.group("Msfme_44") in plvrMfr and not " e " + m.group("Msfme_43") + "e " + m.group("Msfme_44") + "es" in TEXT and not " ou " + m.group("Msfme_43") + "e " + m.group("Msfme_44") + "es" in TEXT and not "s de " + m.group("Msfme_43") + "e " + m.group("Msfme_44") + "es" in TEXT and not "s da " + m.group("Msfme_43") + "e " + m.group("Msfme_44") + "es" in TEXT and not " a " + m.group("Msfme_43") + "e " + m.group("Msfme_44") + "es" in TEXT and not m.group("Msfme_43") + "e-" + m.group("Msfme_44") + "es" in tCompostops and not (m.group("Msfme_43") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_45>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_45").lower() in plvrFeme and m.group("Msfme_46") in plvrFemr and not " e " + m.group("Msfme_45") + "e " + m.group("Msfme_46") + "es" in TEXT and not " ou " + m.group("Msfme_45") + "e " + m.group("Msfme_46") + "es" in TEXT and not "s de " + m.group("Msfme_45") + "e " + m.group("Msfme_46") + "es" in TEXT and not "s da " + m.group("Msfme_45") + "e " + m.group("Msfme_46") + "es" in TEXT and not " a " + m.group("Msfme_45") + "e " + m.group("Msfme_46") + "es" in TEXT and not m.group("Msfme_45") + "e-" + m.group("Msfme_46") + "es" in tCompostops and not (m.group("Msfme_45") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_47>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_47").lower() in plvrFeme and m.group("Msfme_48") in plvrMfal and not " e " + m.group("Msfme_47") + "e " + m.group("Msfme_48") + "is" in TEXT and not " ou " + m.group("Msfme_47") + "e " + m.group("Msfme_48") + "is" in TEXT and not "s de " + m.group("Msfme_47") + "e " + m.group("Msfme_48") + "is" in TEXT and not "s da " + m.group("Msfme_47") + "e " + m.group("Msfme_48") + "is" in TEXT and not " a " + m.group("Msfme_47") + "e " + m.group("Msfme_48") + "is" in TEXT and not m.group("Msfme_47") + "e-" + m.group("Msfme_48") + "is" in tCompostops and not (m.group("Msfme_47") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_49>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_49").lower() in plvrFeme and m.group("Msfme_50") in plvrMfcao and not " e " + m.group("Msfme_49") + "e " + m.group("Msfme_50") + "ões" in TEXT and not + " ou " + m.group("Msfme_49") + "e " + m.group("Msfme_50") + "ões" in TEXT and not + "s de " + m.group("Msfme_49") + "e " + m.group("Msfme_50") + "ões" in TEXT and not + "s da " + m.group("Msfme_49") + "e " + m.group("Msfme_50") + "ões" in TEXT and not + " a " + m.group("Msfme_49") + "e " + m.group("Msfme_50") + "ões" in TEXT and not (m.group("Msfme_49") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_51>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_51").lower() in plvrFeme and not m.group("Msfme_52") in plvrMascao and not " e " + m.group("Msfme_51") + "e " + m.group("Msfme_52") + "ões" in TEXT and not " ou " + m.group("Msfme_51") + "e " + m.group("Msfme_52") + "ões" in TEXT and not "s de " + m.group("Msfme_51") + "e " + m.group("Msfme_52") + "ões" in TEXT and not "s da " + m.group("Msfme_51") + "e " + m.group("Msfme_52") + "ões" in TEXT and not " a " + m.group("Msfme_51") + "e " + m.group("Msfme_52") + "ões" in TEXT and not m.group("Msfme_51") + "e-" + m.group("Msfme_52") + "ões" in tCompostops and not (m.group("Msfme_51") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_53>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_53").lower() in plvrFeme and m.group("Msfme_54") in plvrFemao and not " e " + m.group("Msfme_53") + "e " + m.group("Msfme_54") + "ões" in TEXT and not " ou " + m.group("Msfme_53") + "e " + m.group("Msfme_54") + "ões" in TEXT and not "s de " + m.group("Msfme_53") + "e " + m.group("Msfme_54") + "ões" in TEXT and not "s da " + m.group("Msfme_53") + "e " + m.group("Msfme_54") + "ões" in TEXT and not " a " + m.group("Msfme_53") + "e " + m.group("Msfme_54") + "ões" in TEXT and not (m.group("Msfme_53") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_55>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_55").lower() in plvrFeme and not " e " + m.group("Msfme_55") + "e " + m.group("Msfme_56") + "veis" in TEXT and not " ou " + m.group("Msfme_55") + "e " + m.group("Msfme_56") + "veis" in TEXT and not "s de " + m.group("Msfme_55") + "e " + m.group("Msfme_56") + "veis" in TEXT and not "s da " + m.group("Msfme_55") + "e " + m.group("Msfme_56") + "veis" in TEXT and not " a " + m.group("Msfme_55") + "e " + m.group("Msfme_56") + "veis" in TEXT and not m.group("Msfme_55") + "e-" + m.group("Msfme_56") + "veis" in tCompostops and not (m.group("Msfme_55") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_57>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_57").lower() in plvrFeme and m.group("Msfme_58").lower() in plvrMfe and not " e " + m.group("Msfme_57") + "e " + m.group("Msfme_58") + "es" in TEXT and not " ou " + m.group("Msfme_57") + "e " + m.group("Msfme_58") + "es" in TEXT and not "s de " + m.group("Msfme_57") + "e " + m.group("Msfme_58") + "es" in TEXT and not "s da " + m.group("Msfme_57") + "e " + m.group("Msfme_58") + "es" in TEXT and not " a " + m.group("Msfme_57") + "e " + m.group("Msfme_58") + "es" in TEXT and not m.group("Msfme_57") + "e-" + m.group("Msfme_58") + "es" in tCompostops and not (m.group("Msfme_57") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_59>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_59").lower() in plvrFeme and m.group("Msfme_60").lower() in plvrFeme and not " e " + m.group("Msfme_59") + "e " + m.group("Msfme_60") + "es" in TEXT and not " ou " + m.group("Msfme_59") + "e " + m.group("Msfme_60") + "es" in TEXT and not "s de " + m.group("Msfme_59") + "e " + m.group("Msfme_60") + "es" in TEXT and not "s da " + m.group("Msfme_59") + "e " + m.group("Msfme_60") + "es" in TEXT and not " a " + m.group("Msfme_59") + "e " + m.group("Msfme_60") + "es" in TEXT and not m.group("Msfme_59") + "e-" + m.group("Msfme_60") + "es" in tCompostops and not (m.group("Msfme_59") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_61>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_61").lower() in plvrFeme and m.group("Msfme_62") in plvrMfel and not " e " + m.group("Msfme_61") + "e " + m.group("Msfme_62") + "éis" in TEXT and not " ou " + m.group("Msfme_61") + "e " + m.group("Msfme_62") + "éis" in TEXT and not "s de " + m.group("Msfme_61") + "e " + m.group("Msfme_62") + "éis" in TEXT and not "s da " + m.group("Msfme_61") + "e " + m.group("Msfme_62") + "éis" in TEXT and not " a " + m.group("Msfme_61") + "e " + m.group("Msfme_62") + "éis" in TEXT and not m.group("Msfme_61") + "e-" + m.group("Msfme_62") + "éis" in tCompostops and not (m.group("Msfme_61") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_63>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_63").lower() in plvrFeme and m.group("Msfme_64") in plvrFemel and not " e " + m.group("Msfme_63") + "e " + m.group("Msfme_64") + "éis" in TEXT and not " ou " + m.group("Msfme_63") + "e " + m.group("Msfme_64") + "éis" in TEXT and not "s de " + m.group("Msfme_63") + "e " + m.group("Msfme_64") + "éis" in TEXT and not "s da " + m.group("Msfme_63") + "e " + m.group("Msfme_64") + "éis" in TEXT and not " a " + m.group("Msfme_63") + "e " + m.group("Msfme_64") + "éis" in TEXT and not m.group("Msfme_63") + "e-" + m.group("Msfme_64") + "éis" in tCompostops and not (m.group("Msfme_63") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_65>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_65").lower() in plvrFeme and m.group("Msfme_66") in plvrMfeu and not " e " + m.group("Msfme_65") + "e " + m.group("Msfme_66") + "us" in TEXT and not " ou " + m.group("Msfme_65") + "e " + m.group("Msfme_66") + "us" in TEXT and not "s de " + m.group("Msfme_65") + "e " + m.group("Msfme_66") + "us" in TEXT and not "s da " + m.group("Msfme_65") + "e " + m.group("Msfme_66") + "us" in TEXT and not " a " + m.group("Msfme_65") + "e " + m.group("Msfme_66") + "us" in TEXT and not m.group("Msfme_65") + "e-" + m.group("Msfme_66") + "us" in tCompostops and not (m.group("Msfme_65") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_67>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_67").lower() in plvrFeme and m.group("Msfme_68") in plvrFemu and not " e " + m.group("Msfme_67") + "e " + m.group("Msfme_68") + "us" in TEXT and not " ou " + m.group("Msfme_67") + "e " + m.group("Msfme_68") + "us" in TEXT and not "s de " + m.group("Msfme_67") + "e " + m.group("Msfme_68") + "us" in TEXT and not "s da " + m.group("Msfme_67") + "e " + m.group("Msfme_68") + "us" in TEXT and not " a " + m.group("Msfme_67") + "e " + m.group("Msfme_68") + "us" in TEXT and not m.group("Msfme_67") + "e-" + m.group("Msfme_68") + "us" in tCompostops and not (m.group("Msfme_67") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_69>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_69").lower() in plvrFeme and m.group("Msfme_70") in plvrInvaz and not " e " + m.group("Msfme_69") + "e " + m.group("Msfme_70") + "zes" in TEXT and not " ou " + m.group("Msfme_69") + "e " + m.group("Msfme_70") + "zes" in TEXT and not "s de " + m.group("Msfme_69") + "e " + m.group("Msfme_70") + "zes" in TEXT and not "s da " + m.group("Msfme_69") + "e " + m.group("Msfme_70") + "zes" in TEXT and not " a " + m.group("Msfme_69") + "e " + m.group("Msfme_70") + "zes" in TEXT and not m.group("Msfme_69") + "e-" + m.group("Msfme_70") + "zes" in tCompostops and not (m.group("Msfme_69") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_71>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_71").lower() in plvrFeme and m.group("Msfme_72") in plvrFemz and not " e " + m.group("Msfme_71") + "e " + m.group("Msfme_72") + "zes" in TEXT and not " ou " + m.group("Msfme_71") + "e " + m.group("Msfme_72") + "zes" in TEXT and not "s de " + m.group("Msfme_71") + "e " + m.group("Msfme_72") + "zes" in TEXT and not "s da " + m.group("Msfme_71") + "e " + m.group("Msfme_72") + "zes" in TEXT and not " a " + m.group("Msfme_71") + "e " + m.group("Msfme_72") + "zes" in TEXT and not m.group("Msfme_71") + "e-" + m.group("Msfme_72") + "zes" in tCompostops and not (m.group("Msfme_71") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_73>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_73").lower() in plvrFeme and m.group("Msfme_74") in pvrFeman and not " e " + m.group("Msfme_73") + "e " + m.group("Msfme_74") + "s" in TEXT and not " ou " + m.group("Msfme_73") + "e " + m.group("Msfme_74") + "s" in TEXT and not "s de " + m.group("Msfme_73") + "e " + m.group("Msfme_74") + "s" in TEXT and not "s da " + m.group("Msfme_73") + "e " + m.group("Msfme_74") + "s" in TEXT and not " a " + m.group("Msfme_73") + "e " + m.group("Msfme_74") + "s" in TEXT and not m.group("Msfme_73") + "e-" + m.group("Msfme_74") + "s" in tCompostops and not (m.group("Msfme_73") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_75>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_76>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_75").lower() in plvrFeme and m.group("Msfme_76") in plvrMFm and not " e " + m.group("Msfme_75") + "e " + m.group("Msfme_76") + "ns" in TEXT and not " ou " + m.group("Msfme_75") + "e " + m.group("Msfme_76") + "ns" in TEXT and not "s de " + m.group("Msfme_75") + "e " + m.group("Msfme_76") + "ns" in TEXT and not "s da " + m.group("Msfme_75") + "e " + m.group("Msfme_76") + "ns" in TEXT and not " a " + m.group("Msfme_75") + "e " + m.group("Msfme_76") + "ns" in TEXT and not m.group("Msfme_75") + "e-" + m.group("Msfme_76") + "ns" in tCompostops and not (m.group("Msfme_75") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfme_77>[a-zA-Zçáéíóúâêô]+)e (?P<Msfme_78>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfme_77").lower() in plvrFeme and m.group("Msfme_78") in plvrFemm and not " e " + m.group("Msfme_77") + "e " + m.group("Msfme_78") + "ns" in TEXT and not " ou " + m.group("Msfme_77") + "e " + m.group("Msfme_78") + "ns" in TEXT and not "s de " + m.group("Msfme_77") + "e " + m.group("Msfme_78") + "ns" in TEXT and not "s da " + m.group("Msfme_77") + "e " + m.group("Msfme_78") + "ns" in TEXT and not " a " + m.group("Msfme_77") + "e " + m.group("Msfme_78") + "ns" in TEXT and not m.group("Msfme_77") + "e-" + m.group("Msfme_78") + "ns" in tCompostops and not (m.group("Msfme_77") in "parte" and excMparte.search(TEXT))'],
# plvrMfe a
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_1>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_1").lower() in plvrMfe and m.group("Msmfea_2").lower() in plvrFema and not " e " + m.group("Msmfea_1") + "e " + m.group("Msmfea_2") +"s" in TEXT and not " ou " + m.group("Msmfea_1") + "e " + m.group("Msmfea_2") + "s" in TEXT and not "s de " + m.group("Msmfea_1") + "e " + m.group("Msmfea_2") + "s" in TEXT and not "s da " + m.group("Msmfea_1") + "e " + m.group("Msmfea_2") + "s" in TEXT and not " a " + m.group("Msmfea_1") + "e " + m.group("Msmfea_2") + "s" in TEXT and not m.group("Msmfea_1") + "e-" + m.group("Msmfea_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_3>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_3").lower() in plvrMfe and m.group("Msmfea_4").lower() in plvrMfe and not " e " + m.group("Msmfea_3") + "e " + m.group("Msmfea_4") + "as" in TEXT and not " ou " + m.group("Msmfea_3") + "e " + m.group("Msmfea_4") + "as" in TEXT and not "s de " + m.group("Msmfea_3") + "e " + m.group("Msmfea_4") + "as" in TEXT and not "s da " + m.group("Msmfea_3") + "e " + m.group("Msmfea_4") + "as" in TEXT and not " a " + m.group("Msmfea_3") + "e " + m.group("Msmfea_4") + "as" in TEXT and not m.group("Msmfea_3") + "e-" + m.group("Msmfea_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_5>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_5").lower() in plvrMfe and not m.group("Msmfea_6").lower() in excAdo and not " e " + m.group("Msmfea_5") + "e " + m.group("Msmfea_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msmfea_5") + "e " + m.group("Msmfea_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msmfea_5") + "e " + m.group("Msmfea_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Msmfea_5") + "e " + m.group("Msmfea_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Msmfea_5") + "e " + m.group("Msmfea_6") + m.group(3) + "dos" in TEXT and not m.group("Msmfea_5") + "e-" + m.group("Msmfea_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_7>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_7").lower() in plvrMfe and not m.group("Msmfea_8").lower() in excIsta and not " e " + m.group("Msmfea_7") + "e " + m.group("Msmfea_8") + "s" in TEXT and not " ou " + m.group("Msmfea_7") + "e " + m.group("Msmfea_8") + "s" in TEXT and not "s de " + m.group("Msmfea_7") + "e " + m.group("Msmfea_8") + "s" in TEXT and not "s da " + m.group("Msmfea_7") + "e " + m.group("Msmfea_8") + "s" in TEXT and not " a " + m.group("Msmfea_7") + "e " + m.group("Msmfea_8") + "s" in TEXT and not m.group("Msmfea_7") + "e-" + m.group("Msmfea_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_9>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_9").lower() in plvrMfe and m.group("Msmfea_10").lower() in plvrInva and not " e " + m.group("Msmfea_9") + "e " + m.group("Msmfea_10") + "s" in TEXT and not " ou " + m.group("Msmfea_9") + "e " + m.group("Msmfea_10") + "s" in TEXT and not "s de " + m.group("Msmfea_9") + "e " + m.group("Msmfea_10") + "s" in TEXT and not "s da " + m.group("Msmfea_9") + "e " + m.group("Msmfea_10") + "s" in TEXT and not " a " + m.group("Msmfea_9") + "e " + m.group("Msmfea_10") + "s" in TEXT and not m.group("Msmfea_9") + "e-" + m.group("Msmfea_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_11>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_11").lower() in plvrMfe and not m.group("Msmfea_12").lower() in excAdo and not " e " + m.group("Msmfea_11") + "e " + m.group("Msmfea_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msmfea_11") + "e " + m.group("Msmfea_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msmfea_11") + "e " + m.group("Msmfea_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Msmfea_11") + "e " + m.group("Msmfea_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Msmfea_11") + "e " + m.group("Msmfea_12") + m.group(3) + "das" in TEXT and not m.group("Msmfea_11") + "e-" + m.group("Msmfea_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_15>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_15").lower() in plvrMfe and not " e " + m.group("Msmfea_15") + "e " + m.group("Msmfea_16") + "osas" in TEXT and not " ou " + m.group("Msmfea_15") + "e " + m.group("Msmfea_16") + "osas" in TEXT and not "s de " + m.group("Msmfea_15") + "e " + m.group("Msmfea_16") + "osas" in TEXT and not "s da " + m.group("Msmfea_15") + "e " + m.group("Msmfea_16") + "osas" in TEXT and not " a " + m.group("Msmfea_15") + "e " + m.group("Msmfea_16") + "osas" in TEXT and not m.group("Msmfea_15") + "e-" + m.group("Msmfea_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_17>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_17").lower() in plvrMfe and not " e " + m.group("Msmfea_17") + "e " + m.group("Msmfea_18") + "ivas" in TEXT and not " ou " + m.group("Msmfea_17") + "e " + m.group("Msmfea_18") + "ivas" in TEXT and not "s de " + m.group("Msmfea_17") + "e " + m.group("Msmfea_18") + "ivas" in TEXT and not "s da " + m.group("Msmfea_17") + "e " + m.group("Msmfea_18") + "ivas" in TEXT and not " a " + m.group("Msmfea_17") + "e " + m.group("Msmfea_18") + "ivas" in TEXT and not m.group("Msmfea_17") + "e-" + m.group("Msmfea_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_21>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_21").lower() in plvrMfe and not " e " + m.group("Msmfea_21") + "e " + m.group("Msmfea_22") + "icas" in TEXT and not " ou " + m.group("Msmfea_21") + "e " + m.group("Msmfea_22") + "icas" in TEXT and not "s de " + m.group("Msmfea_21") + "e " + m.group("Msmfea_22") + "icas" in TEXT and not "s da " + m.group("Msmfea_21") + "e " + m.group("Msmfea_22") + "icas" in TEXT and not " a " + m.group("Msmfea_21") + "e " + m.group("Msmfea_22") + "icas" in TEXT and not m.group("Msmfea_21") + "e-" + m.group("Msmfea_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_23>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_23").lower() in plvrMfe and not " e " + m.group("Msmfea_23") + "e " + m.group("Msmfea_24") + "icas" in TEXT and not " ou " + m.group("Msmfea_23") + "e " + m.group("Msmfea_24") + "icas" in TEXT and not "s de " + m.group("Msmfea_23") + "e " + m.group("Msmfea_24") + "icas" in TEXT and not "s da " + m.group("Msmfea_23") + "e " + m.group("Msmfea_24") + "icas" in TEXT and not " a " + m.group("Msmfea_23") + "e " + m.group("Msmfea_24") + "icas" in TEXT and not m.group("Msmfea_23") + "e-" + m.group("Msmfea_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_25>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_25").lower() in plvrMfe and not " e " + m.group("Msmfea_25") + "e " + m.group("Msmfea_26") + "icas" in TEXT and not " ou " + m.group("Msmfea_25") + "e " + m.group("Msmfea_26") + "icas" in TEXT and not "s de " + m.group("Msmfea_25") + "e " + m.group("Msmfea_26") + "icas" in TEXT and not "s da " + m.group("Msmfea_25") + "e " + m.group("Msmfea_26") + "icas" in TEXT and not " a " + m.group("Msmfea_25") + "e " + m.group("Msmfea_26") + "icas" in TEXT and not m.group("Msmfea_25") + "e-" + m.group("Msmfea_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_27>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_27").lower() in plvrMfe and not " e " + m.group("Msmfea_27") + "e " + m.group("Msmfea_28") + "escas" in TEXT and not " ou " + m.group("Msmfea_27") + "e " + m.group("Msmfea_28") + "escas" in TEXT and not "s de " + m.group("Msmfea_27") + "e " + m.group("Msmfea_28") + "escas" in TEXT and not "s da " + m.group("Msmfea_27") + "e " + m.group("Msmfea_28") + "escas" in TEXT and not " a " + m.group("Msmfea_27") + "e " + m.group("Msmfea_28") + "escas" in TEXT and not m.group("Msmfea_27") + "e-" + m.group("Msmfea_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_29>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_29").lower() in plvrMfe and not " e " + m.group("Msmfea_29") + "e " + m.group("Msmfea_30") + "idas" in TEXT and not " ou " + m.group("Msmfea_29") + "s " + m.group("Msmfea_30") + "idas" in TEXT and not "s de " + m.group("Msmfea_29") + "s " + m.group("Msmfea_30") + "idas" in TEXT and not "s da " + m.group("Msmfea_29") + "s " + m.group("Msmfea_30") + "idas" in TEXT and not " a " + m.group("Msmfea_29") + "s " + m.group("Msmfea_30") + "idas" in TEXT and not m.group("Msmfea_29") + "e-" + m.group("Msmfea_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_31>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_31").lower() in plvrMfe and not " e " + m.group("Msmfea_31") + "e " + m.group("Msmfea_32") + "logas" in TEXT and not " ou " + m.group("Msmfea_31") + "e " + m.group("Msmfea_32") + "logas" in TEXT and not "s de " + m.group("Msmfea_31") + "e " + m.group("Msmfea_32") + "logas" in TEXT and not "s da " + m.group("Msmfea_31") + "e " + m.group("Msmfea_32") + "logas" in TEXT and not " a " + m.group("Msmfea_31") + "e " + m.group("Msmfea_32") + "logas" in TEXT and not m.group("Msmfea_31") + "e-" + m.group("Msmfea_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_33>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_33").lower() in plvrMfe and not " e " + m.group("Msmfea_33") + "e " + m.group("Msmfea_34") + "rias" in TEXT and not " ou " + m.group("Msmfea_33") + "e " + m.group("Msmfea_34") + "rias" in TEXT and not "s de " + m.group("Msmfea_33") + "e " + m.group("Msmfea_34") + "rias" in TEXT and not "s da " + m.group("Msmfea_33") + "e " + m.group("Msmfea_34") + "rias" in TEXT and not " a " + m.group("Msmfea_33") + "e " + m.group("Msmfea_34") + "rias" in TEXT and not m.group("Msmfea_33") + "e-" + m.group("Msmfea_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_35>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_35").lower() in plvrMfe and not " e " + m.group("Msmfea_35") + "e " + m.group("Msmfea_36") + "ssimas" in TEXT and not " ou " + m.group("Msmfea_35") + "e " + m.group("Msmfea_36") + "ssimas" in TEXT and not "s de " + m.group("Msmfea_35") + "e " + m.group("Msmfea_36") + "ssimas" in TEXT and not "s da " + m.group("Msmfea_35") + "e " + m.group("Msmfea_36") + "ssimas" in TEXT and not " a " + m.group("Msmfea_35") + "e " + m.group("Msmfea_36") + "ssimas" in TEXT and not m.group("Msmfea_35") + "e-" + m.group("Msmfea_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_37>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_37").lower() in plvrMfe and not " e " + m.group("Msmfea_37") + "e " + m.group("Msmfea_38") + "simas" in TEXT and not " ou " + m.group("Msmfea_37") + "e " + m.group("Msmfea_38") + "simas" in TEXT and not "s de " + m.group("Msmfea_37") + "e " + m.group("Msmfea_38") + "simas" in TEXT and not "s da " + m.group("Msmfea_37") + "e " + m.group("Msmfea_38") + "simas" in TEXT and not " a " + m.group("Msmfea_37") + "e " + m.group("Msmfea_38") + "simas" in TEXT and not m.group("Msmfea_37") + "e-" + m.group("Msmfea_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_41>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_41").lower() in plvrMfe and not m.group("Msmfea_42") in "D-d-" and not " e " + m.group("Msmfea_41") + "e " + m.group("Msmfea_42") + "oras" in TEXT and not " ou " + m.group("Msmfea_41") + "e " + m.group("Msmfea_42") + "oras" in TEXT and not "s de " + m.group("Msmfea_41") + "e " + m.group("Msmfea_42") + "oras" in TEXT and not "s da " + m.group("Msmfea_41") + "e " + m.group("Msmfea_42") + "oras" in TEXT and not " a " + m.group("Msmfea_41") + "e " + m.group("Msmfea_42") + "oras" in TEXT and not m.group("Msmfea_41") + "e-" + m.group("Msmfea_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_43>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_43").lower() in plvrMfe and m.group("Msmfea_44") in plvrMfr and not " e " + m.group("Msmfea_43") + "e " + m.group("Msmfea_44") + "es" in TEXT and not " ou " + m.group("Msmfea_43") + "e " + m.group("Msmfea_44") + "es" in TEXT and not "s de " + m.group("Msmfea_43") + "e " + m.group("Msmfea_44") + "es" in TEXT and not "s da " + m.group("Msmfea_43") + "e " + m.group("Msmfea_44") + "es" in TEXT and not " a " + m.group("Msmfea_43") + "e " + m.group("Msmfea_44") + "es" in TEXT and not m.group("Msmfea_43") + "e-" + m.group("Msmfea_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_45>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_45").lower() in plvrMfe and m.group("Msmfea_46") in plvrFemr and not " e " + m.group("Msmfea_45") + "e " + m.group("Msmfea_46") + "es" in TEXT and not " ou " + m.group("Msmfea_45") + "e " + m.group("Msmfea_46") + "es" in TEXT and not "s de " + m.group("Msmfea_45") + "e " + m.group("Msmfea_46") + "es" in TEXT and not "s da " + m.group("Msmfea_45") + "e " + m.group("Msmfea_46") + "es" in TEXT and not " a " + m.group("Msmfea_45") + "e " + m.group("Msmfea_46") + "es" in TEXT and not m.group("Msmfea_45") + "e-" + m.group("Msmfea_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_47>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_47").lower() in plvrMfe and m.group("Msmfea_48") in plvrMfal and not " e " + m.group("Msmfea_47") + "e " + m.group("Msmfea_48") + "is" in TEXT and not " ou " + m.group("Msmfea_47") + "e " + m.group("Msmfea_48") + "is" in TEXT and not "s de " + m.group("Msmfea_47") + "e " + m.group("Msmfea_48") + "is" in TEXT and not "s da " + m.group("Msmfea_47") + "e " + m.group("Msmfea_48") + "is" in TEXT and not " a " + m.group("Msmfea_47") + "e " + m.group("Msmfea_48") + "is" in TEXT and not m.group("Msmfea_47") + "e-" + m.group("Msmfea_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_49>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_49").lower() in plvrMfe and m.group("Msmfea_50") in plvrMfcao and not " e " + m.group("Msmfea_49") + "e " + m.group("Msmfea_50") + "ões" in TEXT and not + " ou " + m.group("Msmfea_49") + "e " + m.group("Msmfea_50") + "ões" in TEXT and not + "s de " + m.group("Msmfea_49") + "e " + m.group("Msmfea_50") + "ões" in TEXT and not + "s da " + m.group("Msmfea_49") + "e " + m.group("Msmfea_50") + "ões" in TEXT and not + " a " + m.group("Msmfea_49") + "e " + m.group("Msmfea_50") + "ões" in TEXT and not m.group("Msmfea_49") + "e-" + m.group("Msmfea_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_51>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_51").lower() in plvrMfe and not m.group("Msmfea_52") in plvrMascao and not " e " + m.group("Msmfea_51") + "e " + m.group("Msmfea_52") + "ões" in TEXT and not " ou " + m.group("Msmfea_51") + "e " + m.group("Msmfea_52") + "ões" in TEXT and not "s de " + m.group("Msmfea_51") + "e " + m.group("Msmfea_52") + "ões" in TEXT and not "s da " + m.group("Msmfea_51") + "e " + m.group("Msmfea_52") + "ões" in TEXT and not " a " + m.group("Msmfea_51") + "e " + m.group("Msmfea_52") + "ões" in TEXT and not m.group("Msmfea_51") + "e-" + m.group("Msmfea_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_53>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_53").lower() in plvrMfe and m.group("Msmfea_54") in plvrFemao and not " e " + m.group("Msmfea_53") + "e " + m.group("Msmfea_54") + "ões" in TEXT and not " ou " + m.group("Msmfea_53") + "e " + m.group("Msmfea_54") + "ões" in TEXT and not "s de " + m.group("Msmfea_53") + "e " + m.group("Msmfea_54") + "ões" in TEXT and not "s da " + m.group("Msmfea_53") + "e " + m.group("Msmfea_54") + "ões" in TEXT and not " a " + m.group("Msmfea_53") + "e " + m.group("Msmfea_54") + "ões" in TEXT and not m.group("Msmfea_53") + "e-" + m.group("Msmfea_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_55>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_55").lower() in plvrMfe and not " e " + m.group("Msmfea_55") + "e " + m.group("Msmfea_56") + "veis" in TEXT and not " ou " + m.group("Msmfea_55") + "e " + m.group("Msmfea_56") + "veis" in TEXT and not "s de " + m.group("Msmfea_55") + "e " + m.group("Msmfea_56") + "veis" in TEXT and not "s da " + m.group("Msmfea_55") + "e " + m.group("Msmfea_56") + "veis" in TEXT and not " a " + m.group("Msmfea_55") + "e " + m.group("Msmfea_56") + "veis" in TEXT and not m.group("Msmfea_55") + "e-" + m.group("Msmfea_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_57>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_57").lower() in plvrMfe and m.group("Msmfea_58").lower() in plvrMfe and not " e " + m.group("Msmfea_57") + "e " + m.group("Msmfea_58") + "es" in TEXT and not " ou " + m.group("Msmfea_57") + "e " + m.group("Msmfea_58") + "es" in TEXT and not "s de " + m.group("Msmfea_57") + "e " + m.group("Msmfea_58") + "es" in TEXT and not "s da " + m.group("Msmfea_57") + "e " + m.group("Msmfea_58") + "es" in TEXT and not " a " + m.group("Msmfea_57") + "e " + m.group("Msmfea_58") + "es" in TEXT and not m.group("Msmfea_57") + "e-" + m.group("Msmfea_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_59>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_59").lower() in plvrMfe and m.group("Msmfea_60").lower() in plvrMfe and not " e " + m.group("Msmfea_59") + "e " + m.group("Msmfea_60") + "es" in TEXT and not " ou " + m.group("Msmfea_59") + "e " + m.group("Msmfea_60") + "es" in TEXT and not "s de " + m.group("Msmfea_59") + "e " + m.group("Msmfea_60") + "es" in TEXT and not "s da " + m.group("Msmfea_59") + "e " + m.group("Msmfea_60") + "es" in TEXT and not " a " + m.group("Msmfea_59") + "e " + m.group("Msmfea_60") + "es" in TEXT and not m.group("Msmfea_59") + "e-" + m.group("Msmfea_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_61>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_61").lower() in plvrMfe and m.group("Msmfea_62") in plvrMfel and not " e " + m.group("Msmfea_61") + "e " + m.group("Msmfea_62") + "éis" in TEXT and not " ou " + m.group("Msmfea_61") + "e " + m.group("Msmfea_62") + "éis" in TEXT and not "s de " + m.group("Msmfea_61") + "e " + m.group("Msmfea_62") + "éis" in TEXT and not "s da " + m.group("Msmfea_61") + "e " + m.group("Msmfea_62") + "éis" in TEXT and not " a " + m.group("Msmfea_61") + "e " + m.group("Msmfea_62") + "éis" in TEXT and not m.group("Msmfea_61") + "e-" + m.group("Msmfea_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_63>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_63").lower() in plvrMfe and m.group("Msmfea_64") in plvrFemel and not " e " + m.group("Msmfea_63") + "e " + m.group("Msmfea_64") + "éis" in TEXT and not " ou " + m.group("Msmfea_63") + "e " + m.group("Msmfea_64") + "éis" in TEXT and not "s de " + m.group("Msmfea_63") + "e " + m.group("Msmfea_64") + "éis" in TEXT and not "s da " + m.group("Msmfea_63") + "e " + m.group("Msmfea_64") + "éis" in TEXT and not " a " + m.group("Msmfea_63") + "e " + m.group("Msmfea_64") + "éis" in TEXT and not m.group("Msmfea_63") + "e-" + m.group("Msmfea_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_65>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_65").lower() in plvrMfe and m.group("Msmfea_66") in plvrMfeu and not " e " + m.group("Msmfea_65") + "e " + m.group("Msmfea_66") + "us" in TEXT and not " ou " + m.group("Msmfea_65") + "e " + m.group("Msmfea_66") + "us" in TEXT and not "s de " + m.group("Msmfea_65") + "e " + m.group("Msmfea_66") + "us" in TEXT and not "s da " + m.group("Msmfea_65") + "e " + m.group("Msmfea_66") + "us" in TEXT and not " a " + m.group("Msmfea_65") + "e " + m.group("Msmfea_66") + "us" in TEXT and not m.group("Msmfea_65") + "e-" + m.group("Msmfea_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_67>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_67").lower() in plvrMfe and m.group("Msmfea_68") in plvrFemu and not " e " + m.group("Msmfea_67") + "e " + m.group("Msmfea_68") + "us" in TEXT and not " ou " + m.group("Msmfea_67") + "e " + m.group("Msmfea_68") + "us" in TEXT and not "s de " + m.group("Msmfea_67") + "e " + m.group("Msmfea_68") + "us" in TEXT and not "s da " + m.group("Msmfea_67") + "e " + m.group("Msmfea_68") + "us" in TEXT and not " a " + m.group("Msmfea_67") + "e " + m.group("Msmfea_68") + "us" in TEXT and not m.group("Msmfea_67") + "e-" + m.group("Msmfea_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_69>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_69").lower() in plvrMfe and m.group("Msmfea_70") in plvrInvaz and not " e " + m.group("Msmfea_69") + "e " + m.group("Msmfea_70") + "zes" in TEXT and not " ou " + m.group("Msmfea_69") + "e " + m.group("Msmfea_70") + "zes" in TEXT and not "s de " + m.group("Msmfea_69") + "e " + m.group("Msmfea_70") + "zes" in TEXT and not "s da " + m.group("Msmfea_69") + "e " + m.group("Msmfea_70") + "zes" in TEXT and not " a " + m.group("Msmfea_69") + "e " + m.group("Msmfea_70") + "zes" in TEXT and not m.group("Msmfea_69") + "e-" + m.group("Msmfea_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_71>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_71").lower() in plvrMfe and m.group("Msmfea_72") in plvrFemz and not " e " + m.group("Msmfea_71") + "e " + m.group("Msmfea_72") + "zes" in TEXT and not " ou " + m.group("Msmfea_71") + "e " + m.group("Msmfea_72") + "zes" in TEXT and not "s de " + m.group("Msmfea_71") + "e " + m.group("Msmfea_72") + "zes" in TEXT and not "s da " + m.group("Msmfea_71") + "e " + m.group("Msmfea_72") + "zes" in TEXT and not " a " + m.group("Msmfea_71") + "e " + m.group("Msmfea_72") + "zes" in TEXT and not m.group("Msmfea_71") + "e-" + m.group("Msmfea_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_73>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_73").lower() in plvrMfe and m.group("Msmfea_74") in pvrFeman and not " e " + m.group("Msmfea_73") + "e " + m.group("Msmfea_74") + "s" in TEXT and not " ou " + m.group("Msmfea_73") + "e " + m.group("Msmfea_74") + "s" in TEXT and not "s de " + m.group("Msmfea_73") + "e " + m.group("Msmfea_74") + "s" in TEXT and not "s da " + m.group("Msmfea_73") + "e " + m.group("Msmfea_74") + "s" in TEXT and not " a " + m.group("Msmfea_73") + "e " + m.group("Msmfea_74") + "s" in TEXT and not m.group("Msmfea_73") + "e-" + m.group("Msmfea_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_75>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_76>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_75").lower() in plvrMfe and m.group("Msmfea_76") in plvrMFm and not " e " + m.group("Msmfea_75") + "e " + m.group("Msmfea_76") + "ns" in TEXT and not " ou " + m.group("Msmfea_75") + "e " + m.group("Msmfea_76") + "ns" in TEXT and not "s de " + m.group("Msmfea_75") + "e " + m.group("Msmfea_76") + "ns" in TEXT and not "s da " + m.group("Msmfea_75") + "e " + m.group("Msmfea_76") + "ns" in TEXT and not " a " + m.group("Msmfea_75") + "e " + m.group("Msmfea_76") + "ns" in TEXT and not m.group("Msmfea_75") + "e-" + m.group("Msmfea_76") + "ns" in tCompostops and not (m.group("Msmfea_75") in "parte" and excMparte.search(TEXT))'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfea_77>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfea_78>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfea_77").lower() in plvrMfe and m.group("Msmfea_78") in plvrFemm and not " e " + m.group("Msmfea_77") + "e " + m.group("Msmfea_78") + "ns" in TEXT and not " ou " + m.group("Msmfea_77") + "e " + m.group("Msmfea_78") + "ns" in TEXT and not "s de " + m.group("Msmfea_77") + "e " + m.group("Msmfea_78") + "ns" in TEXT and not "s da " + m.group("Msmfea_77") + "e " + m.group("Msmfea_78") + "ns" in TEXT and not " a " + m.group("Msmfea_77") + "e " + m.group("Msmfea_78") + "ns" in TEXT and not m.group("Msmfea_77") + "e-" + m.group("Msmfea_78") + "ns" in tCompostops and not (m.group("Msmfea_77") in "parte" and excMparte.search(TEXT))'],
# plvrMfe o
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_1>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_1").lower() in plvrMfe and m.group("Msmfeo_2").lower() in plvrMasca and not " e " + m.group("Msmfeo_1") + "e " + m.group("Msmfeo_2") +"s" in TEXT and not " ou " + m.group("Msmfeo_1") + "e " + m.group("Msmfeo_2") + "s" in TEXT and not "s de " + m.group("Msmfeo_1") + "e " + m.group("Msmfeo_2") + "s" in TEXT and not "s do " + m.group("Msmfeo_1") + "e " + m.group("Msmfeo_2") + "s" in TEXT and not " o " + m.group("Msmfeo_1") + "e " + m.group("Msmfeo_2") + "s" in TEXT and not m.group("Msmfeo_1") + "e-" + m.group("Msmfeo_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_3>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_3").lower() in plvrMfe and m.group("Msmfeo_4").lower() in plvrMfe and not " e " + m.group("Msmfeo_3") + "e " + m.group("Msmfeo_4") + "os" in TEXT and not " ou " + m.group("Msmfeo_3") + "e " + m.group("Msmfeo_4") + "os" in TEXT and not "s de " + m.group("Msmfeo_3") + "e " + m.group("Msmfeo_4") + "os" in TEXT and not "s do " + m.group("Msmfeo_3") + "e " + m.group("Msmfeo_4") + "os" in TEXT and not " o " + m.group("Msmfeo_3") + "e " + m.group("Msmfeo_4") + "os" in TEXT and not m.group("Msmfeo_3") + "e-" + m.group("Msmfeo_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_5>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_5").lower() in plvrMfe and not m.group("Msmfeo_6").lower() in excAdo and not " e " + m.group("Msmfeo_5") + "e " + m.group("Msmfeo_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msmfeo_5") + "e " + m.group("Msmfeo_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msmfeo_5") + "e " + m.group("Msmfeo_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msmfeo_5") + "e " + m.group("Msmfeo_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msmfeo_5") + "e " + m.group("Msmfeo_6") + m.group(3) + "dos" in TEXT and not m.group("Msmfeo_5") + "e-" + m.group("Msmfeo_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_13>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_13").lower() in plvrMfe and not " e " + m.group("Msmfeo_13") + "e " + m.group("Msmfeo_14") + "osos" in TEXT and not " ou " + m.group("Msmfeo_13") + "e " + m.group("Msmfeo_14") + "osos" in TEXT and not "s de " + m.group("Msmfeo_13") + "e " + m.group("Msmfeo_14") + "osos" in TEXT and not "s do " + m.group("Msmfeo_13") + "e " + m.group("Msmfeo_14") + "osos" in TEXT and not " o " + m.group("Msmfeo_13") + "e " + m.group("Msmfeo_14") + "osos" in TEXT and not m.group("Msmfeo_13") + "e-" + m.group("Msmfeo_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_19>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_19").lower() in plvrMfe and not " e " + m.group("Msmfeo_19") + "e " + m.group("Msmfeo_20") + "ivas" in TEXT and not " ou " + m.group("Msmfeo_19") + "e " + m.group("Msmfeo_20") + "ivas" in TEXT and not "s de " + m.group("Msmfeo_19") + "e " + m.group("Msmfeo_20") + "ivas" in TEXT and not "s do " + m.group("Msmfeo_19") + "e " + m.group("Msmfeo_20") + "ivas" in TEXT and not " o " + m.group("Msmfeo_19") + "e " + m.group("Msmfeo_20") + "ivas" in TEXT and not m.group("Msmfeo_19") + "e-" + m.group("Msmfeo_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_21>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_21").lower() in plvrMfe and not " e " + m.group("Msmfeo_21") + "e " + m.group("Msmfeo_22") + "icos" in TEXT and not " ou " + m.group("Msmfeo_21") + "e " + m.group("Msmfeo_22") + "icos" in TEXT and not "s de " + m.group("Msmfeo_21") + "e " + m.group("Msmfeo_22") + "icos" in TEXT and not "s do " + m.group("Msmfeo_21") + "e " + m.group("Msmfeo_22") + "icos" in TEXT and not " o " + m.group("Msmfeo_21") + "e " + m.group("Msmfeo_22") + "icos" in TEXT and not m.group("Msmfeo_21") + "e-" + m.group("Msmfeo_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_23>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_23").lower() in plvrMfe and not " e " + m.group("Msmfeo_23") + "e " + m.group("Msmfeo_24") + "icos" in TEXT and not " ou " + m.group("Msmfeo_23") + "e " + m.group("Msmfeo_24") + "icos" in TEXT and not "s de " + m.group("Msmfeo_23") + "e " + m.group("Msmfeo_24") + "icos" in TEXT and not "s do " + m.group("Msmfeo_23") + "e " + m.group("Msmfeo_24") + "icos" in TEXT and not " o " + m.group("Msmfeo_23") + "e " + m.group("Msmfeo_24") + "icos" in TEXT and not m.group("Msmfeo_23") + "e-" + m.group("Msmfeo_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_25>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_25").lower() in plvrMfe and not " e " + m.group("Msmfeo_25") + "e " + m.group("Msmfeo_26") + "icos" in TEXT and not " ou " + m.group("Msmfeo_25") + "e " + m.group("Msmfeo_26") + "icos" in TEXT and not "s de " + m.group("Msmfeo_25") + "e " + m.group("Msmfeo_26") + "icos" in TEXT and not "s do " + m.group("Msmfeo_25") + "e " + m.group("Msmfeo_26") + "icos" in TEXT and not " o " + m.group("Msmfeo_25") + "e " + m.group("Msmfeo_26") + "icos" in TEXT and not m.group("Msmfeo_25") + "e-" + m.group("Msmfeo_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_27>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_27").lower() in plvrMfe and not " e " + m.group("Msmfeo_27") + "e " + m.group("Msmfeo_28") + "escos" in TEXT and not " ou " + m.group("Msmfeo_27") + "e " + m.group("Msmfeo_28") + "escos" in TEXT and not "s de " + m.group("Msmfeo_27") + "e " + m.group("Msmfeo_28") + "escos" in TEXT and not "s do " + m.group("Msmfeo_27") + "e " + m.group("Msmfeo_28") + "escos" in TEXT and not " o " + m.group("Msmfeo_27") + "e " + m.group("Msmfeo_28") + "escos" in TEXT and not m.group("Msmfeo_27") + "e-" + m.group("Msmfeo_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_29>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_29").lower() in plvrMfe and not " e " + m.group("Msmfeo_29") + "e " + m.group("Msmfeo_30") + "idos" in TEXT and not " ou " + m.group("Msmfeo_29") + "s " + m.group("Msmfeo_30") + "idos" in TEXT and not "s de " + m.group("Msmfeo_29") + "s " + m.group("Msmfeo_30") + "idos" in TEXT and not "s do " + m.group("Msmfeo_29") + "s " + m.group("Msmfeo_30") + "idos" in TEXT and not " o " + m.group("Msmfeo_29") + "s " + m.group("Msmfeo_30") + "idos" in TEXT and not m.group("Msmfeo_29") + "e-" + m.group("Msmfeo_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_31>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_31").lower() in plvrMfe and not " e " + m.group("Msmfeo_31") + "e " + m.group("Msmfeo_32") + "logos" in TEXT and not " ou " + m.group("Msmfeo_31") + "e " + m.group("Msmfeo_32") + "logos" in TEXT and not "s de " + m.group("Msmfeo_31") + "e " + m.group("Msmfeo_32") + "logos" in TEXT and not "s do " + m.group("Msmfeo_31") + "e " + m.group("Msmfeo_32") + "logos" in TEXT and not " o " + m.group("Msmfeo_31") + "e " + m.group("Msmfeo_32") + "logos" in TEXT and not m.group("Msmfeo_31") + "e-" + m.group("Msmfeo_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_33>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_33").lower() in plvrMfe and not " e " + m.group("Msmfeo_33") + "e " + m.group("Msmfeo_34") + "rios" in TEXT and not " ou " + m.group("Msmfeo_33") + "e " + m.group("Msmfeo_34") + "rios" in TEXT and not "s de " + m.group("Msmfeo_33") + "e " + m.group("Msmfeo_34") + "rios" in TEXT and not "s do " + m.group("Msmfeo_33") + "e " + m.group("Msmfeo_34") + "rios" in TEXT and not " o " + m.group("Msmfeo_33") + "e " + m.group("Msmfeo_34") + "rios" in TEXT and not m.group("Msmfeo_33") + "e-" + m.group("Msmfeo_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_35>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_35").lower() in plvrMfe and not " e " + m.group("Msmfeo_35") + "e " + m.group("Msmfeo_36") + "ssimos" in TEXT and not " ou " + m.group("Msmfeo_35") + "e " + m.group("Msmfeo_36") + "ssimos" in TEXT and not "s de " + m.group("Msmfeo_35") + "e " + m.group("Msmfeo_36") + "ssimos" in TEXT and not "s do " + m.group("Msmfeo_35") + "e " + m.group("Msmfeo_36") + "ssimos" in TEXT and not " o " + m.group("Msmfeo_35") + "e " + m.group("Msmfeo_36") + "ssimos" in TEXT and not m.group("Msmfeo_35") + "e-" + m.group("Msmfeo_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_37>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_37").lower() in plvrMfe and not " e " + m.group("Msmfeo_37") + "e " + m.group("Msmfeo_38") + "simos" in TEXT and not " ou " + m.group("Msmfeo_37") + "e " + m.group("Msmfeo_38") + "simos" in TEXT and not "s de " + m.group("Msmfeo_37") + "e " + m.group("Msmfeo_38") + "simos" in TEXT and not "s do " + m.group("Msmfeo_37") + "e " + m.group("Msmfeo_38") + "simos" in TEXT and not " o " + m.group("Msmfeo_37") + "e " + m.group("Msmfeo_38") + "simos" in TEXT and not m.group("Msmfeo_37") + "e-" + m.group("Msmfeo_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_43>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_43").lower() in plvrMfe and m.group("Msmfeo_44") in plvrMfr and not " e " + m.group("Msmfeo_43") + "e " + m.group("Msmfeo_44") + "es" in TEXT and not " ou " + m.group("Msmfeo_43") + "e " + m.group("Msmfeo_44") + "es" in TEXT and not "s de " + m.group("Msmfeo_43") + "e " + m.group("Msmfeo_44") + "es" in TEXT and not "s do " + m.group("Msmfeo_43") + "e " + m.group("Msmfeo_44") + "es" in TEXT and not " o " + m.group("Msmfeo_43") + "e " + m.group("Msmfeo_44") + "es" in TEXT and not m.group("Msmfeo_43") + "e-" + m.group("Msmfeo_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_45>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_45").lower() in plvrMfe and m.group("Msmfeo_46") in plvrMascr and not " e " + m.group("Msmfeo_45") + "e " + m.group("Msmfeo_46") + "es" in TEXT and not " ou " + m.group("Msmfeo_45") + "e " + m.group("Msmfeo_46") + "es" in TEXT and not "s de " + m.group("Msmfeo_45") + "e " + m.group("Msmfeo_46") + "es" in TEXT and not "s do " + m.group("Msmfeo_45") + "e " + m.group("Msmfeo_46") + "es" in TEXT and not " o " + m.group("Msmfeo_45") + "e " + m.group("Msmfeo_46") + "es" in TEXT and not m.group("Msmfeo_45") + "e-" + m.group("Msmfeo_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_47>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_47").lower() in plvrMfe and m.group("Msmfeo_48") in plvrMfal and not " e " + m.group("Msmfeo_47") + "e " + m.group("Msmfeo_48") + "is" in TEXT and not " ou " + m.group("Msmfeo_47") + "e " + m.group("Msmfeo_48") + "is" in TEXT and not "s de " + m.group("Msmfeo_47") + "e " + m.group("Msmfeo_48") + "is" in TEXT and not "s do " + m.group("Msmfeo_47") + "e " + m.group("Msmfeo_48") + "is" in TEXT and not " o " + m.group("Msmfeo_47") + "e " + m.group("Msmfeo_48") + "is" in TEXT and not m.group("Msmfeo_47") + "e-" + m.group("Msmfeo_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_49>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_49").lower() in plvrMfe and m.group("Msmfeo_50") in plvrMfcao and not " e " + m.group("Msmfeo_49") + "e " + m.group("Msmfeo_50") + "ões" in TEXT and not + " ou " + m.group("Msmfeo_49") + "e " + m.group("Msmfeo_50") + "ões" in TEXT and not + "s de " + m.group("Msmfeo_49") + "e " + m.group("Msmfeo_50") + "ões" in TEXT and not + "s do " + m.group("Msmfeo_49") + "e " + m.group("Msmfeo_50") + "ões" in TEXT and not + " a " + m.group("Msmfeo_49") + "e " + m.group("Msmfeo_50") + "ões" in TEXT and not m.group("Msmfeo_49") + "e-" + m.group("Msmfeo_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_51>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_51").lower() in plvrMfe and m.group("Msmfeo_52") in plvrNfemcao and not " e " + m.group("Msmfeo_51") + "e " + m.group("Msmfeo_52") + "ões" in TEXT and not " ou " + m.group("Msmfeo_51") + "e " + m.group("Msmfeo_52") + "ões" in TEXT and not "s de " + m.group("Msmfeo_51") + "e " + m.group("Msmfeo_52") + "ões" in TEXT and not "s do " + m.group("Msmfeo_51") + "e " + m.group("Msmfeo_52") + "ões" in TEXT and not " o " + m.group("Msmfeo_51") + "e " + m.group("Msmfeo_52") + "ões" in TEXT and not m.group("Msmfeo_51") + "e-" + m.group("Msmfeo_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_57>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_57").lower() in plvrMfe and m.group("Msmfeo_58").lower() in plvrMfe and not " e " + m.group("Msmfeo_57") + "e " + m.group("Msmfeo_58") + "es" in TEXT and not " ou " + m.group("Msmfeo_57") + "e " + m.group("Msmfeo_58") + "es" in TEXT and not "s de " + m.group("Msmfeo_57") + "e " + m.group("Msmfeo_58") + "es" in TEXT and not "s do " + m.group("Msmfeo_57") + "e " + m.group("Msmfeo_58") + "es" in TEXT and not " o " + m.group("Msmfeo_57") + "e " + m.group("Msmfeo_58") + "es" in TEXT and not m.group("Msmfeo_57") + "e-" + m.group("Msmfeo_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_59>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_59").lower() in plvrMfe and m.group("Msmfeo_60").lower() in plvrMasce and not " e " + m.group("Msmfeo_59") + "e " + m.group("Msmfeo_60") + "es" in TEXT and not " ou " + m.group("Msmfeo_59") + "e " + m.group("Msmfeo_60") + "es" in TEXT and not "s de " + m.group("Msmfeo_59") + "e " + m.group("Msmfeo_60") + "es" in TEXT and not "s do " + m.group("Msmfeo_59") + "e " + m.group("Msmfeo_60") + "es" in TEXT and not " o " + m.group("Msmfeo_59") + "e " + m.group("Msmfeo_60") + "es" in TEXT and not m.group("Msmfeo_59") + "e-" + m.group("Msmfeo_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_61>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_61").lower() in plvrMfe and m.group("Msmfeo_62") in plvrMfel and not " e " + m.group("Msmfeo_61") + "e " + m.group("Msmfeo_62") + "éis" in TEXT and not " ou " + m.group("Msmfeo_61") + "e " + m.group("Msmfeo_62") + "éis" in TEXT and not "s de " + m.group("Msmfeo_61") + "e " + m.group("Msmfeo_62") + "éis" in TEXT and not "s do " + m.group("Msmfeo_61") + "e " + m.group("Msmfeo_62") + "éis" in TEXT and not " o " + m.group("Msmfeo_61") + "e " + m.group("Msmfeo_62") + "éis" in TEXT and not m.group("Msmfeo_61") + "e-" + m.group("Msmfeo_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_63>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_63").lower() in plvrMfe and m.group("Msmfeo_64") in plvrMascel and not " e " + m.group("Msmfeo_63") + "e " + m.group("Msmfeo_64") + "éis" in TEXT and not " ou " + m.group("Msmfeo_63") + "e " + m.group("Msmfeo_64") + "éis" in TEXT and not "s de " + m.group("Msmfeo_63") + "e " + m.group("Msmfeo_64") + "éis" in TEXT and not "s do " + m.group("Msmfeo_63") + "e " + m.group("Msmfeo_64") + "éis" in TEXT and not " o " + m.group("Msmfeo_63") + "e " + m.group("Msmfeo_64") + "éis" in TEXT and not m.group("Msmfeo_63") + "e-" + m.group("Msmfeo_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_65>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_65").lower() in plvrMfe and m.group("Msmfeo_66") in plvrMfeu and not " e " + m.group("Msmfeo_65") + "e " + m.group("Msmfeo_66") + "us" in TEXT and not " ou " + m.group("Msmfeo_65") + "e " + m.group("Msmfeo_66") + "us" in TEXT and not "s de " + m.group("Msmfeo_65") + "e " + m.group("Msmfeo_66") + "us" in TEXT and not "s do " + m.group("Msmfeo_65") + "e " + m.group("Msmfeo_66") + "us" in TEXT and not " o " + m.group("Msmfeo_65") + "e " + m.group("Msmfeo_66") + "us" in TEXT and not m.group("Msmfeo_65") + "e-" + m.group("Msmfeo_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_67>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_67").lower() in plvrMfe and m.group("Msmfeo_68") in plvrMascu and not " e " + m.group("Msmfeo_67") + "e " + m.group("Msmfeo_68") + "us" in TEXT and not " ou " + m.group("Msmfeo_67") + "e " + m.group("Msmfeo_68") + "us" in TEXT and not "s de " + m.group("Msmfeo_67") + "e " + m.group("Msmfeo_68") + "us" in TEXT and not "s do " + m.group("Msmfeo_67") + "e " + m.group("Msmfeo_68") + "us" in TEXT and not " o " + m.group("Msmfeo_67") + "e " + m.group("Msmfeo_68") + "us" in TEXT and not m.group("Msmfeo_67") + "e-" + m.group("Msmfeo_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_71>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_71").lower() in plvrMfe and m.group("Msmfeo_72") in plvrMascz and not " e " + m.group("Msmfeo_71") + "e " + m.group("Msmfeo_72") + "zes" in TEXT and not " ou " + m.group("Msmfeo_71") + "e " + m.group("Msmfeo_72") + "zes" in TEXT and not "s de " + m.group("Msmfeo_71") + "e " + m.group("Msmfeo_72") + "zes" in TEXT and not "s do " + m.group("Msmfeo_71") + "e " + m.group("Msmfeo_72") + "zes" in TEXT and not " o " + m.group("Msmfeo_71") + "e " + m.group("Msmfeo_72") + "zes" in TEXT and not m.group("Msmfeo_71") + "e-" + m.group("Msmfeo_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_73>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_73").lower() in plvrMfe and m.group("Msmfeo_74") in pvrMascan and not " e " + m.group("Msmfeo_73") + "e " + m.group("Msmfeo_74") + "s" in TEXT and not " ou " + m.group("Msmfeo_73") + "e " + m.group("Msmfeo_74") + "s" in TEXT and not "s de " + m.group("Msmfeo_73") + "e " + m.group("Msmfeo_74") + "s" in TEXT and not "s do " + m.group("Msmfeo_73") + "e " + m.group("Msmfeo_74") + "s" in TEXT and not " o " + m.group("Msmfeo_73") + "e " + m.group("Msmfeo_74") + "s" in TEXT and not m.group("Msmfeo_73") + "e-" + m.group("Msmfeo_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_75>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_75").lower() in plvrMfe and m.group("Msmfeo_76").lower() in plvrMasco and not " e " + m.group("Msmfeo_75") + "e " + m.group("Msmfeo_76") +"s" in TEXT and not " ou " + m.group("Msmfeo_75") + "e " + m.group("Msmfeo_76") + "s" in TEXT and not "s de " + m.group("Msmfeo_75") + "e " + m.group("Msmfeo_76") + "s" in TEXT and not "s do " + m.group("Msmfeo_75") + "e " + m.group("Msmfeo_76") + "s" in TEXT and not " o " + m.group("Msmfeo_75") + "e " + m.group("Msmfeo_76") + "s" in TEXT and not m.group("Msmfeo_75") + "e-" + m.group("Msmfeo_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_77>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_77").lower() in plvrMfe and not " e " + m.group("Msmfeo_77") + "e " + m.group("Msmfeo_78") + "inhos" in TEXT and not " ou " + m.group("Msmfeo_77") + "e " + m.group("Msmfeo_78") + "inhos" in TEXT and not "s de " + m.group("Msmfeo_77") + "e " + m.group("Msmfeo_78") + "inhos" in TEXT and not "s do " + m.group("Msmfeo_77") + "e " + m.group("Msmfeo_78") + "inhos" in TEXT and not " o " + m.group("Msmfeo_77") + "e " + m.group("Msmfeo_78") + "inhos" in TEXT and not m.group("Msmfeo_77") + "e-" + m.group("Msmfeo_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_83>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_83").lower() in plvrMfe and not " e " + m.group("Msmfeo_83") + "e " + m.group("Msmfeo_84") + "icas" in TEXT and not " ou " + m.group("Msmfeo_83") + "e " + m.group("Msmfeo_84") + "icas" in TEXT and not "s de " + m.group("Msmfeo_83") + "e " + m.group("Msmfeo_84") + "icas" in TEXT and not "s do " + m.group("Msmfeo_83") + "e " + m.group("Msmfeo_84") + "icas" in TEXT and not " o " + m.group("Msmfeo_83") + "e " + m.group("Msmfeo_84") + "icas" in TEXT and not m.group("Msmfeo_83") + "e-" + m.group("Msmfeo_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_85>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_85").lower() in plvrMfe and not " e " + m.group("Msmfeo_85") + "e " + m.group("Msmfeo_86") + "escas" in TEXT and not " ou " + m.group("Msmfeo_85") + "e " + m.group("Msmfeo_86") + "escas" in TEXT and not "s de " + m.group("Msmfeo_85") + "e " + m.group("Msmfeo_86") + "escas" in TEXT and not "s do " + m.group("Msmfeo_85") + "e " + m.group("Msmfeo_86") + "escas" in TEXT and not " o " + m.group("Msmfeo_85") + "e " + m.group("Msmfeo_86") + "escas" in TEXT and not m.group("Msmfeo_85") + "e-" + m.group("Msmfeo_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfeo_87>[a-zA-Zçáéíóúâêô]+)e (?P<Msmfeo_88>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfeo_87").lower() in plvrMfe and m.group("Msmfeo_88") in plvrMascm and not " e " + m.group("Msmfeo_87") + "e " + m.group("Msmfeo_88") + "ns" in TEXT and not " ou " + m.group("Msmfeo_87") + "e " + m.group("Msmfeo_88") + "ns" in TEXT and not "s de " + m.group("Msmfeo_87") + "e " + m.group("Msmfeo_88") + "ns" in TEXT and not "s da " + m.group("Msmfeo_87") + "e " + m.group("Msmfeo_88") + "ns" in TEXT and not " a " + m.group("Msmfeo_87") + "e " + m.group("Msmfeo_88") + "ns" in TEXT and not m.group("Msmfeo_87") + "e-" + m.group("Msmfeo_88") + "ns" in tCompostops and not (m.group("Msmfeo_87") in "parte" and excMparte.search(TEXT))'],
# excIsta a
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_1>[a-zA-Z]+ista) (?P<Msista_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_1").lower() in excIsta and m.group("Msista_2").lower() in plvrFema and not " e " + m.group("Msista_1") + " " + m.group("Msista_2") +"s" in TEXT and not " ou " + m.group("Msista_1") + " " + m.group("Msista_2") + "s" in TEXT and not "s de " + m.group("Msista_1") + " " + m.group("Msista_2") + "s" in TEXT and not "s da " + m.group("Msista_1") + " " + m.group("Msista_2") + "s" in TEXT and not " a " + m.group("Msista_1") + " " + m.group("Msista_2") + "s" in TEXT and not m.group("Msista_1") + "-" + m.group("Msista_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_3>[a-zA-Z]+ista) (?P<Msista_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_3").lower() in excIsta and m.group("Msista_4").lower() in plvrMfe and not " e " + m.group("Msista_3") + " " + m.group("Msista_4") + "as" in TEXT and not " ou " + m.group("Msista_3") + " " + m.group("Msista_4") + "as" in TEXT and not "s de " + m.group("Msista_3") + " " + m.group("Msista_4") + "as" in TEXT and not "s da " + m.group("Msista_3") + " " + m.group("Msista_4") + "as" in TEXT and not " a " + m.group("Msista_3") + " " + m.group("Msista_4") + "as" in TEXT and not m.group("Msista_3") + "-" + m.group("Msista_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_5>[a-zA-Z]+ista) (?P<Msista_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_5").lower() in excIsta and not m.group("Msista_6").lower() in excAdo and not " e " + m.group("Msista_5") + " " + m.group("Msista_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msista_5") + " " + m.group("Msista_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msista_5") + " " + m.group("Msista_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Msista_5") + " " + m.group("Msista_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Msista_5") + " " + m.group("Msista_6") + m.group(3) + "dos" in TEXT and not m.group("Msista_5") + "-" + m.group("Msista_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_7>[a-zA-Z]+ista) (?P<Msista_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_7").lower() in excIsta and not m.group("Msista_8").lower() in excIsta and not " e " + m.group("Msista_7") + " " + m.group("Msista_8") + "s" in TEXT and not " ou " + m.group("Msista_7") + " " + m.group("Msista_8") + "s" in TEXT and not "s de " + m.group("Msista_7") + " " + m.group("Msista_8") + "s" in TEXT and not "s da " + m.group("Msista_7") + " " + m.group("Msista_8") + "s" in TEXT and not " a " + m.group("Msista_7") + " " + m.group("Msista_8") + "s" in TEXT and not m.group("Msista_7") + "-" + m.group("Msista_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_9>[a-zA-Z]+ista) (?P<Msista_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_9").lower() in excIsta and m.group("Msista_10").lower() in plvrInva and not " e " + m.group("Msista_9") + " " + m.group("Msista_10") + "s" in TEXT and not " ou " + m.group("Msista_9") + " " + m.group("Msista_10") + "s" in TEXT and not "s de " + m.group("Msista_9") + " " + m.group("Msista_10") + "s" in TEXT and not "s da " + m.group("Msista_9") + " " + m.group("Msista_10") + "s" in TEXT and not " a " + m.group("Msista_9") + " " + m.group("Msista_10") + "s" in TEXT and not m.group("Msista_9") + "-" + m.group("Msista_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_11>[a-zA-Z]+ista) (?P<Msista_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_11").lower() in excIsta and not m.group("Msista_12").lower() in excAdo and not " e " + m.group("Msista_11") + " " + m.group("Msista_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msista_11") + " " + m.group("Msista_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msista_11") + " " + m.group("Msista_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Msista_11") + " " + m.group("Msista_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Msista_11") + " " + m.group("Msista_12") + m.group(3) + "das" in TEXT and not m.group("Msista_11") + "-" + m.group("Msista_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_15>[a-zA-Z]+ista) (?P<Msista_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_15").lower() in excIsta and not " e " + m.group("Msista_15") + " " + m.group("Msista_16") + "osas" in TEXT and not " ou " + m.group("Msista_15") + " " + m.group("Msista_16") + "osas" in TEXT and not "s de " + m.group("Msista_15") + " " + m.group("Msista_16") + "osas" in TEXT and not "s da " + m.group("Msista_15") + " " + m.group("Msista_16") + "osas" in TEXT and not " a " + m.group("Msista_15") + " " + m.group("Msista_16") + "osas" in TEXT and not m.group("Msista_15") + "-" + m.group("Msista_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_17>[a-zA-Z]+ista) (?P<Msista_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_17").lower() in excIsta and not " e " + m.group("Msista_17") + " " + m.group("Msista_18") + "ivas" in TEXT and not " ou " + m.group("Msista_17") + " " + m.group("Msista_18") + "ivas" in TEXT and not "s de " + m.group("Msista_17") + " " + m.group("Msista_18") + "ivas" in TEXT and not "s da " + m.group("Msista_17") + " " + m.group("Msista_18") + "ivas" in TEXT and not " a " + m.group("Msista_17") + " " + m.group("Msista_18") + "ivas" in TEXT and not m.group("Msista_17") + "-" + m.group("Msista_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_21>[a-zA-Z]+ista) (?P<Msista_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_21").lower() in excIsta and not " e " + m.group("Msista_21") + " " + m.group("Msista_22") + "icas" in TEXT and not " ou " + m.group("Msista_21") + " " + m.group("Msista_22") + "icas" in TEXT and not "s de " + m.group("Msista_21") + " " + m.group("Msista_22") + "icas" in TEXT and not "s da " + m.group("Msista_21") + " " + m.group("Msista_22") + "icas" in TEXT and not " a " + m.group("Msista_21") + " " + m.group("Msista_22") + "icas" in TEXT and not m.group("Msista_21") + "-" + m.group("Msista_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_23>[a-zA-Z]+ista) (?P<Msista_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_23").lower() in excIsta and not " e " + m.group("Msista_23") + " " + m.group("Msista_24") + "icas" in TEXT and not " ou " + m.group("Msista_23") + " " + m.group("Msista_24") + "icas" in TEXT and not "s de " + m.group("Msista_23") + " " + m.group("Msista_24") + "icas" in TEXT and not "s da " + m.group("Msista_23") + " " + m.group("Msista_24") + "icas" in TEXT and not " a " + m.group("Msista_23") + " " + m.group("Msista_24") + "icas" in TEXT and not m.group("Msista_23") + "-" + m.group("Msista_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_25>[a-zA-Z]+ista) (?P<Msista_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_25").lower() in excIsta and not " e " + m.group("Msista_25") + " " + m.group("Msista_26") + "icas" in TEXT and not " ou " + m.group("Msista_25") + " " + m.group("Msista_26") + "icas" in TEXT and not "s de " + m.group("Msista_25") + " " + m.group("Msista_26") + "icas" in TEXT and not "s da " + m.group("Msista_25") + " " + m.group("Msista_26") + "icas" in TEXT and not " a " + m.group("Msista_25") + " " + m.group("Msista_26") + "icas" in TEXT and not m.group("Msista_25") + "-" + m.group("Msista_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_27>[a-zA-Z]+ista) (?P<Msista_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_27").lower() in excIsta and not " e " + m.group("Msista_27") + " " + m.group("Msista_28") + "escas" in TEXT and not " ou " + m.group("Msista_27") + " " + m.group("Msista_28") + "escas" in TEXT and not "s de " + m.group("Msista_27") + " " + m.group("Msista_28") + "escas" in TEXT and not "s da " + m.group("Msista_27") + " " + m.group("Msista_28") + "escas" in TEXT and not " a " + m.group("Msista_27") + " " + m.group("Msista_28") + "escas" in TEXT and not m.group("Msista_27") + "-" + m.group("Msista_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_29>[a-zA-Z]+ista) (?P<Msista_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_29").lower() in excIsta and not " e " + m.group("Msista_29") + " " + m.group("Msista_30") + "idas" in TEXT and not " ou " + m.group("Msista_29") + "s " + m.group("Msista_30") + "idas" in TEXT and not "s de " + m.group("Msista_29") + "s " + m.group("Msista_30") + "idas" in TEXT and not "s da " + m.group("Msista_29") + "s " + m.group("Msista_30") + "idas" in TEXT and not " a " + m.group("Msista_29") + "s " + m.group("Msista_30") + "idas" in TEXT and not m.group("Msista_29") + "-" + m.group("Msista_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_31>[a-zA-Z]+ista) (?P<Msista_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_31").lower() in excIsta and not " e " + m.group("Msista_31") + " " + m.group("Msista_32") + "logas" in TEXT and not " ou " + m.group("Msista_31") + " " + m.group("Msista_32") + "logas" in TEXT and not "s de " + m.group("Msista_31") + " " + m.group("Msista_32") + "logas" in TEXT and not "s da " + m.group("Msista_31") + " " + m.group("Msista_32") + "logas" in TEXT and not " a " + m.group("Msista_31") + " " + m.group("Msista_32") + "logas" in TEXT and not m.group("Msista_31") + "-" + m.group("Msista_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_33>[a-zA-Z]+ista) (?P<Msista_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_33").lower() in excIsta and not " e " + m.group("Msista_33") + " " + m.group("Msista_34") + "rias" in TEXT and not " ou " + m.group("Msista_33") + " " + m.group("Msista_34") + "rias" in TEXT and not "s de " + m.group("Msista_33") + " " + m.group("Msista_34") + "rias" in TEXT and not "s da " + m.group("Msista_33") + " " + m.group("Msista_34") + "rias" in TEXT and not " a " + m.group("Msista_33") + " " + m.group("Msista_34") + "rias" in TEXT and not m.group("Msista_33") + "-" + m.group("Msista_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_35>[a-zA-Z]+ista) (?P<Msista_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_35").lower() in excIsta and not " e " + m.group("Msista_35") + " " + m.group("Msista_36") + "ssimas" in TEXT and not " ou " + m.group("Msista_35") + " " + m.group("Msista_36") + "ssimas" in TEXT and not "s de " + m.group("Msista_35") + " " + m.group("Msista_36") + "ssimas" in TEXT and not "s da " + m.group("Msista_35") + " " + m.group("Msista_36") + "ssimas" in TEXT and not " a " + m.group("Msista_35") + " " + m.group("Msista_36") + "ssimas" in TEXT and not m.group("Msista_35") + "-" + m.group("Msista_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_37>[a-zA-Z]+ista) (?P<Msista_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_37").lower() in excIsta and not " e " + m.group("Msista_37") + " " + m.group("Msista_38") + "simas" in TEXT and not " ou " + m.group("Msista_37") + " " + m.group("Msista_38") + "simas" in TEXT and not "s de " + m.group("Msista_37") + " " + m.group("Msista_38") + "simas" in TEXT and not "s da " + m.group("Msista_37") + " " + m.group("Msista_38") + "simas" in TEXT and not " a " + m.group("Msista_37") + " " + m.group("Msista_38") + "simas" in TEXT and not m.group("Msista_37") + "-" + m.group("Msista_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_41>[a-zA-Z]+ista) (?P<Msista_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_41").lower() in excIsta and not m.group("Msista_42") in "D-d-" and not " e " + m.group("Msista_41") + " " + m.group("Msista_42") + "oras" in TEXT and not " ou " + m.group("Msista_41") + " " + m.group("Msista_42") + "oras" in TEXT and not "s de " + m.group("Msista_41") + " " + m.group("Msista_42") + "oras" in TEXT and not "s da " + m.group("Msista_41") + " " + m.group("Msista_42") + "oras" in TEXT and not " a " + m.group("Msista_41") + " " + m.group("Msista_42") + "oras" in TEXT and not m.group("Msista_41") + "-" + m.group("Msista_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_43>[a-zA-Z]+ista) (?P<Msista_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_43").lower() in excIsta and m.group("Msista_44") in plvrMfr and not " e " + m.group("Msista_43") + " " + m.group("Msista_44") + "es" in TEXT and not " ou " + m.group("Msista_43") + " " + m.group("Msista_44") + "es" in TEXT and not "s de " + m.group("Msista_43") + " " + m.group("Msista_44") + "es" in TEXT and not "s da " + m.group("Msista_43") + " " + m.group("Msista_44") + "es" in TEXT and not " a " + m.group("Msista_43") + " " + m.group("Msista_44") + "es" in TEXT and not m.group("Msista_43") + "-" + m.group("Msista_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_45>[a-zA-Z]+ista) (?P<Msista_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_45").lower() in excIsta and m.group("Msista_46") in plvrFemr and not " e " + m.group("Msista_45") + " " + m.group("Msista_46") + "es" in TEXT and not " ou " + m.group("Msista_45") + " " + m.group("Msista_46") + "es" in TEXT and not "s de " + m.group("Msista_45") + " " + m.group("Msista_46") + "es" in TEXT and not "s da " + m.group("Msista_45") + " " + m.group("Msista_46") + "es" in TEXT and not " a " + m.group("Msista_45") + " " + m.group("Msista_46") + "es" in TEXT and not m.group("Msista_45") + "-" + m.group("Msista_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_47>[a-zA-Z]+ista) (?P<Msista_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_47").lower() in excIsta and m.group("Msista_48") in plvrMfal and not " e " + m.group("Msista_47") + " " + m.group("Msista_48") + "is" in TEXT and not " ou " + m.group("Msista_47") + " " + m.group("Msista_48") + "is" in TEXT and not "s de " + m.group("Msista_47") + " " + m.group("Msista_48") + "is" in TEXT and not "s da " + m.group("Msista_47") + " " + m.group("Msista_48") + "is" in TEXT and not " a " + m.group("Msista_47") + " " + m.group("Msista_48") + "is" in TEXT and not m.group("Msista_47") + "-" + m.group("Msista_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_49>[a-zA-Z]+ista) (?P<Msista_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_49").lower() in excIsta and m.group("Msista_50") in plvrMfcao and not " e " + m.group("Msista_49") + " " + m.group("Msista_50") + "ões" in TEXT and not + " ou " + m.group("Msista_49") + " " + m.group("Msista_50") + "ões" in TEXT and not + "s de " + m.group("Msista_49") + " " + m.group("Msista_50") + "ões" in TEXT and not + "s da " + m.group("Msista_49") + " " + m.group("Msista_50") + "ões" in TEXT and not + " a " + m.group("Msista_49") + " " + m.group("Msista_50") + "ões" in TEXT and not m.group("Msista_49") + "-" + m.group("Msista_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_51>[a-zA-Z]+ista) (?P<Msista_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_51").lower() in excIsta and not m.group("Msista_52") in plvrMascao and not " e " + m.group("Msista_51") + " " + m.group("Msista_52") + "ões" in TEXT and not " ou " + m.group("Msista_51") + " " + m.group("Msista_52") + "ões" in TEXT and not "s de " + m.group("Msista_51") + " " + m.group("Msista_52") + "ões" in TEXT and not "s da " + m.group("Msista_51") + " " + m.group("Msista_52") + "ões" in TEXT and not " a " + m.group("Msista_51") + " " + m.group("Msista_52") + "ões" in TEXT and not m.group("Msista_51") + "-" + m.group("Msista_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_53>[a-zA-Z]+ista) (?P<Msista_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_53").lower() in excIsta and m.group("Msista_54") in plvrFemao and not " e " + m.group("Msista_53") + " " + m.group("Msista_54") + "ões" in TEXT and not " ou " + m.group("Msista_53") + " " + m.group("Msista_54") + "ões" in TEXT and not "s de " + m.group("Msista_53") + " " + m.group("Msista_54") + "ões" in TEXT and not "s da " + m.group("Msista_53") + " " + m.group("Msista_54") + "ões" in TEXT and not " a " + m.group("Msista_53") + " " + m.group("Msista_54") + "ões" in TEXT and not m.group("Msista_53") + "-" + m.group("Msista_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_55>[a-zA-Z]+ista) (?P<Msista_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_55").lower() in excIsta and not " e " + m.group("Msista_55") + " " + m.group("Msista_56") + "veis" in TEXT and not " ou " + m.group("Msista_55") + " " + m.group("Msista_56") + "veis" in TEXT and not "s de " + m.group("Msista_55") + " " + m.group("Msista_56") + "veis" in TEXT and not "s da " + m.group("Msista_55") + " " + m.group("Msista_56") + "veis" in TEXT and not " a " + m.group("Msista_55") + " " + m.group("Msista_56") + "veis" in TEXT and not m.group("Msista_55") + "-" + m.group("Msista_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_57>[a-zA-Z]+ista) (?P<Msista_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_57").lower() in excIsta and m.group("Msista_58").lower() in excIsta and not " e " + m.group("Msista_57") + " " + m.group("Msista_58") + "es" in TEXT and not " ou " + m.group("Msista_57") + " " + m.group("Msista_58") + "es" in TEXT and not "s de " + m.group("Msista_57") + " " + m.group("Msista_58") + "es" in TEXT and not "s da " + m.group("Msista_57") + " " + m.group("Msista_58") + "es" in TEXT and not " a " + m.group("Msista_57") + " " + m.group("Msista_58") + "es" in TEXT and not m.group("Msista_57") + "-" + m.group("Msista_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_59>[a-zA-Z]+ista) (?P<Msista_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_59").lower() in excIsta and m.group("Msista_60").lower() in excIsta and not " e " + m.group("Msista_59") + " " + m.group("Msista_60") + "es" in TEXT and not " ou " + m.group("Msista_59") + " " + m.group("Msista_60") + "es" in TEXT and not "s de " + m.group("Msista_59") + " " + m.group("Msista_60") + "es" in TEXT and not "s da " + m.group("Msista_59") + " " + m.group("Msista_60") + "es" in TEXT and not " a " + m.group("Msista_59") + " " + m.group("Msista_60") + "es" in TEXT and not m.group("Msista_59") + "-" + m.group("Msista_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_61>[a-zA-Z]+ista) (?P<Msista_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_61").lower() in excIsta and m.group("Msista_62") in plvrMfel and not " e " + m.group("Msista_61") + " " + m.group("Msista_62") + "éis" in TEXT and not " ou " + m.group("Msista_61") + " " + m.group("Msista_62") + "éis" in TEXT and not "s de " + m.group("Msista_61") + " " + m.group("Msista_62") + "éis" in TEXT and not "s da " + m.group("Msista_61") + " " + m.group("Msista_62") + "éis" in TEXT and not " a " + m.group("Msista_61") + " " + m.group("Msista_62") + "éis" in TEXT and not m.group("Msista_61") + "-" + m.group("Msista_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_63>[a-zA-Z]+ista) (?P<Msista_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_63").lower() in excIsta and m.group("Msista_64") in plvrFemel and not " e " + m.group("Msista_63") + " " + m.group("Msista_64") + "éis" in TEXT and not " ou " + m.group("Msista_63") + " " + m.group("Msista_64") + "éis" in TEXT and not "s de " + m.group("Msista_63") + " " + m.group("Msista_64") + "éis" in TEXT and not "s da " + m.group("Msista_63") + " " + m.group("Msista_64") + "éis" in TEXT and not " a " + m.group("Msista_63") + " " + m.group("Msista_64") + "éis" in TEXT and not m.group("Msista_63") + "-" + m.group("Msista_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_65>[a-zA-Z]+ista) (?P<Msista_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_65").lower() in excIsta and m.group("Msista_66") in plvrMfeu and not " e " + m.group("Msista_65") + " " + m.group("Msista_66") + "us" in TEXT and not " ou " + m.group("Msista_65") + " " + m.group("Msista_66") + "us" in TEXT and not "s de " + m.group("Msista_65") + " " + m.group("Msista_66") + "us" in TEXT and not "s da " + m.group("Msista_65") + " " + m.group("Msista_66") + "us" in TEXT and not " a " + m.group("Msista_65") + " " + m.group("Msista_66") + "us" in TEXT and not m.group("Msista_65") + "-" + m.group("Msista_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_67>[a-zA-Z]+ista) (?P<Msista_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_67").lower() in excIsta and m.group("Msista_68") in plvrFemu and not " e " + m.group("Msista_67") + " " + m.group("Msista_68") + "us" in TEXT and not " ou " + m.group("Msista_67") + " " + m.group("Msista_68") + "us" in TEXT and not "s de " + m.group("Msista_67") + " " + m.group("Msista_68") + "us" in TEXT and not "s da " + m.group("Msista_67") + " " + m.group("Msista_68") + "us" in TEXT and not " a " + m.group("Msista_67") + " " + m.group("Msista_68") + "us" in TEXT and not m.group("Msista_67") + "-" + m.group("Msista_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_69>[a-zA-Z]+ista) (?P<Msista_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_69").lower() in excIsta and m.group("Msista_70") in plvrInvaz and not " e " + m.group("Msista_69") + " " + m.group("Msista_70") + "zes" in TEXT and not " ou " + m.group("Msista_69") + " " + m.group("Msista_70") + "zes" in TEXT and not "s de " + m.group("Msista_69") + " " + m.group("Msista_70") + "zes" in TEXT and not "s da " + m.group("Msista_69") + " " + m.group("Msista_70") + "zes" in TEXT and not " a " + m.group("Msista_69") + " " + m.group("Msista_70") + "zes" in TEXT and not m.group("Msista_69") + "-" + m.group("Msista_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_71>[a-zA-Z]+ista) (?P<Msista_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_71").lower() in excIsta and m.group("Msista_72") in plvrFemz and not " e " + m.group("Msista_71") + " " + m.group("Msista_72") + "zes" in TEXT and not " ou " + m.group("Msista_71") + " " + m.group("Msista_72") + "zes" in TEXT and not "s de " + m.group("Msista_71") + " " + m.group("Msista_72") + "zes" in TEXT and not "s da " + m.group("Msista_71") + " " + m.group("Msista_72") + "zes" in TEXT and not " a " + m.group("Msista_71") + " " + m.group("Msista_72") + "zes" in TEXT and not m.group("Msista_71") + "-" + m.group("Msista_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_73>[a-zA-Z]+ista) (?P<Msista_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_73").lower() in excIsta and m.group("Msista_74") in pvrFeman and not " e " + m.group("Msista_73") + " " + m.group("Msista_74") + "s" in TEXT and not " ou " + m.group("Msista_73") + " " + m.group("Msista_74") + "s" in TEXT and not "s de " + m.group("Msista_73") + " " + m.group("Msista_74") + "s" in TEXT and not "s da " + m.group("Msista_73") + " " + m.group("Msista_74") + "s" in TEXT and not " a " + m.group("Msista_73") + " " + m.group("Msista_74") + "s" in TEXT and not m.group("Msista_73") + "-" + m.group("Msista_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_75>[a-zA-Z]+ista) (?P<Msista_76>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_75").lower() in excIsta and m.group("Msista_76") in plvrMFm and not " e " + m.group("Msista_75") + " " + m.group("Msista_76") + "ns" in TEXT and not " ou " + m.group("Msista_75") + " " + m.group("Msista_76") + "ns" in TEXT and not "s de " + m.group("Msista_75") + " " + m.group("Msista_76") + "ns" in TEXT and not "s da " + m.group("Msista_75") + " " + m.group("Msista_76") + "ns" in TEXT and not " a " + m.group("Msista_75") + " " + m.group("Msista_76") + "ns" in TEXT and not m.group("Msista_75") + "-" + m.group("Msista_76") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msista_77>[a-zA-Z]+ista) (?P<Msista_78>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msista_77").lower() in excIsta and m.group("Msista_78") in plvrFemm and not " e " + m.group("Msista_77") + " " + m.group("Msista_78") + "ns" in TEXT and not " ou " + m.group("Msista_77") + " " + m.group("Msista_78") + "ns" in TEXT and not "s de " + m.group("Msista_77") + " " + m.group("Msista_78") + "ns" in TEXT and not "s da " + m.group("Msista_77") + " " + m.group("Msista_78") + "ns" in TEXT and not " a " + m.group("Msista_77") + " " + m.group("Msista_78") + "ns" in TEXT and not m.group("Msista_77") + "-" + m.group("Msista_78") + "ns" in tCompostops'],
# excIsta o
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_1>[a-zA-Z]+ista) (?P<Msisto_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_1").lower() in excIsta and m.group("Msisto_2").lower() in plvrMasca and not " e " + m.group("Msisto_1") + " " + m.group("Msisto_2") +"s" in TEXT and not " ou " + m.group("Msisto_1") + " " + m.group("Msisto_2") + "s" in TEXT and not "s de " + m.group("Msisto_1") + " " + m.group("Msisto_2") + "s" in TEXT and not "s do " + m.group("Msisto_1") + " " + m.group("Msisto_2") + "s" in TEXT and not " o " + m.group("Msisto_1") + " " + m.group("Msisto_2") + "s" in TEXT and not m.group("Msisto_1") + "-" + m.group("Msisto_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_3>[a-zA-Z]+ista) (?P<Msisto_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_3").lower() in excIsta and m.group("Msisto_4").lower() in excIsta and not " e " + m.group("Msisto_3") + " " + m.group("Msisto_4") + "os" in TEXT and not " ou " + m.group("Msisto_3") + " " + m.group("Msisto_4") + "os" in TEXT and not "s de " + m.group("Msisto_3") + " " + m.group("Msisto_4") + "os" in TEXT and not "s do " + m.group("Msisto_3") + " " + m.group("Msisto_4") + "os" in TEXT and not " o " + m.group("Msisto_3") + " " + m.group("Msisto_4") + "os" in TEXT and not m.group("Msisto_3") + "-" + m.group("Msisto_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_5>[a-zA-Z]+ista) (?P<Msisto_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_5").lower() in excIsta and not m.group("Msisto_6").lower() in excAdo and not " e " + m.group("Msisto_5") + " " + m.group("Msisto_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msisto_5") + " " + m.group("Msisto_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msisto_5") + " " + m.group("Msisto_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msisto_5") + " " + m.group("Msisto_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msisto_5") + " " + m.group("Msisto_6") + m.group(3) + "dos" in TEXT and not m.group("Msisto_5") + "-" + m.group("Msisto_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_13>[a-zA-Z]+ista) (?P<Msisto_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_13").lower() in excIsta and not " e " + m.group("Msisto_13") + " " + m.group("Msisto_14") + "osos" in TEXT and not " ou " + m.group("Msisto_13") + " " + m.group("Msisto_14") + "osos" in TEXT and not "s de " + m.group("Msisto_13") + " " + m.group("Msisto_14") + "osos" in TEXT and not "s do " + m.group("Msisto_13") + " " + m.group("Msisto_14") + "osos" in TEXT and not " o " + m.group("Msisto_13") + " " + m.group("Msisto_14") + "osos" in TEXT and not m.group("Msisto_13") + "-" + m.group("Msisto_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_19>[a-zA-Z]+ista) (?P<Msisto_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_19").lower() in excIsta and not " e " + m.group("Msisto_19") + " " + m.group("Msisto_20") + "ivas" in TEXT and not " ou " + m.group("Msisto_19") + " " + m.group("Msisto_20") + "ivas" in TEXT and not "s de " + m.group("Msisto_19") + " " + m.group("Msisto_20") + "ivas" in TEXT and not "s do " + m.group("Msisto_19") + " " + m.group("Msisto_20") + "ivas" in TEXT and not " o " + m.group("Msisto_19") + " " + m.group("Msisto_20") + "ivas" in TEXT and not m.group("Msisto_19") + "-" + m.group("Msisto_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_21>[a-zA-Z]+ista) (?P<Msisto_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_21").lower() in excIsta and not " e " + m.group("Msisto_21") + " " + m.group("Msisto_22") + "icos" in TEXT and not " ou " + m.group("Msisto_21") + " " + m.group("Msisto_22") + "icos" in TEXT and not "s de " + m.group("Msisto_21") + " " + m.group("Msisto_22") + "icos" in TEXT and not "s do " + m.group("Msisto_21") + " " + m.group("Msisto_22") + "icos" in TEXT and not " o " + m.group("Msisto_21") + " " + m.group("Msisto_22") + "icos" in TEXT and not m.group("Msisto_21") + "-" + m.group("Msisto_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_23>[a-zA-Z]+ista) (?P<Msisto_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_23").lower() in excIsta and not " e " + m.group("Msisto_23") + " " + m.group("Msisto_24") + "icos" in TEXT and not " ou " + m.group("Msisto_23") + " " + m.group("Msisto_24") + "icos" in TEXT and not "s de " + m.group("Msisto_23") + " " + m.group("Msisto_24") + "icos" in TEXT and not "s do " + m.group("Msisto_23") + " " + m.group("Msisto_24") + "icos" in TEXT and not " o " + m.group("Msisto_23") + " " + m.group("Msisto_24") + "icos" in TEXT and not m.group("Msisto_23") + "-" + m.group("Msisto_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_25>[a-zA-Z]+ista) (?P<Msisto_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_25").lower() in excIsta and not " e " + m.group("Msisto_25") + " " + m.group("Msisto_26") + "icos" in TEXT and not " ou " + m.group("Msisto_25") + " " + m.group("Msisto_26") + "icos" in TEXT and not "s de " + m.group("Msisto_25") + " " + m.group("Msisto_26") + "icos" in TEXT and not "s do " + m.group("Msisto_25") + " " + m.group("Msisto_26") + "icos" in TEXT and not " o " + m.group("Msisto_25") + " " + m.group("Msisto_26") + "icos" in TEXT and not m.group("Msisto_25") + "-" + m.group("Msisto_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_27>[a-zA-Z]+ista) (?P<Msisto_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_27").lower() in excIsta and not " e " + m.group("Msisto_27") + " " + m.group("Msisto_28") + "escos" in TEXT and not " ou " + m.group("Msisto_27") + " " + m.group("Msisto_28") + "escos" in TEXT and not "s de " + m.group("Msisto_27") + " " + m.group("Msisto_28") + "escos" in TEXT and not "s do " + m.group("Msisto_27") + " " + m.group("Msisto_28") + "escos" in TEXT and not " o " + m.group("Msisto_27") + " " + m.group("Msisto_28") + "escos" in TEXT and not m.group("Msisto_27") + "-" + m.group("Msisto_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_29>[a-zA-Z]+ista) (?P<Msisto_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_29").lower() in excIsta and not " e " + m.group("Msisto_29") + " " + m.group("Msisto_30") + "idos" in TEXT and not " ou " + m.group("Msisto_29") + "s " + m.group("Msisto_30") + "idos" in TEXT and not "s de " + m.group("Msisto_29") + "s " + m.group("Msisto_30") + "idos" in TEXT and not "s do " + m.group("Msisto_29") + "s " + m.group("Msisto_30") + "idos" in TEXT and not " o " + m.group("Msisto_29") + "s " + m.group("Msisto_30") + "idos" in TEXT and not m.group("Msisto_29") + "-" + m.group("Msisto_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_31>[a-zA-Z]+ista) (?P<Msisto_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_31").lower() in excIsta and not " e " + m.group("Msisto_31") + " " + m.group("Msisto_32") + "logos" in TEXT and not " ou " + m.group("Msisto_31") + " " + m.group("Msisto_32") + "logos" in TEXT and not "s de " + m.group("Msisto_31") + " " + m.group("Msisto_32") + "logos" in TEXT and not "s do " + m.group("Msisto_31") + " " + m.group("Msisto_32") + "logos" in TEXT and not " o " + m.group("Msisto_31") + " " + m.group("Msisto_32") + "logos" in TEXT and not m.group("Msisto_31") + "-" + m.group("Msisto_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_33>[a-zA-Z]+ista) (?P<Msisto_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_33").lower() in excIsta and not " e " + m.group("Msisto_33") + " " + m.group("Msisto_34") + "rios" in TEXT and not " ou " + m.group("Msisto_33") + " " + m.group("Msisto_34") + "rios" in TEXT and not "s de " + m.group("Msisto_33") + " " + m.group("Msisto_34") + "rios" in TEXT and not "s do " + m.group("Msisto_33") + " " + m.group("Msisto_34") + "rios" in TEXT and not " o " + m.group("Msisto_33") + " " + m.group("Msisto_34") + "rios" in TEXT and not m.group("Msisto_33") + "-" + m.group("Msisto_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_35>[a-zA-Z]+ista) (?P<Msisto_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_35").lower() in excIsta and not " e " + m.group("Msisto_35") + " " + m.group("Msisto_36") + "ssimos" in TEXT and not " ou " + m.group("Msisto_35") + " " + m.group("Msisto_36") + "ssimos" in TEXT and not "s de " + m.group("Msisto_35") + " " + m.group("Msisto_36") + "ssimos" in TEXT and not "s do " + m.group("Msisto_35") + " " + m.group("Msisto_36") + "ssimos" in TEXT and not " o " + m.group("Msisto_35") + " " + m.group("Msisto_36") + "ssimos" in TEXT and not m.group("Msisto_35") + "-" + m.group("Msisto_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_37>[a-zA-Z]+ista) (?P<Msisto_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_37").lower() in excIsta and not " e " + m.group("Msisto_37") + " " + m.group("Msisto_38") + "simos" in TEXT and not " ou " + m.group("Msisto_37") + " " + m.group("Msisto_38") + "simos" in TEXT and not "s de " + m.group("Msisto_37") + " " + m.group("Msisto_38") + "simos" in TEXT and not "s do " + m.group("Msisto_37") + " " + m.group("Msisto_38") + "simos" in TEXT and not " o " + m.group("Msisto_37") + " " + m.group("Msisto_38") + "simos" in TEXT and not m.group("Msisto_37") + "-" + m.group("Msisto_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_43>[a-zA-Z]+ista) (?P<Msisto_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_43").lower() in excIsta and m.group("Msisto_44") in plvrMfr and not " e " + m.group("Msisto_43") + " " + m.group("Msisto_44") + "es" in TEXT and not " ou " + m.group("Msisto_43") + " " + m.group("Msisto_44") + "es" in TEXT and not "s de " + m.group("Msisto_43") + " " + m.group("Msisto_44") + "es" in TEXT and not "s do " + m.group("Msisto_43") + " " + m.group("Msisto_44") + "es" in TEXT and not " o " + m.group("Msisto_43") + " " + m.group("Msisto_44") + "es" in TEXT and not m.group("Msisto_43") + "-" + m.group("Msisto_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_45>[a-zA-Z]+ista) (?P<Msisto_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_45").lower() in excIsta and m.group("Msisto_46") in plvrMascr and not " e " + m.group("Msisto_45") + " " + m.group("Msisto_46") + "es" in TEXT and not " ou " + m.group("Msisto_45") + " " + m.group("Msisto_46") + "es" in TEXT and not "s de " + m.group("Msisto_45") + " " + m.group("Msisto_46") + "es" in TEXT and not "s do " + m.group("Msisto_45") + " " + m.group("Msisto_46") + "es" in TEXT and not " o " + m.group("Msisto_45") + " " + m.group("Msisto_46") + "es" in TEXT and not m.group("Msisto_45") + "-" + m.group("Msisto_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_47>[a-zA-Z]+ista) (?P<Msisto_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_47").lower() in excIsta and m.group("Msisto_48") in plvrMfal and not " e " + m.group("Msisto_47") + " " + m.group("Msisto_48") + "is" in TEXT and not " ou " + m.group("Msisto_47") + " " + m.group("Msisto_48") + "is" in TEXT and not "s de " + m.group("Msisto_47") + " " + m.group("Msisto_48") + "is" in TEXT and not "s do " + m.group("Msisto_47") + " " + m.group("Msisto_48") + "is" in TEXT and not " o " + m.group("Msisto_47") + " " + m.group("Msisto_48") + "is" in TEXT and not m.group("Msisto_47") + "-" + m.group("Msisto_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_49>[a-zA-Z]+ista) (?P<Msisto_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_49").lower() in excIsta and m.group("Msisto_50") in plvrMfcao and not " e " + m.group("Msisto_49") + " " + m.group("Msisto_50") + "ões" in TEXT and not + " ou " + m.group("Msisto_49") + " " + m.group("Msisto_50") + "ões" in TEXT and not + "s de " + m.group("Msisto_49") + " " + m.group("Msisto_50") + "ões" in TEXT and not + "s do " + m.group("Msisto_49") + " " + m.group("Msisto_50") + "ões" in TEXT and not + " a " + m.group("Msisto_49") + " " + m.group("Msisto_50") + "ões" in TEXT and not m.group("Msisto_49") + "-" + m.group("Msisto_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_51>[a-zA-Z]+ista) (?P<Msisto_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_51").lower() in excIsta and m.group("Msisto_52") in plvrNfemcao and not " e " + m.group("Msisto_51") + " " + m.group("Msisto_52") + "ões" in TEXT and not " ou " + m.group("Msisto_51") + " " + m.group("Msisto_52") + "ões" in TEXT and not "s de " + m.group("Msisto_51") + " " + m.group("Msisto_52") + "ões" in TEXT and not "s do " + m.group("Msisto_51") + " " + m.group("Msisto_52") + "ões" in TEXT and not " o " + m.group("Msisto_51") + " " + m.group("Msisto_52") + "ões" in TEXT and not m.group("Msisto_51") + "-" + m.group("Msisto_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_57>[a-zA-Z]+ista) (?P<Msisto_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_57").lower() in excIsta and m.group("Msisto_58").lower() in excIsta and not " e " + m.group("Msisto_57") + " " + m.group("Msisto_58") + "es" in TEXT and not " ou " + m.group("Msisto_57") + " " + m.group("Msisto_58") + "es" in TEXT and not "s de " + m.group("Msisto_57") + " " + m.group("Msisto_58") + "es" in TEXT and not "s do " + m.group("Msisto_57") + " " + m.group("Msisto_58") + "es" in TEXT and not " o " + m.group("Msisto_57") + " " + m.group("Msisto_58") + "es" in TEXT and not m.group("Msisto_57") + "-" + m.group("Msisto_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_59>[a-zA-Z]+ista) (?P<Msisto_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_59").lower() in excIsta and m.group("Msisto_60").lower() in plvrMasce and not " e " + m.group("Msisto_59") + " " + m.group("Msisto_60") + "es" in TEXT and not " ou " + m.group("Msisto_59") + " " + m.group("Msisto_60") + "es" in TEXT and not "s de " + m.group("Msisto_59") + " " + m.group("Msisto_60") + "es" in TEXT and not "s do " + m.group("Msisto_59") + " " + m.group("Msisto_60") + "es" in TEXT and not " o " + m.group("Msisto_59") + " " + m.group("Msisto_60") + "es" in TEXT and not m.group("Msisto_59") + "-" + m.group("Msisto_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_61>[a-zA-Z]+ista) (?P<Msisto_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_61").lower() in excIsta and m.group("Msisto_62") in plvrMfel and not " e " + m.group("Msisto_61") + " " + m.group("Msisto_62") + "éis" in TEXT and not " ou " + m.group("Msisto_61") + " " + m.group("Msisto_62") + "éis" in TEXT and not "s de " + m.group("Msisto_61") + " " + m.group("Msisto_62") + "éis" in TEXT and not "s do " + m.group("Msisto_61") + " " + m.group("Msisto_62") + "éis" in TEXT and not " o " + m.group("Msisto_61") + " " + m.group("Msisto_62") + "éis" in TEXT and not m.group("Msisto_61") + "-" + m.group("Msisto_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_63>[a-zA-Z]+ista) (?P<Msisto_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_63").lower() in excIsta and m.group("Msisto_64") in plvrMascel and not " e " + m.group("Msisto_63") + " " + m.group("Msisto_64") + "éis" in TEXT and not " ou " + m.group("Msisto_63") + " " + m.group("Msisto_64") + "éis" in TEXT and not "s de " + m.group("Msisto_63") + " " + m.group("Msisto_64") + "éis" in TEXT and not "s do " + m.group("Msisto_63") + " " + m.group("Msisto_64") + "éis" in TEXT and not " o " + m.group("Msisto_63") + " " + m.group("Msisto_64") + "éis" in TEXT and not m.group("Msisto_63") + "-" + m.group("Msisto_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_65>[a-zA-Z]+ista) (?P<Msisto_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_65").lower() in excIsta and m.group("Msisto_66") in plvrMfeu and not " e " + m.group("Msisto_65") + " " + m.group("Msisto_66") + "us" in TEXT and not " ou " + m.group("Msisto_65") + " " + m.group("Msisto_66") + "us" in TEXT and not "s de " + m.group("Msisto_65") + " " + m.group("Msisto_66") + "us" in TEXT and not "s do " + m.group("Msisto_65") + " " + m.group("Msisto_66") + "us" in TEXT and not " o " + m.group("Msisto_65") + " " + m.group("Msisto_66") + "us" in TEXT and not m.group("Msisto_65") + "-" + m.group("Msisto_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_67>[a-zA-Z]+ista) (?P<Msisto_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_67").lower() in excIsta and m.group("Msisto_68") in plvrMascu and not " e " + m.group("Msisto_67") + " " + m.group("Msisto_68") + "us" in TEXT and not " ou " + m.group("Msisto_67") + " " + m.group("Msisto_68") + "us" in TEXT and not "s de " + m.group("Msisto_67") + " " + m.group("Msisto_68") + "us" in TEXT and not "s do " + m.group("Msisto_67") + " " + m.group("Msisto_68") + "us" in TEXT and not " o " + m.group("Msisto_67") + " " + m.group("Msisto_68") + "us" in TEXT and not m.group("Msisto_67") + "-" + m.group("Msisto_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_71>[a-zA-Z]+ista) (?P<Msisto_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_71").lower() in excIsta and m.group("Msisto_72") in plvrMascz and not " e " + m.group("Msisto_71") + " " + m.group("Msisto_72") + "zes" in TEXT and not " ou " + m.group("Msisto_71") + " " + m.group("Msisto_72") + "zes" in TEXT and not "s de " + m.group("Msisto_71") + " " + m.group("Msisto_72") + "zes" in TEXT and not "s do " + m.group("Msisto_71") + " " + m.group("Msisto_72") + "zes" in TEXT and not " o " + m.group("Msisto_71") + " " + m.group("Msisto_72") + "zes" in TEXT and not m.group("Msisto_71") + "-" + m.group("Msisto_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_73>[a-zA-Z]+ista) (?P<Msisto_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_73").lower() in excIsta and m.group("Msisto_74") in pvrMascan and not " e " + m.group("Msisto_73") + " " + m.group("Msisto_74") + "s" in TEXT and not " ou " + m.group("Msisto_73") + " " + m.group("Msisto_74") + "s" in TEXT and not "s de " + m.group("Msisto_73") + " " + m.group("Msisto_74") + "s" in TEXT and not "s do " + m.group("Msisto_73") + " " + m.group("Msisto_74") + "s" in TEXT and not " o " + m.group("Msisto_73") + " " + m.group("Msisto_74") + "s" in TEXT and not m.group("Msisto_73") + "-" + m.group("Msisto_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_75>[a-zA-Z]+ista) (?P<Msisto_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_75").lower() in excIsta and m.group("Msisto_76").lower() in plvrMasco and not " e " + m.group("Msisto_75") + " " + m.group("Msisto_76") +"s" in TEXT and not " ou " + m.group("Msisto_75") + " " + m.group("Msisto_76") + "s" in TEXT and not "s de " + m.group("Msisto_75") + " " + m.group("Msisto_76") + "s" in TEXT and not "s do " + m.group("Msisto_75") + " " + m.group("Msisto_76") + "s" in TEXT and not " o " + m.group("Msisto_75") + " " + m.group("Msisto_76") + "s" in TEXT and not m.group("Msisto_75") + "-" + m.group("Msisto_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_77>[a-zA-Z]+ista) (?P<Msisto_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_77").lower() in excIsta and not " e " + m.group("Msisto_77") + " " + m.group("Msisto_78") + "inhos" in TEXT and not " ou " + m.group("Msisto_77") + " " + m.group("Msisto_78") + "inhos" in TEXT and not "s de " + m.group("Msisto_77") + " " + m.group("Msisto_78") + "inhos" in TEXT and not "s do " + m.group("Msisto_77") + " " + m.group("Msisto_78") + "inhos" in TEXT and not " o " + m.group("Msisto_77") + " " + m.group("Msisto_78") + "inhos" in TEXT and not m.group("Msisto_77") + "-" + m.group("Msisto_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_83>[a-zA-Z]+ista) (?P<Msisto_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_83").lower() in excIsta and not " e " + m.group("Msisto_83") + " " + m.group("Msisto_84") + "icas" in TEXT and not " ou " + m.group("Msisto_83") + " " + m.group("Msisto_84") + "icas" in TEXT and not "s de " + m.group("Msisto_83") + " " + m.group("Msisto_84") + "icas" in TEXT and not "s do " + m.group("Msisto_83") + " " + m.group("Msisto_84") + "icas" in TEXT and not " o " + m.group("Msisto_83") + " " + m.group("Msisto_84") + "icas" in TEXT and not m.group("Msisto_83") + "-" + m.group("Msisto_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_85>[a-zA-Z]+ista) (?P<Msisto_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_85").lower() in excIsta and not " e " + m.group("Msisto_85") + " " + m.group("Msisto_86") + "escas" in TEXT and not " ou " + m.group("Msisto_85") + " " + m.group("Msisto_86") + "escas" in TEXT and not "s de " + m.group("Msisto_85") + " " + m.group("Msisto_86") + "escas" in TEXT and not "s do " + m.group("Msisto_85") + " " + m.group("Msisto_86") + "escas" in TEXT and not " o " + m.group("Msisto_85") + " " + m.group("Msisto_86") + "escas" in TEXT and not m.group("Msisto_85") + "-" + m.group("Msisto_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msisto_87>[a-zA-Z]+ista) (?P<Msisto_88>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msisto_87").lower() in excIsta and m.group("Msisto_88") in plvrMascm and not " e " + m.group("Msisto_87") + " " + m.group("Msisto_88") + "ns" in TEXT and not " ou " + m.group("Msisto_87") + " " + m.group("Msisto_88") + "ns" in TEXT and not "s de " + m.group("Msisto_87") + " " + m.group("Msisto_88") + "ns" in TEXT and not "s da " + m.group("Msisto_87") + " " + m.group("Msisto_88") + "ns" in TEXT and not " a " + m.group("Msisto_87") + " " + m.group("Msisto_88") + "ns" in TEXT and not m.group("Msisto_87") + "-" + m.group("Msisto_88") + "ns" in tCompostops'],
# plvrInva a
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_1>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_1").lower() in plvrInva and m.group("Msinva_2").lower() in plvrFema and not " e " + m.group("Msinva_1") + " " + m.group("Msinva_2") +"s" in TEXT and not " ou " + m.group("Msinva_1") + " " + m.group("Msinva_2") + "s" in TEXT and not "s de " + m.group("Msinva_1") + " " + m.group("Msinva_2") + "s" in TEXT and not "s da " + m.group("Msinva_1") + " " + m.group("Msinva_2") + "s" in TEXT and not " a " + m.group("Msinva_1") + " " + m.group("Msinva_2") + "s" in TEXT and not m.group("Msinva_1") + "-" + m.group("Msinva_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_3>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_3").lower() in plvrInva and m.group("Msinva_4").lower() in plvrMfe and not " e " + m.group("Msinva_3") + " " + m.group("Msinva_4") + "as" in TEXT and not " ou " + m.group("Msinva_3") + " " + m.group("Msinva_4") + "as" in TEXT and not "s de " + m.group("Msinva_3") + " " + m.group("Msinva_4") + "as" in TEXT and not "s da " + m.group("Msinva_3") + " " + m.group("Msinva_4") + "as" in TEXT and not " a " + m.group("Msinva_3") + " " + m.group("Msinva_4") + "as" in TEXT and not m.group("Msinva_3") + "-" + m.group("Msinva_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_5>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_5").lower() in plvrInva and not m.group("Msinva_6").lower() in excAdo and not " e " + m.group("Msinva_5") + " " + m.group("Msinva_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msinva_5") + " " + m.group("Msinva_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msinva_5") + " " + m.group("Msinva_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Msinva_5") + " " + m.group("Msinva_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Msinva_5") + " " + m.group("Msinva_6") + m.group(3) + "dos" in TEXT and not m.group("Msinva_5") + "-" + m.group("Msinva_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_7>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_7").lower() in plvrInva and not m.group("Msinva_8").lower() in XexcIsta and not " e " + m.group("Msinva_7") + " " + m.group("Msinva_8") + "s" in TEXT and not " ou " + m.group("Msinva_7") + " " + m.group("Msinva_8") + "s" in TEXT and not "s de " + m.group("Msinva_7") + " " + m.group("Msinva_8") + "s" in TEXT and not "s da " + m.group("Msinva_7") + " " + m.group("Msinva_8") + "s" in TEXT and not " a " + m.group("Msinva_7") + " " + m.group("Msinva_8") + "s" in TEXT and not m.group("Msinva_7") + "-" + m.group("Msinva_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_9>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_10>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_9").lower() in plvrInva and m.group("Msinva_10").lower() in plvrInva and not " e " + m.group("Msinva_9") + " " + m.group("Msinva_10") + "s" in TEXT and not " ou " + m.group("Msinva_9") + " " + m.group("Msinva_10") + "s" in TEXT and not "s de " + m.group("Msinva_9") + " " + m.group("Msinva_10") + "s" in TEXT and not "s da " + m.group("Msinva_9") + " " + m.group("Msinva_10") + "s" in TEXT and not " a " + m.group("Msinva_9") + " " + m.group("Msinva_10") + "s" in TEXT and not m.group("Msinva_9") + "-" + m.group("Msinva_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_11>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_11").lower() in plvrInva and not m.group("Msinva_12").lower() in excAdo and not " e " + m.group("Msinva_11") + " " + m.group("Msinva_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msinva_11") + " " + m.group("Msinva_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msinva_11") + " " + m.group("Msinva_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Msinva_11") + " " + m.group("Msinva_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Msinva_11") + " " + m.group("Msinva_12") + m.group(3) + "das" in TEXT and not m.group("Msinva_11") + "-" + m.group("Msinva_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_15>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_15").lower() in plvrInva and not " e " + m.group("Msinva_15") + " " + m.group("Msinva_16") + "osas" in TEXT and not " ou " + m.group("Msinva_15") + " " + m.group("Msinva_16") + "osas" in TEXT and not "s de " + m.group("Msinva_15") + " " + m.group("Msinva_16") + "osas" in TEXT and not "s da " + m.group("Msinva_15") + " " + m.group("Msinva_16") + "osas" in TEXT and not " a " + m.group("Msinva_15") + " " + m.group("Msinva_16") + "osas" in TEXT and not m.group("Msinva_15") + "-" + m.group("Msinva_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_17>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_17").lower() in plvrInva and not " e " + m.group("Msinva_17") + " " + m.group("Msinva_18") + "ivas" in TEXT and not " ou " + m.group("Msinva_17") + " " + m.group("Msinva_18") + "ivas" in TEXT and not "s de " + m.group("Msinva_17") + " " + m.group("Msinva_18") + "ivas" in TEXT and not "s da " + m.group("Msinva_17") + " " + m.group("Msinva_18") + "ivas" in TEXT and not " a " + m.group("Msinva_17") + " " + m.group("Msinva_18") + "ivas" in TEXT and not m.group("Msinva_17") + "-" + m.group("Msinva_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_21>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_21").lower() in plvrInva and not " e " + m.group("Msinva_21") + " " + m.group("Msinva_22") + "icas" in TEXT and not " ou " + m.group("Msinva_21") + " " + m.group("Msinva_22") + "icas" in TEXT and not "s de " + m.group("Msinva_21") + " " + m.group("Msinva_22") + "icas" in TEXT and not "s da " + m.group("Msinva_21") + " " + m.group("Msinva_22") + "icas" in TEXT and not " a " + m.group("Msinva_21") + " " + m.group("Msinva_22") + "icas" in TEXT and not m.group("Msinva_21") + "-" + m.group("Msinva_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_23>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_23").lower() in plvrInva and not " e " + m.group("Msinva_23") + " " + m.group("Msinva_24") + "icas" in TEXT and not " ou " + m.group("Msinva_23") + " " + m.group("Msinva_24") + "icas" in TEXT and not "s de " + m.group("Msinva_23") + " " + m.group("Msinva_24") + "icas" in TEXT and not "s da " + m.group("Msinva_23") + " " + m.group("Msinva_24") + "icas" in TEXT and not " a " + m.group("Msinva_23") + " " + m.group("Msinva_24") + "icas" in TEXT and not m.group("Msinva_23") + "-" + m.group("Msinva_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_25>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_25").lower() in plvrInva and not " e " + m.group("Msinva_25") + " " + m.group("Msinva_26") + "icas" in TEXT and not " ou " + m.group("Msinva_25") + " " + m.group("Msinva_26") + "icas" in TEXT and not "s de " + m.group("Msinva_25") + " " + m.group("Msinva_26") + "icas" in TEXT and not "s da " + m.group("Msinva_25") + " " + m.group("Msinva_26") + "icas" in TEXT and not " a " + m.group("Msinva_25") + " " + m.group("Msinva_26") + "icas" in TEXT and not m.group("Msinva_25") + "-" + m.group("Msinva_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_27>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_27").lower() in plvrInva and not " e " + m.group("Msinva_27") + " " + m.group("Msinva_28") + "escas" in TEXT and not " ou " + m.group("Msinva_27") + " " + m.group("Msinva_28") + "escas" in TEXT and not "s de " + m.group("Msinva_27") + " " + m.group("Msinva_28") + "escas" in TEXT and not "s da " + m.group("Msinva_27") + " " + m.group("Msinva_28") + "escas" in TEXT and not " a " + m.group("Msinva_27") + " " + m.group("Msinva_28") + "escas" in TEXT and not m.group("Msinva_27") + "-" + m.group("Msinva_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_29>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_29").lower() in plvrInva and not " e " + m.group("Msinva_29") + " " + m.group("Msinva_30") + "idas" in TEXT and not " ou " + m.group("Msinva_29") + "s " + m.group("Msinva_30") + "idas" in TEXT and not "s de " + m.group("Msinva_29") + "s " + m.group("Msinva_30") + "idas" in TEXT and not "s da " + m.group("Msinva_29") + "s " + m.group("Msinva_30") + "idas" in TEXT and not " a " + m.group("Msinva_29") + "s " + m.group("Msinva_30") + "idas" in TEXT and not m.group("Msinva_29") + "-" + m.group("Msinva_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_31>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_31").lower() in plvrInva and not " e " + m.group("Msinva_31") + " " + m.group("Msinva_32") + "logas" in TEXT and not " ou " + m.group("Msinva_31") + " " + m.group("Msinva_32") + "logas" in TEXT and not "s de " + m.group("Msinva_31") + " " + m.group("Msinva_32") + "logas" in TEXT and not "s da " + m.group("Msinva_31") + " " + m.group("Msinva_32") + "logas" in TEXT and not " a " + m.group("Msinva_31") + " " + m.group("Msinva_32") + "logas" in TEXT and not m.group("Msinva_31") + "-" + m.group("Msinva_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_33>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_33").lower() in plvrInva and not " e " + m.group("Msinva_33") + " " + m.group("Msinva_34") + "rias" in TEXT and not " ou " + m.group("Msinva_33") + " " + m.group("Msinva_34") + "rias" in TEXT and not "s de " + m.group("Msinva_33") + " " + m.group("Msinva_34") + "rias" in TEXT and not "s da " + m.group("Msinva_33") + " " + m.group("Msinva_34") + "rias" in TEXT and not " a " + m.group("Msinva_33") + " " + m.group("Msinva_34") + "rias" in TEXT and not m.group("Msinva_33") + "-" + m.group("Msinva_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_35>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_35").lower() in plvrInva and not " e " + m.group("Msinva_35") + " " + m.group("Msinva_36") + "ssimas" in TEXT and not " ou " + m.group("Msinva_35") + " " + m.group("Msinva_36") + "ssimas" in TEXT and not "s de " + m.group("Msinva_35") + " " + m.group("Msinva_36") + "ssimas" in TEXT and not "s da " + m.group("Msinva_35") + " " + m.group("Msinva_36") + "ssimas" in TEXT and not " a " + m.group("Msinva_35") + " " + m.group("Msinva_36") + "ssimas" in TEXT and not m.group("Msinva_35") + "-" + m.group("Msinva_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_37>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_37").lower() in plvrInva and not " e " + m.group("Msinva_37") + " " + m.group("Msinva_38") + "simas" in TEXT and not " ou " + m.group("Msinva_37") + " " + m.group("Msinva_38") + "simas" in TEXT and not "s de " + m.group("Msinva_37") + " " + m.group("Msinva_38") + "simas" in TEXT and not "s da " + m.group("Msinva_37") + " " + m.group("Msinva_38") + "simas" in TEXT and not " a " + m.group("Msinva_37") + " " + m.group("Msinva_38") + "simas" in TEXT and not m.group("Msinva_37") + "-" + m.group("Msinva_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_41>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_41").lower() in plvrInva and not m.group("Msinva_42") in "D-d-" and not " e " + m.group("Msinva_41") + " " + m.group("Msinva_42") + "oras" in TEXT and not " ou " + m.group("Msinva_41") + " " + m.group("Msinva_42") + "oras" in TEXT and not "s de " + m.group("Msinva_41") + " " + m.group("Msinva_42") + "oras" in TEXT and not "s da " + m.group("Msinva_41") + " " + m.group("Msinva_42") + "oras" in TEXT and not " a " + m.group("Msinva_41") + " " + m.group("Msinva_42") + "oras" in TEXT and not m.group("Msinva_41") + "-" + m.group("Msinva_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_43>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_43").lower() in plvrInva and m.group("Msinva_44") in plvrMfr and not " e " + m.group("Msinva_43") + " " + m.group("Msinva_44") + "es" in TEXT and not " ou " + m.group("Msinva_43") + " " + m.group("Msinva_44") + "es" in TEXT and not "s de " + m.group("Msinva_43") + " " + m.group("Msinva_44") + "es" in TEXT and not "s da " + m.group("Msinva_43") + " " + m.group("Msinva_44") + "es" in TEXT and not " a " + m.group("Msinva_43") + " " + m.group("Msinva_44") + "es" in TEXT and not m.group("Msinva_43") + "-" + m.group("Msinva_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_45>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_45").lower() in plvrInva and m.group("Msinva_46") in plvrFemr and not " e " + m.group("Msinva_45") + " " + m.group("Msinva_46") + "es" in TEXT and not " ou " + m.group("Msinva_45") + " " + m.group("Msinva_46") + "es" in TEXT and not "s de " + m.group("Msinva_45") + " " + m.group("Msinva_46") + "es" in TEXT and not "s da " + m.group("Msinva_45") + " " + m.group("Msinva_46") + "es" in TEXT and not " a " + m.group("Msinva_45") + " " + m.group("Msinva_46") + "es" in TEXT and not m.group("Msinva_45") + "-" + m.group("Msinva_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_47>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_47").lower() in plvrInva and m.group("Msinva_48") in plvrMfal and not " e " + m.group("Msinva_47") + " " + m.group("Msinva_48") + "is" in TEXT and not " ou " + m.group("Msinva_47") + " " + m.group("Msinva_48") + "is" in TEXT and not "s de " + m.group("Msinva_47") + " " + m.group("Msinva_48") + "is" in TEXT and not "s da " + m.group("Msinva_47") + " " + m.group("Msinva_48") + "is" in TEXT and not " a " + m.group("Msinva_47") + " " + m.group("Msinva_48") + "is" in TEXT and not m.group("Msinva_47") + "-" + m.group("Msinva_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_49>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_49").lower() in plvrInva and m.group("Msinva_50") in plvrMfcao and not " e " + m.group("Msinva_49") + " " + m.group("Msinva_50") + "ões" in TEXT and not + " ou " + m.group("Msinva_49") + " " + m.group("Msinva_50") + "ões" in TEXT and not + "s de " + m.group("Msinva_49") + " " + m.group("Msinva_50") + "ões" in TEXT and not + "s da " + m.group("Msinva_49") + " " + m.group("Msinva_50") + "ões" in TEXT and not + " a " + m.group("Msinva_49") + " " + m.group("Msinva_50") + "ões" in TEXT and not m.group("Msinva_49") + "-" + m.group("Msinva_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_51>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_51").lower() in plvrInva and not m.group("Msinva_52") in plvrMascao and not " e " + m.group("Msinva_51") + " " + m.group("Msinva_52") + "ões" in TEXT and not " ou " + m.group("Msinva_51") + " " + m.group("Msinva_52") + "ões" in TEXT and not "s de " + m.group("Msinva_51") + " " + m.group("Msinva_52") + "ões" in TEXT and not "s da " + m.group("Msinva_51") + " " + m.group("Msinva_52") + "ões" in TEXT and not " a " + m.group("Msinva_51") + " " + m.group("Msinva_52") + "ões" in TEXT and not m.group("Msinva_51") + "-" + m.group("Msinva_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_53>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_53").lower() in plvrInva and m.group("Msinva_54") in plvrFemao and not " e " + m.group("Msinva_53") + " " + m.group("Msinva_54") + "ões" in TEXT and not " ou " + m.group("Msinva_53") + " " + m.group("Msinva_54") + "ões" in TEXT and not "s de " + m.group("Msinva_53") + " " + m.group("Msinva_54") + "ões" in TEXT and not "s da " + m.group("Msinva_53") + " " + m.group("Msinva_54") + "ões" in TEXT and not " a " + m.group("Msinva_53") + " " + m.group("Msinva_54") + "ões" in TEXT and not m.group("Msinva_53") + "-" + m.group("Msinva_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_55>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_55").lower() in plvrInva and not " e " + m.group("Msinva_55") + " " + m.group("Msinva_56") + "veis" in TEXT and not " ou " + m.group("Msinva_55") + " " + m.group("Msinva_56") + "veis" in TEXT and not "s de " + m.group("Msinva_55") + " " + m.group("Msinva_56") + "veis" in TEXT and not "s da " + m.group("Msinva_55") + " " + m.group("Msinva_56") + "veis" in TEXT and not " a " + m.group("Msinva_55") + " " + m.group("Msinva_56") + "veis" in TEXT and not m.group("Msinva_55") + "-" + m.group("Msinva_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_57>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_57").lower() in plvrInva and m.group("Msinva_58").lower() in plvrInva and not " e " + m.group("Msinva_57") + " " + m.group("Msinva_58") + "es" in TEXT and not " ou " + m.group("Msinva_57") + " " + m.group("Msinva_58") + "es" in TEXT and not "s de " + m.group("Msinva_57") + " " + m.group("Msinva_58") + "es" in TEXT and not "s da " + m.group("Msinva_57") + " " + m.group("Msinva_58") + "es" in TEXT and not " a " + m.group("Msinva_57") + " " + m.group("Msinva_58") + "es" in TEXT and not m.group("Msinva_57") + "-" + m.group("Msinva_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_59>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_59").lower() in plvrInva and m.group("Msinva_60").lower() in plvrInva and not " e " + m.group("Msinva_59") + " " + m.group("Msinva_60") + "es" in TEXT and not " ou " + m.group("Msinva_59") + " " + m.group("Msinva_60") + "es" in TEXT and not "s de " + m.group("Msinva_59") + " " + m.group("Msinva_60") + "es" in TEXT and not "s da " + m.group("Msinva_59") + " " + m.group("Msinva_60") + "es" in TEXT and not " a " + m.group("Msinva_59") + " " + m.group("Msinva_60") + "es" in TEXT and not m.group("Msinva_59") + "-" + m.group("Msinva_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_61>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_61").lower() in plvrInva and m.group("Msinva_62") in plvrMfel and not " e " + m.group("Msinva_61") + " " + m.group("Msinva_62") + "éis" in TEXT and not " ou " + m.group("Msinva_61") + " " + m.group("Msinva_62") + "éis" in TEXT and not "s de " + m.group("Msinva_61") + " " + m.group("Msinva_62") + "éis" in TEXT and not "s da " + m.group("Msinva_61") + " " + m.group("Msinva_62") + "éis" in TEXT and not " a " + m.group("Msinva_61") + " " + m.group("Msinva_62") + "éis" in TEXT and not m.group("Msinva_61") + "-" + m.group("Msinva_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_63>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_63").lower() in plvrInva and m.group("Msinva_64") in plvrFemel and not " e " + m.group("Msinva_63") + " " + m.group("Msinva_64") + "éis" in TEXT and not " ou " + m.group("Msinva_63") + " " + m.group("Msinva_64") + "éis" in TEXT and not "s de " + m.group("Msinva_63") + " " + m.group("Msinva_64") + "éis" in TEXT and not "s da " + m.group("Msinva_63") + " " + m.group("Msinva_64") + "éis" in TEXT and not " a " + m.group("Msinva_63") + " " + m.group("Msinva_64") + "éis" in TEXT and not m.group("Msinva_63") + "-" + m.group("Msinva_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_65>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_65").lower() in plvrInva and m.group("Msinva_66") in plvrMfeu and not " e " + m.group("Msinva_65") + " " + m.group("Msinva_66") + "us" in TEXT and not " ou " + m.group("Msinva_65") + " " + m.group("Msinva_66") + "us" in TEXT and not "s de " + m.group("Msinva_65") + " " + m.group("Msinva_66") + "us" in TEXT and not "s da " + m.group("Msinva_65") + " " + m.group("Msinva_66") + "us" in TEXT and not " a " + m.group("Msinva_65") + " " + m.group("Msinva_66") + "us" in TEXT and not m.group("Msinva_65") + "-" + m.group("Msinva_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_67>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_67").lower() in plvrInva and m.group("Msinva_68") in plvrFemu and not " e " + m.group("Msinva_67") + " " + m.group("Msinva_68") + "us" in TEXT and not " ou " + m.group("Msinva_67") + " " + m.group("Msinva_68") + "us" in TEXT and not "s de " + m.group("Msinva_67") + " " + m.group("Msinva_68") + "us" in TEXT and not "s da " + m.group("Msinva_67") + " " + m.group("Msinva_68") + "us" in TEXT and not " a " + m.group("Msinva_67") + " " + m.group("Msinva_68") + "us" in TEXT and not m.group("Msinva_67") + "-" + m.group("Msinva_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_69>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_69").lower() in plvrInva and m.group("Msinva_70") in plvrInvaz and not " e " + m.group("Msinva_69") + " " + m.group("Msinva_70") + "zes" in TEXT and not " ou " + m.group("Msinva_69") + " " + m.group("Msinva_70") + "zes" in TEXT and not "s de " + m.group("Msinva_69") + " " + m.group("Msinva_70") + "zes" in TEXT and not "s da " + m.group("Msinva_69") + " " + m.group("Msinva_70") + "zes" in TEXT and not " a " + m.group("Msinva_69") + " " + m.group("Msinva_70") + "zes" in TEXT and not m.group("Msinva_69") + "-" + m.group("Msinva_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_71>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_71").lower() in plvrInva and m.group("Msinva_72") in plvrFemz and not " e " + m.group("Msinva_71") + " " + m.group("Msinva_72") + "zes" in TEXT and not " ou " + m.group("Msinva_71") + " " + m.group("Msinva_72") + "zes" in TEXT and not "s de " + m.group("Msinva_71") + " " + m.group("Msinva_72") + "zes" in TEXT and not "s da " + m.group("Msinva_71") + " " + m.group("Msinva_72") + "zes" in TEXT and not " a " + m.group("Msinva_71") + " " + m.group("Msinva_72") + "zes" in TEXT and not m.group("Msinva_71") + "-" + m.group("Msinva_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_73>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_73").lower() in plvrInva and m.group("Msinva_74") in pvrFeman and not " e " + m.group("Msinva_73") + " " + m.group("Msinva_74") + "s" in TEXT and not " ou " + m.group("Msinva_73") + " " + m.group("Msinva_74") + "s" in TEXT and not "s de " + m.group("Msinva_73") + " " + m.group("Msinva_74") + "s" in TEXT and not "s da " + m.group("Msinva_73") + " " + m.group("Msinva_74") + "s" in TEXT and not " a " + m.group("Msinva_73") + " " + m.group("Msinva_74") + "s" in TEXT and not m.group("Msinva_73") + "-" + m.group("Msinva_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_75>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_76>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_75").lower() in plvrInva and m.group("Msinva_76") in plvrMFm and not " e " + m.group("Msinva_75") + " " + m.group("Msinva_76") + "ns" in TEXT and not " ou " + m.group("Msinva_75") + " " + m.group("Msinva_76") + "ns" in TEXT and not "s de " + m.group("Msinva_75") + " " + m.group("Msinva_76") + "ns" in TEXT and not "s da " + m.group("Msinva_75") + " " + m.group("Msinva_76") + "ns" in TEXT and not " a " + m.group("Msinva_75") + " " + m.group("Msinva_76") + "ns" in TEXT and not m.group("Msinva_75") + "-" + m.group("Msinva_76") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinva_77>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinva_78>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinva_77").lower() in plvrInva and m.group("Msinva_78") in plvrFemm and not " e " + m.group("Msinva_77") + " " + m.group("Msinva_78") + "ns" in TEXT and not " ou " + m.group("Msinva_77") + " " + m.group("Msinva_78") + "ns" in TEXT and not "s de " + m.group("Msinva_77") + " " + m.group("Msinva_78") + "ns" in TEXT and not "s da " + m.group("Msinva_77") + " " + m.group("Msinva_78") + "ns" in TEXT and not " a " + m.group("Msinva_77") + " " + m.group("Msinva_78") + "ns" in TEXT and not m.group("Msinva_77") + "-" + m.group("Msinva_78") + "ns" in tCompostops'],
# plvrInva o
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_1>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_1").lower() in plvrInva and m.group("Msinvo_2").lower() in plvrMasca and not " e " + m.group("Msinvo_1") + " " + m.group("Msinvo_2") +"s" in TEXT and not " ou " + m.group("Msinvo_1") + " " + m.group("Msinvo_2") + "s" in TEXT and not "s de " + m.group("Msinvo_1") + " " + m.group("Msinvo_2") + "s" in TEXT and not "s do " + m.group("Msinvo_1") + " " + m.group("Msinvo_2") + "s" in TEXT and not " o " + m.group("Msinvo_1") + " " + m.group("Msinvo_2") + "s" in TEXT and not m.group("Msinvo_1") + "-" + m.group("Msinvo_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_3>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_3").lower() in plvrInva and m.group("Msinvo_4").lower() in plvrInva and not " e " + m.group("Msinvo_3") + " " + m.group("Msinvo_4") + "os" in TEXT and not " ou " + m.group("Msinvo_3") + " " + m.group("Msinvo_4") + "os" in TEXT and not "s de " + m.group("Msinvo_3") + " " + m.group("Msinvo_4") + "os" in TEXT and not "s do " + m.group("Msinvo_3") + " " + m.group("Msinvo_4") + "os" in TEXT and not " o " + m.group("Msinvo_3") + " " + m.group("Msinvo_4") + "os" in TEXT and not m.group("Msinvo_3") + "-" + m.group("Msinvo_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_5>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_5").lower() in plvrInva and not m.group("Msinvo_6").lower() in excAdo and not " e " + m.group("Msinvo_5") + " " + m.group("Msinvo_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msinvo_5") + " " + m.group("Msinvo_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msinvo_5") + " " + m.group("Msinvo_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msinvo_5") + " " + m.group("Msinvo_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msinvo_5") + " " + m.group("Msinvo_6") + m.group(3) + "dos" in TEXT and not m.group("Msinvo_5") + "-" + m.group("Msinvo_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_13>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_13").lower() in plvrInva and not " e " + m.group("Msinvo_13") + " " + m.group("Msinvo_14") + "osos" in TEXT and not " ou " + m.group("Msinvo_13") + " " + m.group("Msinvo_14") + "osos" in TEXT and not "s de " + m.group("Msinvo_13") + " " + m.group("Msinvo_14") + "osos" in TEXT and not "s do " + m.group("Msinvo_13") + " " + m.group("Msinvo_14") + "osos" in TEXT and not " o " + m.group("Msinvo_13") + " " + m.group("Msinvo_14") + "osos" in TEXT and not m.group("Msinvo_13") + "-" + m.group("Msinvo_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_19>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_19").lower() in plvrInva and not " e " + m.group("Msinvo_19") + " " + m.group("Msinvo_20") + "ivas" in TEXT and not " ou " + m.group("Msinvo_19") + " " + m.group("Msinvo_20") + "ivas" in TEXT and not "s de " + m.group("Msinvo_19") + " " + m.group("Msinvo_20") + "ivas" in TEXT and not "s do " + m.group("Msinvo_19") + " " + m.group("Msinvo_20") + "ivas" in TEXT and not " o " + m.group("Msinvo_19") + " " + m.group("Msinvo_20") + "ivas" in TEXT and not m.group("Msinvo_19") + "-" + m.group("Msinvo_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_21>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_21").lower() in plvrInva and not " e " + m.group("Msinvo_21") + " " + m.group("Msinvo_22") + "icos" in TEXT and not " ou " + m.group("Msinvo_21") + " " + m.group("Msinvo_22") + "icos" in TEXT and not "s de " + m.group("Msinvo_21") + " " + m.group("Msinvo_22") + "icos" in TEXT and not "s do " + m.group("Msinvo_21") + " " + m.group("Msinvo_22") + "icos" in TEXT and not " o " + m.group("Msinvo_21") + " " + m.group("Msinvo_22") + "icos" in TEXT and not m.group("Msinvo_21") + "-" + m.group("Msinvo_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_23>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_23").lower() in plvrInva and not " e " + m.group("Msinvo_23") + " " + m.group("Msinvo_24") + "icos" in TEXT and not " ou " + m.group("Msinvo_23") + " " + m.group("Msinvo_24") + "icos" in TEXT and not "s de " + m.group("Msinvo_23") + " " + m.group("Msinvo_24") + "icos" in TEXT and not "s do " + m.group("Msinvo_23") + " " + m.group("Msinvo_24") + "icos" in TEXT and not " o " + m.group("Msinvo_23") + " " + m.group("Msinvo_24") + "icos" in TEXT and not m.group("Msinvo_23") + "-" + m.group("Msinvo_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_25>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_25").lower() in plvrInva and not " e " + m.group("Msinvo_25") + " " + m.group("Msinvo_26") + "icos" in TEXT and not " ou " + m.group("Msinvo_25") + " " + m.group("Msinvo_26") + "icos" in TEXT and not "s de " + m.group("Msinvo_25") + " " + m.group("Msinvo_26") + "icos" in TEXT and not "s do " + m.group("Msinvo_25") + " " + m.group("Msinvo_26") + "icos" in TEXT and not " o " + m.group("Msinvo_25") + " " + m.group("Msinvo_26") + "icos" in TEXT and not m.group("Msinvo_25") + "-" + m.group("Msinvo_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_27>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_27").lower() in plvrInva and not " e " + m.group("Msinvo_27") + " " + m.group("Msinvo_28") + "escos" in TEXT and not " ou " + m.group("Msinvo_27") + " " + m.group("Msinvo_28") + "escos" in TEXT and not "s de " + m.group("Msinvo_27") + " " + m.group("Msinvo_28") + "escos" in TEXT and not "s do " + m.group("Msinvo_27") + " " + m.group("Msinvo_28") + "escos" in TEXT and not " o " + m.group("Msinvo_27") + " " + m.group("Msinvo_28") + "escos" in TEXT and not m.group("Msinvo_27") + "-" + m.group("Msinvo_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_29>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_29").lower() in plvrInva and not " e " + m.group("Msinvo_29") + " " + m.group("Msinvo_30") + "idos" in TEXT and not " ou " + m.group("Msinvo_29") + "s " + m.group("Msinvo_30") + "idos" in TEXT and not "s de " + m.group("Msinvo_29") + "s " + m.group("Msinvo_30") + "idos" in TEXT and not "s do " + m.group("Msinvo_29") + "s " + m.group("Msinvo_30") + "idos" in TEXT and not " o " + m.group("Msinvo_29") + "s " + m.group("Msinvo_30") + "idos" in TEXT and not m.group("Msinvo_29") + "-" + m.group("Msinvo_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_31>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_31").lower() in plvrInva and not " e " + m.group("Msinvo_31") + " " + m.group("Msinvo_32") + "logos" in TEXT and not " ou " + m.group("Msinvo_31") + " " + m.group("Msinvo_32") + "logos" in TEXT and not "s de " + m.group("Msinvo_31") + " " + m.group("Msinvo_32") + "logos" in TEXT and not "s do " + m.group("Msinvo_31") + " " + m.group("Msinvo_32") + "logos" in TEXT and not " o " + m.group("Msinvo_31") + " " + m.group("Msinvo_32") + "logos" in TEXT and not m.group("Msinvo_31") + "-" + m.group("Msinvo_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_33>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_33").lower() in plvrInva and not " e " + m.group("Msinvo_33") + " " + m.group("Msinvo_34") + "rios" in TEXT and not " ou " + m.group("Msinvo_33") + " " + m.group("Msinvo_34") + "rios" in TEXT and not "s de " + m.group("Msinvo_33") + " " + m.group("Msinvo_34") + "rios" in TEXT and not "s do " + m.group("Msinvo_33") + " " + m.group("Msinvo_34") + "rios" in TEXT and not " o " + m.group("Msinvo_33") + " " + m.group("Msinvo_34") + "rios" in TEXT and not m.group("Msinvo_33") + "-" + m.group("Msinvo_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_35>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_35").lower() in plvrInva and not " e " + m.group("Msinvo_35") + " " + m.group("Msinvo_36") + "ssimos" in TEXT and not " ou " + m.group("Msinvo_35") + " " + m.group("Msinvo_36") + "ssimos" in TEXT and not "s de " + m.group("Msinvo_35") + " " + m.group("Msinvo_36") + "ssimos" in TEXT and not "s do " + m.group("Msinvo_35") + " " + m.group("Msinvo_36") + "ssimos" in TEXT and not " o " + m.group("Msinvo_35") + " " + m.group("Msinvo_36") + "ssimos" in TEXT and not m.group("Msinvo_35") + "-" + m.group("Msinvo_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_37>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_37").lower() in plvrInva and not " e " + m.group("Msinvo_37") + " " + m.group("Msinvo_38") + "simos" in TEXT and not " ou " + m.group("Msinvo_37") + " " + m.group("Msinvo_38") + "simos" in TEXT and not "s de " + m.group("Msinvo_37") + " " + m.group("Msinvo_38") + "simos" in TEXT and not "s do " + m.group("Msinvo_37") + " " + m.group("Msinvo_38") + "simos" in TEXT and not " o " + m.group("Msinvo_37") + " " + m.group("Msinvo_38") + "simos" in TEXT and not m.group("Msinvo_37") + "-" + m.group("Msinvo_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_43>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_43").lower() in plvrInva and m.group("Msinvo_44") in plvrMfr and not " e " + m.group("Msinvo_43") + " " + m.group("Msinvo_44") + "es" in TEXT and not " ou " + m.group("Msinvo_43") + " " + m.group("Msinvo_44") + "es" in TEXT and not "s de " + m.group("Msinvo_43") + " " + m.group("Msinvo_44") + "es" in TEXT and not "s do " + m.group("Msinvo_43") + " " + m.group("Msinvo_44") + "es" in TEXT and not " o " + m.group("Msinvo_43") + " " + m.group("Msinvo_44") + "es" in TEXT and not m.group("Msinvo_43") + "-" + m.group("Msinvo_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_45>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_45").lower() in plvrInva and m.group("Msinvo_46") in plvrMascr and not " e " + m.group("Msinvo_45") + " " + m.group("Msinvo_46") + "es" in TEXT and not " ou " + m.group("Msinvo_45") + " " + m.group("Msinvo_46") + "es" in TEXT and not "s de " + m.group("Msinvo_45") + " " + m.group("Msinvo_46") + "es" in TEXT and not "s do " + m.group("Msinvo_45") + " " + m.group("Msinvo_46") + "es" in TEXT and not " o " + m.group("Msinvo_45") + " " + m.group("Msinvo_46") + "es" in TEXT and not m.group("Msinvo_45") + "-" + m.group("Msinvo_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_47>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_47").lower() in plvrInva and m.group("Msinvo_48") in plvrMfal and not " e " + m.group("Msinvo_47") + " " + m.group("Msinvo_48") + "is" in TEXT and not " ou " + m.group("Msinvo_47") + " " + m.group("Msinvo_48") + "is" in TEXT and not "s de " + m.group("Msinvo_47") + " " + m.group("Msinvo_48") + "is" in TEXT and not "s do " + m.group("Msinvo_47") + " " + m.group("Msinvo_48") + "is" in TEXT and not " o " + m.group("Msinvo_47") + " " + m.group("Msinvo_48") + "is" in TEXT and not m.group("Msinvo_47") + "-" + m.group("Msinvo_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_49>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_49").lower() in plvrInva and m.group("Msinvo_50") in plvrMfcao and not " e " + m.group("Msinvo_49") + " " + m.group("Msinvo_50") + "ões" in TEXT and not + " ou " + m.group("Msinvo_49") + " " + m.group("Msinvo_50") + "ões" in TEXT and not + "s de " + m.group("Msinvo_49") + " " + m.group("Msinvo_50") + "ões" in TEXT and not + "s do " + m.group("Msinvo_49") + " " + m.group("Msinvo_50") + "ões" in TEXT and not + " a " + m.group("Msinvo_49") + " " + m.group("Msinvo_50") + "ões" in TEXT and not m.group("Msinvo_49") + "-" + m.group("Msinvo_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_51>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_51").lower() in plvrInva and m.group("Msinvo_52") in plvrNfemcao and not " e " + m.group("Msinvo_51") + " " + m.group("Msinvo_52") + "ões" in TEXT and not " ou " + m.group("Msinvo_51") + " " + m.group("Msinvo_52") + "ões" in TEXT and not "s de " + m.group("Msinvo_51") + " " + m.group("Msinvo_52") + "ões" in TEXT and not "s do " + m.group("Msinvo_51") + " " + m.group("Msinvo_52") + "ões" in TEXT and not " o " + m.group("Msinvo_51") + " " + m.group("Msinvo_52") + "ões" in TEXT and not m.group("Msinvo_51") + "-" + m.group("Msinvo_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_57>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_57").lower() in plvrInva and m.group("Msinvo_58").lower() in plvrInva and not " e " + m.group("Msinvo_57") + " " + m.group("Msinvo_58") + "es" in TEXT and not " ou " + m.group("Msinvo_57") + " " + m.group("Msinvo_58") + "es" in TEXT and not "s de " + m.group("Msinvo_57") + " " + m.group("Msinvo_58") + "es" in TEXT and not "s do " + m.group("Msinvo_57") + " " + m.group("Msinvo_58") + "es" in TEXT and not " o " + m.group("Msinvo_57") + " " + m.group("Msinvo_58") + "es" in TEXT and not m.group("Msinvo_57") + "-" + m.group("Msinvo_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_59>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_59").lower() in plvrInva and m.group("Msinvo_60").lower() in plvrMasce and not " e " + m.group("Msinvo_59") + " " + m.group("Msinvo_60") + "es" in TEXT and not " ou " + m.group("Msinvo_59") + " " + m.group("Msinvo_60") + "es" in TEXT and not "s de " + m.group("Msinvo_59") + " " + m.group("Msinvo_60") + "es" in TEXT and not "s do " + m.group("Msinvo_59") + " " + m.group("Msinvo_60") + "es" in TEXT and not " o " + m.group("Msinvo_59") + " " + m.group("Msinvo_60") + "es" in TEXT and not m.group("Msinvo_59") + "-" + m.group("Msinvo_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_61>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_61").lower() in plvrInva and m.group("Msinvo_62") in plvrMfel and not " e " + m.group("Msinvo_61") + " " + m.group("Msinvo_62") + "éis" in TEXT and not " ou " + m.group("Msinvo_61") + " " + m.group("Msinvo_62") + "éis" in TEXT and not "s de " + m.group("Msinvo_61") + " " + m.group("Msinvo_62") + "éis" in TEXT and not "s do " + m.group("Msinvo_61") + " " + m.group("Msinvo_62") + "éis" in TEXT and not " o " + m.group("Msinvo_61") + " " + m.group("Msinvo_62") + "éis" in TEXT and not m.group("Msinvo_61") + "-" + m.group("Msinvo_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_63>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_63").lower() in plvrInva and m.group("Msinvo_64") in plvrMascel and not " e " + m.group("Msinvo_63") + " " + m.group("Msinvo_64") + "éis" in TEXT and not " ou " + m.group("Msinvo_63") + " " + m.group("Msinvo_64") + "éis" in TEXT and not "s de " + m.group("Msinvo_63") + " " + m.group("Msinvo_64") + "éis" in TEXT and not "s do " + m.group("Msinvo_63") + " " + m.group("Msinvo_64") + "éis" in TEXT and not " o " + m.group("Msinvo_63") + " " + m.group("Msinvo_64") + "éis" in TEXT and not m.group("Msinvo_63") + "-" + m.group("Msinvo_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_65>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_65").lower() in plvrInva and m.group("Msinvo_66") in plvrMfeu and not " e " + m.group("Msinvo_65") + " " + m.group("Msinvo_66") + "us" in TEXT and not " ou " + m.group("Msinvo_65") + " " + m.group("Msinvo_66") + "us" in TEXT and not "s de " + m.group("Msinvo_65") + " " + m.group("Msinvo_66") + "us" in TEXT and not "s do " + m.group("Msinvo_65") + " " + m.group("Msinvo_66") + "us" in TEXT and not " o " + m.group("Msinvo_65") + " " + m.group("Msinvo_66") + "us" in TEXT and not m.group("Msinvo_65") + "-" + m.group("Msinvo_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_67>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_67").lower() in plvrInva and m.group("Msinvo_68") in plvrMascu and not " e " + m.group("Msinvo_67") + " " + m.group("Msinvo_68") + "us" in TEXT and not " ou " + m.group("Msinvo_67") + " " + m.group("Msinvo_68") + "us" in TEXT and not "s de " + m.group("Msinvo_67") + " " + m.group("Msinvo_68") + "us" in TEXT and not "s do " + m.group("Msinvo_67") + " " + m.group("Msinvo_68") + "us" in TEXT and not " o " + m.group("Msinvo_67") + " " + m.group("Msinvo_68") + "us" in TEXT and not m.group("Msinvo_67") + "-" + m.group("Msinvo_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_71>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_71").lower() in plvrInva and m.group("Msinvo_72") in plvrMascz and not " e " + m.group("Msinvo_71") + " " + m.group("Msinvo_72") + "zes" in TEXT and not " ou " + m.group("Msinvo_71") + " " + m.group("Msinvo_72") + "zes" in TEXT and not "s de " + m.group("Msinvo_71") + " " + m.group("Msinvo_72") + "zes" in TEXT and not "s do " + m.group("Msinvo_71") + " " + m.group("Msinvo_72") + "zes" in TEXT and not " o " + m.group("Msinvo_71") + " " + m.group("Msinvo_72") + "zes" in TEXT and not m.group("Msinvo_71") + "-" + m.group("Msinvo_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_73>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_73").lower() in plvrInva and m.group("Msinvo_74") in pvrMascan and not " e " + m.group("Msinvo_73") + " " + m.group("Msinvo_74") + "s" in TEXT and not " ou " + m.group("Msinvo_73") + " " + m.group("Msinvo_74") + "s" in TEXT and not "s de " + m.group("Msinvo_73") + " " + m.group("Msinvo_74") + "s" in TEXT and not "s do " + m.group("Msinvo_73") + " " + m.group("Msinvo_74") + "s" in TEXT and not " o " + m.group("Msinvo_73") + " " + m.group("Msinvo_74") + "s" in TEXT and not m.group("Msinvo_73") + "-" + m.group("Msinvo_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_75>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_75").lower() in plvrInva and m.group("Msinvo_76").lower() in plvrMasco and not " e " + m.group("Msinvo_75") + " " + m.group("Msinvo_76") +"s" in TEXT and not " ou " + m.group("Msinvo_75") + " " + m.group("Msinvo_76") + "s" in TEXT and not "s de " + m.group("Msinvo_75") + " " + m.group("Msinvo_76") + "s" in TEXT and not "s do " + m.group("Msinvo_75") + " " + m.group("Msinvo_76") + "s" in TEXT and not " o " + m.group("Msinvo_75") + " " + m.group("Msinvo_76") + "s" in TEXT and not m.group("Msinvo_75") + "-" + m.group("Msinvo_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_77>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_77").lower() in plvrInva and not " e " + m.group("Msinvo_77") + " " + m.group("Msinvo_78") + "inhos" in TEXT and not " ou " + m.group("Msinvo_77") + " " + m.group("Msinvo_78") + "inhos" in TEXT and not "s de " + m.group("Msinvo_77") + " " + m.group("Msinvo_78") + "inhos" in TEXT and not "s do " + m.group("Msinvo_77") + " " + m.group("Msinvo_78") + "inhos" in TEXT and not " o " + m.group("Msinvo_77") + " " + m.group("Msinvo_78") + "inhos" in TEXT and not m.group("Msinvo_77") + "-" + m.group("Msinvo_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_83>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_83").lower() in plvrInva and not " e " + m.group("Msinvo_83") + " " + m.group("Msinvo_84") + "icas" in TEXT and not " ou " + m.group("Msinvo_83") + " " + m.group("Msinvo_84") + "icas" in TEXT and not "s de " + m.group("Msinvo_83") + " " + m.group("Msinvo_84") + "icas" in TEXT and not "s do " + m.group("Msinvo_83") + " " + m.group("Msinvo_84") + "icas" in TEXT and not " o " + m.group("Msinvo_83") + " " + m.group("Msinvo_84") + "icas" in TEXT and not m.group("Msinvo_83") + "-" + m.group("Msinvo_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_85>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_85").lower() in plvrInva and not " e " + m.group("Msinvo_85") + " " + m.group("Msinvo_86") + "escas" in TEXT and not " ou " + m.group("Msinvo_85") + " " + m.group("Msinvo_86") + "escas" in TEXT and not "s de " + m.group("Msinvo_85") + " " + m.group("Msinvo_86") + "escas" in TEXT and not "s do " + m.group("Msinvo_85") + " " + m.group("Msinvo_86") + "escas" in TEXT and not " o " + m.group("Msinvo_85") + " " + m.group("Msinvo_86") + "escas" in TEXT and not m.group("Msinvo_85") + "-" + m.group("Msinvo_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msinvo_87>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msinvo_88>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msinvo_87").lower() in plvrInva and m.group("Msinvo_88") in plvrMascm and not " e " + m.group("Msinvo_87") + " " + m.group("Msinvo_88") + "ns" in TEXT and not " ou " + m.group("Msinvo_87") + " " + m.group("Msinvo_88") + "ns" in TEXT and not "s de " + m.group("Msinvo_87") + " " + m.group("Msinvo_88") + "ns" in TEXT and not "s da " + m.group("Msinvo_87") + " " + m.group("Msinvo_88") + "ns" in TEXT and not " a " + m.group("Msinvo_87") + " " + m.group("Msinvo_88") + "ns" in TEXT and not m.group("Msinvo_87") + "-" + m.group("Msinvo_88") + "ns" in tCompostops'],
# excAdo a
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_1>[a-zA-Z]+)([aí])da (?P<Mseda_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_1").lower() in excAdo and m.group("Mseda_2").lower() in plvrFema and not " e " + m.group("Mseda_1") + m.group(2) + "da " + m.group("Mseda_2") +"s" in TEXT and not " ou " + m.group("Mseda_1") + m.group(2) + "da " + m.group("Mseda_2") + "s" in TEXT and not "s de " + m.group("Mseda_1") + m.group(2) + "da " + m.group("Mseda_2") + "s" in TEXT and not "s da " + m.group("Mseda_1") + m.group(2) + "da " + m.group("Mseda_2") + "s" in TEXT and not " a " + m.group("Mseda_1") + m.group(2) + "da " + m.group("Mseda_2") + "s" in TEXT and not m.group("Mseda_1") + m.group(2) + "da-" + m.group("Mseda_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_3>[a-zA-Z]+)([aí])da (?P<Mseda_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_3").lower() in excAdo and m.group("Mseda_4").lower() in plvrMfoa and not " e " + m.group("Mseda_3") + m.group(2) + "da " + m.group("Mseda_4") + "as" in TEXT and not " ou " + m.group("Mseda_3") + m.group(2) + "da " + m.group("Mseda_4") + "as" in TEXT and not "s de " + m.group("Mseda_3") + m.group(2) + "da " + m.group("Mseda_4") + "as" in TEXT and not "s da " + m.group("Mseda_3") + m.group(2) + "da " + m.group("Mseda_4") + "as" in TEXT and not " a " + m.group("Mseda_3") + m.group(2) + "da " + m.group("Mseda_4") + "as" in TEXT and not m.group("Mseda_3") + m.group(2) + "da-" + m.group("Mseda_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_5>[a-zA-Z]+)([aí])da (?P<Mseda_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + m.group(4) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_5").lower() in excAdo and not m.group("Mseda_6").lower() in excAdo and not " e " + m.group("Mseda_5") + m.group(2) + "da " + m.group("Mseda_6") + m.group(4) + "dos" in TEXT and not " ou " + m.group("Mseda_5") + m.group(2) + "da " + m.group("Mseda_6") + m.group(4) + "dos" in TEXT and not "s de " + m.group("Mseda_5") + m.group(2) + "da " + m.group("Mseda_6") + m.group(4) + "dos" in TEXT and not "s da " + m.group("Mseda_5") + m.group(2) + "da " + m.group("Mseda_6") + m.group(4) + "dos" in TEXT and not " a " + m.group("Mseda_5") + m.group(2) + "da " + m.group("Mseda_6") + m.group(4) + "dos" in TEXT and not m.group("Mseda_5") + m.group(2) + "da-" + m.group("Mseda_6") + m.group(4) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_7>[a-zA-Z]+)([aí])da (?P<Mseda_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_7").lower() in excAdo and not m.group("Mseda_8").lower() in excIsta and not " e " + m.group("Mseda_7") + m.group(2) + "da " + m.group("Mseda_8") + "s" in TEXT and not " ou " + m.group("Mseda_7") + m.group(2) + "da " + m.group("Mseda_8") + "s" in TEXT and not "s de " + m.group("Mseda_7") + m.group(2) + "da " + m.group("Mseda_8") + "s" in TEXT and not "s da " + m.group("Mseda_7") + m.group(2) + "da " + m.group("Mseda_8") + "s" in TEXT and not " a " + m.group("Mseda_7") + m.group(2) + "da " + m.group("Mseda_8") + "s" in TEXT and not m.group("Mseda_7") + m.group(2) + "da-" + m.group("Mseda_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_9>[a-zA-Z]+)([aí])da (?P<Mseda_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_9").lower() in excAdo and m.group("Mseda_10").lower() in plvrInva and not " e " + m.group("Mseda_9") + m.group(2) + "da " + m.group("Mseda_10") + "s" in TEXT and not " ou " + m.group("Mseda_9") + m.group(2) + "da " + m.group("Mseda_10") + "s" in TEXT and not "s de " + m.group("Mseda_9") + m.group(2) + "da " + m.group("Mseda_10") + "s" in TEXT and not "s da " + m.group("Mseda_9") + m.group(2) + "da " + m.group("Mseda_10") + "s" in TEXT and not " a " + m.group("Mseda_9") + m.group(2) + "da " + m.group("Mseda_10") + "s" in TEXT and not m.group("Mseda_9") + m.group(2) + "da-" + m.group("Mseda_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_11>[a-zA-Z]+)([aí])da (?P<Mseda_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + m.group(4) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_11").lower() in excAdo and not m.group("Mseda_12").lower() in excAdo and not " e " + m.group("Mseda_11") + m.group(2) + "da " + m.group("Mseda_12") + m.group(4) + "das" in TEXT and not " ou " + m.group("Mseda_11") + m.group(2) + "da " + m.group("Mseda_12") + m.group(4) + "das" in TEXT and not "s de " + m.group("Mseda_11") + m.group(2) + "da " + m.group("Mseda_12") + m.group(4) + "das" in TEXT and not "s da " + m.group("Mseda_11") + m.group(2) + "da " + m.group("Mseda_12") + m.group(4) + "das" in TEXT and not " a " + m.group("Mseda_11") + m.group(2) + "da " + m.group("Mseda_12") + m.group(4) + "das" in TEXT and not m.group("Mseda_11") + m.group(2) + "da-" + m.group("Mseda_12") + m.group(4) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_13>[a-zA-Z]+)([aí])da (?P<Mseda_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_13").lower() in excAdo and not " e " + m.group("Mseda_13") + m.group(2) + "da " + m.group("Mseda_14") + "osos" in TEXT and not " ou " + m.group("Mseda_13") + m.group(2) + "da " + m.group("Mseda_14") + "osos" in TEXT and not "s de " + m.group("Mseda_13") + m.group(2) + "da " + m.group("Mseda_14") + "osos" in TEXT and not "s da " + m.group("Mseda_13") + m.group(2) + "da " + m.group("Mseda_14") + "osos" in TEXT and not " a " + m.group("Mseda_13") + m.group(2) + "da " + m.group("Mseda_14") + "osos" in TEXT and not m.group("Mseda_13") + m.group(2) + "da-" + m.group("Mseda_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_15>[a-zA-Z]+)([aí])da (?P<Mseda_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_15").lower() in excAdo and not " e " + m.group("Mseda_15") + m.group(2) + "da " + m.group("Mseda_16") + "osas" in TEXT and not " ou " + m.group("Mseda_15") + m.group(2) + "da " + m.group("Mseda_16") + "osas" in TEXT and not "s de " + m.group("Mseda_15") + m.group(2) + "da " + m.group("Mseda_16") + "osas" in TEXT and not "s da " + m.group("Mseda_15") + m.group(2) + "da " + m.group("Mseda_16") + "osas" in TEXT and not " a " + m.group("Mseda_15") + m.group(2) + "da " + m.group("Mseda_16") + "osas" in TEXT and not m.group("Mseda_15") + m.group(2) + "da-" + m.group("Mseda_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_17>[a-zA-Z]+)([aí])da (?P<Mseda_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_17").lower() in excAdo and not " e " + m.group("Mseda_17") + m.group(2) + "da " + m.group("Mseda_18") + "ivas" in TEXT and not " ou " + m.group("Mseda_17") + m.group(2) + "da " + m.group("Mseda_18") + "ivas" in TEXT and not "s de " + m.group("Mseda_17") + m.group(2) + "da " + m.group("Mseda_18") + "ivas" in TEXT and not "s da " + m.group("Mseda_17") + m.group(2) + "da " + m.group("Mseda_18") + "ivas" in TEXT and not " a " + m.group("Mseda_17") + m.group(2) + "da " + m.group("Mseda_18") + "ivas" in TEXT and not m.group("Mseda_17") + m.group(2) + "da-" + m.group("Mseda_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_19>[a-zA-Z]+)([aí])da (?P<Mseda_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_19").lower() in excAdo and not " e " + m.group("Mseda_19") + m.group(2) + "da " + m.group("Mseda_20") + "ivas" in TEXT and not " ou " + m.group("Mseda_19") + m.group(2) + "da " + m.group("Mseda_20") + "ivas" in TEXT and not "s de " + m.group("Mseda_19") + m.group(2) + "da " + m.group("Mseda_20") + "ivas" in TEXT and not "s da " + m.group("Mseda_19") + m.group(2) + "da " + m.group("Mseda_20") + "ivas" in TEXT and not " a " + m.group("Mseda_19") + m.group(2) + "da " + m.group("Mseda_20") + "ivas" in TEXT and not m.group("Mseda_19") + m.group(2) + "da-" + m.group("Mseda_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_21>[a-zA-Z]+)([aí])da (?P<Mseda_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_21").lower() in excAdo and not " e " + m.group("Mseda_21") + m.group(2) + "da " + m.group("Mseda_22") + "icas" in TEXT and not " ou " + m.group("Mseda_21") + m.group(2) + "da " + m.group("Mseda_22") + "icas" in TEXT and not "s de " + m.group("Mseda_21") + m.group(2) + "da " + m.group("Mseda_22") + "icas" in TEXT and not "s da " + m.group("Mseda_21") + m.group(2) + "da " + m.group("Mseda_22") + "icas" in TEXT and not " a " + m.group("Mseda_21") + m.group(2) + "da " + m.group("Mseda_22") + "icas" in TEXT and not m.group("Mseda_21") + m.group(2) + "da-" + m.group("Mseda_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_23>[a-zA-Z]+)([aí])da (?P<Mseda_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_23").lower() in excAdo and not " e " + m.group("Mseda_23") + m.group(2) + "da " + m.group("Mseda_24") + "icas" in TEXT and not " ou " + m.group("Mseda_23") + m.group(2) + "da " + m.group("Mseda_24") + "icas" in TEXT and not "s de " + m.group("Mseda_23") + m.group(2) + "da " + m.group("Mseda_24") + "icas" in TEXT and not "s da " + m.group("Mseda_23") + m.group(2) + "da " + m.group("Mseda_24") + "icas" in TEXT and not " a " + m.group("Mseda_23") + m.group(2) + "da " + m.group("Mseda_24") + "icas" in TEXT and not m.group("Mseda_23") + m.group(2) + "da-" + m.group("Mseda_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_25>[a-zA-Z]+)([aí])da (?P<Mseda_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_25").lower() in excAdo and not " e " + m.group("Mseda_25") + m.group(2) + "da " + m.group("Mseda_26") + "icas" in TEXT and not " ou " + m.group("Mseda_25") + m.group(2) + "da " + m.group("Mseda_26") + "icas" in TEXT and not "s de " + m.group("Mseda_25") + m.group(2) + "da " + m.group("Mseda_26") + "icas" in TEXT and not "s da " + m.group("Mseda_25") + m.group(2) + "da " + m.group("Mseda_26") + "icas" in TEXT and not " a " + m.group("Mseda_25") + m.group(2) + "da " + m.group("Mseda_26") + "icas" in TEXT and not m.group("Mseda_25") + m.group(2) + "da-" + m.group("Mseda_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_27>[a-zA-Z]+)([aí])da (?P<Mseda_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_27").lower() in excAdo and not " e " + m.group("Mseda_27") + m.group(2) + "da " + m.group("Mseda_28") + "escas" in TEXT and not " ou " + m.group("Mseda_27") + m.group(2) + "da " + m.group("Mseda_28") + "escas" in TEXT and not "s de " + m.group("Mseda_27") + m.group(2) + "da " + m.group("Mseda_28") + "escas" in TEXT and not "s da " + m.group("Mseda_27") + m.group(2) + "da " + m.group("Mseda_28") + "escas" in TEXT and not " a " + m.group("Mseda_27") + m.group(2) + "da " + m.group("Mseda_28") + "escas" in TEXT and not m.group("Mseda_27") + m.group(2) + "da-" + m.group("Mseda_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_29>[a-zA-Z]+)([aí])da (?P<Mseda_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_29").lower() in excAdo and not " e " + m.group("Mseda_29") + m.group(2) + "da " + m.group("Mseda_30") + "idas" in TEXT and not " ou " + m.group("Mseda_29") + "s " + m.group("Mseda_30") + "idas" in TEXT and not "s de " + m.group("Mseda_29") + "s " + m.group("Mseda_30") + "idas" in TEXT and not "s da " + m.group("Mseda_29") + "s " + m.group("Mseda_30") + "idas" in TEXT and not " a " + m.group("Mseda_29") + "s " + m.group("Mseda_30") + "idas" in TEXT and not m.group("Mseda_29") + m.group(2) + "da-" + m.group("Mseda_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_31>[a-zA-Z]+)([aí])da (?P<Mseda_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_31").lower() in excAdo and not " e " + m.group("Mseda_31") + m.group(2) + "da " + m.group("Mseda_32") + "logas" in TEXT and not " ou " + m.group("Mseda_31") + m.group(2) + "da " + m.group("Mseda_32") + "logas" in TEXT and not "s de " + m.group("Mseda_31") + m.group(2) + "da " + m.group("Mseda_32") + "logas" in TEXT and not "s da " + m.group("Mseda_31") + m.group(2) + "da " + m.group("Mseda_32") + "logas" in TEXT and not " a " + m.group("Mseda_31") + m.group(2) + "da " + m.group("Mseda_32") + "logas" in TEXT and not m.group("Mseda_31") + m.group(2) + "da-" + m.group("Mseda_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_33>[a-zA-Z]+)([aí])da (?P<Mseda_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_33").lower() in excAdo and not " e " + m.group("Mseda_33") + m.group(2) + "da " + m.group("Mseda_34") + "rias" in TEXT and not " ou " + m.group("Mseda_33") + m.group(2) + "da " + m.group("Mseda_34") + "rias" in TEXT and not "s de " + m.group("Mseda_33") + m.group(2) + "da " + m.group("Mseda_34") + "rias" in TEXT and not "s da " + m.group("Mseda_33") + m.group(2) + "da " + m.group("Mseda_34") + "rias" in TEXT and not " a " + m.group("Mseda_33") + m.group(2) + "da " + m.group("Mseda_34") + "rias" in TEXT and not m.group("Mseda_33") + m.group(2) + "da-" + m.group("Mseda_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_35>[a-zA-Z]+)([aí])da (?P<Mseda_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_35").lower() in excAdo and not " e " + m.group("Mseda_35") + m.group(2) + "da " + m.group("Mseda_36") + "ssimas" in TEXT and not " ou " + m.group("Mseda_35") + m.group(2) + "da " + m.group("Mseda_36") + "ssimas" in TEXT and not "s de " + m.group("Mseda_35") + m.group(2) + "da " + m.group("Mseda_36") + "ssimas" in TEXT and not "s da " + m.group("Mseda_35") + m.group(2) + "da " + m.group("Mseda_36") + "ssimas" in TEXT and not " a " + m.group("Mseda_35") + m.group(2) + "da " + m.group("Mseda_36") + "ssimas" in TEXT and not m.group("Mseda_35") + m.group(2) + "da-" + m.group("Mseda_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_37>[a-zA-Z]+)([aí])da (?P<Mseda_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_37").lower() in excAdo and not " e " + m.group("Mseda_37") + m.group(2) + "da " + m.group("Mseda_38") + "simas" in TEXT and not " ou " + m.group("Mseda_37") + m.group(2) + "da " + m.group("Mseda_38") + "simas" in TEXT and not "s de " + m.group("Mseda_37") + m.group(2) + "da " + m.group("Mseda_38") + "simas" in TEXT and not "s da " + m.group("Mseda_37") + m.group(2) + "da " + m.group("Mseda_38") + "simas" in TEXT and not " a " + m.group("Mseda_37") + m.group(2) + "da " + m.group("Mseda_38") + "simas" in TEXT and not m.group("Mseda_37") + m.group(2) + "da-" + m.group("Mseda_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_41>[a-zA-Z]+)([aí])da (?P<Mseda_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_41").lower() in excAdo and not m.group("Mseda_42") in "D-d-" and not " e " + m.group("Mseda_41") + m.group(2) + "da " + m.group("Mseda_42") + "oras" in TEXT and not " ou " + m.group("Mseda_41") + m.group(2) + "da " + m.group("Mseda_42") + "oras" in TEXT and not "s de " + m.group("Mseda_41") + m.group(2) + "da " + m.group("Mseda_42") + "oras" in TEXT and not "s da " + m.group("Mseda_41") + m.group(2) + "da " + m.group("Mseda_42") + "oras" in TEXT and not " a " + m.group("Mseda_41") + m.group(2) + "da " + m.group("Mseda_42") + "oras" in TEXT and not m.group("Mseda_41") + m.group(2) + "da-" + m.group("Mseda_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_43>[a-zA-Z]+)([aí])da (?P<Mseda_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_43").lower() in excAdo and m.group("Mseda_44") in plvrMfr and not " e " + m.group("Mseda_43") + m.group(2) + "da " + m.group("Mseda_44") + "es" in TEXT and not " ou " + m.group("Mseda_43") + m.group(2) + "da " + m.group("Mseda_44") + "es" in TEXT and not "s de " + m.group("Mseda_43") + m.group(2) + "da " + m.group("Mseda_44") + "es" in TEXT and not "s da " + m.group("Mseda_43") + m.group(2) + "da " + m.group("Mseda_44") + "es" in TEXT and not " a " + m.group("Mseda_43") + m.group(2) + "da " + m.group("Mseda_44") + "es" in TEXT and not m.group("Mseda_43") + m.group(2) + "da-" + m.group("Mseda_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_45>[a-zA-Z]+)([aí])da (?P<Mseda_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_45").lower() in excAdo and m.group("Mseda_46") in plvrFemr and not " e " + m.group("Mseda_45") + m.group(2) + "da " + m.group("Mseda_46") + "es" in TEXT and not " ou " + m.group("Mseda_45") + m.group(2) + "da " + m.group("Mseda_46") + "es" in TEXT and not "s de " + m.group("Mseda_45") + m.group(2) + "da " + m.group("Mseda_46") + "es" in TEXT and not "s da " + m.group("Mseda_45") + m.group(2) + "da " + m.group("Mseda_46") + "es" in TEXT and not " a " + m.group("Mseda_45") + m.group(2) + "da " + m.group("Mseda_46") + "es" in TEXT and not m.group("Mseda_45") + m.group(2) + "da-" + m.group("Mseda_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_47>[a-zA-Z]+)([aí])da (?P<Mseda_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_47").lower() in excAdo and m.group("Mseda_48") in plvrMfal and not " e " + m.group("Mseda_47") + m.group(2) + "da " + m.group("Mseda_48") + "is" in TEXT and not " ou " + m.group("Mseda_47") + m.group(2) + "da " + m.group("Mseda_48") + "is" in TEXT and not "s de " + m.group("Mseda_47") + m.group(2) + "da " + m.group("Mseda_48") + "is" in TEXT and not "s da " + m.group("Mseda_47") + m.group(2) + "da " + m.group("Mseda_48") + "is" in TEXT and not " a " + m.group("Mseda_47") + m.group(2) + "da " + m.group("Mseda_48") + "is" in TEXT and not m.group("Mseda_47") + m.group(2) + "da-" + m.group("Mseda_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_49>[a-zA-Z]+)([aí])da (?P<Mseda_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_49").lower() in excAdo and m.group("Mseda_50") in plvrMfcao and not " e " + m.group("Mseda_49") + m.group(2) + "da " + m.group("Mseda_50") + "ões" in TEXT and not + " ou " + m.group("Mseda_49") + m.group(2) + "da " + m.group("Mseda_50") + "ões" in TEXT and not + "s de " + m.group("Mseda_49") + m.group(2) + "da " + m.group("Mseda_50") + "ões" in TEXT and not + "s da " + m.group("Mseda_49") + m.group(2) + "da " + m.group("Mseda_50") + "ões" in TEXT and not + " a " + m.group("Mseda_49") + m.group(2) + "da " + m.group("Mseda_50") + "ões" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_51>[a-zA-Z]+)([aí])da (?P<Mseda_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_51").lower() in excAdo and not m.group("Mseda_52") in plvrMascao and not " e " + m.group("Mseda_51") + m.group(2) + "da " + m.group("Mseda_52") + "ões" in TEXT and not " ou " + m.group("Mseda_51") + m.group(2) + "da " + m.group("Mseda_52") + "ões" in TEXT and not "s de " + m.group("Mseda_51") + m.group(2) + "da " + m.group("Mseda_52") + "ões" in TEXT and not "s da " + m.group("Mseda_51") + m.group(2) + "da " + m.group("Mseda_52") + "ões" in TEXT and not " a " + m.group("Mseda_51") + m.group(2) + "da " + m.group("Mseda_52") + "ões" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_53>[a-zA-Z]+)([aí])da (?P<Mseda_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_53").lower() in excAdo and m.group("Mseda_54") in plvrFemao and not " e " + m.group("Mseda_53") + m.group(2) + "da " + m.group("Mseda_54") + "ões" in TEXT and not " ou " + m.group("Mseda_53") + m.group(2) + "da " + m.group("Mseda_54") + "ões" in TEXT and not "s de " + m.group("Mseda_53") + m.group(2) + "da " + m.group("Mseda_54") + "ões" in TEXT and not "s da " + m.group("Mseda_53") + m.group(2) + "da " + m.group("Mseda_54") + "ões" in TEXT and not " a " + m.group("Mseda_53") + m.group(2) + "da " + m.group("Mseda_54") + "ões" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_55>[a-zA-Z]+)([aí])da (?P<Mseda_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_55").lower() in excAdo and not " e " + m.group("Mseda_55") + m.group(2) + "da " + m.group("Mseda_56") + "veis" in TEXT and not " ou " + m.group("Mseda_55") + m.group(2) + "da " + m.group("Mseda_56") + "veis" in TEXT and not "s de " + m.group("Mseda_55") + m.group(2) + "da " + m.group("Mseda_56") + "veis" in TEXT and not "s da " + m.group("Mseda_55") + m.group(2) + "da " + m.group("Mseda_56") + "veis" in TEXT and not " a " + m.group("Mseda_55") + m.group(2) + "da " + m.group("Mseda_56") + "veis" in TEXT and not m.group("Mseda_55") + m.group(2) + "da-" + m.group("Mseda_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_57>[a-zA-Z]+)([aí])da (?P<Mseda_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_57").lower() in excAdo and m.group("Mseda_58").lower() in plvrMfe and not " e " + m.group("Mseda_57") + m.group(2) + "da " + m.group("Mseda_58") + "es" in TEXT and not " ou " + m.group("Mseda_57") + m.group(2) + "da " + m.group("Mseda_58") + "es" in TEXT and not "s de " + m.group("Mseda_57") + m.group(2) + "da " + m.group("Mseda_58") + "es" in TEXT and not "s da " + m.group("Mseda_57") + m.group(2) + "da " + m.group("Mseda_58") + "es" in TEXT and not " a " + m.group("Mseda_57") + m.group(2) + "da " + m.group("Mseda_58") + "es" in TEXT and not m.group("Mseda_57") + m.group(2) + "da-" + m.group("Mseda_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_59>[a-zA-Z]+)([aí])da (?P<Mseda_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_59").lower() in excAdo and m.group("Mseda_60").lower() in plvrFeme and not " e " + m.group("Mseda_59") + m.group(2) + "da " + m.group("Mseda_60") + "es" in TEXT and not " ou " + m.group("Mseda_59") + m.group(2) + "da " + m.group("Mseda_60") + "es" in TEXT and not "s de " + m.group("Mseda_59") + m.group(2) + "da " + m.group("Mseda_60") + "es" in TEXT and not "s da " + m.group("Mseda_59") + m.group(2) + "da " + m.group("Mseda_60") + "es" in TEXT and not " a " + m.group("Mseda_59") + m.group(2) + "da " + m.group("Mseda_60") + "es" in TEXT and not m.group("Mseda_59") + m.group(2) + "da-" + m.group("Mseda_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_61>[a-zA-Z]+)([aí])da (?P<Mseda_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_61").lower() in excAdo and m.group("Mseda_62") in plvrMfel and not " e " + m.group("Mseda_61") + m.group(2) + "da " + m.group("Mseda_62") + "éis" in TEXT and not " ou " + m.group("Mseda_61") + m.group(2) + "da " + m.group("Mseda_62") + "éis" in TEXT and not "s de " + m.group("Mseda_61") + m.group(2) + "da " + m.group("Mseda_62") + "éis" in TEXT and not "s da " + m.group("Mseda_61") + m.group(2) + "da " + m.group("Mseda_62") + "éis" in TEXT and not " a " + m.group("Mseda_61") + m.group(2) + "da " + m.group("Mseda_62") + "éis" in TEXT and not m.group("Mseda_61") + m.group(2) + "da-" + m.group("Mseda_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_63>[a-zA-Z]+)([aí])da (?P<Mseda_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_63").lower() in excAdo and m.group("Mseda_64") in plvrFemel and not " e " + m.group("Mseda_63") + m.group(2) + "da " + m.group("Mseda_64") + "éis" in TEXT and not " ou " + m.group("Mseda_63") + m.group(2) + "da " + m.group("Mseda_64") + "éis" in TEXT and not "s de " + m.group("Mseda_63") + m.group(2) + "da " + m.group("Mseda_64") + "éis" in TEXT and not "s da " + m.group("Mseda_63") + m.group(2) + "da " + m.group("Mseda_64") + "éis" in TEXT and not " a " + m.group("Mseda_63") + m.group(2) + "da " + m.group("Mseda_64") + "éis" in TEXT and not m.group("Mseda_63") + m.group(2) + "da-" + m.group("Mseda_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_65>[a-zA-Z]+)([aí])da (?P<Mseda_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_65").lower() in excAdo and m.group("Mseda_66") in plvrMfeu and not " e " + m.group("Mseda_65") + m.group(2) + "da " + m.group("Mseda_66") + "us" in TEXT and not " ou " + m.group("Mseda_65") + m.group(2) + "da " + m.group("Mseda_66") + "us" in TEXT and not "s de " + m.group("Mseda_65") + m.group(2) + "da " + m.group("Mseda_66") + "us" in TEXT and not "s da " + m.group("Mseda_65") + m.group(2) + "da " + m.group("Mseda_66") + "us" in TEXT and not " a " + m.group("Mseda_65") + m.group(2) + "da " + m.group("Mseda_66") + "us" in TEXT and not m.group("Mseda_65") + m.group(2) + "da-" + m.group("Mseda_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_67>[a-zA-Z]+)([aí])da (?P<Mseda_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_67").lower() in excAdo and m.group("Mseda_68") in plvrFemu and not " e " + m.group("Mseda_67") + m.group(2) + "da " + m.group("Mseda_68") + "us" in TEXT and not " ou " + m.group("Mseda_67") + m.group(2) + "da " + m.group("Mseda_68") + "us" in TEXT and not "s de " + m.group("Mseda_67") + m.group(2) + "da " + m.group("Mseda_68") + "us" in TEXT and not "s da " + m.group("Mseda_67") + m.group(2) + "da " + m.group("Mseda_68") + "us" in TEXT and not " a " + m.group("Mseda_67") + m.group(2) + "da " + m.group("Mseda_68") + "us" in TEXT and not m.group("Mseda_67") + m.group(2) + "da-" + m.group("Mseda_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_69>[a-zA-Z]+)([aí])da (?P<Mseda_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_69").lower() in excAdo and m.group("Mseda_70") in plvrInvaz and not " e " + m.group("Mseda_69") + m.group(2) + "da " + m.group("Mseda_70") + "zes" in TEXT and not " ou " + m.group("Mseda_69") + m.group(2) + "da " + m.group("Mseda_70") + "zes" in TEXT and not "s de " + m.group("Mseda_69") + m.group(2) + "da " + m.group("Mseda_70") + "zes" in TEXT and not "s da " + m.group("Mseda_69") + m.group(2) + "da " + m.group("Mseda_70") + "zes" in TEXT and not " a " + m.group("Mseda_69") + m.group(2) + "da " + m.group("Mseda_70") + "zes" in TEXT and not m.group("Mseda_69") + m.group(2) + "da-" + m.group("Mseda_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_71>[a-zA-Z]+)([aí])da (?P<Mseda_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_71").lower() in excAdo and m.group("Mseda_72") in plvrFemz and not " e " + m.group("Mseda_71") + m.group(2) + "da " + m.group("Mseda_72") + "zes" in TEXT and not " ou " + m.group("Mseda_71") + m.group(2) + "da " + m.group("Mseda_72") + "zes" in TEXT and not "s de " + m.group("Mseda_71") + m.group(2) + "da " + m.group("Mseda_72") + "zes" in TEXT and not "s da " + m.group("Mseda_71") + m.group(2) + "da " + m.group("Mseda_72") + "zes" in TEXT and not " a " + m.group("Mseda_71") + m.group(2) + "da " + m.group("Mseda_72") + "zes" in TEXT and not m.group("Mseda_71") + m.group(2) + "da-" + m.group("Mseda_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_73>[a-zA-Z]+)([aí])da (?P<Mseda_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_73").lower() in excAdo and m.group("Mseda_74") in pvrFeman and not " e " + m.group("Mseda_73") + m.group(2) + "da " + m.group("Mseda_74") + "s" in TEXT and not " ou " + m.group("Mseda_73") + m.group(2) + "da " + m.group("Mseda_74") + "s" in TEXT and not "s de " + m.group("Mseda_73") + m.group(2) + "da " + m.group("Mseda_74") + "s" in TEXT and not "s da " + m.group("Mseda_73") + m.group(2) + "da " + m.group("Mseda_74") + "s" in TEXT and not " a " + m.group("Mseda_73") + m.group(2) + "da " + m.group("Mseda_74") + "s" in TEXT and not m.group("Mseda_73") + m.group(2) + "da-" + m.group("Mseda_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_75>[a-zA-Z]+)([aí])da (?P<Mseda_76>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_75").lower() in excAdo and m.group("Mseda_76") in plvrMFm and not " e " + m.group("Mseda_75") + m.group(2) + "da " + m.group("Mseda_76") + "ns" in TEXT and not " ou " + m.group("Mseda_75") + m.group(2) + "da " + m.group("Mseda_76") + "ns" in TEXT and not "s de " + m.group("Mseda_75") + m.group(2) + "da " + m.group("Mseda_76") + "ns" in TEXT and not "s da " + m.group("Mseda_75") + m.group(2) + "da " + m.group("Mseda_76") + "ns" in TEXT and not " a " + m.group("Mseda_75") + m.group(2) + "da " + m.group("Mseda_76") + "ns" in TEXT and not m.group("Mseda_75") + m.group(2) + "da-" + m.group("Mseda_76") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mseda_77>[a-zA-Z]+)([aí])da (?P<Mseda_78>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "das " + m.group(3) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mseda_77").lower() in excAdo and m.group("Mseda_78") in plvrFemm and not " e " + m.group("Mseda_77") + m.group(2) + "da " + m.group("Mseda_78") + "ns" in TEXT and not " ou " + m.group("Mseda_77") + m.group(2) + "da " + m.group("Mseda_78") + "ns" in TEXT and not "s de " + m.group("Mseda_77") + m.group(2) + "da " + m.group("Mseda_78") + "ns" in TEXT and not "s da " + m.group("Mseda_77") + m.group(2) + "da " + m.group("Mseda_78") + "ns" in TEXT and not " a " + m.group("Mseda_77") + m.group(2) + "da " + m.group("Mseda_78") + "ns" in TEXT and not m.group("Mseda_77") + m.group(2) + "da-" + m.group("Mseda_78") + "ns" in tCompostops'],
# osa a
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_1>[a-zA-Zç]+)osa (?P<Msosa_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_2").lower() in plvrFema and not " e " + m.group("Msosa_1") + "osa " + m.group("Msosa_2") +"s" in TEXT and not " ou " + m.group("Msosa_1") + "osa " + m.group("Msosa_2") + "s" in TEXT and not "s de " + m.group("Msosa_1") + "osa " + m.group("Msosa_2") + "s" in TEXT and not "s da " + m.group("Msosa_1") + "osa " + m.group("Msosa_2") + "s" in TEXT and not " a " + m.group("Msosa_1") + "osa " + m.group("Msosa_2") + "s" in TEXT and not m.group("Msosa_1") + "osa-" + m.group("Msosa_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_3>[a-zA-Zç]+)osa (?P<Msosa_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_4").lower() in plvrMfoa and not " e " + m.group("Msosa_3") + "osa " + m.group("Msosa_4") + "as" in TEXT and not " ou " + m.group("Msosa_3") + "osa " + m.group("Msosa_4") + "as" in TEXT and not "s de " + m.group("Msosa_3") + "osa " + m.group("Msosa_4") + "as" in TEXT and not "s da " + m.group("Msosa_3") + "osa " + m.group("Msosa_4") + "as" in TEXT and not " a " + m.group("Msosa_3") + "osa " + m.group("Msosa_4") + "as" in TEXT and not m.group("Msosa_3") + "osa-" + m.group("Msosa_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_5>[a-zA-Zç]+)osa (?P<Msosa_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msosa_6").lower() in excAdo and not " e " + m.group("Msosa_5") + "osa " + m.group("Msosa_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msosa_5") + "osa " + m.group("Msosa_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msosa_5") + "osa " + m.group("Msosa_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Msosa_5") + "osa " + m.group("Msosa_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Msosa_5") + "osa " + m.group("Msosa_6") + m.group(3) + "dos" in TEXT and not m.group("Msosa_5") + "osa-" + m.group("Msosa_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_7>[a-zA-Zç]+)osa (?P<Msosa_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msosa_8").lower() in excIsta and not " e " + m.group("Msosa_7") + "osa " + m.group("Msosa_8") + "s" in TEXT and not " ou " + m.group("Msosa_7") + "osa " + m.group("Msosa_8") + "s" in TEXT and not "s de " + m.group("Msosa_7") + "osa " + m.group("Msosa_8") + "s" in TEXT and not "s da " + m.group("Msosa_7") + "osa " + m.group("Msosa_8") + "s" in TEXT and not " a " + m.group("Msosa_7") + "osa " + m.group("Msosa_8") + "s" in TEXT and not m.group("Msosa_7") + "osa-" + m.group("Msosa_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_9>[a-zA-Zç]+)osa (?P<Msosa_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_10").lower() in plvrInva and not " e " + m.group("Msosa_9") + "osa " + m.group("Msosa_10") + "s" in TEXT and not " ou " + m.group("Msosa_9") + "osa " + m.group("Msosa_10") + "s" in TEXT and not "s de " + m.group("Msosa_9") + "osa " + m.group("Msosa_10") + "s" in TEXT and not "s da " + m.group("Msosa_9") + "osa " + m.group("Msosa_10") + "s" in TEXT and not " a " + m.group("Msosa_9") + "osa " + m.group("Msosa_10") + "s" in TEXT and not m.group("Msosa_9") + "osa-" + m.group("Msosa_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_11>[a-zA-Zç]+)osa (?P<Msosa_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msosa_12").lower() in excAdo and not " e " + m.group("Msosa_11") + "osa " + m.group("Msosa_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msosa_11") + "osa " + m.group("Msosa_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msosa_11") + "osa " + m.group("Msosa_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Msosa_11") + "osa " + m.group("Msosa_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Msosa_11") + "osa " + m.group("Msosa_12") + m.group(3) + "das" in TEXT and not m.group("Msosa_11") + "osa-" + m.group("Msosa_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_13>[a-zA-Zç]+)osa (?P<Msosa_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msosa_13") + "osa " + m.group("Msosa_14") + "osos" in TEXT and not " ou " + m.group("Msosa_13") + "osa " + m.group("Msosa_14") + "osos" in TEXT and not "s de " + m.group("Msosa_13") + "osa " + m.group("Msosa_14") + "osos" in TEXT and not "s da " + m.group("Msosa_13") + "osa " + m.group("Msosa_14") + "osos" in TEXT and not " a " + m.group("Msosa_13") + "osa " + m.group("Msosa_14") + "osos" in TEXT and not m.group("Msosa_13") + "osa-" + m.group("Msosa_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_15>[a-zA-Zç]+)osa (?P<Msosa_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msosa_15") + "osa " + m.group("Msosa_16") + "osas" in TEXT and not " ou " + m.group("Msosa_15") + "osa " + m.group("Msosa_16") + "osas" in TEXT and not "s de " + m.group("Msosa_15") + "osa " + m.group("Msosa_16") + "osas" in TEXT and not "s da " + m.group("Msosa_15") + "osa " + m.group("Msosa_16") + "osas" in TEXT and not " a " + m.group("Msosa_15") + "osa " + m.group("Msosa_16") + "osas" in TEXT and not m.group("Msosa_15") + "osa-" + m.group("Msosa_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_17>[a-zA-Zç]+)osa (?P<Msosa_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msosa_17") + "osa " + m.group("Msosa_18") + "ivas" in TEXT and not " ou " + m.group("Msosa_17") + "osa " + m.group("Msosa_18") + "ivas" in TEXT and not "s de " + m.group("Msosa_17") + "osa " + m.group("Msosa_18") + "ivas" in TEXT and not "s da " + m.group("Msosa_17") + "osa " + m.group("Msosa_18") + "ivas" in TEXT and not " a " + m.group("Msosa_17") + "osa " + m.group("Msosa_18") + "ivas" in TEXT and not m.group("Msosa_17") + "osa-" + m.group("Msosa_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_19>[a-zA-Zç]+)osa (?P<Msosa_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msosa_19") + "osa " + m.group("Msosa_20") + "ivas" in TEXT and not " ou " + m.group("Msosa_19") + "osa " + m.group("Msosa_20") + "ivas" in TEXT and not "s de " + m.group("Msosa_19") + "osa " + m.group("Msosa_20") + "ivas" in TEXT and not "s da " + m.group("Msosa_19") + "osa " + m.group("Msosa_20") + "ivas" in TEXT and not " a " + m.group("Msosa_19") + "osa " + m.group("Msosa_20") + "ivas" in TEXT and not m.group("Msosa_19") + "osa-" + m.group("Msosa_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_21>[a-zA-Zç]+)osa (?P<Msosa_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msosa_21") + "osa " + m.group("Msosa_22") + "icas" in TEXT and not " ou " + m.group("Msosa_21") + "osa " + m.group("Msosa_22") + "icas" in TEXT and not "s de " + m.group("Msosa_21") + "osa " + m.group("Msosa_22") + "icas" in TEXT and not "s da " + m.group("Msosa_21") + "osa " + m.group("Msosa_22") + "icas" in TEXT and not " a " + m.group("Msosa_21") + "osa " + m.group("Msosa_22") + "icas" in TEXT and not m.group("Msosa_21") + "osa-" + m.group("Msosa_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_23>[a-zA-Zç]+)osa (?P<Msosa_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msosa_23") + "osa " + m.group("Msosa_24") + "icas" in TEXT and not " ou " + m.group("Msosa_23") + "osa " + m.group("Msosa_24") + "icas" in TEXT and not "s de " + m.group("Msosa_23") + "osa " + m.group("Msosa_24") + "icas" in TEXT and not "s da " + m.group("Msosa_23") + "osa " + m.group("Msosa_24") + "icas" in TEXT and not " a " + m.group("Msosa_23") + "osa " + m.group("Msosa_24") + "icas" in TEXT and not m.group("Msosa_23") + "osa-" + m.group("Msosa_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_25>[a-zA-Zç]+)osa (?P<Msosa_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msosa_25") + "osa " + m.group("Msosa_26") + "icas" in TEXT and not " ou " + m.group("Msosa_25") + "osa " + m.group("Msosa_26") + "icas" in TEXT and not "s de " + m.group("Msosa_25") + "osa " + m.group("Msosa_26") + "icas" in TEXT and not "s da " + m.group("Msosa_25") + "osa " + m.group("Msosa_26") + "icas" in TEXT and not " a " + m.group("Msosa_25") + "osa " + m.group("Msosa_26") + "icas" in TEXT and not m.group("Msosa_25") + "osa-" + m.group("Msosa_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_27>[a-zA-Zç]+)osa (?P<Msosa_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msosa_27") + "osa " + m.group("Msosa_28") + "escas" in TEXT and not " ou " + m.group("Msosa_27") + "osa " + m.group("Msosa_28") + "escas" in TEXT and not "s de " + m.group("Msosa_27") + "osa " + m.group("Msosa_28") + "escas" in TEXT and not "s da " + m.group("Msosa_27") + "osa " + m.group("Msosa_28") + "escas" in TEXT and not " a " + m.group("Msosa_27") + "osa " + m.group("Msosa_28") + "escas" in TEXT and not m.group("Msosa_27") + "osa-" + m.group("Msosa_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_29>[a-zA-Zç]+)osa (?P<Msosa_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msosa_29") + "osa " + m.group("Msosa_30") + "idas" in TEXT and not " ou " + m.group("Msosa_29") + "s " + m.group("Msosa_30") + "idas" in TEXT and not "s de " + m.group("Msosa_29") + "s " + m.group("Msosa_30") + "idas" in TEXT and not "s da " + m.group("Msosa_29") + "s " + m.group("Msosa_30") + "idas" in TEXT and not " a " + m.group("Msosa_29") + "s " + m.group("Msosa_30") + "idas" in TEXT and not m.group("Msosa_29") + "osa-" + m.group("Msosa_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_31>[a-zA-Zç]+)osa (?P<Msosa_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msosa_31") + "osa " + m.group("Msosa_32") + "logas" in TEXT and not " ou " + m.group("Msosa_31") + "osa " + m.group("Msosa_32") + "logas" in TEXT and not "s de " + m.group("Msosa_31") + "osa " + m.group("Msosa_32") + "logas" in TEXT and not "s da " + m.group("Msosa_31") + "osa " + m.group("Msosa_32") + "logas" in TEXT and not " a " + m.group("Msosa_31") + "osa " + m.group("Msosa_32") + "logas" in TEXT and not m.group("Msosa_31") + "osa-" + m.group("Msosa_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_33>[a-zA-Zç]+)osa (?P<Msosa_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msosa_33") + "osa " + m.group("Msosa_34") + "rias" in TEXT and not " ou " + m.group("Msosa_33") + "osa " + m.group("Msosa_34") + "rias" in TEXT and not "s de " + m.group("Msosa_33") + "osa " + m.group("Msosa_34") + "rias" in TEXT and not "s da " + m.group("Msosa_33") + "osa " + m.group("Msosa_34") + "rias" in TEXT and not " a " + m.group("Msosa_33") + "osa " + m.group("Msosa_34") + "rias" in TEXT and not m.group("Msosa_33") + "osa-" + m.group("Msosa_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_35>[a-zA-Zç]+)osa (?P<Msosa_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msosa_35") + "osa " + m.group("Msosa_36") + "ssimas" in TEXT and not " ou " + m.group("Msosa_35") + "osa " + m.group("Msosa_36") + "ssimas" in TEXT and not "s de " + m.group("Msosa_35") + "osa " + m.group("Msosa_36") + "ssimas" in TEXT and not "s da " + m.group("Msosa_35") + "osa " + m.group("Msosa_36") + "ssimas" in TEXT and not " a " + m.group("Msosa_35") + "osa " + m.group("Msosa_36") + "ssimas" in TEXT and not m.group("Msosa_35") + "osa-" + m.group("Msosa_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_37>[a-zA-Zç]+)osa (?P<Msosa_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msosa_37") + "osa " + m.group("Msosa_38") + "simas" in TEXT and not " ou " + m.group("Msosa_37") + "osa " + m.group("Msosa_38") + "simas" in TEXT and not "s de " + m.group("Msosa_37") + "osa " + m.group("Msosa_38") + "simas" in TEXT and not "s da " + m.group("Msosa_37") + "osa " + m.group("Msosa_38") + "simas" in TEXT and not " a " + m.group("Msosa_37") + "osa " + m.group("Msosa_38") + "simas" in TEXT and not m.group("Msosa_37") + "osa-" + m.group("Msosa_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_41>[a-zA-Zç]+)osa (?P<Msosa_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msosa_42") in "D-d-" and not " e " + m.group("Msosa_41") + "osa " + m.group("Msosa_42") + "oras" in TEXT and not " ou " + m.group("Msosa_41") + "osa " + m.group("Msosa_42") + "oras" in TEXT and not "s de " + m.group("Msosa_41") + "osa " + m.group("Msosa_42") + "oras" in TEXT and not "s da " + m.group("Msosa_41") + "osa " + m.group("Msosa_42") + "oras" in TEXT and not " a " + m.group("Msosa_41") + "osa " + m.group("Msosa_42") + "oras" in TEXT and not m.group("Msosa_41") + "osa-" + m.group("Msosa_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_43>[a-zA-Zç]+)osa (?P<Msosa_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_44") in plvrMfr and not " e " + m.group("Msosa_43") + "osa " + m.group("Msosa_44") + "es" in TEXT and not " ou " + m.group("Msosa_43") + "osa " + m.group("Msosa_44") + "es" in TEXT and not "s de " + m.group("Msosa_43") + "osa " + m.group("Msosa_44") + "es" in TEXT and not "s da " + m.group("Msosa_43") + "osa " + m.group("Msosa_44") + "es" in TEXT and not " a " + m.group("Msosa_43") + "osa " + m.group("Msosa_44") + "es" in TEXT and not m.group("Msosa_43") + "osa-" + m.group("Msosa_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_45>[a-zA-Zç]+)osa (?P<Msosa_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_46") in plvrFemr and not " e " + m.group("Msosa_45") + "osa " + m.group("Msosa_46") + "es" in TEXT and not " ou " + m.group("Msosa_45") + "osa " + m.group("Msosa_46") + "es" in TEXT and not "s de " + m.group("Msosa_45") + "osa " + m.group("Msosa_46") + "es" in TEXT and not "s da " + m.group("Msosa_45") + "osa " + m.group("Msosa_46") + "es" in TEXT and not " a " + m.group("Msosa_45") + "osa " + m.group("Msosa_46") + "es" in TEXT and not m.group("Msosa_45") + "osa-" + m.group("Msosa_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_47>[a-zA-Zç]+)osa (?P<Msosa_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_48") in plvrMfal and not " e " + m.group("Msosa_47") + "osa " + m.group("Msosa_48") + "is" in TEXT and not " ou " + m.group("Msosa_47") + "osa " + m.group("Msosa_48") + "is" in TEXT and not "s de " + m.group("Msosa_47") + "osa " + m.group("Msosa_48") + "is" in TEXT and not "s da " + m.group("Msosa_47") + "osa " + m.group("Msosa_48") + "is" in TEXT and not " a " + m.group("Msosa_47") + "osa " + m.group("Msosa_48") + "is" in TEXT and not m.group("Msosa_47") + "osa-" + m.group("Msosa_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_49>[a-zA-Zç]+)osa (?P<Msosa_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_50") in plvrMfcao and not " e " + m.group("Msosa_49") + "osa " + m.group("Msosa_50") + "ões" in TEXT and not + " ou " + m.group("Msosa_49") + "osa " + m.group("Msosa_50") + "ões" in TEXT and not + "s de " + m.group("Msosa_49") + "osa " + m.group("Msosa_50") + "ões" in TEXT and not + "s da " + m.group("Msosa_49") + "osa " + m.group("Msosa_50") + "ões" in TEXT and not + " a " + m.group("Msosa_49") + "osa " + m.group("Msosa_50") + "ões" in TEXT and not m.group("Msosa_49") + "osa-" + m.group("Msosa_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_51>[a-zA-Zç]+)osa (?P<Msosa_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msosa_52") in plvrMascao and not " e " + m.group("Msosa_51") + "osa " + m.group("Msosa_52") + "ões" in TEXT and not " ou " + m.group("Msosa_51") + "osa " + m.group("Msosa_52") + "ões" in TEXT and not "s de " + m.group("Msosa_51") + "osa " + m.group("Msosa_52") + "ões" in TEXT and not "s da " + m.group("Msosa_51") + "osa " + m.group("Msosa_52") + "ões" in TEXT and not " a " + m.group("Msosa_51") + "osa " + m.group("Msosa_52") + "ões" in TEXT and not m.group("Msosa_51") + "osa-" + m.group("Msosa_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_53>[a-zA-Zç]+)osa (?P<Msosa_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_54") in plvrFemao and not " e " + m.group("Msosa_53") + "osa " + m.group("Msosa_54") + "ões" in TEXT and not " ou " + m.group("Msosa_53") + "osa " + m.group("Msosa_54") + "ões" in TEXT and not "s de " + m.group("Msosa_53") + "osa " + m.group("Msosa_54") + "ões" in TEXT and not "s da " + m.group("Msosa_53") + "osa " + m.group("Msosa_54") + "ões" in TEXT and not " a " + m.group("Msosa_53") + "osa " + m.group("Msosa_54") + "ões" in TEXT and not m.group("Msosa_53") + "osa-" + m.group("Msosa_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_55>[a-zA-Zç]+)osa (?P<Msosa_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msosa_55") + "osa " + m.group("Msosa_56") + "veis" in TEXT and not " ou " + m.group("Msosa_55") + "osa " + m.group("Msosa_56") + "veis" in TEXT and not "s de " + m.group("Msosa_55") + "osa " + m.group("Msosa_56") + "veis" in TEXT and not "s da " + m.group("Msosa_55") + "osa " + m.group("Msosa_56") + "veis" in TEXT and not " a " + m.group("Msosa_55") + "osa " + m.group("Msosa_56") + "veis" in TEXT and not m.group("Msosa_55") + "osa-" + m.group("Msosa_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_57>[a-zA-Zç]+)osa (?P<Msosa_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_58").lower() in plvrMfe and not " e " + m.group("Msosa_57") + "osa " + m.group("Msosa_58") + "es" in TEXT and not " ou " + m.group("Msosa_57") + "osa " + m.group("Msosa_58") + "es" in TEXT and not "s de " + m.group("Msosa_57") + "osa " + m.group("Msosa_58") + "es" in TEXT and not "s da " + m.group("Msosa_57") + "osa " + m.group("Msosa_58") + "es" in TEXT and not " a " + m.group("Msosa_57") + "osa " + m.group("Msosa_58") + "es" in TEXT and not m.group("Msosa_57") + "osa-" + m.group("Msosa_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_59>[a-zA-Zç]+)osa (?P<Msosa_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_60").lower() in plvrFeme and not " e " + m.group("Msosa_59") + "osa " + m.group("Msosa_60") + "es" in TEXT and not " ou " + m.group("Msosa_59") + "osa " + m.group("Msosa_60") + "es" in TEXT and not "s de " + m.group("Msosa_59") + "osa " + m.group("Msosa_60") + "es" in TEXT and not "s da " + m.group("Msosa_59") + "osa " + m.group("Msosa_60") + "es" in TEXT and not " a " + m.group("Msosa_59") + "osa " + m.group("Msosa_60") + "es" in TEXT and not m.group("Msosa_59") + "osa-" + m.group("Msosa_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_61>[a-zA-Zç]+)osa (?P<Msosa_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_62") in plvrMfel and not " e " + m.group("Msosa_61") + "osa " + m.group("Msosa_62") + "éis" in TEXT and not " ou " + m.group("Msosa_61") + "osa " + m.group("Msosa_62") + "éis" in TEXT and not "s de " + m.group("Msosa_61") + "osa " + m.group("Msosa_62") + "éis" in TEXT and not "s da " + m.group("Msosa_61") + "osa " + m.group("Msosa_62") + "éis" in TEXT and not " a " + m.group("Msosa_61") + "osa " + m.group("Msosa_62") + "éis" in TEXT and not m.group("Msosa_61") + "osa-" + m.group("Msosa_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_63>[a-zA-Zç]+)osa (?P<Msosa_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_64") in plvrFemel and not " e " + m.group("Msosa_63") + "osa " + m.group("Msosa_64") + "éis" in TEXT and not " ou " + m.group("Msosa_63") + "osa " + m.group("Msosa_64") + "éis" in TEXT and not "s de " + m.group("Msosa_63") + "osa " + m.group("Msosa_64") + "éis" in TEXT and not "s da " + m.group("Msosa_63") + "osa " + m.group("Msosa_64") + "éis" in TEXT and not " a " + m.group("Msosa_63") + "osa " + m.group("Msosa_64") + "éis" in TEXT and not m.group("Msosa_63") + "osa-" + m.group("Msosa_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_65>[a-zA-Zç]+)osa (?P<Msosa_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_66") in plvrMfeu and not " e " + m.group("Msosa_65") + "osa " + m.group("Msosa_66") + "us" in TEXT and not " ou " + m.group("Msosa_65") + "osa " + m.group("Msosa_66") + "us" in TEXT and not "s de " + m.group("Msosa_65") + "osa " + m.group("Msosa_66") + "us" in TEXT and not "s da " + m.group("Msosa_65") + "osa " + m.group("Msosa_66") + "us" in TEXT and not " a " + m.group("Msosa_65") + "osa " + m.group("Msosa_66") + "us" in TEXT and not m.group("Msosa_65") + "osa-" + m.group("Msosa_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_67>[a-zA-Zç]+)osa (?P<Msosa_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_68") in plvrFemu and not " e " + m.group("Msosa_67") + "osa " + m.group("Msosa_68") + "us" in TEXT and not " ou " + m.group("Msosa_67") + "osa " + m.group("Msosa_68") + "us" in TEXT and not "s de " + m.group("Msosa_67") + "osa " + m.group("Msosa_68") + "us" in TEXT and not "s da " + m.group("Msosa_67") + "osa " + m.group("Msosa_68") + "us" in TEXT and not " a " + m.group("Msosa_67") + "osa " + m.group("Msosa_68") + "us" in TEXT and not m.group("Msosa_67") + "osa-" + m.group("Msosa_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_69>[a-zA-Zç]+)osa (?P<Msosa_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_70") in plvrInvaz and not " e " + m.group("Msosa_69") + "osa " + m.group("Msosa_70") + "zes" in TEXT and not " ou " + m.group("Msosa_69") + "osa " + m.group("Msosa_70") + "zes" in TEXT and not "s de " + m.group("Msosa_69") + "osa " + m.group("Msosa_70") + "zes" in TEXT and not "s da " + m.group("Msosa_69") + "osa " + m.group("Msosa_70") + "zes" in TEXT and not " a " + m.group("Msosa_69") + "osa " + m.group("Msosa_70") + "zes" in TEXT and not m.group("Msosa_69") + "osa-" + m.group("Msosa_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_71>[a-zA-Zç]+)osa (?P<Msosa_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_72") in plvrFemz and not " e " + m.group("Msosa_71") + "osa " + m.group("Msosa_72") + "zes" in TEXT and not " ou " + m.group("Msosa_71") + "osa " + m.group("Msosa_72") + "zes" in TEXT and not "s de " + m.group("Msosa_71") + "osa " + m.group("Msosa_72") + "zes" in TEXT and not "s da " + m.group("Msosa_71") + "osa " + m.group("Msosa_72") + "zes" in TEXT and not " a " + m.group("Msosa_71") + "osa " + m.group("Msosa_72") + "zes" in TEXT and not m.group("Msosa_71") + "osa-" + m.group("Msosa_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_73>[a-zA-Zç]+)osa (?P<Msosa_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_74") in pvrFeman and not " e " + m.group("Msosa_73") + "osa " + m.group("Msosa_74") + "s" in TEXT and not " ou " + m.group("Msosa_73") + "osa " + m.group("Msosa_74") + "s" in TEXT and not "s de " + m.group("Msosa_73") + "osa " + m.group("Msosa_74") + "s" in TEXT and not "s da " + m.group("Msosa_73") + "osa " + m.group("Msosa_74") + "s" in TEXT and not " a " + m.group("Msosa_73") + "osa " + m.group("Msosa_74") + "s" in TEXT and not m.group("Msosa_73") + "osa-" + m.group("Msosa_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_99>[a-zA-Zç]+)osa (?P<Msosa_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_100") in plvrMFm and not " e " + m.group("Msosa_99") + "osa " + m.group("Msosa_100") + "ns" in TEXT and not " ou " + m.group("Msosa_99") + "osa " + m.group("Msosa_100") + "ns" in TEXT and not "s de " + m.group("Msosa_99") + "osa " + m.group("Msosa_100") + "ns" in TEXT and not "s da " + m.group("Msosa_99") + "osa " + m.group("Msosa_100") + "ns" in TEXT and not " a " + m.group("Msosa_99") + "osa " + m.group("Msosa_100") + "ns" in TEXT and not m.group("Msosa_99") + "osa-" + m.group("Msosa_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msosa_101>[a-zA-Zç]+)osa (?P<Msosa_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "osas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msosa_102") in plvrFemm and not " e " + m.group("Msosa_101") + "osa " + m.group("Msosa_102") + "ns" in TEXT and not " ou " + m.group("Msosa_101") + "osa " + m.group("Msosa_102") + "ns" in TEXT and not "s de " + m.group("Msosa_101") + "osa " + m.group("Msosa_102") + "ns" in TEXT and not "s da " + m.group("Msosa_101") + "osa " + m.group("Msosa_102") + "ns" in TEXT and not " a " + m.group("Msosa_101") + "osa " + m.group("Msosa_102") + "ns" in TEXT and not m.group("Msosa_101") + "osa-" + m.group("Msosa_102") + "ns" in tCompostops'],
# oso o
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_1>[a-zA-Zç]+)oso (?P<Msoso_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_2").lower() in plvrMasca and not " e " + m.group("Msoso_1") + "oso " + m.group("Msoso_2") +"s" in TEXT and not " ou " + m.group("Msoso_1") + "oso " + m.group("Msoso_2") + "s" in TEXT and not "s de " + m.group("Msoso_1") + "oso " + m.group("Msoso_2") + "s" in TEXT and not "s do " + m.group("Msoso_1") + "oso " + m.group("Msoso_2") + "s" in TEXT and not " o " + m.group("Msoso_1") + "oso " + m.group("Msoso_2") + "s" in TEXT and not m.group("Msoso_1") + "oso-" + m.group("Msoso_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_3>[a-zA-Zç]+)oso (?P<Msoso_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_4").lower() in plvrMfoa and not " e " + m.group("Msoso_3") + "oso " + m.group("Msoso_4") + "os" in TEXT and not " ou " + m.group("Msoso_3") + "oso " + m.group("Msoso_4") + "os" in TEXT and not "s de " + m.group("Msoso_3") + "oso " + m.group("Msoso_4") + "os" in TEXT and not "s do " + m.group("Msoso_3") + "oso " + m.group("Msoso_4") + "os" in TEXT and not " o " + m.group("Msoso_3") + "oso " + m.group("Msoso_4") + "os" in TEXT and not m.group("Msoso_3") + "oso-" + m.group("Msoso_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_5>[a-zA-Zç]+)oso (?P<Msoso_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msoso_6").lower() in excAdo and not " e " + m.group("Msoso_5") + "oso " + m.group("Msoso_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msoso_5") + "oso " + m.group("Msoso_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msoso_5") + "oso " + m.group("Msoso_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msoso_5") + "oso " + m.group("Msoso_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msoso_5") + "oso " + m.group("Msoso_6") + m.group(3) + "dos" in TEXT and not m.group("Msoso_5") + "oso-" + m.group("Msoso_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_7>[a-zA-Zç]+)oso (?P<Msoso_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msoso_8").lower() in excIsta and not " e " + m.group("Msoso_7") + "oso " + m.group("Msoso_8") + "s" in TEXT and not " ou " + m.group("Msoso_7") + "oso " + m.group("Msoso_8") + "s" in TEXT and not "s de " + m.group("Msoso_7") + "oso " + m.group("Msoso_8") + "s" in TEXT and not "s do " + m.group("Msoso_7") + "oso " + m.group("Msoso_8") + "s" in TEXT and not " o " + m.group("Msoso_7") + "oso " + m.group("Msoso_8") + "s" in TEXT and not m.group("Msoso_7") + "oso-" + m.group("Msoso_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_9>[a-zA-Zç]+)oso (?P<Msoso_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_10").lower() in plvrInva and not " e " + m.group("Msoso_9") + "oso " + m.group("Msoso_10") + "s" in TEXT and not " ou " + m.group("Msoso_9") + "oso " + m.group("Msoso_10") + "s" in TEXT and not "s de " + m.group("Msoso_9") + "oso " + m.group("Msoso_10") + "s" in TEXT and not "s do " + m.group("Msoso_9") + "oso " + m.group("Msoso_10") + "s" in TEXT and not " a " + m.group("Msoso_9") + "oso " + m.group("Msoso_10") + "s" in TEXT and not m.group("Msoso_9") + "oso-" + m.group("Msoso_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_11>[a-zA-Zç]+)oso (?P<Msoso_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msoso_12").lower() in excAdo and not " e " + m.group("Msoso_11") + "oso " + m.group("Msoso_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msoso_11") + "oso " + m.group("Msoso_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msoso_11") + "oso " + m.group("Msoso_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Msoso_11") + "oso " + m.group("Msoso_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Msoso_11") + "oso " + m.group("Msoso_12") + m.group(3) + "das" in TEXT and not m.group("Msoso_11") + "oso-" + m.group("Msoso_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_13>[a-zA-Zç]+)oso (?P<Msoso_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_13") + "oso " + m.group("Msoso_14") + "osos" in TEXT and not " ou " + m.group("Msoso_13") + "oso " + m.group("Msoso_14") + "osos" in TEXT and not "s de " + m.group("Msoso_13") + "oso " + m.group("Msoso_14") + "osos" in TEXT and not "s do " + m.group("Msoso_13") + "oso " + m.group("Msoso_14") + "osos" in TEXT and not " o " + m.group("Msoso_13") + "oso " + m.group("Msoso_14") + "osos" in TEXT and not m.group("Msoso_13") + "oso-" + m.group("Msoso_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_15>[a-zA-Zç]+)oso (?P<Msoso_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_15") + "oso " + m.group("Msoso_16") + "osas" in TEXT and not " ou " + m.group("Msoso_15") + "oso " + m.group("Msoso_16") + "osas" in TEXT and not "s de " + m.group("Msoso_15") + "oso " + m.group("Msoso_16") + "osas" in TEXT and not "s do " + m.group("Msoso_15") + "oso " + m.group("Msoso_16") + "osas" in TEXT and not " o " + m.group("Msoso_15") + "oso " + m.group("Msoso_16") + "osas" in TEXT and not m.group("Msoso_15") + "oso-" + m.group("Msoso_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_17>[a-zA-Zç]+)oso (?P<Msoso_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_17") + "oso " + m.group("Msoso_18") + "ivas" in TEXT and not " ou " + m.group("Msoso_17") + "oso " + m.group("Msoso_18") + "ivas" in TEXT and not "s de " + m.group("Msoso_17") + "oso " + m.group("Msoso_18") + "ivas" in TEXT and not "s do " + m.group("Msoso_17") + "oso " + m.group("Msoso_18") + "ivas" in TEXT and not " o " + m.group("Msoso_17") + "oso " + m.group("Msoso_18") + "ivas" in TEXT and not m.group("Msoso_17") + "oso-" + m.group("Msoso_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_19>[a-zA-Zç]+)oso (?P<Msoso_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_19") + "oso " + m.group("Msoso_20") + "ivas" in TEXT and not " ou " + m.group("Msoso_19") + "oso " + m.group("Msoso_20") + "ivas" in TEXT and not "s de " + m.group("Msoso_19") + "oso " + m.group("Msoso_20") + "ivas" in TEXT and not "s do " + m.group("Msoso_19") + "oso " + m.group("Msoso_20") + "ivas" in TEXT and not " o " + m.group("Msoso_19") + "oso " + m.group("Msoso_20") + "ivas" in TEXT and not m.group("Msoso_19") + "oso-" + m.group("Msoso_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_21>[a-zA-Zç]+)oso (?P<Msoso_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_21") + "oso " + m.group("Msoso_22") + "icos" in TEXT and not " ou " + m.group("Msoso_21") + "oso " + m.group("Msoso_22") + "icos" in TEXT and not "s de " + m.group("Msoso_21") + "oso " + m.group("Msoso_22") + "icos" in TEXT and not "s do " + m.group("Msoso_21") + "oso " + m.group("Msoso_22") + "icos" in TEXT and not " o " + m.group("Msoso_21") + "oso " + m.group("Msoso_22") + "icos" in TEXT and not m.group("Msoso_21") + "oso-" + m.group("Msoso_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_23>[a-zA-Zç]+)oso (?P<Msoso_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_23") + "oso " + m.group("Msoso_24") + "icos" in TEXT and not " ou " + m.group("Msoso_23") + "oso " + m.group("Msoso_24") + "icos" in TEXT and not "s de " + m.group("Msoso_23") + "oso " + m.group("Msoso_24") + "icos" in TEXT and not "s do " + m.group("Msoso_23") + "oso " + m.group("Msoso_24") + "icos" in TEXT and not " o " + m.group("Msoso_23") + "oso " + m.group("Msoso_24") + "icos" in TEXT and not m.group("Msoso_23") + "oso-" + m.group("Msoso_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_25>[a-zA-Zç]+)oso (?P<Msoso_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_25") + "oso " + m.group("Msoso_26") + "icos" in TEXT and not " ou " + m.group("Msoso_25") + "oso " + m.group("Msoso_26") + "icos" in TEXT and not "s de " + m.group("Msoso_25") + "oso " + m.group("Msoso_26") + "icos" in TEXT and not "s do " + m.group("Msoso_25") + "oso " + m.group("Msoso_26") + "icos" in TEXT and not " o " + m.group("Msoso_25") + "oso " + m.group("Msoso_26") + "icos" in TEXT and not m.group("Msoso_25") + "oso-" + m.group("Msoso_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_27>[a-zA-Zç]+)oso (?P<Msoso_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_27") + "oso " + m.group("Msoso_28") + "escos" in TEXT and not " ou " + m.group("Msoso_27") + "oso " + m.group("Msoso_28") + "escos" in TEXT and not "s de " + m.group("Msoso_27") + "oso " + m.group("Msoso_28") + "escos" in TEXT and not "s do " + m.group("Msoso_27") + "oso " + m.group("Msoso_28") + "escos" in TEXT and not " o " + m.group("Msoso_27") + "oso " + m.group("Msoso_28") + "escos" in TEXT and not m.group("Msoso_27") + "oso-" + m.group("Msoso_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_29>[a-zA-Zç]+)oso (?P<Msoso_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_29") + "oso " + m.group("Msoso_30") + "idos" in TEXT and not " ou " + m.group("Msoso_29") + "s " + m.group("Msoso_30") + "idos" in TEXT and not "s de " + m.group("Msoso_29") + "s " + m.group("Msoso_30") + "idos" in TEXT and not "s do " + m.group("Msoso_29") + "s " + m.group("Msoso_30") + "idos" in TEXT and not " o " + m.group("Msoso_29") + "s " + m.group("Msoso_30") + "idos" in TEXT and not m.group("Msoso_29") + "oso-" + m.group("Msoso_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_31>[a-zA-Zç]+)oso (?P<Msoso_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_31") + "oso " + m.group("Msoso_32") + "logos" in TEXT and not " ou " + m.group("Msoso_31") + "oso " + m.group("Msoso_32") + "logos" in TEXT and not "s de " + m.group("Msoso_31") + "oso " + m.group("Msoso_32") + "logos" in TEXT and not "s do " + m.group("Msoso_31") + "oso " + m.group("Msoso_32") + "logos" in TEXT and not " o " + m.group("Msoso_31") + "oso " + m.group("Msoso_32") + "logos" in TEXT and not m.group("Msoso_31") + "oso-" + m.group("Msoso_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_33>[a-zA-Zç]+)oso (?P<Msoso_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_33") + "oso " + m.group("Msoso_34") + "rios" in TEXT and not " ou " + m.group("Msoso_33") + "oso " + m.group("Msoso_34") + "rios" in TEXT and not "s de " + m.group("Msoso_33") + "oso " + m.group("Msoso_34") + "rios" in TEXT and not "s do " + m.group("Msoso_33") + "oso " + m.group("Msoso_34") + "rios" in TEXT and not " o " + m.group("Msoso_33") + "oso " + m.group("Msoso_34") + "rios" in TEXT and not m.group("Msoso_33") + "oso-" + m.group("Msoso_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_35>[a-zA-Zç]+)oso (?P<Msoso_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_35") + "oso " + m.group("Msoso_36") + "ssimos" in TEXT and not " ou " + m.group("Msoso_35") + "oso " + m.group("Msoso_36") + "ssimos" in TEXT and not "s de " + m.group("Msoso_35") + "oso " + m.group("Msoso_36") + "ssimos" in TEXT and not "s do " + m.group("Msoso_35") + "oso " + m.group("Msoso_36") + "ssimos" in TEXT and not " o " + m.group("Msoso_35") + "oso " + m.group("Msoso_36") + "ssimos" in TEXT and not m.group("Msoso_35") + "oso-" + m.group("Msoso_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_37>[a-zA-Zç]+)oso (?P<Msoso_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_37") + "oso " + m.group("Msoso_38") + "simos" in TEXT and not " ou " + m.group("Msoso_37") + "oso " + m.group("Msoso_38") + "simos" in TEXT and not "s de " + m.group("Msoso_37") + "oso " + m.group("Msoso_38") + "simos" in TEXT and not "s do " + m.group("Msoso_37") + "oso " + m.group("Msoso_38") + "simos" in TEXT and not " o " + m.group("Msoso_37") + "oso " + m.group("Msoso_38") + "simos" in TEXT and not m.group("Msoso_37") + "oso-" + m.group("Msoso_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_41>[a-zA-Zç]+)oso (?P<Msoso_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msoso_42") in "D-d-" and not " e " + m.group("Msoso_41") + "oso " + m.group("Msoso_42") + "ores" in TEXT and not " ou " + m.group("Msoso_41") + "oso " + m.group("Msoso_42") + "ores" in TEXT and not "s de " + m.group("Msoso_41") + "oso " + m.group("Msoso_42") + "ores" in TEXT and not "s do " + m.group("Msoso_41") + "oso " + m.group("Msoso_42") + "ores" in TEXT and not " o " + m.group("Msoso_41") + "oso " + m.group("Msoso_42") + "ores" in TEXT and not m.group("Msoso_41") + "oso-" + m.group("Msoso_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_43>[a-zA-Zç]+)oso (?P<Msoso_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_44") in plvrMfr and not " e " + m.group("Msoso_43") + "oso " + m.group("Msoso_44") + "es" in TEXT and not " ou " + m.group("Msoso_43") + "oso " + m.group("Msoso_44") + "es" in TEXT and not "s de " + m.group("Msoso_43") + "oso " + m.group("Msoso_44") + "es" in TEXT and not "s do " + m.group("Msoso_43") + "oso " + m.group("Msoso_44") + "es" in TEXT and not " o " + m.group("Msoso_43") + "oso " + m.group("Msoso_44") + "es" in TEXT and not m.group("Msoso_43") + "oso-" + m.group("Msoso_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_45>[a-zA-Zç]+)oso (?P<Msoso_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_46") in plvrMascr and not " e " + m.group("Msoso_45") + "oso " + m.group("Msoso_46") + "es" in TEXT and not " ou " + m.group("Msoso_45") + "oso " + m.group("Msoso_46") + "es" in TEXT and not "s de " + m.group("Msoso_45") + "oso " + m.group("Msoso_46") + "es" in TEXT and not "s do " + m.group("Msoso_45") + "oso " + m.group("Msoso_46") + "es" in TEXT and not " o " + m.group("Msoso_45") + "oso " + m.group("Msoso_46") + "es" in TEXT and not m.group("Msoso_45") + "oso-" + m.group("Msoso_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_47>[a-zA-Zç]+)oso (?P<Msoso_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_48") in plvrMfal and not " e " + m.group("Msoso_47") + "oso " + m.group("Msoso_48") + "is" in TEXT and not " ou " + m.group("Msoso_47") + "oso " + m.group("Msoso_48") + "is" in TEXT and not "s de " + m.group("Msoso_47") + "oso " + m.group("Msoso_48") + "is" in TEXT and not "s do " + m.group("Msoso_47") + "oso " + m.group("Msoso_48") + "is" in TEXT and not " o " + m.group("Msoso_47") + "oso " + m.group("Msoso_48") + "is" in TEXT and not m.group("Msoso_47") + "oso-" + m.group("Msoso_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_49>[a-zA-Zç]+)oso (?P<Msoso_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_50") in plvrMfcao and not " e " + m.group("Msoso_49") + "oso " + m.group("Msoso_50") + "ões" in TEXT and not + " ou " + m.group("Msoso_49") + "oso " + m.group("Msoso_50") + "ões" in TEXT and not + "s de " + m.group("Msoso_49") + "oso " + m.group("Msoso_50") + "ões" in TEXT and not + "s do " + m.group("Msoso_49") + "oso " + m.group("Msoso_50") + "ões" in TEXT and not + " a " + m.group("Msoso_49") + "oso " + m.group("Msoso_50") + "ões" in TEXT and not m.group("Msoso_49") + "oso-" + m.group("Msoso_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_51>[a-zA-Zç]+)oso (?P<Msoso_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_52") in plvrNfemcao and not " e " + m.group("Msoso_51") + "oso " + m.group("Msoso_52") + "ões" in TEXT and not " ou " + m.group("Msoso_51") + "oso " + m.group("Msoso_52") + "ões" in TEXT and not "s de " + m.group("Msoso_51") + "oso " + m.group("Msoso_52") + "ões" in TEXT and not "s do " + m.group("Msoso_51") + "oso " + m.group("Msoso_52") + "ões" in TEXT and not " o " + m.group("Msoso_51") + "oso " + m.group("Msoso_52") + "ões" in TEXT and not m.group("Msoso_51") + "oso-" + m.group("Msoso_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_55>[a-zA-Zç]+)oso (?P<Msoso_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_55") + "oso " + m.group("Msoso_56") + "veis" in TEXT and not " ou " + m.group("Msoso_55") + "oso " + m.group("Msoso_56") + "veis" in TEXT and not "s de " + m.group("Msoso_55") + "oso " + m.group("Msoso_56") + "veis" in TEXT and not "s do " + m.group("Msoso_55") + "oso " + m.group("Msoso_56") + "veis" in TEXT and not " o " + m.group("Msoso_55") + "oso " + m.group("Msoso_56") + "veis" in TEXT and not m.group("Msoso_55") + "oso-" + m.group("Msoso_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_57>[a-zA-Zç]+)oso (?P<Msoso_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_58").lower() in plvrMfe and not " e " + m.group("Msoso_57") + "oso " + m.group("Msoso_58") + "es" in TEXT and not " ou " + m.group("Msoso_57") + "oso " + m.group("Msoso_58") + "es" in TEXT and not "s de " + m.group("Msoso_57") + "oso " + m.group("Msoso_58") + "es" in TEXT and not "s do " + m.group("Msoso_57") + "oso " + m.group("Msoso_58") + "es" in TEXT and not " o " + m.group("Msoso_57") + "oso " + m.group("Msoso_58") + "es" in TEXT and not m.group("Msoso_57") + "oso-" + m.group("Msoso_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_59>[a-zA-Zç]+)oso (?P<Msoso_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_60").lower() in plvrMasce and not " e " + m.group("Msoso_59") + "oso " + m.group("Msoso_60") + "es" in TEXT and not " ou " + m.group("Msoso_59") + "oso " + m.group("Msoso_60") + "es" in TEXT and not "s de " + m.group("Msoso_59") + "oso " + m.group("Msoso_60") + "es" in TEXT and not "s do " + m.group("Msoso_59") + "oso " + m.group("Msoso_60") + "es" in TEXT and not " o " + m.group("Msoso_59") + "oso " + m.group("Msoso_60") + "es" in TEXT and not m.group("Msoso_59") + "oso-" + m.group("Msoso_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_61>[a-zA-Zç]+)oso (?P<Msoso_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_62") in plvrMfel and not " e " + m.group("Msoso_61") + "oso " + m.group("Msoso_62") + "éis" in TEXT and not " ou " + m.group("Msoso_61") + "oso " + m.group("Msoso_62") + "éis" in TEXT and not "s de " + m.group("Msoso_61") + "oso " + m.group("Msoso_62") + "éis" in TEXT and not "s do " + m.group("Msoso_61") + "oso " + m.group("Msoso_62") + "éis" in TEXT and not " o " + m.group("Msoso_61") + "oso " + m.group("Msoso_62") + "éis" in TEXT and not m.group("Msoso_61") + "oso-" + m.group("Msoso_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_63>[a-zA-Zç]+)oso (?P<Msoso_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_64") in plvrMascel and not " e " + m.group("Msoso_63") + "oso " + m.group("Msoso_64") + "éis" in TEXT and not " ou " + m.group("Msoso_63") + "oso " + m.group("Msoso_64") + "éis" in TEXT and not "s de " + m.group("Msoso_63") + "oso " + m.group("Msoso_64") + "éis" in TEXT and not "s do " + m.group("Msoso_63") + "oso " + m.group("Msoso_64") + "éis" in TEXT and not " o " + m.group("Msoso_63") + "oso " + m.group("Msoso_64") + "éis" in TEXT and not m.group("Msoso_63") + "oso-" + m.group("Msoso_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_65>[a-zA-Zç]+)oso (?P<Msoso_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_66") in plvrMfeu and not " e " + m.group("Msoso_65") + "oso " + m.group("Msoso_66") + "us" in TEXT and not " ou " + m.group("Msoso_65") + "oso " + m.group("Msoso_66") + "us" in TEXT and not "s de " + m.group("Msoso_65") + "oso " + m.group("Msoso_66") + "us" in TEXT and not "s do " + m.group("Msoso_65") + "oso " + m.group("Msoso_66") + "us" in TEXT and not " o " + m.group("Msoso_65") + "oso " + m.group("Msoso_66") + "us" in TEXT and not m.group("Msoso_65") + "oso-" + m.group("Msoso_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_67>[a-zA-Zç]+)oso (?P<Msoso_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_68") in plvrMascu and not " e " + m.group("Msoso_67") + "oso " + m.group("Msoso_68") + "us" in TEXT and not " ou " + m.group("Msoso_67") + "oso " + m.group("Msoso_68") + "us" in TEXT and not "s de " + m.group("Msoso_67") + "oso " + m.group("Msoso_68") + "us" in TEXT and not "s do " + m.group("Msoso_67") + "oso " + m.group("Msoso_68") + "us" in TEXT and not " o " + m.group("Msoso_67") + "oso " + m.group("Msoso_68") + "us" in TEXT and not m.group("Msoso_67") + "oso-" + m.group("Msoso_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_69>[a-zA-Zç]+)oso (?P<Msoso_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_70") in plvrInvaz and not " e " + m.group("Msoso_69") + "oso " + m.group("Msoso_70") + "zes" in TEXT and not " ou " + m.group("Msoso_69") + "oso " + m.group("Msoso_70") + "zes" in TEXT and not "s de " + m.group("Msoso_69") + "oso " + m.group("Msoso_70") + "zes" in TEXT and not "s do " + m.group("Msoso_69") + "oso " + m.group("Msoso_70") + "zes" in TEXT and not " o " + m.group("Msoso_69") + "oso " + m.group("Msoso_70") + "zes" in TEXT and not m.group("Msoso_69") + "oso-" + m.group("Msoso_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_71>[a-zA-Zç]+)oso (?P<Msoso_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_72") in plvrMascz and not " e " + m.group("Msoso_71") + "oso " + m.group("Msoso_72") + "zes" in TEXT and not " ou " + m.group("Msoso_71") + "oso " + m.group("Msoso_72") + "zes" in TEXT and not "s de " + m.group("Msoso_71") + "oso " + m.group("Msoso_72") + "zes" in TEXT and not "s do " + m.group("Msoso_71") + "oso " + m.group("Msoso_72") + "zes" in TEXT and not " o " + m.group("Msoso_71") + "oso " + m.group("Msoso_72") + "zes" in TEXT and not m.group("Msoso_71") + "oso-" + m.group("Msoso_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_73>[a-zA-Zç]+)oso (?P<Msoso_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_74") in pvrMascan and not " e " + m.group("Msoso_73") + "oso " + m.group("Msoso_74") + "s" in TEXT and not " ou " + m.group("Msoso_73") + "oso " + m.group("Msoso_74") + "s" in TEXT and not "s de " + m.group("Msoso_73") + "oso " + m.group("Msoso_74") + "s" in TEXT and not "s do " + m.group("Msoso_73") + "oso " + m.group("Msoso_74") + "s" in TEXT and not " o " + m.group("Msoso_73") + "oso " + m.group("Msoso_74") + "s" in TEXT and not m.group("Msoso_73") + "oso-" + m.group("Msoso_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_75>[a-zA-Zç]+)oso (?P<Msoso_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_76").lower() in plvrMasco and not " e " + m.group("Msoso_75") + "oso " + m.group("Msoso_76") +"s" in TEXT and not " ou " + m.group("Msoso_75") + "oso " + m.group("Msoso_76") + "s" in TEXT and not "s de " + m.group("Msoso_75") + "oso " + m.group("Msoso_76") + "s" in TEXT and not "s do " + m.group("Msoso_75") + "oso " + m.group("Msoso_76") + "s" in TEXT and not " o " + m.group("Msoso_75") + "oso " + m.group("Msoso_76") + "s" in TEXT and not m.group("Msoso_75") + "oso-" + m.group("Msoso_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_77>[a-zA-Zç]+)oso (?P<Msoso_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_77") + "oso " + m.group("Msoso_78") + "inhos" in TEXT and not " ou " + m.group("Msoso_77") + "oso " + m.group("Msoso_78") + "inhos" in TEXT and not "s de " + m.group("Msoso_77") + "oso " + m.group("Msoso_78") + "inhos" in TEXT and not "s do " + m.group("Msoso_77") + "oso " + m.group("Msoso_78") + "inhos" in TEXT and not " o " + m.group("Msoso_77") + "oso " + m.group("Msoso_78") + "inhos" in TEXT and not m.group("Msoso_77") + "oso-" + m.group("Msoso_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_79>[a-zA-Zç]+)oso (?P<Msoso_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_79") + "oso " + m.group("Msoso_80") + "icas" in TEXT and not " ou " + m.group("Msoso_79") + "oso " + m.group("Msoso_80") + "icas" in TEXT and not "s de " + m.group("Msoso_79") + "oso " + m.group("Msoso_80") + "icas" in TEXT and not "s do " + m.group("Msoso_79") + "oso " + m.group("Msoso_80") + "icas" in TEXT and not " o " + m.group("Msoso_79") + "oso " + m.group("Msoso_80") + "icas" in TEXT and not m.group("Msoso_79") + "oso-" + m.group("Msoso_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_81>[a-zA-Zç]+)oso (?P<Msoso_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_81") + "oso " + m.group("Msoso_82") + "icas" in TEXT and not " ou " + m.group("Msoso_81") + "oso " + m.group("Msoso_82") + "icas" in TEXT and not "s de " + m.group("Msoso_81") + "oso " + m.group("Msoso_82") + "icas" in TEXT and not "s do " + m.group("Msoso_81") + "oso " + m.group("Msoso_82") + "icas" in TEXT and not " o " + m.group("Msoso_81") + "oso " + m.group("Msoso_82") + "icas" in TEXT and not m.group("Msoso_81") + "oso-" + m.group("Msoso_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_83>[a-zA-Zç]+)oso (?P<Msoso_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_83") + "oso " + m.group("Msoso_84") + "icas" in TEXT and not " ou " + m.group("Msoso_83") + "oso " + m.group("Msoso_84") + "icas" in TEXT and not "s de " + m.group("Msoso_83") + "oso " + m.group("Msoso_84") + "icas" in TEXT and not "s do " + m.group("Msoso_83") + "oso " + m.group("Msoso_84") + "icas" in TEXT and not " o " + m.group("Msoso_83") + "oso " + m.group("Msoso_84") + "icas" in TEXT and not m.group("Msoso_83") + "oso-" + m.group("Msoso_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_85>[a-zA-Zç]+)oso (?P<Msoso_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_85") + "oso " + m.group("Msoso_86") + "escas" in TEXT and not " ou " + m.group("Msoso_85") + "oso " + m.group("Msoso_86") + "escas" in TEXT and not "s de " + m.group("Msoso_85") + "oso " + m.group("Msoso_86") + "escas" in TEXT and not "s do " + m.group("Msoso_85") + "oso " + m.group("Msoso_86") + "escas" in TEXT and not " o " + m.group("Msoso_85") + "oso " + m.group("Msoso_86") + "escas" in TEXT and not m.group("Msoso_85") + "oso-" + m.group("Msoso_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_87>[a-zA-Zç]+)oso (?P<Msoso_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_87") + "oso " + m.group("Msoso_88") + "idas" in TEXT and not " ou " + m.group("Msoso_87") + "s " + m.group("Msoso_88") + "idas" in TEXT and not "s de " + m.group("Msoso_87") + "s " + m.group("Msoso_88") + "idas" in TEXT and not "s do " + m.group("Msoso_87") + "s " + m.group("Msoso_88") + "idas" in TEXT and not " o " + m.group("Msoso_87") + "s " + m.group("Msoso_88") + "idas" in TEXT and not m.group("Msoso_87") + "oso-" + m.group("Msoso_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_89>[a-zA-Zç]+)oso (?P<Msoso_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_89") + "oso " + m.group("Msoso_90") + "logas" in TEXT and not " ou " + m.group("Msoso_89") + "oso " + m.group("Msoso_90") + "logas" in TEXT and not "s de " + m.group("Msoso_89") + "oso " + m.group("Msoso_90") + "logas" in TEXT and not "s do " + m.group("Msoso_89") + "oso " + m.group("Msoso_90") + "logas" in TEXT and not " o " + m.group("Msoso_89") + "oso " + m.group("Msoso_90") + "logas" in TEXT and not m.group("Msoso_89") + "oso-" + m.group("Msoso_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_91>[a-zA-Zç]+)oso (?P<Msoso_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_91") + "oso " + m.group("Msoso_92") + "rias" in TEXT and not " ou " + m.group("Msoso_91") + "oso " + m.group("Msoso_92") + "rias" in TEXT and not "s de " + m.group("Msoso_91") + "oso " + m.group("Msoso_92") + "rias" in TEXT and not "s do " + m.group("Msoso_91") + "oso " + m.group("Msoso_92") + "rias" in TEXT and not " o " + m.group("Msoso_91") + "oso " + m.group("Msoso_92") + "rias" in TEXT and not m.group("Msoso_91") + "oso-" + m.group("Msoso_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_93>[a-zA-Zç]+)oso (?P<Msoso_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_93") + "oso " + m.group("Msoso_94") + "ssimas" in TEXT and not " ou " + m.group("Msoso_93") + "oso " + m.group("Msoso_94") + "ssimas" in TEXT and not "s de " + m.group("Msoso_93") + "oso " + m.group("Msoso_94") + "ssimas" in TEXT and not "s do " + m.group("Msoso_93") + "oso " + m.group("Msoso_94") + "ssimas" in TEXT and not " o " + m.group("Msoso_93") + "oso " + m.group("Msoso_94") + "ssimas" in TEXT and not m.group("Msoso_93") + "oso-" + m.group("Msoso_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_95>[a-zA-Zç]+)oso (?P<Msoso_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msoso_95") + "oso " + m.group("Msoso_96") + "simas" in TEXT and not " ou " + m.group("Msoso_95") + "oso " + m.group("Msoso_96") + "simas" in TEXT and not "s de " + m.group("Msoso_95") + "oso " + m.group("Msoso_96") + "simas" in TEXT and not "s do " + m.group("Msoso_95") + "oso " + m.group("Msoso_96") + "simas" in TEXT and not " o " + m.group("Msoso_95") + "oso " + m.group("Msoso_96") + "simas" in TEXT and not m.group("Msoso_95") + "oso-" + m.group("Msoso_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_97>[a-zA-Zç]+)oso (?P<Msoso_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_98").lower() in plvrMfoa and not " e " + m.group("Msoso_97") + "oso " + m.group("Msoso_98") + "as" in TEXT and not " ou " + m.group("Msoso_97") + "oso " + m.group("Msoso_98") + "as" in TEXT and not "s de " + m.group("Msoso_97") + "oso " + m.group("Msoso_98") + "as" in TEXT and not "s do " + m.group("Msoso_97") + "oso " + m.group("Msoso_98") + "as" in TEXT and not " o " + m.group("Msoso_97") + "oso " + m.group("Msoso_98") + "as" in TEXT and not m.group("Msoso_97") + "oso-" + m.group("Msoso_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_99>[a-zA-Zç]+)oso (?P<Msoso_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_100") in plvrMFm and not " e " + m.group("Msoso_99") + "oso " + m.group("Msoso_100") + "ns" in TEXT and not " ou " + m.group("Msoso_99") + "oso " + m.group("Msoso_100") + "ns" in TEXT and not "s de " + m.group("Msoso_99") + "oso " + m.group("Msoso_100") + "ns" in TEXT and not "s da " + m.group("Msoso_99") + "oso " + m.group("Msoso_100") + "ns" in TEXT and not " a " + m.group("Msoso_99") + "oso " + m.group("Msoso_100") + "ns" in TEXT and not m.group("Msoso_99") + "oso-" + m.group("Msoso_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msoso_101>[a-zA-Zç]+)oso (?P<Msoso_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "osos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msoso_102") in plvrMascm and not " e " + m.group("Msoso_101") + "oso " + m.group("Msoso_102") + "ns" in TEXT and not " ou " + m.group("Msoso_101") + "oso " + m.group("Msoso_102") + "ns" in TEXT and not "s de " + m.group("Msoso_101") + "oso " + m.group("Msoso_102") + "ns" in TEXT and not "s da " + m.group("Msoso_101") + "oso " + m.group("Msoso_102") + "ns" in TEXT and not " a " + m.group("Msoso_101") + "oso " + m.group("Msoso_102") + "ns" in TEXT and not m.group("Msoso_101") + "oso-" + m.group("Msoso_102") + "ns" in tCompostops'],
# ncia a
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_1>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_2").lower() in plvrFema and not " e " + m.group("Mscia_1") + m.group(2) + "ncia " + m.group("Mscia_2") +"s" in TEXT and not " ou " + m.group("Mscia_1") + m.group(2) + "ncia " + m.group("Mscia_2") + "s" in TEXT and not "s de " + m.group("Mscia_1") + m.group(2) + "ncia " + m.group("Mscia_2") + "s" in TEXT and not "s da " + m.group("Mscia_1") + m.group(2) + "ncia " + m.group("Mscia_2") + "s" in TEXT and not " a " + m.group("Mscia_1") + m.group(2) + "ncia " + m.group("Mscia_2") + "s" in TEXT and not m.group("Mscia_1") + m.group(2) + "ncia-" + m.group("Mscia_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_3>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_4").lower() in plvrMfoa and not " e " + m.group("Mscia_3") + m.group(2) + "ncia " + m.group("Mscia_4") + "as" in TEXT and not " ou " + m.group("Mscia_3") + m.group(2) + "ncia " + m.group("Mscia_4") + "as" in TEXT and not "s de " + m.group("Mscia_3") + m.group(2) + "ncia " + m.group("Mscia_4") + "as" in TEXT and not "s da " + m.group("Mscia_3") + m.group(2) + "ncia " + m.group("Mscia_4") + "as" in TEXT and not " a " + m.group("Mscia_3") + m.group(2) + "ncia " + m.group("Mscia_4") + "as" in TEXT and not m.group("Mscia_3") + m.group(2) + "ncia-" + m.group("Mscia_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_5>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + m.group(4) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscia_6").lower() in excAdo and not " e " + m.group("Mscia_5") + m.group(2) + "ncia " + m.group("Mscia_6") + m.group(4) + "dos" in TEXT and not " ou " + m.group("Mscia_5") + m.group(2) + "ncia " + m.group("Mscia_6") + m.group(4) + "dos" in TEXT and not "s de " + m.group("Mscia_5") + m.group(2) + "ncia " + m.group("Mscia_6") + m.group(4) + "dos" in TEXT and not "s da " + m.group("Mscia_5") + m.group(2) + "ncia " + m.group("Mscia_6") + m.group(4) + "dos" in TEXT and not " a " + m.group("Mscia_5") + m.group(2) + "ncia " + m.group("Mscia_6") + m.group(4) + "dos" in TEXT and not m.group("Mscia_5") + m.group(2) + "ncia-" + m.group("Mscia_6") + m.group(4) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_7>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscia_8").lower() in excIsta and not " e " + m.group("Mscia_7") + m.group(2) + "ncia " + m.group("Mscia_8") + "s" in TEXT and not " ou " + m.group("Mscia_7") + m.group(2) + "ncia " + m.group("Mscia_8") + "s" in TEXT and not "s de " + m.group("Mscia_7") + m.group(2) + "ncia " + m.group("Mscia_8") + "s" in TEXT and not "s da " + m.group("Mscia_7") + m.group(2) + "ncia " + m.group("Mscia_8") + "s" in TEXT and not " a " + m.group("Mscia_7") + m.group(2) + "ncia " + m.group("Mscia_8") + "s" in TEXT and not m.group("Mscia_7") + m.group(2) + "ncia-" + m.group("Mscia_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_9>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_10").lower() in plvrInva and not " e " + m.group("Mscia_9") + m.group(2) + "ncia " + m.group("Mscia_10") + "s" in TEXT and not " ou " + m.group("Mscia_9") + m.group(2) + "ncia " + m.group("Mscia_10") + "s" in TEXT and not "s de " + m.group("Mscia_9") + m.group(2) + "ncia " + m.group("Mscia_10") + "s" in TEXT and not "s da " + m.group("Mscia_9") + m.group(2) + "ncia " + m.group("Mscia_10") + "s" in TEXT and not " a " + m.group("Mscia_9") + m.group(2) + "ncia " + m.group("Mscia_10") + "s" in TEXT and not m.group("Mscia_9") + m.group(2) + "ncia-" + m.group("Mscia_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_11>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + m.group(4) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscia_12").lower() in excAdo and not " e " + m.group("Mscia_11") + m.group(2) + "ncia " + m.group("Mscia_12") + m.group(4) + "das" in TEXT and not " ou " + m.group("Mscia_11") + m.group(2) + "ncia " + m.group("Mscia_12") + m.group(4) + "das" in TEXT and not "s de " + m.group("Mscia_11") + m.group(2) + "ncia " + m.group("Mscia_12") + m.group(4) + "das" in TEXT and not "s da " + m.group("Mscia_11") + m.group(2) + "ncia " + m.group("Mscia_12") + m.group(4) + "das" in TEXT and not " a " + m.group("Mscia_11") + m.group(2) + "ncia " + m.group("Mscia_12") + m.group(4) + "das" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_13>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mscia_13") + m.group(2) + "ncia " + m.group("Mscia_14") + "osos" in TEXT and not " ou " + m.group("Mscia_13") + m.group(2) + "ncia " + m.group("Mscia_14") + "osos" in TEXT and not "s de " + m.group("Mscia_13") + m.group(2) + "ncia " + m.group("Mscia_14") + "osos" in TEXT and not "s da " + m.group("Mscia_13") + m.group(2) + "ncia " + m.group("Mscia_14") + "osos" in TEXT and not " a " + m.group("Mscia_13") + m.group(2) + "ncia " + m.group("Mscia_14") + "osos" in TEXT and not m.group("Mscia_13") + m.group(2) + "ncia-" + m.group("Mscia_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_15>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mscia_15") + m.group(2) + "ncia " + m.group("Mscia_16") + "osas" in TEXT and not " ou " + m.group("Mscia_15") + m.group(2) + "ncia " + m.group("Mscia_16") + "osas" in TEXT and not "s de " + m.group("Mscia_15") + m.group(2) + "ncia " + m.group("Mscia_16") + "osas" in TEXT and not "s da " + m.group("Mscia_15") + m.group(2) + "ncia " + m.group("Mscia_16") + "osas" in TEXT and not " a " + m.group("Mscia_15") + m.group(2) + "ncia " + m.group("Mscia_16") + "osas" in TEXT and not m.group("Mscia_15") + m.group(2) + "ncia-" + m.group("Mscia_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_17>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mscia_17") + m.group(2) + "ncia " + m.group("Mscia_18") + "ivas" in TEXT and not " ou " + m.group("Mscia_17") + m.group(2) + "ncia " + m.group("Mscia_18") + "ivas" in TEXT and not "s de " + m.group("Mscia_17") + m.group(2) + "ncia " + m.group("Mscia_18") + "ivas" in TEXT and not "s da " + m.group("Mscia_17") + m.group(2) + "ncia " + m.group("Mscia_18") + "ivas" in TEXT and not " a " + m.group("Mscia_17") + m.group(2) + "ncia " + m.group("Mscia_18") + "ivas" in TEXT and not m.group("Mscia_17") + m.group(2) + "ncia-" + m.group("Mscia_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_19>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mscia_19") + m.group(2) + "ncia " + m.group("Mscia_20") + "ivas" in TEXT and not " ou " + m.group("Mscia_19") + m.group(2) + "ncia " + m.group("Mscia_20") + "ivas" in TEXT and not "s de " + m.group("Mscia_19") + m.group(2) + "ncia " + m.group("Mscia_20") + "ivas" in TEXT and not "s da " + m.group("Mscia_19") + m.group(2) + "ncia " + m.group("Mscia_20") + "ivas" in TEXT and not " a " + m.group("Mscia_19") + m.group(2) + "ncia " + m.group("Mscia_20") + "ivas" in TEXT and not m.group("Mscia_19") + m.group(2) + "ncia-" + m.group("Mscia_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_21>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mscia_21") + m.group(2) + "ncia " + m.group("Mscia_22") + "icas" in TEXT and not " ou " + m.group("Mscia_21") + m.group(2) + "ncia " + m.group("Mscia_22") + "icas" in TEXT and not "s de " + m.group("Mscia_21") + m.group(2) + "ncia " + m.group("Mscia_22") + "icas" in TEXT and not "s da " + m.group("Mscia_21") + m.group(2) + "ncia " + m.group("Mscia_22") + "icas" in TEXT and not " a " + m.group("Mscia_21") + m.group(2) + "ncia " + m.group("Mscia_22") + "icas" in TEXT and not m.group("Mscia_21") + m.group(2) + "ncia-" + m.group("Mscia_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_23>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mscia_23") + m.group(2) + "ncia " + m.group("Mscia_24") + "icas" in TEXT and not " ou " + m.group("Mscia_23") + m.group(2) + "ncia " + m.group("Mscia_24") + "icas" in TEXT and not "s de " + m.group("Mscia_23") + m.group(2) + "ncia " + m.group("Mscia_24") + "icas" in TEXT and not "s da " + m.group("Mscia_23") + m.group(2) + "ncia " + m.group("Mscia_24") + "icas" in TEXT and not " a " + m.group("Mscia_23") + m.group(2) + "ncia " + m.group("Mscia_24") + "icas" in TEXT and not m.group("Mscia_23") + m.group(2) + "ncia-" + m.group("Mscia_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_25>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mscia_25") + m.group(2) + "ncia " + m.group("Mscia_26") + "icas" in TEXT and not " ou " + m.group("Mscia_25") + m.group(2) + "ncia " + m.group("Mscia_26") + "icas" in TEXT and not "s de " + m.group("Mscia_25") + m.group(2) + "ncia " + m.group("Mscia_26") + "icas" in TEXT and not "s da " + m.group("Mscia_25") + m.group(2) + "ncia " + m.group("Mscia_26") + "icas" in TEXT and not " a " + m.group("Mscia_25") + m.group(2) + "ncia " + m.group("Mscia_26") + "icas" in TEXT and not m.group("Mscia_25") + m.group(2) + "ncia-" + m.group("Mscia_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_27>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mscia_27") + m.group(2) + "ncia " + m.group("Mscia_28") + "escas" in TEXT and not " ou " + m.group("Mscia_27") + m.group(2) + "ncia " + m.group("Mscia_28") + "escas" in TEXT and not "s de " + m.group("Mscia_27") + m.group(2) + "ncia " + m.group("Mscia_28") + "escas" in TEXT and not "s da " + m.group("Mscia_27") + m.group(2) + "ncia " + m.group("Mscia_28") + "escas" in TEXT and not " a " + m.group("Mscia_27") + m.group(2) + "ncia " + m.group("Mscia_28") + "escas" in TEXT and not m.group("Mscia_27") + m.group(2) + "ncia-" + m.group("Mscia_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_29>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mscia_29") + m.group(2) + "ncia " + m.group("Mscia_30") + "idas" in TEXT and not " ou " + m.group("Mscia_29") + "s " + m.group("Mscia_30") + "idas" in TEXT and not "s de " + m.group("Mscia_29") + "s " + m.group("Mscia_30") + "idas" in TEXT and not "s da " + m.group("Mscia_29") + "s " + m.group("Mscia_30") + "idas" in TEXT and not " a " + m.group("Mscia_29") + "s " + m.group("Mscia_30") + "idas" in TEXT and not m.group("Mscia_29") + m.group(2) + "ncia-" + m.group("Mscia_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_31>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mscia_31") + m.group(2) + "ncia " + m.group("Mscia_32") + "logas" in TEXT and not " ou " + m.group("Mscia_31") + m.group(2) + "ncia " + m.group("Mscia_32") + "logas" in TEXT and not "s de " + m.group("Mscia_31") + m.group(2) + "ncia " + m.group("Mscia_32") + "logas" in TEXT and not "s da " + m.group("Mscia_31") + m.group(2) + "ncia " + m.group("Mscia_32") + "logas" in TEXT and not " a " + m.group("Mscia_31") + m.group(2) + "ncia " + m.group("Mscia_32") + "logas" in TEXT and not m.group("Mscia_31") + m.group(2) + "ncia-" + m.group("Mscia_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_33>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mscia_33") + m.group(2) + "ncia " + m.group("Mscia_34") + "rias" in TEXT and not " ou " + m.group("Mscia_33") + m.group(2) + "ncia " + m.group("Mscia_34") + "rias" in TEXT and not "s de " + m.group("Mscia_33") + m.group(2) + "ncia " + m.group("Mscia_34") + "rias" in TEXT and not "s da " + m.group("Mscia_33") + m.group(2) + "ncia " + m.group("Mscia_34") + "rias" in TEXT and not " a " + m.group("Mscia_33") + m.group(2) + "ncia " + m.group("Mscia_34") + "rias" in TEXT and not m.group("Mscia_33") + m.group(2) + "ncia-" + m.group("Mscia_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_35>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mscia_35") + m.group(2) + "ncia " + m.group("Mscia_36") + "ssimas" in TEXT and not " ou " + m.group("Mscia_35") + m.group(2) + "ncia " + m.group("Mscia_36") + "ssimas" in TEXT and not "s de " + m.group("Mscia_35") + m.group(2) + "ncia " + m.group("Mscia_36") + "ssimas" in TEXT and not "s da " + m.group("Mscia_35") + m.group(2) + "ncia " + m.group("Mscia_36") + "ssimas" in TEXT and not " a " + m.group("Mscia_35") + m.group(2) + "ncia " + m.group("Mscia_36") + "ssimas" in TEXT and not m.group("Mscia_35") + m.group(2) + "ncia-" + m.group("Mscia_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_37>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mscia_37") + m.group(2) + "ncia " + m.group("Mscia_38") + "simas" in TEXT and not " ou " + m.group("Mscia_37") + m.group(2) + "ncia " + m.group("Mscia_38") + "simas" in TEXT and not "s de " + m.group("Mscia_37") + m.group(2) + "ncia " + m.group("Mscia_38") + "simas" in TEXT and not "s da " + m.group("Mscia_37") + m.group(2) + "ncia " + m.group("Mscia_38") + "simas" in TEXT and not " a " + m.group("Mscia_37") + m.group(2) + "ncia " + m.group("Mscia_38") + "simas" in TEXT and not m.group("Mscia_37") + m.group(2) + "ncia-" + m.group("Mscia_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_41>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscia_42") in "D-d-" and not " e " + m.group("Mscia_41") + m.group(2) + "ncia " + m.group("Mscia_42") + "oras" in TEXT and not " ou " + m.group("Mscia_41") + m.group(2) + "ncia " + m.group("Mscia_42") + "oras" in TEXT and not "s de " + m.group("Mscia_41") + m.group(2) + "ncia " + m.group("Mscia_42") + "oras" in TEXT and not "s da " + m.group("Mscia_41") + m.group(2) + "ncia " + m.group("Mscia_42") + "oras" in TEXT and not " a " + m.group("Mscia_41") + m.group(2) + "ncia " + m.group("Mscia_42") + "oras" in TEXT and not m.group("Mscia_41") + m.group(2) + "ncia-" + m.group("Mscia_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_43>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_44") in plvrMfr and not " e " + m.group("Mscia_43") + m.group(2) + "ncia " + m.group("Mscia_44") + "es" in TEXT and not " ou " + m.group("Mscia_43") + m.group(2) + "ncia " + m.group("Mscia_44") + "es" in TEXT and not "s de " + m.group("Mscia_43") + m.group(2) + "ncia " + m.group("Mscia_44") + "es" in TEXT and not "s da " + m.group("Mscia_43") + m.group(2) + "ncia " + m.group("Mscia_44") + "es" in TEXT and not " a " + m.group("Mscia_43") + m.group(2) + "ncia " + m.group("Mscia_44") + "es" in TEXT and not m.group("Mscia_43") + m.group(2) + "ncia-" + m.group("Mscia_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_45>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_46") in plvrFemr and not " e " + m.group("Mscia_45") + m.group(2) + "ncia " + m.group("Mscia_46") + "es" in TEXT and not " ou " + m.group("Mscia_45") + m.group(2) + "ncia " + m.group("Mscia_46") + "es" in TEXT and not "s de " + m.group("Mscia_45") + m.group(2) + "ncia " + m.group("Mscia_46") + "es" in TEXT and not "s da " + m.group("Mscia_45") + m.group(2) + "ncia " + m.group("Mscia_46") + "es" in TEXT and not " a " + m.group("Mscia_45") + m.group(2) + "ncia " + m.group("Mscia_46") + "es" in TEXT and not m.group("Mscia_45") + m.group(2) + "ncia-" + m.group("Mscia_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_47>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_48") in plvrMfal and not " e " + m.group("Mscia_47") + m.group(2) + "ncia " + m.group("Mscia_48") + "is" in TEXT and not " ou " + m.group("Mscia_47") + m.group(2) + "ncia " + m.group("Mscia_48") + "is" in TEXT and not "s de " + m.group("Mscia_47") + m.group(2) + "ncia " + m.group("Mscia_48") + "is" in TEXT and not "s da " + m.group("Mscia_47") + m.group(2) + "ncia " + m.group("Mscia_48") + "is" in TEXT and not " a " + m.group("Mscia_47") + m.group(2) + "ncia " + m.group("Mscia_48") + "is" in TEXT and not m.group("Mscia_47") + m.group(2) + "ncia-" + m.group("Mscia_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_49>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_50") in plvrMfcao and not " e " + m.group("Mscia_49") + m.group(2) + "ncia " + m.group("Mscia_50") + "ões" in TEXT and not + " ou " + m.group("Mscia_49") + m.group(2) + "ncia " + m.group("Mscia_50") + "ões" in TEXT and not + "s de " + m.group("Mscia_49") + m.group(2) + "ncia " + m.group("Mscia_50") + "ões" in TEXT and not + "s da " + m.group("Mscia_49") + m.group(2) + "ncia " + m.group("Mscia_50") + "ões" in TEXT and not + " a " + m.group("Mscia_49") + m.group(2) + "ncia " + m.group("Mscia_50") + "ões" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_51>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscia_52") in plvrMascao and not " e " + m.group("Mscia_51") + m.group(2) + "ncia " + m.group("Mscia_52") + "ões" in TEXT and not " ou " + m.group("Mscia_51") + m.group(2) + "ncia " + m.group("Mscia_52") + "ões" in TEXT and not "s de " + m.group("Mscia_51") + m.group(2) + "ncia " + m.group("Mscia_52") + "ões" in TEXT and not "s da " + m.group("Mscia_51") + m.group(2) + "ncia " + m.group("Mscia_52") + "ões" in TEXT and not " a " + m.group("Mscia_51") + m.group(2) + "ncia " + m.group("Mscia_52") + "ões" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_53>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_54") in plvrFemao and not " e " + m.group("Mscia_53") + m.group(2) + "ncia " + m.group("Mscia_54") + "ões" in TEXT and not " ou " + m.group("Mscia_53") + m.group(2) + "ncia " + m.group("Mscia_54") + "ões" in TEXT and not "s de " + m.group("Mscia_53") + m.group(2) + "ncia " + m.group("Mscia_54") + "ões" in TEXT and not "s da " + m.group("Mscia_53") + m.group(2) + "ncia " + m.group("Mscia_54") + "ões" in TEXT and not " a " + m.group("Mscia_53") + m.group(2) + "ncia " + m.group("Mscia_54") + "ões" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_55>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mscia_55") + m.group(2) + "ncia " + m.group("Mscia_56") + "veis" in TEXT and not " ou " + m.group("Mscia_55") + m.group(2) + "ncia " + m.group("Mscia_56") + "veis" in TEXT and not "s de " + m.group("Mscia_55") + m.group(2) + "ncia " + m.group("Mscia_56") + "veis" in TEXT and not "s da " + m.group("Mscia_55") + m.group(2) + "ncia " + m.group("Mscia_56") + "veis" in TEXT and not " a " + m.group("Mscia_55") + m.group(2) + "ncia " + m.group("Mscia_56") + "veis" in TEXT and not m.group("Mscia_55") + m.group(2) + "ncia-" + m.group("Mscia_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_57>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_58").lower() in plvrMfe and not " e " + m.group("Mscia_57") + m.group(2) + "ncia " + m.group("Mscia_58") + "es" in TEXT and not " ou " + m.group("Mscia_57") + m.group(2) + "ncia " + m.group("Mscia_58") + "es" in TEXT and not "s de " + m.group("Mscia_57") + m.group(2) + "ncia " + m.group("Mscia_58") + "es" in TEXT and not "s da " + m.group("Mscia_57") + m.group(2) + "ncia " + m.group("Mscia_58") + "es" in TEXT and not " a " + m.group("Mscia_57") + m.group(2) + "ncia " + m.group("Mscia_58") + "es" in TEXT and not m.group("Mscia_57") + m.group(2) + "ncia-" + m.group("Mscia_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_59>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_60").lower() in plvrFeme and not " e " + m.group("Mscia_59") + m.group(2) + "ncia " + m.group("Mscia_60") + "es" in TEXT and not " ou " + m.group("Mscia_59") + m.group(2) + "ncia " + m.group("Mscia_60") + "es" in TEXT and not "s de " + m.group("Mscia_59") + m.group(2) + "ncia " + m.group("Mscia_60") + "es" in TEXT and not "s da " + m.group("Mscia_59") + m.group(2) + "ncia " + m.group("Mscia_60") + "es" in TEXT and not " a " + m.group("Mscia_59") + m.group(2) + "ncia " + m.group("Mscia_60") + "es" in TEXT and not m.group("Mscia_59") + m.group(2) + "ncia-" + m.group("Mscia_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_61>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_62") in plvrMfel and not " e " + m.group("Mscia_61") + m.group(2) + "ncia " + m.group("Mscia_62") + "éis" in TEXT and not " ou " + m.group("Mscia_61") + m.group(2) + "ncia " + m.group("Mscia_62") + "éis" in TEXT and not "s de " + m.group("Mscia_61") + m.group(2) + "ncia " + m.group("Mscia_62") + "éis" in TEXT and not "s da " + m.group("Mscia_61") + m.group(2) + "ncia " + m.group("Mscia_62") + "éis" in TEXT and not " a " + m.group("Mscia_61") + m.group(2) + "ncia " + m.group("Mscia_62") + "éis" in TEXT and not m.group("Mscia_61") + m.group(2) + "ncia-" + m.group("Mscia_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_63>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_64") in plvrFemel and not " e " + m.group("Mscia_63") + m.group(2) + "ncia " + m.group("Mscia_64") + "éis" in TEXT and not " ou " + m.group("Mscia_63") + m.group(2) + "ncia " + m.group("Mscia_64") + "éis" in TEXT and not "s de " + m.group("Mscia_63") + m.group(2) + "ncia " + m.group("Mscia_64") + "éis" in TEXT and not "s da " + m.group("Mscia_63") + m.group(2) + "ncia " + m.group("Mscia_64") + "éis" in TEXT and not " a " + m.group("Mscia_63") + m.group(2) + "ncia " + m.group("Mscia_64") + "éis" in TEXT and not m.group("Mscia_63") + m.group(2) + "ncia-" + m.group("Mscia_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_65>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_66") in plvrMfeu and not " e " + m.group("Mscia_65") + m.group(2) + "ncia " + m.group("Mscia_66") + "us" in TEXT and not " ou " + m.group("Mscia_65") + m.group(2) + "ncia " + m.group("Mscia_66") + "us" in TEXT and not "s de " + m.group("Mscia_65") + m.group(2) + "ncia " + m.group("Mscia_66") + "us" in TEXT and not "s da " + m.group("Mscia_65") + m.group(2) + "ncia " + m.group("Mscia_66") + "us" in TEXT and not " a " + m.group("Mscia_65") + m.group(2) + "ncia " + m.group("Mscia_66") + "us" in TEXT and not m.group("Mscia_65") + m.group(2) + "ncia-" + m.group("Mscia_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_67>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_68") in plvrFemu and not " e " + m.group("Mscia_67") + m.group(2) + "ncia " + m.group("Mscia_68") + "us" in TEXT and not " ou " + m.group("Mscia_67") + m.group(2) + "ncia " + m.group("Mscia_68") + "us" in TEXT and not "s de " + m.group("Mscia_67") + m.group(2) + "ncia " + m.group("Mscia_68") + "us" in TEXT and not "s da " + m.group("Mscia_67") + m.group(2) + "ncia " + m.group("Mscia_68") + "us" in TEXT and not " a " + m.group("Mscia_67") + m.group(2) + "ncia " + m.group("Mscia_68") + "us" in TEXT and not m.group("Mscia_67") + m.group(2) + "ncia-" + m.group("Mscia_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_69>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_70") in plvrInvaz and not " e " + m.group("Mscia_69") + m.group(2) + "ncia " + m.group("Mscia_70") + "zes" in TEXT and not " ou " + m.group("Mscia_69") + m.group(2) + "ncia " + m.group("Mscia_70") + "zes" in TEXT and not "s de " + m.group("Mscia_69") + m.group(2) + "ncia " + m.group("Mscia_70") + "zes" in TEXT and not "s da " + m.group("Mscia_69") + m.group(2) + "ncia " + m.group("Mscia_70") + "zes" in TEXT and not " a " + m.group("Mscia_69") + m.group(2) + "ncia " + m.group("Mscia_70") + "zes" in TEXT and not m.group("Mscia_69") + m.group(2) + "ncia-" + m.group("Mscia_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_71>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_72") in plvrFemz and not " e " + m.group("Mscia_71") + m.group(2) + "ncia " + m.group("Mscia_72") + "zes" in TEXT and not " ou " + m.group("Mscia_71") + m.group(2) + "ncia " + m.group("Mscia_72") + "zes" in TEXT and not "s de " + m.group("Mscia_71") + m.group(2) + "ncia " + m.group("Mscia_72") + "zes" in TEXT and not "s da " + m.group("Mscia_71") + m.group(2) + "ncia " + m.group("Mscia_72") + "zes" in TEXT and not " a " + m.group("Mscia_71") + m.group(2) + "ncia " + m.group("Mscia_72") + "zes" in TEXT and not m.group("Mscia_71") + m.group(2) + "ncia-" + m.group("Mscia_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_73>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_74") in pvrFeman and not " e " + m.group("Mscia_73") + m.group(2) + "ncia " + m.group("Mscia_74") + "s" in TEXT and not " ou " + m.group("Mscia_73") + m.group(2) + "ncia " + m.group("Mscia_74") + "s" in TEXT and not "s de " + m.group("Mscia_73") + m.group(2) + "ncia " + m.group("Mscia_74") + "s" in TEXT and not "s da " + m.group("Mscia_73") + m.group(2) + "ncia " + m.group("Mscia_74") + "s" in TEXT and not " a " + m.group("Mscia_73") + m.group(2) + "ncia " + m.group("Mscia_74") + "s" in TEXT and not m.group("Mscia_73") + m.group(2) + "ncia-" + m.group("Mscia_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_75>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_76>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_76") in plvrMFm and not " e " + m.group("Mscia_75") + m.group(2) + "ncia " + m.group("Mscia_76") + "ns" in TEXT and not " ou " + m.group("Mscia_75") + m.group(2) + "ncia " + m.group("Mscia_76") + "ns" in TEXT and not "s de " + m.group("Mscia_75") + m.group(2) + "ncia " + m.group("Mscia_76") + "ns" in TEXT and not "s da " + m.group("Mscia_75") + m.group(2) + "ncia " + m.group("Mscia_76") + "ns" in TEXT and not " a " + m.group("Mscia_75") + m.group(2) + "ncia " + m.group("Mscia_76") + "ns" in TEXT and not m.group("Mscia_75") + m.group(2) + "ncia-" + m.group("Mscia_76") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscia_77>[a-zA-Zç]+)([âêíôú])ncia (?P<Mscia_78>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + m.group(2) + "ncias " + m.group(3) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscia_78") in plvrFemm and not " e " + m.group("Mscia_77") + m.group(2) + "ncia " + m.group("Mscia_78") + "ns" in TEXT and not " ou " + m.group("Mscia_77") + m.group(2) + "ncia " + m.group("Mscia_78") + "ns" in TEXT and not "s de " + m.group("Mscia_77") + m.group(2) + "ncia " + m.group("Mscia_78") + "ns" in TEXT and not "s da " + m.group("Mscia_77") + m.group(2) + "ncia " + m.group("Mscia_78") + "ns" in TEXT and not " a " + m.group("Mscia_77") + m.group(2) + "ncia " + m.group("Mscia_78") + "ns" in TEXT and not m.group("Mscia_77") + m.group(2) + "ncia-" + m.group("Mscia_78") + "ns" in tCompostops'],
# iva a
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_1>[a-zA-Zç]+)iva (?P<Msiva_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_2").lower() in plvrFema and not " e " + m.group("Msiva_1") + "iva " + m.group("Msiva_2") +"s" in TEXT and not " ou " + m.group("Msiva_1") + "iva " + m.group("Msiva_2") + "s" in TEXT and not "s de " + m.group("Msiva_1") + "iva " + m.group("Msiva_2") + "s" in TEXT and not "s da " + m.group("Msiva_1") + "iva " + m.group("Msiva_2") + "s" in TEXT and not " a " + m.group("Msiva_1") + "iva " + m.group("Msiva_2") + "s" in TEXT and not m.group("Msiva_1") + "iva-" + m.group("Msiva_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_3>[a-zA-Zç]+)iva (?P<Msiva_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_4").lower() in plvrMfoa and not " e " + m.group("Msiva_3") + "iva " + m.group("Msiva_4") + "as" in TEXT and not " ou " + m.group("Msiva_3") + "iva " + m.group("Msiva_4") + "as" in TEXT and not "s de " + m.group("Msiva_3") + "iva " + m.group("Msiva_4") + "as" in TEXT and not "s da " + m.group("Msiva_3") + "iva " + m.group("Msiva_4") + "as" in TEXT and not " a " + m.group("Msiva_3") + "iva " + m.group("Msiva_4") + "as" in TEXT and not m.group("Msiva_3") + "iva-" + m.group("Msiva_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_5>[a-zA-Zç]+)iva (?P<Msiva_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msiva_6").lower() in excAdo and not " e " + m.group("Msiva_5") + "iva " + m.group("Msiva_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msiva_5") + "iva " + m.group("Msiva_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msiva_5") + "iva " + m.group("Msiva_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Msiva_5") + "iva " + m.group("Msiva_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Msiva_5") + "iva " + m.group("Msiva_6") + m.group(3) + "dos" in TEXT and not m.group("Msiva_5") + "iva-" + m.group("Msiva_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_7>[a-zA-Zç]+)iva (?P<Msiva_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msiva_8").lower() in excIsta and not " e " + m.group("Msiva_7") + "iva " + m.group("Msiva_8") + "s" in TEXT and not " ou " + m.group("Msiva_7") + "iva " + m.group("Msiva_8") + "s" in TEXT and not "s de " + m.group("Msiva_7") + "iva " + m.group("Msiva_8") + "s" in TEXT and not "s da " + m.group("Msiva_7") + "iva " + m.group("Msiva_8") + "s" in TEXT and not " a " + m.group("Msiva_7") + "iva " + m.group("Msiva_8") + "s" in TEXT and not m.group("Msiva_7") + "iva-" + m.group("Msiva_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_9>[a-zA-Zç]+)iva (?P<Msiva_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_10").lower() in plvrInva and not " e " + m.group("Msiva_9") + "iva " + m.group("Msiva_10") + "s" in TEXT and not " ou " + m.group("Msiva_9") + "iva " + m.group("Msiva_10") + "s" in TEXT and not "s de " + m.group("Msiva_9") + "iva " + m.group("Msiva_10") + "s" in TEXT and not "s da " + m.group("Msiva_9") + "iva " + m.group("Msiva_10") + "s" in TEXT and not " a " + m.group("Msiva_9") + "iva " + m.group("Msiva_10") + "s" in TEXT and not m.group("Msiva_9") + "iva-" + m.group("Msiva_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_11>[a-zA-Zç]+)iva (?P<Msiva_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msiva_12").lower() in excAdo and not " e " + m.group("Msiva_11") + "iva " + m.group("Msiva_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msiva_11") + "iva " + m.group("Msiva_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msiva_11") + "iva " + m.group("Msiva_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Msiva_11") + "iva " + m.group("Msiva_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Msiva_11") + "iva " + m.group("Msiva_12") + m.group(3) + "das" in TEXT and not m.group("Msiva_11") + "iva-" + m.group("Msiva_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_13>[a-zA-Zç]+)iva (?P<Msiva_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msiva_13") + "iva " + m.group("Msiva_14") + "osos" in TEXT and not " ou " + m.group("Msiva_13") + "iva " + m.group("Msiva_14") + "osos" in TEXT and not "s de " + m.group("Msiva_13") + "iva " + m.group("Msiva_14") + "osos" in TEXT and not "s da " + m.group("Msiva_13") + "iva " + m.group("Msiva_14") + "osos" in TEXT and not " a " + m.group("Msiva_13") + "iva " + m.group("Msiva_14") + "osos" in TEXT and not m.group("Msiva_13") + "iva-" + m.group("Msiva_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_15>[a-zA-Zç]+)iva (?P<Msiva_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msiva_15") + "iva " + m.group("Msiva_16") + "osas" in TEXT and not " ou " + m.group("Msiva_15") + "iva " + m.group("Msiva_16") + "osas" in TEXT and not "s de " + m.group("Msiva_15") + "iva " + m.group("Msiva_16") + "osas" in TEXT and not "s da " + m.group("Msiva_15") + "iva " + m.group("Msiva_16") + "osas" in TEXT and not " a " + m.group("Msiva_15") + "iva " + m.group("Msiva_16") + "osas" in TEXT and not m.group("Msiva_15") + "iva-" + m.group("Msiva_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_17>[a-zA-Zç]+)iva (?P<Msiva_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msiva_17") + "iva " + m.group("Msiva_18") + "ivas" in TEXT and not " ou " + m.group("Msiva_17") + "iva " + m.group("Msiva_18") + "ivas" in TEXT and not "s de " + m.group("Msiva_17") + "iva " + m.group("Msiva_18") + "ivas" in TEXT and not "s da " + m.group("Msiva_17") + "iva " + m.group("Msiva_18") + "ivas" in TEXT and not " a " + m.group("Msiva_17") + "iva " + m.group("Msiva_18") + "ivas" in TEXT and not m.group("Msiva_17") + "iva-" + m.group("Msiva_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_19>[a-zA-Zç]+)iva (?P<Msiva_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msiva_19") + "iva " + m.group("Msiva_20") + "ivas" in TEXT and not " ou " + m.group("Msiva_19") + "iva " + m.group("Msiva_20") + "ivas" in TEXT and not "s de " + m.group("Msiva_19") + "iva " + m.group("Msiva_20") + "ivas" in TEXT and not "s da " + m.group("Msiva_19") + "iva " + m.group("Msiva_20") + "ivas" in TEXT and not " a " + m.group("Msiva_19") + "iva " + m.group("Msiva_20") + "ivas" in TEXT and not m.group("Msiva_19") + "iva-" + m.group("Msiva_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_21>[a-zA-Zç]+)iva (?P<Msiva_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msiva_21") + "iva " + m.group("Msiva_22") + "icas" in TEXT and not " ou " + m.group("Msiva_21") + "iva " + m.group("Msiva_22") + "icas" in TEXT and not "s de " + m.group("Msiva_21") + "iva " + m.group("Msiva_22") + "icas" in TEXT and not "s da " + m.group("Msiva_21") + "iva " + m.group("Msiva_22") + "icas" in TEXT and not " a " + m.group("Msiva_21") + "iva " + m.group("Msiva_22") + "icas" in TEXT and not m.group("Msiva_21") + "iva-" + m.group("Msiva_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_23>[a-zA-Zç]+)iva (?P<Msiva_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msiva_23") + "iva " + m.group("Msiva_24") + "icas" in TEXT and not " ou " + m.group("Msiva_23") + "iva " + m.group("Msiva_24") + "icas" in TEXT and not "s de " + m.group("Msiva_23") + "iva " + m.group("Msiva_24") + "icas" in TEXT and not "s da " + m.group("Msiva_23") + "iva " + m.group("Msiva_24") + "icas" in TEXT and not " a " + m.group("Msiva_23") + "iva " + m.group("Msiva_24") + "icas" in TEXT and not m.group("Msiva_23") + "iva-" + m.group("Msiva_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_25>[a-zA-Zç]+)iva (?P<Msiva_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msiva_25") + "iva " + m.group("Msiva_26") + "icas" in TEXT and not " ou " + m.group("Msiva_25") + "iva " + m.group("Msiva_26") + "icas" in TEXT and not "s de " + m.group("Msiva_25") + "iva " + m.group("Msiva_26") + "icas" in TEXT and not "s da " + m.group("Msiva_25") + "iva " + m.group("Msiva_26") + "icas" in TEXT and not " a " + m.group("Msiva_25") + "iva " + m.group("Msiva_26") + "icas" in TEXT and not m.group("Msiva_25") + "iva-" + m.group("Msiva_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_27>[a-zA-Zç]+)iva (?P<Msiva_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msiva_27") + "iva " + m.group("Msiva_28") + "escas" in TEXT and not " ou " + m.group("Msiva_27") + "iva " + m.group("Msiva_28") + "escas" in TEXT and not "s de " + m.group("Msiva_27") + "iva " + m.group("Msiva_28") + "escas" in TEXT and not "s da " + m.group("Msiva_27") + "iva " + m.group("Msiva_28") + "escas" in TEXT and not " a " + m.group("Msiva_27") + "iva " + m.group("Msiva_28") + "escas" in TEXT and not m.group("Msiva_27") + "iva-" + m.group("Msiva_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_29>[a-zA-Zç]+)iva (?P<Msiva_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msiva_29") + "iva " + m.group("Msiva_30") + "idas" in TEXT and not " ou " + m.group("Msiva_29") + "s " + m.group("Msiva_30") + "idas" in TEXT and not "s de " + m.group("Msiva_29") + "s " + m.group("Msiva_30") + "idas" in TEXT and not "s da " + m.group("Msiva_29") + "s " + m.group("Msiva_30") + "idas" in TEXT and not " a " + m.group("Msiva_29") + "s " + m.group("Msiva_30") + "idas" in TEXT and not m.group("Msiva_29") + "iva-" + m.group("Msiva_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_31>[a-zA-Zç]+)iva (?P<Msiva_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msiva_31") + "iva " + m.group("Msiva_32") + "logas" in TEXT and not " ou " + m.group("Msiva_31") + "iva " + m.group("Msiva_32") + "logas" in TEXT and not "s de " + m.group("Msiva_31") + "iva " + m.group("Msiva_32") + "logas" in TEXT and not "s da " + m.group("Msiva_31") + "iva " + m.group("Msiva_32") + "logas" in TEXT and not " a " + m.group("Msiva_31") + "iva " + m.group("Msiva_32") + "logas" in TEXT and not m.group("Msiva_31") + "iva-" + m.group("Msiva_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_33>[a-zA-Zç]+)iva (?P<Msiva_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msiva_33") + "iva " + m.group("Msiva_34") + "rias" in TEXT and not " ou " + m.group("Msiva_33") + "iva " + m.group("Msiva_34") + "rias" in TEXT and not "s de " + m.group("Msiva_33") + "iva " + m.group("Msiva_34") + "rias" in TEXT and not "s da " + m.group("Msiva_33") + "iva " + m.group("Msiva_34") + "rias" in TEXT and not " a " + m.group("Msiva_33") + "iva " + m.group("Msiva_34") + "rias" in TEXT and not m.group("Msiva_33") + "iva-" + m.group("Msiva_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_35>[a-zA-Zç]+)iva (?P<Msiva_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msiva_35") + "iva " + m.group("Msiva_36") + "ssimas" in TEXT and not " ou " + m.group("Msiva_35") + "iva " + m.group("Msiva_36") + "ssimas" in TEXT and not "s de " + m.group("Msiva_35") + "iva " + m.group("Msiva_36") + "ssimas" in TEXT and not "s da " + m.group("Msiva_35") + "iva " + m.group("Msiva_36") + "ssimas" in TEXT and not " a " + m.group("Msiva_35") + "iva " + m.group("Msiva_36") + "ssimas" in TEXT and not m.group("Msiva_35") + "iva-" + m.group("Msiva_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_37>[a-zA-Zç]+)iva (?P<Msiva_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msiva_37") + "iva " + m.group("Msiva_38") + "simas" in TEXT and not " ou " + m.group("Msiva_37") + "iva " + m.group("Msiva_38") + "simas" in TEXT and not "s de " + m.group("Msiva_37") + "iva " + m.group("Msiva_38") + "simas" in TEXT and not "s da " + m.group("Msiva_37") + "iva " + m.group("Msiva_38") + "simas" in TEXT and not " a " + m.group("Msiva_37") + "iva " + m.group("Msiva_38") + "simas" in TEXT and not m.group("Msiva_37") + "iva-" + m.group("Msiva_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_41>[a-zA-Zç]+)iva (?P<Msiva_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msiva_42") in "D-d-" and not " e " + m.group("Msiva_41") + "iva " + m.group("Msiva_42") + "oras" in TEXT and not " ou " + m.group("Msiva_41") + "iva " + m.group("Msiva_42") + "oras" in TEXT and not "s de " + m.group("Msiva_41") + "iva " + m.group("Msiva_42") + "oras" in TEXT and not "s da " + m.group("Msiva_41") + "iva " + m.group("Msiva_42") + "oras" in TEXT and not " a " + m.group("Msiva_41") + "iva " + m.group("Msiva_42") + "oras" in TEXT and not m.group("Msiva_41") + "iva-" + m.group("Msiva_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_43>[a-zA-Zç]+)iva (?P<Msiva_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_44") in plvrMfr and not " e " + m.group("Msiva_43") + "iva " + m.group("Msiva_44") + "es" in TEXT and not " ou " + m.group("Msiva_43") + "iva " + m.group("Msiva_44") + "es" in TEXT and not "s de " + m.group("Msiva_43") + "iva " + m.group("Msiva_44") + "es" in TEXT and not "s da " + m.group("Msiva_43") + "iva " + m.group("Msiva_44") + "es" in TEXT and not " a " + m.group("Msiva_43") + "iva " + m.group("Msiva_44") + "es" in TEXT and not m.group("Msiva_43") + "iva-" + m.group("Msiva_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_45>[a-zA-Zç]+)iva (?P<Msiva_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_46") in plvrFemr and not " e " + m.group("Msiva_45") + "iva " + m.group("Msiva_46") + "es" in TEXT and not " ou " + m.group("Msiva_45") + "iva " + m.group("Msiva_46") + "es" in TEXT and not "s de " + m.group("Msiva_45") + "iva " + m.group("Msiva_46") + "es" in TEXT and not "s da " + m.group("Msiva_45") + "iva " + m.group("Msiva_46") + "es" in TEXT and not " a " + m.group("Msiva_45") + "iva " + m.group("Msiva_46") + "es" in TEXT and not m.group("Msiva_45") + "iva-" + m.group("Msiva_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_47>[a-zA-Zç]+)iva (?P<Msiva_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_48") in plvrMfal and not " e " + m.group("Msiva_47") + "iva " + m.group("Msiva_48") + "is" in TEXT and not " ou " + m.group("Msiva_47") + "iva " + m.group("Msiva_48") + "is" in TEXT and not "s de " + m.group("Msiva_47") + "iva " + m.group("Msiva_48") + "is" in TEXT and not "s da " + m.group("Msiva_47") + "iva " + m.group("Msiva_48") + "is" in TEXT and not " a " + m.group("Msiva_47") + "iva " + m.group("Msiva_48") + "is" in TEXT and not m.group("Msiva_47") + "iva-" + m.group("Msiva_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_49>[a-zA-Zç]+)iva (?P<Msiva_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_50") in plvrMfcao and not " e " + m.group("Msiva_49") + "iva " + m.group("Msiva_50") + "ões" in TEXT and not + " ou " + m.group("Msiva_49") + "iva " + m.group("Msiva_50") + "ões" in TEXT and not + "s de " + m.group("Msiva_49") + "iva " + m.group("Msiva_50") + "ões" in TEXT and not + "s da " + m.group("Msiva_49") + "iva " + m.group("Msiva_50") + "ões" in TEXT and not + " a " + m.group("Msiva_49") + "iva " + m.group("Msiva_50") + "ões" in TEXT and not m.group("Msiva_49") + "iva-" + m.group("Msiva_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_51>[a-zA-Zç]+)iva (?P<Msiva_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msiva_52") in plvrMascao and not " e " + m.group("Msiva_51") + "iva " + m.group("Msiva_52") + "ões" in TEXT and not " ou " + m.group("Msiva_51") + "iva " + m.group("Msiva_52") + "ões" in TEXT and not "s de " + m.group("Msiva_51") + "iva " + m.group("Msiva_52") + "ões" in TEXT and not "s da " + m.group("Msiva_51") + "iva " + m.group("Msiva_52") + "ões" in TEXT and not " a " + m.group("Msiva_51") + "iva " + m.group("Msiva_52") + "ões" in TEXT and not m.group("Msiva_51") + "iva-" + m.group("Msiva_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_53>[a-zA-Zç]+)iva (?P<Msiva_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_54") in plvrFemao and not " e " + m.group("Msiva_53") + "iva " + m.group("Msiva_54") + "ões" in TEXT and not " ou " + m.group("Msiva_53") + "iva " + m.group("Msiva_54") + "ões" in TEXT and not "s de " + m.group("Msiva_53") + "iva " + m.group("Msiva_54") + "ões" in TEXT and not "s da " + m.group("Msiva_53") + "iva " + m.group("Msiva_54") + "ões" in TEXT and not " a " + m.group("Msiva_53") + "iva " + m.group("Msiva_54") + "ões" in TEXT and not m.group("Msiva_53") + "iva-" + m.group("Msiva_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_55>[a-zA-Zç]+)iva (?P<Msiva_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msiva_55") + "iva " + m.group("Msiva_56") + "veis" in TEXT and not " ou " + m.group("Msiva_55") + "iva " + m.group("Msiva_56") + "veis" in TEXT and not "s de " + m.group("Msiva_55") + "iva " + m.group("Msiva_56") + "veis" in TEXT and not "s da " + m.group("Msiva_55") + "iva " + m.group("Msiva_56") + "veis" in TEXT and not " a " + m.group("Msiva_55") + "iva " + m.group("Msiva_56") + "veis" in TEXT and not m.group("Msiva_55") + "iva-" + m.group("Msiva_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_57>[a-zA-Zç]+)iva (?P<Msiva_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_58").lower() in plvrMfe and not " e " + m.group("Msiva_57") + "iva " + m.group("Msiva_58") + "es" in TEXT and not " ou " + m.group("Msiva_57") + "iva " + m.group("Msiva_58") + "es" in TEXT and not "s de " + m.group("Msiva_57") + "iva " + m.group("Msiva_58") + "es" in TEXT and not "s da " + m.group("Msiva_57") + "iva " + m.group("Msiva_58") + "es" in TEXT and not " a " + m.group("Msiva_57") + "iva " + m.group("Msiva_58") + "es" in TEXT and not m.group("Msiva_57") + "iva-" + m.group("Msiva_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_59>[a-zA-Zç]+)iva (?P<Msiva_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_60").lower() in plvrFeme and not " e " + m.group("Msiva_59") + "iva " + m.group("Msiva_60") + "es" in TEXT and not " ou " + m.group("Msiva_59") + "iva " + m.group("Msiva_60") + "es" in TEXT and not "s de " + m.group("Msiva_59") + "iva " + m.group("Msiva_60") + "es" in TEXT and not "s da " + m.group("Msiva_59") + "iva " + m.group("Msiva_60") + "es" in TEXT and not " a " + m.group("Msiva_59") + "iva " + m.group("Msiva_60") + "es" in TEXT and not m.group("Msiva_59") + "iva-" + m.group("Msiva_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_61>[a-zA-Zç]+)iva (?P<Msiva_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_62") in plvrMfel and not " e " + m.group("Msiva_61") + "iva " + m.group("Msiva_62") + "éis" in TEXT and not " ou " + m.group("Msiva_61") + "iva " + m.group("Msiva_62") + "éis" in TEXT and not "s de " + m.group("Msiva_61") + "iva " + m.group("Msiva_62") + "éis" in TEXT and not "s da " + m.group("Msiva_61") + "iva " + m.group("Msiva_62") + "éis" in TEXT and not " a " + m.group("Msiva_61") + "iva " + m.group("Msiva_62") + "éis" in TEXT and not m.group("Msiva_61") + "iva-" + m.group("Msiva_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_63>[a-zA-Zç]+)iva (?P<Msiva_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_64") in plvrFemel and not " e " + m.group("Msiva_63") + "iva " + m.group("Msiva_64") + "éis" in TEXT and not " ou " + m.group("Msiva_63") + "iva " + m.group("Msiva_64") + "éis" in TEXT and not "s de " + m.group("Msiva_63") + "iva " + m.group("Msiva_64") + "éis" in TEXT and not "s da " + m.group("Msiva_63") + "iva " + m.group("Msiva_64") + "éis" in TEXT and not " a " + m.group("Msiva_63") + "iva " + m.group("Msiva_64") + "éis" in TEXT and not m.group("Msiva_63") + "iva-" + m.group("Msiva_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_65>[a-zA-Zç]+)iva (?P<Msiva_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_66") in plvrMfeu and not " e " + m.group("Msiva_65") + "iva " + m.group("Msiva_66") + "us" in TEXT and not " ou " + m.group("Msiva_65") + "iva " + m.group("Msiva_66") + "us" in TEXT and not "s de " + m.group("Msiva_65") + "iva " + m.group("Msiva_66") + "us" in TEXT and not "s da " + m.group("Msiva_65") + "iva " + m.group("Msiva_66") + "us" in TEXT and not " a " + m.group("Msiva_65") + "iva " + m.group("Msiva_66") + "us" in TEXT and not m.group("Msiva_65") + "iva-" + m.group("Msiva_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_67>[a-zA-Zç]+)iva (?P<Msiva_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_68") in plvrFemu and not " e " + m.group("Msiva_67") + "iva " + m.group("Msiva_68") + "us" in TEXT and not " ou " + m.group("Msiva_67") + "iva " + m.group("Msiva_68") + "us" in TEXT and not "s de " + m.group("Msiva_67") + "iva " + m.group("Msiva_68") + "us" in TEXT and not "s da " + m.group("Msiva_67") + "iva " + m.group("Msiva_68") + "us" in TEXT and not " a " + m.group("Msiva_67") + "iva " + m.group("Msiva_68") + "us" in TEXT and not m.group("Msiva_67") + "iva-" + m.group("Msiva_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_69>[a-zA-Zç]+)iva (?P<Msiva_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_70") in plvrInvaz and not " e " + m.group("Msiva_69") + "iva " + m.group("Msiva_70") + "zes" in TEXT and not " ou " + m.group("Msiva_69") + "iva " + m.group("Msiva_70") + "zes" in TEXT and not "s de " + m.group("Msiva_69") + "iva " + m.group("Msiva_70") + "zes" in TEXT and not "s da " + m.group("Msiva_69") + "iva " + m.group("Msiva_70") + "zes" in TEXT and not " a " + m.group("Msiva_69") + "iva " + m.group("Msiva_70") + "zes" in TEXT and not m.group("Msiva_69") + "iva-" + m.group("Msiva_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_71>[a-zA-Zç]+)iva (?P<Msiva_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_72") in plvrFemz and not " e " + m.group("Msiva_71") + "iva " + m.group("Msiva_72") + "zes" in TEXT and not " ou " + m.group("Msiva_71") + "iva " + m.group("Msiva_72") + "zes" in TEXT and not "s de " + m.group("Msiva_71") + "iva " + m.group("Msiva_72") + "zes" in TEXT and not "s da " + m.group("Msiva_71") + "iva " + m.group("Msiva_72") + "zes" in TEXT and not " a " + m.group("Msiva_71") + "iva " + m.group("Msiva_72") + "zes" in TEXT and not m.group("Msiva_71") + "iva-" + m.group("Msiva_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_73>[a-zA-Zç]+)iva (?P<Msiva_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_74") in pvrFeman and not " e " + m.group("Msiva_73") + "iva " + m.group("Msiva_74") + "s" in TEXT and not " ou " + m.group("Msiva_73") + "iva " + m.group("Msiva_74") + "s" in TEXT and not "s de " + m.group("Msiva_73") + "iva " + m.group("Msiva_74") + "s" in TEXT and not "s da " + m.group("Msiva_73") + "iva " + m.group("Msiva_74") + "s" in TEXT and not " a " + m.group("Msiva_73") + "iva " + m.group("Msiva_74") + "s" in TEXT and not m.group("Msiva_73") + "iva-" + m.group("Msiva_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_99>[a-zA-Zç]+)iva (?P<Msiva_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_100") in plvrMFm and not " e " + m.group("Msiva_99") + "iva " + m.group("Msiva_100") + "ns" in TEXT and not " ou " + m.group("Msiva_99") + "iva " + m.group("Msiva_100") + "ns" in TEXT and not "s de " + m.group("Msiva_99") + "iva " + m.group("Msiva_100") + "ns" in TEXT and not "s da " + m.group("Msiva_99") + "iva " + m.group("Msiva_100") + "ns" in TEXT and not " a " + m.group("Msiva_99") + "iva " + m.group("Msiva_100") + "ns" in TEXT and not m.group("Msiva_99") + "iva-" + m.group("Msiva_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msiva_101>[a-zA-Zç]+)iva (?P<Msiva_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ivas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msiva_102") in plvrFemm and not " e " + m.group("Msiva_101") + "iva " + m.group("Msiva_102") + "ns" in TEXT and not " ou " + m.group("Msiva_101") + "iva " + m.group("Msiva_102") + "ns" in TEXT and not "s de " + m.group("Msiva_101") + "iva " + m.group("Msiva_102") + "ns" in TEXT and not "s da " + m.group("Msiva_101") + "iva " + m.group("Msiva_102") + "ns" in TEXT and not " a " + m.group("Msiva_101") + "iva " + m.group("Msiva_102") + "ns" in TEXT and not m.group("Msiva_101") + "iva-" + m.group("Msiva_102") + "ns" in tCompostops'],
# ivo o
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_1>[a-zA-Zç]+)ivo (?P<Msivo_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_2").lower() in plvrMasca and not " e " + m.group("Msivo_1") + "ivo " + m.group("Msivo_2") +"s" in TEXT and not " ou " + m.group("Msivo_1") + "ivo " + m.group("Msivo_2") + "s" in TEXT and not "s de " + m.group("Msivo_1") + "ivo " + m.group("Msivo_2") + "s" in TEXT and not "s do " + m.group("Msivo_1") + "ivo " + m.group("Msivo_2") + "s" in TEXT and not " o " + m.group("Msivo_1") + "ivo " + m.group("Msivo_2") + "s" in TEXT and not m.group("Msivo_1") + "ivo-" + m.group("Msivo_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_3>[a-zA-Zç]+)ivo (?P<Msivo_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_4").lower() in plvrMfoa and not " e " + m.group("Msivo_3") + "ivo " + m.group("Msivo_4") + "os" in TEXT and not " ou " + m.group("Msivo_3") + "ivo " + m.group("Msivo_4") + "os" in TEXT and not "s de " + m.group("Msivo_3") + "ivo " + m.group("Msivo_4") + "os" in TEXT and not "s do " + m.group("Msivo_3") + "ivo " + m.group("Msivo_4") + "os" in TEXT and not " o " + m.group("Msivo_3") + "ivo " + m.group("Msivo_4") + "os" in TEXT and not m.group("Msivo_3") + "ivo-" + m.group("Msivo_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_5>[a-zA-Zç]+)ivo (?P<Msivo_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msivo_6").lower() in excAdo and not " e " + m.group("Msivo_5") + "ivo " + m.group("Msivo_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msivo_5") + "ivo " + m.group("Msivo_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msivo_5") + "ivo " + m.group("Msivo_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msivo_5") + "ivo " + m.group("Msivo_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msivo_5") + "ivo " + m.group("Msivo_6") + m.group(3) + "dos" in TEXT and not m.group("Msivo_5") + "ivo-" + m.group("Msivo_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_7>[a-zA-Zç]+)ivo (?P<Msivo_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msivo_8").lower() in excIsta and not " e " + m.group("Msivo_7") + "ivo " + m.group("Msivo_8") + "s" in TEXT and not " ou " + m.group("Msivo_7") + "ivo " + m.group("Msivo_8") + "s" in TEXT and not "s de " + m.group("Msivo_7") + "ivo " + m.group("Msivo_8") + "s" in TEXT and not "s do " + m.group("Msivo_7") + "ivo " + m.group("Msivo_8") + "s" in TEXT and not " o " + m.group("Msivo_7") + "ivo " + m.group("Msivo_8") + "s" in TEXT and not m.group("Msivo_7") + "ivo-" + m.group("Msivo_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_9>[a-zA-Zç]+)ivo (?P<Msivo_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_10").lower() in plvrInva and not " e " + m.group("Msivo_9") + "ivo " + m.group("Msivo_10") + "s" in TEXT and not " ou " + m.group("Msivo_9") + "ivo " + m.group("Msivo_10") + "s" in TEXT and not "s de " + m.group("Msivo_9") + "ivo " + m.group("Msivo_10") + "s" in TEXT and not "s do " + m.group("Msivo_9") + "ivo " + m.group("Msivo_10") + "s" in TEXT and not " a " + m.group("Msivo_9") + "ivo " + m.group("Msivo_10") + "s" in TEXT and not m.group("Msivo_9") + "ivo-" + m.group("Msivo_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_11>[a-zA-Zç]+)ivo (?P<Msivo_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msivo_12").lower() in excAdo and not " e " + m.group("Msivo_11") + "ivo " + m.group("Msivo_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msivo_11") + "ivo " + m.group("Msivo_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msivo_11") + "ivo " + m.group("Msivo_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Msivo_11") + "ivo " + m.group("Msivo_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Msivo_11") + "ivo " + m.group("Msivo_12") + m.group(3) + "das" in TEXT and not m.group("Msivo_11") + "ivo-" + m.group("Msivo_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_13>[a-zA-Zç]+)ivo (?P<Msivo_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_13") + "ivo " + m.group("Msivo_14") + "osos" in TEXT and not " ou " + m.group("Msivo_13") + "ivo " + m.group("Msivo_14") + "osos" in TEXT and not "s de " + m.group("Msivo_13") + "ivo " + m.group("Msivo_14") + "osos" in TEXT and not "s do " + m.group("Msivo_13") + "ivo " + m.group("Msivo_14") + "osos" in TEXT and not " o " + m.group("Msivo_13") + "ivo " + m.group("Msivo_14") + "osos" in TEXT and not m.group("Msivo_13") + "ivo-" + m.group("Msivo_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_15>[a-zA-Zç]+)ivo (?P<Msivo_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_15") + "ivo " + m.group("Msivo_16") + "osas" in TEXT and not " ou " + m.group("Msivo_15") + "ivo " + m.group("Msivo_16") + "osas" in TEXT and not "s de " + m.group("Msivo_15") + "ivo " + m.group("Msivo_16") + "osas" in TEXT and not "s do " + m.group("Msivo_15") + "ivo " + m.group("Msivo_16") + "osas" in TEXT and not " o " + m.group("Msivo_15") + "ivo " + m.group("Msivo_16") + "osas" in TEXT and not m.group("Msivo_15") + "ivo-" + m.group("Msivo_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_17>[a-zA-Zç]+)ivo (?P<Msivo_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_17") + "ivo " + m.group("Msivo_18") + "ivas" in TEXT and not " ou " + m.group("Msivo_17") + "ivo " + m.group("Msivo_18") + "ivas" in TEXT and not "s de " + m.group("Msivo_17") + "ivo " + m.group("Msivo_18") + "ivas" in TEXT and not "s do " + m.group("Msivo_17") + "ivo " + m.group("Msivo_18") + "ivas" in TEXT and not " o " + m.group("Msivo_17") + "ivo " + m.group("Msivo_18") + "ivas" in TEXT and not m.group("Msivo_17") + "ivo-" + m.group("Msivo_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_19>[a-zA-Zç]+)ivo (?P<Msivo_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_19") + "ivo " + m.group("Msivo_20") + "ivas" in TEXT and not " ou " + m.group("Msivo_19") + "ivo " + m.group("Msivo_20") + "ivas" in TEXT and not "s de " + m.group("Msivo_19") + "ivo " + m.group("Msivo_20") + "ivas" in TEXT and not "s do " + m.group("Msivo_19") + "ivo " + m.group("Msivo_20") + "ivas" in TEXT and not " o " + m.group("Msivo_19") + "ivo " + m.group("Msivo_20") + "ivas" in TEXT and not m.group("Msivo_19") + "ivo-" + m.group("Msivo_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_21>[a-zA-Zç]+)ivo (?P<Msivo_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_21") + "ivo " + m.group("Msivo_22") + "icos" in TEXT and not " ou " + m.group("Msivo_21") + "ivo " + m.group("Msivo_22") + "icos" in TEXT and not "s de " + m.group("Msivo_21") + "ivo " + m.group("Msivo_22") + "icos" in TEXT and not "s do " + m.group("Msivo_21") + "ivo " + m.group("Msivo_22") + "icos" in TEXT and not " o " + m.group("Msivo_21") + "ivo " + m.group("Msivo_22") + "icos" in TEXT and not m.group("Msivo_21") + "ivo-" + m.group("Msivo_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_23>[a-zA-Zç]+)ivo (?P<Msivo_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_23") + "ivo " + m.group("Msivo_24") + "icos" in TEXT and not " ou " + m.group("Msivo_23") + "ivo " + m.group("Msivo_24") + "icos" in TEXT and not "s de " + m.group("Msivo_23") + "ivo " + m.group("Msivo_24") + "icos" in TEXT and not "s do " + m.group("Msivo_23") + "ivo " + m.group("Msivo_24") + "icos" in TEXT and not " o " + m.group("Msivo_23") + "ivo " + m.group("Msivo_24") + "icos" in TEXT and not m.group("Msivo_23") + "ivo-" + m.group("Msivo_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_25>[a-zA-Zç]+)ivo (?P<Msivo_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_25") + "ivo " + m.group("Msivo_26") + "icos" in TEXT and not " ou " + m.group("Msivo_25") + "ivo " + m.group("Msivo_26") + "icos" in TEXT and not "s de " + m.group("Msivo_25") + "ivo " + m.group("Msivo_26") + "icos" in TEXT and not "s do " + m.group("Msivo_25") + "ivo " + m.group("Msivo_26") + "icos" in TEXT and not " o " + m.group("Msivo_25") + "ivo " + m.group("Msivo_26") + "icos" in TEXT and not m.group("Msivo_25") + "ivo-" + m.group("Msivo_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_27>[a-zA-Zç]+)ivo (?P<Msivo_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_27") + "ivo " + m.group("Msivo_28") + "escos" in TEXT and not " ou " + m.group("Msivo_27") + "ivo " + m.group("Msivo_28") + "escos" in TEXT and not "s de " + m.group("Msivo_27") + "ivo " + m.group("Msivo_28") + "escos" in TEXT and not "s do " + m.group("Msivo_27") + "ivo " + m.group("Msivo_28") + "escos" in TEXT and not " o " + m.group("Msivo_27") + "ivo " + m.group("Msivo_28") + "escos" in TEXT and not m.group("Msivo_27") + "ivo-" + m.group("Msivo_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_29>[a-zA-Zç]+)ivo (?P<Msivo_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_29") + "ivo " + m.group("Msivo_30") + "idos" in TEXT and not " ou " + m.group("Msivo_29") + "s " + m.group("Msivo_30") + "idos" in TEXT and not "s de " + m.group("Msivo_29") + "s " + m.group("Msivo_30") + "idos" in TEXT and not "s do " + m.group("Msivo_29") + "s " + m.group("Msivo_30") + "idos" in TEXT and not " o " + m.group("Msivo_29") + "s " + m.group("Msivo_30") + "idos" in TEXT and not m.group("Msivo_29") + "ivo-" + m.group("Msivo_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_31>[a-zA-Zç]+)ivo (?P<Msivo_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_31") + "ivo " + m.group("Msivo_32") + "logos" in TEXT and not " ou " + m.group("Msivo_31") + "ivo " + m.group("Msivo_32") + "logos" in TEXT and not "s de " + m.group("Msivo_31") + "ivo " + m.group("Msivo_32") + "logos" in TEXT and not "s do " + m.group("Msivo_31") + "ivo " + m.group("Msivo_32") + "logos" in TEXT and not " o " + m.group("Msivo_31") + "ivo " + m.group("Msivo_32") + "logos" in TEXT and not m.group("Msivo_31") + "ivo-" + m.group("Msivo_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_33>[a-zA-Zç]+)ivo (?P<Msivo_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_33") + "ivo " + m.group("Msivo_34") + "rios" in TEXT and not " ou " + m.group("Msivo_33") + "ivo " + m.group("Msivo_34") + "rios" in TEXT and not "s de " + m.group("Msivo_33") + "ivo " + m.group("Msivo_34") + "rios" in TEXT and not "s do " + m.group("Msivo_33") + "ivo " + m.group("Msivo_34") + "rios" in TEXT and not " o " + m.group("Msivo_33") + "ivo " + m.group("Msivo_34") + "rios" in TEXT and not m.group("Msivo_33") + "ivo-" + m.group("Msivo_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_35>[a-zA-Zç]+)ivo (?P<Msivo_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_35") + "ivo " + m.group("Msivo_36") + "ssimos" in TEXT and not " ou " + m.group("Msivo_35") + "ivo " + m.group("Msivo_36") + "ssimos" in TEXT and not "s de " + m.group("Msivo_35") + "ivo " + m.group("Msivo_36") + "ssimos" in TEXT and not "s do " + m.group("Msivo_35") + "ivo " + m.group("Msivo_36") + "ssimos" in TEXT and not " o " + m.group("Msivo_35") + "ivo " + m.group("Msivo_36") + "ssimos" in TEXT and not m.group("Msivo_35") + "ivo-" + m.group("Msivo_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_37>[a-zA-Zç]+)ivo (?P<Msivo_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_37") + "ivo " + m.group("Msivo_38") + "simos" in TEXT and not " ou " + m.group("Msivo_37") + "ivo " + m.group("Msivo_38") + "simos" in TEXT and not "s de " + m.group("Msivo_37") + "ivo " + m.group("Msivo_38") + "simos" in TEXT and not "s do " + m.group("Msivo_37") + "ivo " + m.group("Msivo_38") + "simos" in TEXT and not " o " + m.group("Msivo_37") + "ivo " + m.group("Msivo_38") + "simos" in TEXT and not m.group("Msivo_37") + "ivo-" + m.group("Msivo_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_41>[a-zA-Zç]+)ivo (?P<Msivo_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msivo_42") in "D-d-" and not " e " + m.group("Msivo_41") + "ivo " + m.group("Msivo_42") + "ores" in TEXT and not " ou " + m.group("Msivo_41") + "ivo " + m.group("Msivo_42") + "ores" in TEXT and not "s de " + m.group("Msivo_41") + "ivo " + m.group("Msivo_42") + "ores" in TEXT and not "s do " + m.group("Msivo_41") + "ivo " + m.group("Msivo_42") + "ores" in TEXT and not " o " + m.group("Msivo_41") + "ivo " + m.group("Msivo_42") + "ores" in TEXT and not m.group("Msivo_41") + "ivo-" + m.group("Msivo_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_43>[a-zA-Zç]+)ivo (?P<Msivo_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_44") in plvrMfr and not " e " + m.group("Msivo_43") + "ivo " + m.group("Msivo_44") + "es" in TEXT and not " ou " + m.group("Msivo_43") + "ivo " + m.group("Msivo_44") + "es" in TEXT and not "s de " + m.group("Msivo_43") + "ivo " + m.group("Msivo_44") + "es" in TEXT and not "s do " + m.group("Msivo_43") + "ivo " + m.group("Msivo_44") + "es" in TEXT and not " o " + m.group("Msivo_43") + "ivo " + m.group("Msivo_44") + "es" in TEXT and not m.group("Msivo_43") + "ivo-" + m.group("Msivo_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_45>[a-zA-Zç]+)ivo (?P<Msivo_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_46") in plvrMascr and not " e " + m.group("Msivo_45") + "ivo " + m.group("Msivo_46") + "es" in TEXT and not " ou " + m.group("Msivo_45") + "ivo " + m.group("Msivo_46") + "es" in TEXT and not "s de " + m.group("Msivo_45") + "ivo " + m.group("Msivo_46") + "es" in TEXT and not "s do " + m.group("Msivo_45") + "ivo " + m.group("Msivo_46") + "es" in TEXT and not " o " + m.group("Msivo_45") + "ivo " + m.group("Msivo_46") + "es" in TEXT and not m.group("Msivo_45") + "ivo-" + m.group("Msivo_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_47>[a-zA-Zç]+)ivo (?P<Msivo_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_48") in plvrMfal and not " e " + m.group("Msivo_47") + "ivo " + m.group("Msivo_48") + "is" in TEXT and not " ou " + m.group("Msivo_47") + "ivo " + m.group("Msivo_48") + "is" in TEXT and not "s de " + m.group("Msivo_47") + "ivo " + m.group("Msivo_48") + "is" in TEXT and not "s do " + m.group("Msivo_47") + "ivo " + m.group("Msivo_48") + "is" in TEXT and not " o " + m.group("Msivo_47") + "ivo " + m.group("Msivo_48") + "is" in TEXT and not m.group("Msivo_47") + "ivo-" + m.group("Msivo_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_49>[a-zA-Zç]+)ivo (?P<Msivo_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_50") in plvrMfcao and not " e " + m.group("Msivo_49") + "ivo " + m.group("Msivo_50") + "ões" in TEXT and not + " ou " + m.group("Msivo_49") + "ivo " + m.group("Msivo_50") + "ões" in TEXT and not + "s de " + m.group("Msivo_49") + "ivo " + m.group("Msivo_50") + "ões" in TEXT and not + "s do " + m.group("Msivo_49") + "ivo " + m.group("Msivo_50") + "ões" in TEXT and not + " a " + m.group("Msivo_49") + "ivo " + m.group("Msivo_50") + "ões" in TEXT and not m.group("Msivo_49") + "ivo-" + m.group("Msivo_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_51>[a-zA-Zç]+)ivo (?P<Msivo_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_52") in plvrNfemcao and not " e " + m.group("Msivo_51") + "ivo " + m.group("Msivo_52") + "ões" in TEXT and not " ou " + m.group("Msivo_51") + "ivo " + m.group("Msivo_52") + "ões" in TEXT and not "s de " + m.group("Msivo_51") + "ivo " + m.group("Msivo_52") + "ões" in TEXT and not "s do " + m.group("Msivo_51") + "ivo " + m.group("Msivo_52") + "ões" in TEXT and not " o " + m.group("Msivo_51") + "ivo " + m.group("Msivo_52") + "ões" in TEXT and not m.group("Msivo_51") + "ivo-" + m.group("Msivo_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_55>[a-zA-Zç]+)ivo (?P<Msivo_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_55") + "ivo " + m.group("Msivo_56") + "veis" in TEXT and not " ou " + m.group("Msivo_55") + "ivo " + m.group("Msivo_56") + "veis" in TEXT and not "s de " + m.group("Msivo_55") + "ivo " + m.group("Msivo_56") + "veis" in TEXT and not "s do " + m.group("Msivo_55") + "ivo " + m.group("Msivo_56") + "veis" in TEXT and not " o " + m.group("Msivo_55") + "ivo " + m.group("Msivo_56") + "veis" in TEXT and not m.group("Msivo_55") + "ivo-" + m.group("Msivo_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_57>[a-zA-Zç]+)ivo (?P<Msivo_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_58").lower() in plvrMfe and not " e " + m.group("Msivo_57") + "ivo " + m.group("Msivo_58") + "es" in TEXT and not " ou " + m.group("Msivo_57") + "ivo " + m.group("Msivo_58") + "es" in TEXT and not "s de " + m.group("Msivo_57") + "ivo " + m.group("Msivo_58") + "es" in TEXT and not "s do " + m.group("Msivo_57") + "ivo " + m.group("Msivo_58") + "es" in TEXT and not " o " + m.group("Msivo_57") + "ivo " + m.group("Msivo_58") + "es" in TEXT and not m.group("Msivo_57") + "ivo-" + m.group("Msivo_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_59>[a-zA-Zç]+)ivo (?P<Msivo_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_60").lower() in plvrMasce and not " e " + m.group("Msivo_59") + "ivo " + m.group("Msivo_60") + "es" in TEXT and not " ou " + m.group("Msivo_59") + "ivo " + m.group("Msivo_60") + "es" in TEXT and not "s de " + m.group("Msivo_59") + "ivo " + m.group("Msivo_60") + "es" in TEXT and not "s do " + m.group("Msivo_59") + "ivo " + m.group("Msivo_60") + "es" in TEXT and not " o " + m.group("Msivo_59") + "ivo " + m.group("Msivo_60") + "es" in TEXT and not m.group("Msivo_59") + "ivo-" + m.group("Msivo_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_61>[a-zA-Zç]+)ivo (?P<Msivo_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_62") in plvrMfel and not " e " + m.group("Msivo_61") + "ivo " + m.group("Msivo_62") + "éis" in TEXT and not " ou " + m.group("Msivo_61") + "ivo " + m.group("Msivo_62") + "éis" in TEXT and not "s de " + m.group("Msivo_61") + "ivo " + m.group("Msivo_62") + "éis" in TEXT and not "s do " + m.group("Msivo_61") + "ivo " + m.group("Msivo_62") + "éis" in TEXT and not " o " + m.group("Msivo_61") + "ivo " + m.group("Msivo_62") + "éis" in TEXT and not m.group("Msivo_61") + "ivo-" + m.group("Msivo_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_63>[a-zA-Zç]+)ivo (?P<Msivo_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_64") in plvrMascel and not " e " + m.group("Msivo_63") + "ivo " + m.group("Msivo_64") + "éis" in TEXT and not " ou " + m.group("Msivo_63") + "ivo " + m.group("Msivo_64") + "éis" in TEXT and not "s de " + m.group("Msivo_63") + "ivo " + m.group("Msivo_64") + "éis" in TEXT and not "s do " + m.group("Msivo_63") + "ivo " + m.group("Msivo_64") + "éis" in TEXT and not " o " + m.group("Msivo_63") + "ivo " + m.group("Msivo_64") + "éis" in TEXT and not m.group("Msivo_63") + "ivo-" + m.group("Msivo_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_65>[a-zA-Zç]+)ivo (?P<Msivo_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_66") in plvrMfeu and not " e " + m.group("Msivo_65") + "ivo " + m.group("Msivo_66") + "us" in TEXT and not " ou " + m.group("Msivo_65") + "ivo " + m.group("Msivo_66") + "us" in TEXT and not "s de " + m.group("Msivo_65") + "ivo " + m.group("Msivo_66") + "us" in TEXT and not "s do " + m.group("Msivo_65") + "ivo " + m.group("Msivo_66") + "us" in TEXT and not " o " + m.group("Msivo_65") + "ivo " + m.group("Msivo_66") + "us" in TEXT and not m.group("Msivo_65") + "ivo-" + m.group("Msivo_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_67>[a-zA-Zç]+)ivo (?P<Msivo_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_68") in plvrMascu and not " e " + m.group("Msivo_67") + "ivo " + m.group("Msivo_68") + "us" in TEXT and not " ou " + m.group("Msivo_67") + "ivo " + m.group("Msivo_68") + "us" in TEXT and not "s de " + m.group("Msivo_67") + "ivo " + m.group("Msivo_68") + "us" in TEXT and not "s do " + m.group("Msivo_67") + "ivo " + m.group("Msivo_68") + "us" in TEXT and not " o " + m.group("Msivo_67") + "ivo " + m.group("Msivo_68") + "us" in TEXT and not m.group("Msivo_67") + "ivo-" + m.group("Msivo_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_69>[a-zA-Zç]+)ivo (?P<Msivo_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_70") in plvrInvaz and not " e " + m.group("Msivo_69") + "ivo " + m.group("Msivo_70") + "zes" in TEXT and not " ou " + m.group("Msivo_69") + "ivo " + m.group("Msivo_70") + "zes" in TEXT and not "s de " + m.group("Msivo_69") + "ivo " + m.group("Msivo_70") + "zes" in TEXT and not "s do " + m.group("Msivo_69") + "ivo " + m.group("Msivo_70") + "zes" in TEXT and not " o " + m.group("Msivo_69") + "ivo " + m.group("Msivo_70") + "zes" in TEXT and not m.group("Msivo_69") + "ivo-" + m.group("Msivo_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_71>[a-zA-Zç]+)ivo (?P<Msivo_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_72") in plvrMascz and not " e " + m.group("Msivo_71") + "ivo " + m.group("Msivo_72") + "zes" in TEXT and not " ou " + m.group("Msivo_71") + "ivo " + m.group("Msivo_72") + "zes" in TEXT and not "s de " + m.group("Msivo_71") + "ivo " + m.group("Msivo_72") + "zes" in TEXT and not "s do " + m.group("Msivo_71") + "ivo " + m.group("Msivo_72") + "zes" in TEXT and not " o " + m.group("Msivo_71") + "ivo " + m.group("Msivo_72") + "zes" in TEXT and not m.group("Msivo_71") + "ivo-" + m.group("Msivo_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_73>[a-zA-Zç]+)ivo (?P<Msivo_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_74") in pvrMascan and not " e " + m.group("Msivo_73") + "ivo " + m.group("Msivo_74") + "s" in TEXT and not " ou " + m.group("Msivo_73") + "ivo " + m.group("Msivo_74") + "s" in TEXT and not "s de " + m.group("Msivo_73") + "ivo " + m.group("Msivo_74") + "s" in TEXT and not "s do " + m.group("Msivo_73") + "ivo " + m.group("Msivo_74") + "s" in TEXT and not " o " + m.group("Msivo_73") + "ivo " + m.group("Msivo_74") + "s" in TEXT and not m.group("Msivo_73") + "ivo-" + m.group("Msivo_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_75>[a-zA-Zç]+)ivo (?P<Msivo_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_76").lower() in plvrMasco and not " e " + m.group("Msivo_75") + "ivo " + m.group("Msivo_76") +"s" in TEXT and not " ou " + m.group("Msivo_75") + "ivo " + m.group("Msivo_76") + "s" in TEXT and not "s de " + m.group("Msivo_75") + "ivo " + m.group("Msivo_76") + "s" in TEXT and not "s do " + m.group("Msivo_75") + "ivo " + m.group("Msivo_76") + "s" in TEXT and not " o " + m.group("Msivo_75") + "ivo " + m.group("Msivo_76") + "s" in TEXT and not m.group("Msivo_75") + "ivo-" + m.group("Msivo_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_77>[a-zA-Zç]+)ivo (?P<Msivo_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_77") + "ivo " + m.group("Msivo_78") + "inhos" in TEXT and not " ou " + m.group("Msivo_77") + "ivo " + m.group("Msivo_78") + "inhos" in TEXT and not "s de " + m.group("Msivo_77") + "ivo " + m.group("Msivo_78") + "inhos" in TEXT and not "s do " + m.group("Msivo_77") + "ivo " + m.group("Msivo_78") + "inhos" in TEXT and not " o " + m.group("Msivo_77") + "ivo " + m.group("Msivo_78") + "inhos" in TEXT and not m.group("Msivo_77") + "ivo-" + m.group("Msivo_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_79>[a-zA-Zç]+)ivo (?P<Msivo_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_79") + "ivo " + m.group("Msivo_80") + "icas" in TEXT and not " ou " + m.group("Msivo_79") + "ivo " + m.group("Msivo_80") + "icas" in TEXT and not "s de " + m.group("Msivo_79") + "ivo " + m.group("Msivo_80") + "icas" in TEXT and not "s do " + m.group("Msivo_79") + "ivo " + m.group("Msivo_80") + "icas" in TEXT and not " o " + m.group("Msivo_79") + "ivo " + m.group("Msivo_80") + "icas" in TEXT and not m.group("Msivo_79") + "ivo-" + m.group("Msivo_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_81>[a-zA-Zç]+)ivo (?P<Msivo_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_81") + "ivo " + m.group("Msivo_82") + "icas" in TEXT and not " ou " + m.group("Msivo_81") + "ivo " + m.group("Msivo_82") + "icas" in TEXT and not "s de " + m.group("Msivo_81") + "ivo " + m.group("Msivo_82") + "icas" in TEXT and not "s do " + m.group("Msivo_81") + "ivo " + m.group("Msivo_82") + "icas" in TEXT and not " o " + m.group("Msivo_81") + "ivo " + m.group("Msivo_82") + "icas" in TEXT and not m.group("Msivo_81") + "ivo-" + m.group("Msivo_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_83>[a-zA-Zç]+)ivo (?P<Msivo_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_83") + "ivo " + m.group("Msivo_84") + "icas" in TEXT and not " ou " + m.group("Msivo_83") + "ivo " + m.group("Msivo_84") + "icas" in TEXT and not "s de " + m.group("Msivo_83") + "ivo " + m.group("Msivo_84") + "icas" in TEXT and not "s do " + m.group("Msivo_83") + "ivo " + m.group("Msivo_84") + "icas" in TEXT and not " o " + m.group("Msivo_83") + "ivo " + m.group("Msivo_84") + "icas" in TEXT and not m.group("Msivo_83") + "ivo-" + m.group("Msivo_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_85>[a-zA-Zç]+)ivo (?P<Msivo_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_85") + "ivo " + m.group("Msivo_86") + "escas" in TEXT and not " ou " + m.group("Msivo_85") + "ivo " + m.group("Msivo_86") + "escas" in TEXT and not "s de " + m.group("Msivo_85") + "ivo " + m.group("Msivo_86") + "escas" in TEXT and not "s do " + m.group("Msivo_85") + "ivo " + m.group("Msivo_86") + "escas" in TEXT and not " o " + m.group("Msivo_85") + "ivo " + m.group("Msivo_86") + "escas" in TEXT and not m.group("Msivo_85") + "ivo-" + m.group("Msivo_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_87>[a-zA-Zç]+)ivo (?P<Msivo_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_87") + "ivo " + m.group("Msivo_88") + "idas" in TEXT and not " ou " + m.group("Msivo_87") + "s " + m.group("Msivo_88") + "idas" in TEXT and not "s de " + m.group("Msivo_87") + "s " + m.group("Msivo_88") + "idas" in TEXT and not "s do " + m.group("Msivo_87") + "s " + m.group("Msivo_88") + "idas" in TEXT and not " o " + m.group("Msivo_87") + "s " + m.group("Msivo_88") + "idas" in TEXT and not m.group("Msivo_87") + "ivo-" + m.group("Msivo_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_89>[a-zA-Zç]+)ivo (?P<Msivo_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_89") + "ivo " + m.group("Msivo_90") + "logas" in TEXT and not " ou " + m.group("Msivo_89") + "ivo " + m.group("Msivo_90") + "logas" in TEXT and not "s de " + m.group("Msivo_89") + "ivo " + m.group("Msivo_90") + "logas" in TEXT and not "s do " + m.group("Msivo_89") + "ivo " + m.group("Msivo_90") + "logas" in TEXT and not " o " + m.group("Msivo_89") + "ivo " + m.group("Msivo_90") + "logas" in TEXT and not m.group("Msivo_89") + "ivo-" + m.group("Msivo_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_91>[a-zA-Zç]+)ivo (?P<Msivo_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_91") + "ivo " + m.group("Msivo_92") + "rias" in TEXT and not " ou " + m.group("Msivo_91") + "ivo " + m.group("Msivo_92") + "rias" in TEXT and not "s de " + m.group("Msivo_91") + "ivo " + m.group("Msivo_92") + "rias" in TEXT and not "s do " + m.group("Msivo_91") + "ivo " + m.group("Msivo_92") + "rias" in TEXT and not " o " + m.group("Msivo_91") + "ivo " + m.group("Msivo_92") + "rias" in TEXT and not m.group("Msivo_91") + "ivo-" + m.group("Msivo_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_93>[a-zA-Zç]+)ivo (?P<Msivo_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_93") + "ivo " + m.group("Msivo_94") + "ssimas" in TEXT and not " ou " + m.group("Msivo_93") + "ivo " + m.group("Msivo_94") + "ssimas" in TEXT and not "s de " + m.group("Msivo_93") + "ivo " + m.group("Msivo_94") + "ssimas" in TEXT and not "s do " + m.group("Msivo_93") + "ivo " + m.group("Msivo_94") + "ssimas" in TEXT and not " o " + m.group("Msivo_93") + "ivo " + m.group("Msivo_94") + "ssimas" in TEXT and not m.group("Msivo_93") + "ivo-" + m.group("Msivo_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_95>[a-zA-Zç]+)ivo (?P<Msivo_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msivo_95") + "ivo " + m.group("Msivo_96") + "simas" in TEXT and not " ou " + m.group("Msivo_95") + "ivo " + m.group("Msivo_96") + "simas" in TEXT and not "s de " + m.group("Msivo_95") + "ivo " + m.group("Msivo_96") + "simas" in TEXT and not "s do " + m.group("Msivo_95") + "ivo " + m.group("Msivo_96") + "simas" in TEXT and not " o " + m.group("Msivo_95") + "ivo " + m.group("Msivo_96") + "simas" in TEXT and not m.group("Msivo_95") + "ivo-" + m.group("Msivo_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_97>[a-zA-Zç]+)ivo (?P<Msivo_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_98").lower() in plvrMfoa and not " e " + m.group("Msivo_97") + "ivo " + m.group("Msivo_98") + "as" in TEXT and not " ou " + m.group("Msivo_97") + "ivo " + m.group("Msivo_98") + "as" in TEXT and not "s de " + m.group("Msivo_97") + "ivo " + m.group("Msivo_98") + "as" in TEXT and not "s do " + m.group("Msivo_97") + "ivo " + m.group("Msivo_98") + "as" in TEXT and not " o " + m.group("Msivo_97") + "ivo " + m.group("Msivo_98") + "as" in TEXT and not m.group("Msivo_97") + "ivo-" + m.group("Msivo_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_99>[a-zA-Zç]+)ivo (?P<Msivo_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_100") in plvrMFm and not " e " + m.group("Msivo_99") + "ivo " + m.group("Msivo_100") + "ns" in TEXT and not " ou " + m.group("Msivo_99") + "ivo " + m.group("Msivo_100") + "ns" in TEXT and not "s de " + m.group("Msivo_99") + "ivo " + m.group("Msivo_100") + "ns" in TEXT and not "s da " + m.group("Msivo_99") + "ivo " + m.group("Msivo_100") + "ns" in TEXT and not " a " + m.group("Msivo_99") + "ivo " + m.group("Msivo_100") + "ns" in TEXT and not m.group("Msivo_99") + "ivo-" + m.group("Msivo_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msivo_101>[a-zA-Zç]+)ivo (?P<Msivo_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ivos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msivo_102") in plvrMascm and not " e " + m.group("Msivo_101") + "ivo " + m.group("Msivo_102") + "ns" in TEXT and not " ou " + m.group("Msivo_101") + "ivo " + m.group("Msivo_102") + "ns" in TEXT and not "s de " + m.group("Msivo_101") + "ivo " + m.group("Msivo_102") + "ns" in TEXT and not "s da " + m.group("Msivo_101") + "ivo " + m.group("Msivo_102") + "ns" in TEXT and not " a " + m.group("Msivo_101") + "ivo " + m.group("Msivo_102") + "ns" in TEXT and not m.group("Msivo_101") + "ivo-" + m.group("Msivo_102") + "ns" in tCompostops'],
# mento o
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_1>[a-zA-Zç]+)mento (?P<Msmto_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_2").lower() in plvrMasca and not " e " + m.group("Msmto_1") + "mento " + m.group("Msmto_2") +"s" in TEXT and not " ou " + m.group("Msmto_1") + "mento " + m.group("Msmto_2") + "s" in TEXT and not "s de " + m.group("Msmto_1") + "mento " + m.group("Msmto_2") + "s" in TEXT and not "s do " + m.group("Msmto_1") + "mento " + m.group("Msmto_2") + "s" in TEXT and not " o " + m.group("Msmto_1") + "mento " + m.group("Msmto_2") + "s" in TEXT and not m.group("Msmto_1") + "oso-" + m.group("Msmto_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_3>[a-zA-Zç]+)mento (?P<Msmto_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_4").lower() in plvrMfoa and not " e " + m.group("Msmto_3") + "mento " + m.group("Msmto_4") + "os" in TEXT and not " ou " + m.group("Msmto_3") + "mento " + m.group("Msmto_4") + "os" in TEXT and not "s de " + m.group("Msmto_3") + "mento " + m.group("Msmto_4") + "os" in TEXT and not "s do " + m.group("Msmto_3") + "mento " + m.group("Msmto_4") + "os" in TEXT and not " o " + m.group("Msmto_3") + "mento " + m.group("Msmto_4") + "os" in TEXT and not m.group("Msmto_3") + "oso-" + m.group("Msmto_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_5>[a-zA-Zç]+)mento (?P<Msmto_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmto_6").lower() in excAdo and not " e " + m.group("Msmto_5") + "mento " + m.group("Msmto_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msmto_5") + "mento " + m.group("Msmto_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msmto_5") + "mento " + m.group("Msmto_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msmto_5") + "mento " + m.group("Msmto_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msmto_5") + "mento " + m.group("Msmto_6") + m.group(3) + "dos" in TEXT and not m.group("Msmto_5") + "oso-" + m.group("Msmto_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_7>[a-zA-Zç]+)mento (?P<Msmto_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmto_8").lower() in excIsta and not " e " + m.group("Msmto_7") + "mento " + m.group("Msmto_8") + "s" in TEXT and not " ou " + m.group("Msmto_7") + "mento " + m.group("Msmto_8") + "s" in TEXT and not "s de " + m.group("Msmto_7") + "mento " + m.group("Msmto_8") + "s" in TEXT and not "s do " + m.group("Msmto_7") + "mento " + m.group("Msmto_8") + "s" in TEXT and not " o " + m.group("Msmto_7") + "mento " + m.group("Msmto_8") + "s" in TEXT and not m.group("Msmto_7") + "oso-" + m.group("Msmto_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_9>[a-zA-Zç]+)mento (?P<Msmto_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_10").lower() in plvrInva and not " e " + m.group("Msmto_9") + "mento " + m.group("Msmto_10") + "s" in TEXT and not " ou " + m.group("Msmto_9") + "mento " + m.group("Msmto_10") + "s" in TEXT and not "s de " + m.group("Msmto_9") + "mento " + m.group("Msmto_10") + "s" in TEXT and not "s do " + m.group("Msmto_9") + "mento " + m.group("Msmto_10") + "s" in TEXT and not " a " + m.group("Msmto_9") + "mento " + m.group("Msmto_10") + "s" in TEXT and not m.group("Msmto_9") + "oso-" + m.group("Msmto_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_11>[a-zA-Zç]+)mento (?P<Msmto_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmto_12").lower() in excAdo and not " e " + m.group("Msmto_11") + "mento " + m.group("Msmto_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msmto_11") + "mento " + m.group("Msmto_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msmto_11") + "mento " + m.group("Msmto_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Msmto_11") + "mento " + m.group("Msmto_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Msmto_11") + "mento " + m.group("Msmto_12") + m.group(3) + "das" in TEXT and not m.group("Msmto_11") + "oso-" + m.group("Msmto_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_13>[a-zA-Zç]+)mento (?P<Msmto_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_13") + "mento " + m.group("Msmto_14") + "osos" in TEXT and not " ou " + m.group("Msmto_13") + "mento " + m.group("Msmto_14") + "osos" in TEXT and not "s de " + m.group("Msmto_13") + "mento " + m.group("Msmto_14") + "osos" in TEXT and not "s do " + m.group("Msmto_13") + "mento " + m.group("Msmto_14") + "osos" in TEXT and not " o " + m.group("Msmto_13") + "mento " + m.group("Msmto_14") + "osos" in TEXT and not m.group("Msmto_13") + "oso-" + m.group("Msmto_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_15>[a-zA-Zç]+)mento (?P<Msmto_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_15") + "mento " + m.group("Msmto_16") + "osas" in TEXT and not " ou " + m.group("Msmto_15") + "mento " + m.group("Msmto_16") + "osas" in TEXT and not "s de " + m.group("Msmto_15") + "mento " + m.group("Msmto_16") + "osas" in TEXT and not "s do " + m.group("Msmto_15") + "mento " + m.group("Msmto_16") + "osas" in TEXT and not " o " + m.group("Msmto_15") + "mento " + m.group("Msmto_16") + "osas" in TEXT and not m.group("Msmto_15") + "oso-" + m.group("Msmto_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_17>[a-zA-Zç]+)mento (?P<Msmto_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_17") + "mento " + m.group("Msmto_18") + "ivas" in TEXT and not " ou " + m.group("Msmto_17") + "mento " + m.group("Msmto_18") + "ivas" in TEXT and not "s de " + m.group("Msmto_17") + "mento " + m.group("Msmto_18") + "ivas" in TEXT and not "s do " + m.group("Msmto_17") + "mento " + m.group("Msmto_18") + "ivas" in TEXT and not " o " + m.group("Msmto_17") + "mento " + m.group("Msmto_18") + "ivas" in TEXT and not m.group("Msmto_17") + "oso-" + m.group("Msmto_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_19>[a-zA-Zç]+)mento (?P<Msmto_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_19") + "mento " + m.group("Msmto_20") + "ivas" in TEXT and not " ou " + m.group("Msmto_19") + "mento " + m.group("Msmto_20") + "ivas" in TEXT and not "s de " + m.group("Msmto_19") + "mento " + m.group("Msmto_20") + "ivas" in TEXT and not "s do " + m.group("Msmto_19") + "mento " + m.group("Msmto_20") + "ivas" in TEXT and not " o " + m.group("Msmto_19") + "mento " + m.group("Msmto_20") + "ivas" in TEXT and not m.group("Msmto_19") + "oso-" + m.group("Msmto_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_21>[a-zA-Zç]+)mento (?P<Msmto_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_21") + "mento " + m.group("Msmto_22") + "icos" in TEXT and not " ou " + m.group("Msmto_21") + "mento " + m.group("Msmto_22") + "icos" in TEXT and not "s de " + m.group("Msmto_21") + "mento " + m.group("Msmto_22") + "icos" in TEXT and not "s do " + m.group("Msmto_21") + "mento " + m.group("Msmto_22") + "icos" in TEXT and not " o " + m.group("Msmto_21") + "mento " + m.group("Msmto_22") + "icos" in TEXT and not m.group("Msmto_21") + "oso-" + m.group("Msmto_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_23>[a-zA-Zç]+)mento (?P<Msmto_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_23") + "mento " + m.group("Msmto_24") + "icos" in TEXT and not " ou " + m.group("Msmto_23") + "mento " + m.group("Msmto_24") + "icos" in TEXT and not "s de " + m.group("Msmto_23") + "mento " + m.group("Msmto_24") + "icos" in TEXT and not "s do " + m.group("Msmto_23") + "mento " + m.group("Msmto_24") + "icos" in TEXT and not " o " + m.group("Msmto_23") + "mento " + m.group("Msmto_24") + "icos" in TEXT and not m.group("Msmto_23") + "oso-" + m.group("Msmto_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_25>[a-zA-Zç]+)mento (?P<Msmto_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_25") + "mento " + m.group("Msmto_26") + "icos" in TEXT and not " ou " + m.group("Msmto_25") + "mento " + m.group("Msmto_26") + "icos" in TEXT and not "s de " + m.group("Msmto_25") + "mento " + m.group("Msmto_26") + "icos" in TEXT and not "s do " + m.group("Msmto_25") + "mento " + m.group("Msmto_26") + "icos" in TEXT and not " o " + m.group("Msmto_25") + "mento " + m.group("Msmto_26") + "icos" in TEXT and not m.group("Msmto_25") + "oso-" + m.group("Msmto_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_27>[a-zA-Zç]+)mento (?P<Msmto_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_27") + "mento " + m.group("Msmto_28") + "escos" in TEXT and not " ou " + m.group("Msmto_27") + "mento " + m.group("Msmto_28") + "escos" in TEXT and not "s de " + m.group("Msmto_27") + "mento " + m.group("Msmto_28") + "escos" in TEXT and not "s do " + m.group("Msmto_27") + "mento " + m.group("Msmto_28") + "escos" in TEXT and not " o " + m.group("Msmto_27") + "mento " + m.group("Msmto_28") + "escos" in TEXT and not m.group("Msmto_27") + "oso-" + m.group("Msmto_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_29>[a-zA-Zç]+)mento (?P<Msmto_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_29") + "mento " + m.group("Msmto_30") + "idos" in TEXT and not " ou " + m.group("Msmto_29") + "s " + m.group("Msmto_30") + "idos" in TEXT and not "s de " + m.group("Msmto_29") + "s " + m.group("Msmto_30") + "idos" in TEXT and not "s do " + m.group("Msmto_29") + "s " + m.group("Msmto_30") + "idos" in TEXT and not " o " + m.group("Msmto_29") + "s " + m.group("Msmto_30") + "idos" in TEXT and not m.group("Msmto_29") + "oso-" + m.group("Msmto_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_31>[a-zA-Zç]+)mento (?P<Msmto_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_31") + "mento " + m.group("Msmto_32") + "logos" in TEXT and not " ou " + m.group("Msmto_31") + "mento " + m.group("Msmto_32") + "logos" in TEXT and not "s de " + m.group("Msmto_31") + "mento " + m.group("Msmto_32") + "logos" in TEXT and not "s do " + m.group("Msmto_31") + "mento " + m.group("Msmto_32") + "logos" in TEXT and not " o " + m.group("Msmto_31") + "mento " + m.group("Msmto_32") + "logos" in TEXT and not m.group("Msmto_31") + "oso-" + m.group("Msmto_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_33>[a-zA-Zç]+)mento (?P<Msmto_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_33") + "mento " + m.group("Msmto_34") + "rios" in TEXT and not " ou " + m.group("Msmto_33") + "mento " + m.group("Msmto_34") + "rios" in TEXT and not "s de " + m.group("Msmto_33") + "mento " + m.group("Msmto_34") + "rios" in TEXT and not "s do " + m.group("Msmto_33") + "mento " + m.group("Msmto_34") + "rios" in TEXT and not " o " + m.group("Msmto_33") + "mento " + m.group("Msmto_34") + "rios" in TEXT and not m.group("Msmto_33") + "oso-" + m.group("Msmto_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_35>[a-zA-Zç]+)mento (?P<Msmto_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_35") + "mento " + m.group("Msmto_36") + "ssimos" in TEXT and not " ou " + m.group("Msmto_35") + "mento " + m.group("Msmto_36") + "ssimos" in TEXT and not "s de " + m.group("Msmto_35") + "mento " + m.group("Msmto_36") + "ssimos" in TEXT and not "s do " + m.group("Msmto_35") + "mento " + m.group("Msmto_36") + "ssimos" in TEXT and not " o " + m.group("Msmto_35") + "mento " + m.group("Msmto_36") + "ssimos" in TEXT and not m.group("Msmto_35") + "oso-" + m.group("Msmto_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_37>[a-zA-Zç]+)mento (?P<Msmto_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_37") + "mento " + m.group("Msmto_38") + "simos" in TEXT and not " ou " + m.group("Msmto_37") + "mento " + m.group("Msmto_38") + "simos" in TEXT and not "s de " + m.group("Msmto_37") + "mento " + m.group("Msmto_38") + "simos" in TEXT and not "s do " + m.group("Msmto_37") + "mento " + m.group("Msmto_38") + "simos" in TEXT and not " o " + m.group("Msmto_37") + "mento " + m.group("Msmto_38") + "simos" in TEXT and not m.group("Msmto_37") + "oso-" + m.group("Msmto_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_41>[a-zA-Zç]+)mento (?P<Msmto_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmto_42") in "D-d-" and not " e " + m.group("Msmto_41") + "mento " + m.group("Msmto_42") + "ores" in TEXT and not " ou " + m.group("Msmto_41") + "mento " + m.group("Msmto_42") + "ores" in TEXT and not "s de " + m.group("Msmto_41") + "mento " + m.group("Msmto_42") + "ores" in TEXT and not "s do " + m.group("Msmto_41") + "mento " + m.group("Msmto_42") + "ores" in TEXT and not " o " + m.group("Msmto_41") + "mento " + m.group("Msmto_42") + "ores" in TEXT and not m.group("Msmto_41") + "oso-" + m.group("Msmto_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_43>[a-zA-Zç]+)mento (?P<Msmto_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_44") in plvrMfr and not " e " + m.group("Msmto_43") + "mento " + m.group("Msmto_44") + "es" in TEXT and not " ou " + m.group("Msmto_43") + "mento " + m.group("Msmto_44") + "es" in TEXT and not "s de " + m.group("Msmto_43") + "mento " + m.group("Msmto_44") + "es" in TEXT and not "s do " + m.group("Msmto_43") + "mento " + m.group("Msmto_44") + "es" in TEXT and not " o " + m.group("Msmto_43") + "mento " + m.group("Msmto_44") + "es" in TEXT and not m.group("Msmto_43") + "oso-" + m.group("Msmto_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_45>[a-zA-Zç]+)mento (?P<Msmto_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_46") in plvrMascr and not " e " + m.group("Msmto_45") + "mento " + m.group("Msmto_46") + "es" in TEXT and not " ou " + m.group("Msmto_45") + "mento " + m.group("Msmto_46") + "es" in TEXT and not "s de " + m.group("Msmto_45") + "mento " + m.group("Msmto_46") + "es" in TEXT and not "s do " + m.group("Msmto_45") + "mento " + m.group("Msmto_46") + "es" in TEXT and not " o " + m.group("Msmto_45") + "mento " + m.group("Msmto_46") + "es" in TEXT and not m.group("Msmto_45") + "oso-" + m.group("Msmto_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_47>[a-zA-Zç]+)mento (?P<Msmto_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_48") in plvrMfal and not " e " + m.group("Msmto_47") + "mento " + m.group("Msmto_48") + "is" in TEXT and not " ou " + m.group("Msmto_47") + "mento " + m.group("Msmto_48") + "is" in TEXT and not "s de " + m.group("Msmto_47") + "mento " + m.group("Msmto_48") + "is" in TEXT and not "s do " + m.group("Msmto_47") + "mento " + m.group("Msmto_48") + "is" in TEXT and not " o " + m.group("Msmto_47") + "mento " + m.group("Msmto_48") + "is" in TEXT and not m.group("Msmto_47") + "oso-" + m.group("Msmto_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_49>[a-zA-Zç]+)mento (?P<Msmto_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_50") in plvrMfcao and not " e " + m.group("Msmto_49") + "mento " + m.group("Msmto_50") + "ões" in TEXT and not + " ou " + m.group("Msmto_49") + "mento " + m.group("Msmto_50") + "ões" in TEXT and not + "s de " + m.group("Msmto_49") + "mento " + m.group("Msmto_50") + "ões" in TEXT and not + "s do " + m.group("Msmto_49") + "mento " + m.group("Msmto_50") + "ões" in TEXT and not + " a " + m.group("Msmto_49") + "mento " + m.group("Msmto_50") + "ões" in TEXT and not m.group("Msmto_49") + "oso-" + m.group("Msmto_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_51>[a-zA-Zç]+)mento (?P<Msmto_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_52") in plvrNfemcao and not " e " + m.group("Msmto_51") + "mento " + m.group("Msmto_52") + "ões" in TEXT and not " ou " + m.group("Msmto_51") + "mento " + m.group("Msmto_52") + "ões" in TEXT and not "s de " + m.group("Msmto_51") + "mento " + m.group("Msmto_52") + "ões" in TEXT and not "s do " + m.group("Msmto_51") + "mento " + m.group("Msmto_52") + "ões" in TEXT and not " o " + m.group("Msmto_51") + "mento " + m.group("Msmto_52") + "ões" in TEXT and not m.group("Msmto_51") + "oso-" + m.group("Msmto_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_55>[a-zA-Zç]+)mento (?P<Msmto_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_55") + "mento " + m.group("Msmto_56") + "veis" in TEXT and not " ou " + m.group("Msmto_55") + "mento " + m.group("Msmto_56") + "veis" in TEXT and not "s de " + m.group("Msmto_55") + "mento " + m.group("Msmto_56") + "veis" in TEXT and not "s do " + m.group("Msmto_55") + "mento " + m.group("Msmto_56") + "veis" in TEXT and not " o " + m.group("Msmto_55") + "mento " + m.group("Msmto_56") + "veis" in TEXT and not m.group("Msmto_55") + "oso-" + m.group("Msmto_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_57>[a-zA-Zç]+)mento (?P<Msmto_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_58").lower() in plvrMfe and not " e " + m.group("Msmto_57") + "mento " + m.group("Msmto_58") + "es" in TEXT and not " ou " + m.group("Msmto_57") + "mento " + m.group("Msmto_58") + "es" in TEXT and not "s de " + m.group("Msmto_57") + "mento " + m.group("Msmto_58") + "es" in TEXT and not "s do " + m.group("Msmto_57") + "mento " + m.group("Msmto_58") + "es" in TEXT and not " o " + m.group("Msmto_57") + "mento " + m.group("Msmto_58") + "es" in TEXT and not m.group("Msmto_57") + "oso-" + m.group("Msmto_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_59>[a-zA-Zç]+)mento (?P<Msmto_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_60").lower() in plvrMasce and not " e " + m.group("Msmto_59") + "mento " + m.group("Msmto_60") + "es" in TEXT and not " ou " + m.group("Msmto_59") + "mento " + m.group("Msmto_60") + "es" in TEXT and not "s de " + m.group("Msmto_59") + "mento " + m.group("Msmto_60") + "es" in TEXT and not "s do " + m.group("Msmto_59") + "mento " + m.group("Msmto_60") + "es" in TEXT and not " o " + m.group("Msmto_59") + "mento " + m.group("Msmto_60") + "es" in TEXT and not m.group("Msmto_59") + "oso-" + m.group("Msmto_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_61>[a-zA-Zç]+)mento (?P<Msmto_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_62") in plvrMfel and not " e " + m.group("Msmto_61") + "mento " + m.group("Msmto_62") + "éis" in TEXT and not " ou " + m.group("Msmto_61") + "mento " + m.group("Msmto_62") + "éis" in TEXT and not "s de " + m.group("Msmto_61") + "mento " + m.group("Msmto_62") + "éis" in TEXT and not "s do " + m.group("Msmto_61") + "mento " + m.group("Msmto_62") + "éis" in TEXT and not " o " + m.group("Msmto_61") + "mento " + m.group("Msmto_62") + "éis" in TEXT and not m.group("Msmto_61") + "oso-" + m.group("Msmto_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_63>[a-zA-Zç]+)mento (?P<Msmto_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_64") in plvrMascel and not " e " + m.group("Msmto_63") + "mento " + m.group("Msmto_64") + "éis" in TEXT and not " ou " + m.group("Msmto_63") + "mento " + m.group("Msmto_64") + "éis" in TEXT and not "s de " + m.group("Msmto_63") + "mento " + m.group("Msmto_64") + "éis" in TEXT and not "s do " + m.group("Msmto_63") + "mento " + m.group("Msmto_64") + "éis" in TEXT and not " o " + m.group("Msmto_63") + "mento " + m.group("Msmto_64") + "éis" in TEXT and not m.group("Msmto_63") + "oso-" + m.group("Msmto_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_65>[a-zA-Zç]+)mento (?P<Msmto_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_66") in plvrMfeu and not " e " + m.group("Msmto_65") + "mento " + m.group("Msmto_66") + "us" in TEXT and not " ou " + m.group("Msmto_65") + "mento " + m.group("Msmto_66") + "us" in TEXT and not "s de " + m.group("Msmto_65") + "mento " + m.group("Msmto_66") + "us" in TEXT and not "s do " + m.group("Msmto_65") + "mento " + m.group("Msmto_66") + "us" in TEXT and not " o " + m.group("Msmto_65") + "mento " + m.group("Msmto_66") + "us" in TEXT and not m.group("Msmto_65") + "oso-" + m.group("Msmto_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_67>[a-zA-Zç]+)mento (?P<Msmto_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_68") in plvrMascu and not " e " + m.group("Msmto_67") + "mento " + m.group("Msmto_68") + "us" in TEXT and not " ou " + m.group("Msmto_67") + "mento " + m.group("Msmto_68") + "us" in TEXT and not "s de " + m.group("Msmto_67") + "mento " + m.group("Msmto_68") + "us" in TEXT and not "s do " + m.group("Msmto_67") + "mento " + m.group("Msmto_68") + "us" in TEXT and not " o " + m.group("Msmto_67") + "mento " + m.group("Msmto_68") + "us" in TEXT and not m.group("Msmto_67") + "oso-" + m.group("Msmto_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_69>[a-zA-Zç]+)mento (?P<Msmto_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_70") in plvrInvaz and not " e " + m.group("Msmto_69") + "mento " + m.group("Msmto_70") + "zes" in TEXT and not " ou " + m.group("Msmto_69") + "mento " + m.group("Msmto_70") + "zes" in TEXT and not "s de " + m.group("Msmto_69") + "mento " + m.group("Msmto_70") + "zes" in TEXT and not "s do " + m.group("Msmto_69") + "mento " + m.group("Msmto_70") + "zes" in TEXT and not " o " + m.group("Msmto_69") + "mento " + m.group("Msmto_70") + "zes" in TEXT and not m.group("Msmto_69") + "oso-" + m.group("Msmto_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_71>[a-zA-Zç]+)mento (?P<Msmto_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_72") in plvrMascz and not " e " + m.group("Msmto_71") + "mento " + m.group("Msmto_72") + "zes" in TEXT and not " ou " + m.group("Msmto_71") + "mento " + m.group("Msmto_72") + "zes" in TEXT and not "s de " + m.group("Msmto_71") + "mento " + m.group("Msmto_72") + "zes" in TEXT and not "s do " + m.group("Msmto_71") + "mento " + m.group("Msmto_72") + "zes" in TEXT and not " o " + m.group("Msmto_71") + "mento " + m.group("Msmto_72") + "zes" in TEXT and not m.group("Msmto_71") + "oso-" + m.group("Msmto_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_73>[a-zA-Zç]+)mento (?P<Msmto_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_74") in pvrMascan and not " e " + m.group("Msmto_73") + "mento " + m.group("Msmto_74") + "s" in TEXT and not " ou " + m.group("Msmto_73") + "mento " + m.group("Msmto_74") + "s" in TEXT and not "s de " + m.group("Msmto_73") + "mento " + m.group("Msmto_74") + "s" in TEXT and not "s do " + m.group("Msmto_73") + "mento " + m.group("Msmto_74") + "s" in TEXT and not " o " + m.group("Msmto_73") + "mento " + m.group("Msmto_74") + "s" in TEXT and not m.group("Msmto_73") + "oso-" + m.group("Msmto_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_75>[a-zA-Zç]+)mento (?P<Msmto_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_76").lower() in plvrMasco and not " e " + m.group("Msmto_75") + "mento " + m.group("Msmto_76") +"s" in TEXT and not " ou " + m.group("Msmto_75") + "mento " + m.group("Msmto_76") + "s" in TEXT and not "s de " + m.group("Msmto_75") + "mento " + m.group("Msmto_76") + "s" in TEXT and not "s do " + m.group("Msmto_75") + "mento " + m.group("Msmto_76") + "s" in TEXT and not " o " + m.group("Msmto_75") + "mento " + m.group("Msmto_76") + "s" in TEXT and not m.group("Msmto_75") + "oso-" + m.group("Msmto_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_77>[a-zA-Zç]+)mento (?P<Msmto_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_77") + "mento " + m.group("Msmto_78") + "inhos" in TEXT and not " ou " + m.group("Msmto_77") + "mento " + m.group("Msmto_78") + "inhos" in TEXT and not "s de " + m.group("Msmto_77") + "mento " + m.group("Msmto_78") + "inhos" in TEXT and not "s do " + m.group("Msmto_77") + "mento " + m.group("Msmto_78") + "inhos" in TEXT and not " o " + m.group("Msmto_77") + "mento " + m.group("Msmto_78") + "inhos" in TEXT and not m.group("Msmto_77") + "oso-" + m.group("Msmto_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_79>[a-zA-Zç]+)mento (?P<Msmto_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_79") + "mento " + m.group("Msmto_80") + "icas" in TEXT and not " ou " + m.group("Msmto_79") + "mento " + m.group("Msmto_80") + "icas" in TEXT and not "s de " + m.group("Msmto_79") + "mento " + m.group("Msmto_80") + "icas" in TEXT and not "s do " + m.group("Msmto_79") + "mento " + m.group("Msmto_80") + "icas" in TEXT and not " o " + m.group("Msmto_79") + "mento " + m.group("Msmto_80") + "icas" in TEXT and not m.group("Msmto_79") + "oso-" + m.group("Msmto_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_81>[a-zA-Zç]+)mento (?P<Msmto_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_81") + "mento " + m.group("Msmto_82") + "icas" in TEXT and not " ou " + m.group("Msmto_81") + "mento " + m.group("Msmto_82") + "icas" in TEXT and not "s de " + m.group("Msmto_81") + "mento " + m.group("Msmto_82") + "icas" in TEXT and not "s do " + m.group("Msmto_81") + "mento " + m.group("Msmto_82") + "icas" in TEXT and not " o " + m.group("Msmto_81") + "mento " + m.group("Msmto_82") + "icas" in TEXT and not m.group("Msmto_81") + "oso-" + m.group("Msmto_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_83>[a-zA-Zç]+)mento (?P<Msmto_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_83") + "mento " + m.group("Msmto_84") + "icas" in TEXT and not " ou " + m.group("Msmto_83") + "mento " + m.group("Msmto_84") + "icas" in TEXT and not "s de " + m.group("Msmto_83") + "mento " + m.group("Msmto_84") + "icas" in TEXT and not "s do " + m.group("Msmto_83") + "mento " + m.group("Msmto_84") + "icas" in TEXT and not " o " + m.group("Msmto_83") + "mento " + m.group("Msmto_84") + "icas" in TEXT and not m.group("Msmto_83") + "oso-" + m.group("Msmto_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_85>[a-zA-Zç]+)mento (?P<Msmto_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_85") + "mento " + m.group("Msmto_86") + "escas" in TEXT and not " ou " + m.group("Msmto_85") + "mento " + m.group("Msmto_86") + "escas" in TEXT and not "s de " + m.group("Msmto_85") + "mento " + m.group("Msmto_86") + "escas" in TEXT and not "s do " + m.group("Msmto_85") + "mento " + m.group("Msmto_86") + "escas" in TEXT and not " o " + m.group("Msmto_85") + "mento " + m.group("Msmto_86") + "escas" in TEXT and not m.group("Msmto_85") + "oso-" + m.group("Msmto_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_87>[a-zA-Zç]+)mento (?P<Msmto_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_87") + "mento " + m.group("Msmto_88") + "idas" in TEXT and not " ou " + m.group("Msmto_87") + "s " + m.group("Msmto_88") + "idas" in TEXT and not "s de " + m.group("Msmto_87") + "s " + m.group("Msmto_88") + "idas" in TEXT and not "s do " + m.group("Msmto_87") + "s " + m.group("Msmto_88") + "idas" in TEXT and not " o " + m.group("Msmto_87") + "s " + m.group("Msmto_88") + "idas" in TEXT and not m.group("Msmto_87") + "oso-" + m.group("Msmto_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_89>[a-zA-Zç]+)mento (?P<Msmto_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_89") + "mento " + m.group("Msmto_90") + "logas" in TEXT and not " ou " + m.group("Msmto_89") + "mento " + m.group("Msmto_90") + "logas" in TEXT and not "s de " + m.group("Msmto_89") + "mento " + m.group("Msmto_90") + "logas" in TEXT and not "s do " + m.group("Msmto_89") + "mento " + m.group("Msmto_90") + "logas" in TEXT and not " o " + m.group("Msmto_89") + "mento " + m.group("Msmto_90") + "logas" in TEXT and not m.group("Msmto_89") + "oso-" + m.group("Msmto_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_91>[a-zA-Zç]+)mento (?P<Msmto_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_91") + "mento " + m.group("Msmto_92") + "rias" in TEXT and not " ou " + m.group("Msmto_91") + "mento " + m.group("Msmto_92") + "rias" in TEXT and not "s de " + m.group("Msmto_91") + "mento " + m.group("Msmto_92") + "rias" in TEXT and not "s do " + m.group("Msmto_91") + "mento " + m.group("Msmto_92") + "rias" in TEXT and not " o " + m.group("Msmto_91") + "mento " + m.group("Msmto_92") + "rias" in TEXT and not m.group("Msmto_91") + "oso-" + m.group("Msmto_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_93>[a-zA-Zç]+)mento (?P<Msmto_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_93") + "mento " + m.group("Msmto_94") + "ssimas" in TEXT and not " ou " + m.group("Msmto_93") + "mento " + m.group("Msmto_94") + "ssimas" in TEXT and not "s de " + m.group("Msmto_93") + "mento " + m.group("Msmto_94") + "ssimas" in TEXT and not "s do " + m.group("Msmto_93") + "mento " + m.group("Msmto_94") + "ssimas" in TEXT and not " o " + m.group("Msmto_93") + "mento " + m.group("Msmto_94") + "ssimas" in TEXT and not m.group("Msmto_93") + "oso-" + m.group("Msmto_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_95>[a-zA-Zç]+)mento (?P<Msmto_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmto_95") + "mento " + m.group("Msmto_96") + "simas" in TEXT and not " ou " + m.group("Msmto_95") + "mento " + m.group("Msmto_96") + "simas" in TEXT and not "s de " + m.group("Msmto_95") + "mento " + m.group("Msmto_96") + "simas" in TEXT and not "s do " + m.group("Msmto_95") + "mento " + m.group("Msmto_96") + "simas" in TEXT and not " o " + m.group("Msmto_95") + "mento " + m.group("Msmto_96") + "simas" in TEXT and not m.group("Msmto_95") + "oso-" + m.group("Msmto_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_97>[a-zA-Zç]+)mento (?P<Msmto_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_98").lower() in plvrMfoa and not " e " + m.group("Msmto_97") + "mento " + m.group("Msmto_98") + "as" in TEXT and not " ou " + m.group("Msmto_97") + "mento " + m.group("Msmto_98") + "as" in TEXT and not "s de " + m.group("Msmto_97") + "mento " + m.group("Msmto_98") + "as" in TEXT and not "s do " + m.group("Msmto_97") + "mento " + m.group("Msmto_98") + "as" in TEXT and not " o " + m.group("Msmto_97") + "mento " + m.group("Msmto_98") + "as" in TEXT and not m.group("Msmto_97") + "oso-" + m.group("Msmto_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_99>[a-zA-Zç]+)mento (?P<Msmto_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_100") in plvrMFm and not " e " + m.group("Msmto_99") + "mento " + m.group("Msmto_100") + "ns" in TEXT and not " ou " + m.group("Msmto_99") + "mento " + m.group("Msmto_100") + "ns" in TEXT and not "s de " + m.group("Msmto_99") + "mento " + m.group("Msmto_100") + "ns" in TEXT and not "s da " + m.group("Msmto_99") + "mento " + m.group("Msmto_100") + "ns" in TEXT and not " a " + m.group("Msmto_99") + "mento " + m.group("Msmto_100") + "ns" in TEXT and not m.group("Msmto_99") + "oso-" + m.group("Msmto_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmto_101>[a-zA-Zç]+)mento (?P<Msmto_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "mentos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmto_102") in plvrMascm and not " e " + m.group("Msmto_101") + "mento " + m.group("Msmto_102") + "ns" in TEXT and not " ou " + m.group("Msmto_101") + "mento " + m.group("Msmto_102") + "ns" in TEXT and not "s de " + m.group("Msmto_101") + "mento " + m.group("Msmto_102") + "ns" in TEXT and not "s da " + m.group("Msmto_101") + "mento " + m.group("Msmto_102") + "ns" in TEXT and not " a " + m.group("Msmto_101") + "mento " + m.group("Msmto_102") + "ns" in TEXT and not m.group("Msmto_101") + "oso-" + m.group("Msmto_102") + "ns" in tCompostops'],
# esca
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_1>[a-zA-Zç]+)esca (?P<Mssca_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_2").lower() in plvrFema and not " e " + m.group("Mssca_1") + "esca " + m.group("Mssca_2") +"s" in TEXT and not " ou " + m.group("Mssca_1") + "esca " + m.group("Mssca_2") + "s" in TEXT and not "s de " + m.group("Mssca_1") + "esca " + m.group("Mssca_2") + "s" in TEXT and not "s da " + m.group("Mssca_1") + "esca " + m.group("Mssca_2") + "s" in TEXT and not " a " + m.group("Mssca_1") + "esca " + m.group("Mssca_2") + "s" in TEXT and not m.group("Mssca_1") + "esca-" + m.group("Mssca_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_3>[a-zA-Zç]+)esca (?P<Mssca_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_4").lower() in plvrMfoa and not " e " + m.group("Mssca_3") + "esca " + m.group("Mssca_4") + "as" in TEXT and not " ou " + m.group("Mssca_3") + "esca " + m.group("Mssca_4") + "as" in TEXT and not "s de " + m.group("Mssca_3") + "esca " + m.group("Mssca_4") + "as" in TEXT and not "s da " + m.group("Mssca_3") + "esca " + m.group("Mssca_4") + "as" in TEXT and not " a " + m.group("Mssca_3") + "esca " + m.group("Mssca_4") + "as" in TEXT and not m.group("Mssca_3") + "esca-" + m.group("Mssca_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_5>[a-zA-Zç]+)esca (?P<Mssca_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssca_6").lower() in excAdo and not " e " + m.group("Mssca_5") + "esca " + m.group("Mssca_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Mssca_5") + "esca " + m.group("Mssca_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Mssca_5") + "esca " + m.group("Mssca_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Mssca_5") + "esca " + m.group("Mssca_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Mssca_5") + "esca " + m.group("Mssca_6") + m.group(3) + "dos" in TEXT and not m.group("Mssca_5") + "esca-" + m.group("Mssca_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_7>[a-zA-Zç]+)esca (?P<Mssca_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssca_8").lower() in excIsta and not " e " + m.group("Mssca_7") + "esca " + m.group("Mssca_8") + "s" in TEXT and not " ou " + m.group("Mssca_7") + "esca " + m.group("Mssca_8") + "s" in TEXT and not "s de " + m.group("Mssca_7") + "esca " + m.group("Mssca_8") + "s" in TEXT and not "s da " + m.group("Mssca_7") + "esca " + m.group("Mssca_8") + "s" in TEXT and not " a " + m.group("Mssca_7") + "esca " + m.group("Mssca_8") + "s" in TEXT and not m.group("Mssca_7") + "esca-" + m.group("Mssca_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_9>[a-zA-Zç]+)esca (?P<Mssca_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_10").lower() in plvrInva and not " e " + m.group("Mssca_9") + "esca " + m.group("Mssca_10") + "s" in TEXT and not " ou " + m.group("Mssca_9") + "esca " + m.group("Mssca_10") + "s" in TEXT and not "s de " + m.group("Mssca_9") + "esca " + m.group("Mssca_10") + "s" in TEXT and not "s da " + m.group("Mssca_9") + "esca " + m.group("Mssca_10") + "s" in TEXT and not " a " + m.group("Mssca_9") + "esca " + m.group("Mssca_10") + "s" in TEXT and not m.group("Mssca_9") + "esca-" + m.group("Mssca_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_11>[a-zA-Zç]+)esca (?P<Mssca_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssca_12").lower() in excAdo and not " e " + m.group("Mssca_11") + "esca " + m.group("Mssca_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Mssca_11") + "esca " + m.group("Mssca_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Mssca_11") + "esca " + m.group("Mssca_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Mssca_11") + "esca " + m.group("Mssca_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Mssca_11") + "esca " + m.group("Mssca_12") + m.group(3) + "das" in TEXT and not m.group("Mssca_11") + "esca-" + m.group("Mssca_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_13>[a-zA-Zç]+)esca (?P<Mssca_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssca_13") + "esca " + m.group("Mssca_14") + "osos" in TEXT and not " ou " + m.group("Mssca_13") + "esca " + m.group("Mssca_14") + "osos" in TEXT and not "s de " + m.group("Mssca_13") + "esca " + m.group("Mssca_14") + "osos" in TEXT and not "s da " + m.group("Mssca_13") + "esca " + m.group("Mssca_14") + "osos" in TEXT and not " a " + m.group("Mssca_13") + "esca " + m.group("Mssca_14") + "osos" in TEXT and not m.group("Mssca_13") + "esca-" + m.group("Mssca_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_15>[a-zA-Zç]+)esca (?P<Mssca_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssca_15") + "esca " + m.group("Mssca_16") + "osas" in TEXT and not " ou " + m.group("Mssca_15") + "esca " + m.group("Mssca_16") + "osas" in TEXT and not "s de " + m.group("Mssca_15") + "esca " + m.group("Mssca_16") + "osas" in TEXT and not "s da " + m.group("Mssca_15") + "esca " + m.group("Mssca_16") + "osas" in TEXT and not " a " + m.group("Mssca_15") + "esca " + m.group("Mssca_16") + "osas" in TEXT and not m.group("Mssca_15") + "esca-" + m.group("Mssca_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_17>[a-zA-Zç]+)esca (?P<Mssca_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssca_17") + "esca " + m.group("Mssca_18") + "ivas" in TEXT and not " ou " + m.group("Mssca_17") + "esca " + m.group("Mssca_18") + "ivas" in TEXT and not "s de " + m.group("Mssca_17") + "esca " + m.group("Mssca_18") + "ivas" in TEXT and not "s da " + m.group("Mssca_17") + "esca " + m.group("Mssca_18") + "ivas" in TEXT and not " a " + m.group("Mssca_17") + "esca " + m.group("Mssca_18") + "ivas" in TEXT and not m.group("Mssca_17") + "esca-" + m.group("Mssca_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_19>[a-zA-Zç]+)esca (?P<Mssca_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssca_19") + "esca " + m.group("Mssca_20") + "ivas" in TEXT and not " ou " + m.group("Mssca_19") + "esca " + m.group("Mssca_20") + "ivas" in TEXT and not "s de " + m.group("Mssca_19") + "esca " + m.group("Mssca_20") + "ivas" in TEXT and not "s da " + m.group("Mssca_19") + "esca " + m.group("Mssca_20") + "ivas" in TEXT and not " a " + m.group("Mssca_19") + "esca " + m.group("Mssca_20") + "ivas" in TEXT and not m.group("Mssca_19") + "esca-" + m.group("Mssca_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_21>[a-zA-Zç]+)esca (?P<Mssca_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssca_21") + "esca " + m.group("Mssca_22") + "icas" in TEXT and not " ou " + m.group("Mssca_21") + "esca " + m.group("Mssca_22") + "icas" in TEXT and not "s de " + m.group("Mssca_21") + "esca " + m.group("Mssca_22") + "icas" in TEXT and not "s da " + m.group("Mssca_21") + "esca " + m.group("Mssca_22") + "icas" in TEXT and not " a " + m.group("Mssca_21") + "esca " + m.group("Mssca_22") + "icas" in TEXT and not m.group("Mssca_21") + "esca-" + m.group("Mssca_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_23>[a-zA-Zç]+)esca (?P<Mssca_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssca_23") + "esca " + m.group("Mssca_24") + "icas" in TEXT and not " ou " + m.group("Mssca_23") + "esca " + m.group("Mssca_24") + "icas" in TEXT and not "s de " + m.group("Mssca_23") + "esca " + m.group("Mssca_24") + "icas" in TEXT and not "s da " + m.group("Mssca_23") + "esca " + m.group("Mssca_24") + "icas" in TEXT and not " a " + m.group("Mssca_23") + "esca " + m.group("Mssca_24") + "icas" in TEXT and not m.group("Mssca_23") + "esca-" + m.group("Mssca_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_25>[a-zA-Zç]+)esca (?P<Mssca_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssca_25") + "esca " + m.group("Mssca_26") + "icas" in TEXT and not " ou " + m.group("Mssca_25") + "esca " + m.group("Mssca_26") + "icas" in TEXT and not "s de " + m.group("Mssca_25") + "esca " + m.group("Mssca_26") + "icas" in TEXT and not "s da " + m.group("Mssca_25") + "esca " + m.group("Mssca_26") + "icas" in TEXT and not " a " + m.group("Mssca_25") + "esca " + m.group("Mssca_26") + "icas" in TEXT and not m.group("Mssca_25") + "esca-" + m.group("Mssca_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_27>[a-zA-Zç]+)esca (?P<Mssca_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssca_27") + "esca " + m.group("Mssca_28") + "escas" in TEXT and not " ou " + m.group("Mssca_27") + "esca " + m.group("Mssca_28") + "escas" in TEXT and not "s de " + m.group("Mssca_27") + "esca " + m.group("Mssca_28") + "escas" in TEXT and not "s da " + m.group("Mssca_27") + "esca " + m.group("Mssca_28") + "escas" in TEXT and not " a " + m.group("Mssca_27") + "esca " + m.group("Mssca_28") + "escas" in TEXT and not m.group("Mssca_27") + "esca-" + m.group("Mssca_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_29>[a-zA-Zç]+)esca (?P<Mssca_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssca_29") + "esca " + m.group("Mssca_30") + "idas" in TEXT and not " ou " + m.group("Mssca_29") + "s " + m.group("Mssca_30") + "idas" in TEXT and not "s de " + m.group("Mssca_29") + "s " + m.group("Mssca_30") + "idas" in TEXT and not "s da " + m.group("Mssca_29") + "s " + m.group("Mssca_30") + "idas" in TEXT and not " a " + m.group("Mssca_29") + "s " + m.group("Mssca_30") + "idas" in TEXT and not m.group("Mssca_29") + "esca-" + m.group("Mssca_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_31>[a-zA-Zç]+)esca (?P<Mssca_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssca_31") + "esca " + m.group("Mssca_32") + "logas" in TEXT and not " ou " + m.group("Mssca_31") + "esca " + m.group("Mssca_32") + "logas" in TEXT and not "s de " + m.group("Mssca_31") + "esca " + m.group("Mssca_32") + "logas" in TEXT and not "s da " + m.group("Mssca_31") + "esca " + m.group("Mssca_32") + "logas" in TEXT and not " a " + m.group("Mssca_31") + "esca " + m.group("Mssca_32") + "logas" in TEXT and not m.group("Mssca_31") + "esca-" + m.group("Mssca_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_33>[a-zA-Zç]+)esca (?P<Mssca_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssca_33") + "esca " + m.group("Mssca_34") + "rias" in TEXT and not " ou " + m.group("Mssca_33") + "esca " + m.group("Mssca_34") + "rias" in TEXT and not "s de " + m.group("Mssca_33") + "esca " + m.group("Mssca_34") + "rias" in TEXT and not "s da " + m.group("Mssca_33") + "esca " + m.group("Mssca_34") + "rias" in TEXT and not " a " + m.group("Mssca_33") + "esca " + m.group("Mssca_34") + "rias" in TEXT and not m.group("Mssca_33") + "esca-" + m.group("Mssca_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_35>[a-zA-Zç]+)esca (?P<Mssca_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssca_35") + "esca " + m.group("Mssca_36") + "ssimas" in TEXT and not " ou " + m.group("Mssca_35") + "esca " + m.group("Mssca_36") + "ssimas" in TEXT and not "s de " + m.group("Mssca_35") + "esca " + m.group("Mssca_36") + "ssimas" in TEXT and not "s da " + m.group("Mssca_35") + "esca " + m.group("Mssca_36") + "ssimas" in TEXT and not " a " + m.group("Mssca_35") + "esca " + m.group("Mssca_36") + "ssimas" in TEXT and not m.group("Mssca_35") + "esca-" + m.group("Mssca_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_37>[a-zA-Zç]+)esca (?P<Mssca_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssca_37") + "esca " + m.group("Mssca_38") + "simas" in TEXT and not " ou " + m.group("Mssca_37") + "esca " + m.group("Mssca_38") + "simas" in TEXT and not "s de " + m.group("Mssca_37") + "esca " + m.group("Mssca_38") + "simas" in TEXT and not "s da " + m.group("Mssca_37") + "esca " + m.group("Mssca_38") + "simas" in TEXT and not " a " + m.group("Mssca_37") + "esca " + m.group("Mssca_38") + "simas" in TEXT and not m.group("Mssca_37") + "esca-" + m.group("Mssca_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_41>[a-zA-Zç]+)esca (?P<Mssca_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssca_42") in "D-d-" and not " e " + m.group("Mssca_41") + "esca " + m.group("Mssca_42") + "oras" in TEXT and not " ou " + m.group("Mssca_41") + "esca " + m.group("Mssca_42") + "oras" in TEXT and not "s de " + m.group("Mssca_41") + "esca " + m.group("Mssca_42") + "oras" in TEXT and not "s da " + m.group("Mssca_41") + "esca " + m.group("Mssca_42") + "oras" in TEXT and not " a " + m.group("Mssca_41") + "esca " + m.group("Mssca_42") + "oras" in TEXT and not m.group("Mssca_41") + "esca-" + m.group("Mssca_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_43>[a-zA-Zç]+)esca (?P<Mssca_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_44") in plvrMfr and not " e " + m.group("Mssca_43") + "esca " + m.group("Mssca_44") + "es" in TEXT and not " ou " + m.group("Mssca_43") + "esca " + m.group("Mssca_44") + "es" in TEXT and not "s de " + m.group("Mssca_43") + "esca " + m.group("Mssca_44") + "es" in TEXT and not "s da " + m.group("Mssca_43") + "esca " + m.group("Mssca_44") + "es" in TEXT and not " a " + m.group("Mssca_43") + "esca " + m.group("Mssca_44") + "es" in TEXT and not m.group("Mssca_43") + "esca-" + m.group("Mssca_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_45>[a-zA-Zç]+)esca (?P<Mssca_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_46") in plvrFemr and not " e " + m.group("Mssca_45") + "esca " + m.group("Mssca_46") + "es" in TEXT and not " ou " + m.group("Mssca_45") + "esca " + m.group("Mssca_46") + "es" in TEXT and not "s de " + m.group("Mssca_45") + "esca " + m.group("Mssca_46") + "es" in TEXT and not "s da " + m.group("Mssca_45") + "esca " + m.group("Mssca_46") + "es" in TEXT and not " a " + m.group("Mssca_45") + "esca " + m.group("Mssca_46") + "es" in TEXT and not m.group("Mssca_45") + "esca-" + m.group("Mssca_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_47>[a-zA-Zç]+)esca (?P<Mssca_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_48") in plvrMfal and not " e " + m.group("Mssca_47") + "esca " + m.group("Mssca_48") + "is" in TEXT and not " ou " + m.group("Mssca_47") + "esca " + m.group("Mssca_48") + "is" in TEXT and not "s de " + m.group("Mssca_47") + "esca " + m.group("Mssca_48") + "is" in TEXT and not "s da " + m.group("Mssca_47") + "esca " + m.group("Mssca_48") + "is" in TEXT and not " a " + m.group("Mssca_47") + "esca " + m.group("Mssca_48") + "is" in TEXT and not m.group("Mssca_47") + "esca-" + m.group("Mssca_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_49>[a-zA-Zç]+)esca (?P<Mssca_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_50") in plvrMfcao and not " e " + m.group("Mssca_49") + "esca " + m.group("Mssca_50") + "ões" in TEXT and not + " ou " + m.group("Mssca_49") + "esca " + m.group("Mssca_50") + "ões" in TEXT and not + "s de " + m.group("Mssca_49") + "esca " + m.group("Mssca_50") + "ões" in TEXT and not + "s da " + m.group("Mssca_49") + "esca " + m.group("Mssca_50") + "ões" in TEXT and not + " a " + m.group("Mssca_49") + "esca " + m.group("Mssca_50") + "ões" in TEXT and not m.group("Mssca_49") + "esca-" + m.group("Mssca_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_51>[a-zA-Zç]+)esca (?P<Mssca_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssca_52") in plvrMascao and not " e " + m.group("Mssca_51") + "esca " + m.group("Mssca_52") + "ões" in TEXT and not " ou " + m.group("Mssca_51") + "esca " + m.group("Mssca_52") + "ões" in TEXT and not "s de " + m.group("Mssca_51") + "esca " + m.group("Mssca_52") + "ões" in TEXT and not "s da " + m.group("Mssca_51") + "esca " + m.group("Mssca_52") + "ões" in TEXT and not " a " + m.group("Mssca_51") + "esca " + m.group("Mssca_52") + "ões" in TEXT and not m.group("Mssca_51") + "esca-" + m.group("Mssca_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_53>[a-zA-Zç]+)esca (?P<Mssca_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_54") in plvrFemao and not " e " + m.group("Mssca_53") + "esca " + m.group("Mssca_54") + "ões" in TEXT and not " ou " + m.group("Mssca_53") + "esca " + m.group("Mssca_54") + "ões" in TEXT and not "s de " + m.group("Mssca_53") + "esca " + m.group("Mssca_54") + "ões" in TEXT and not "s da " + m.group("Mssca_53") + "esca " + m.group("Mssca_54") + "ões" in TEXT and not " a " + m.group("Mssca_53") + "esca " + m.group("Mssca_54") + "ões" in TEXT and not m.group("Mssca_53") + "esca-" + m.group("Mssca_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_55>[a-zA-Zç]+)esca (?P<Mssca_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssca_55") + "esca " + m.group("Mssca_56") + "veis" in TEXT and not " ou " + m.group("Mssca_55") + "esca " + m.group("Mssca_56") + "veis" in TEXT and not "s de " + m.group("Mssca_55") + "esca " + m.group("Mssca_56") + "veis" in TEXT and not "s da " + m.group("Mssca_55") + "esca " + m.group("Mssca_56") + "veis" in TEXT and not " a " + m.group("Mssca_55") + "esca " + m.group("Mssca_56") + "veis" in TEXT and not m.group("Mssca_55") + "esca-" + m.group("Mssca_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_57>[a-zA-Zç]+)esca (?P<Mssca_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_58").lower() in plvrMfe and not " e " + m.group("Mssca_57") + "esca " + m.group("Mssca_58") + "es" in TEXT and not " ou " + m.group("Mssca_57") + "esca " + m.group("Mssca_58") + "es" in TEXT and not "s de " + m.group("Mssca_57") + "esca " + m.group("Mssca_58") + "es" in TEXT and not "s da " + m.group("Mssca_57") + "esca " + m.group("Mssca_58") + "es" in TEXT and not " a " + m.group("Mssca_57") + "esca " + m.group("Mssca_58") + "es" in TEXT and not m.group("Mssca_57") + "esca-" + m.group("Mssca_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_59>[a-zA-Zç]+)esca (?P<Mssca_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_60").lower() in plvrFeme and not " e " + m.group("Mssca_59") + "esca " + m.group("Mssca_60") + "es" in TEXT and not " ou " + m.group("Mssca_59") + "esca " + m.group("Mssca_60") + "es" in TEXT and not "s de " + m.group("Mssca_59") + "esca " + m.group("Mssca_60") + "es" in TEXT and not "s da " + m.group("Mssca_59") + "esca " + m.group("Mssca_60") + "es" in TEXT and not " a " + m.group("Mssca_59") + "esca " + m.group("Mssca_60") + "es" in TEXT and not m.group("Mssca_59") + "esca-" + m.group("Mssca_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_61>[a-zA-Zç]+)esca (?P<Mssca_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_62") in plvrMfel and not " e " + m.group("Mssca_61") + "esca " + m.group("Mssca_62") + "éis" in TEXT and not " ou " + m.group("Mssca_61") + "esca " + m.group("Mssca_62") + "éis" in TEXT and not "s de " + m.group("Mssca_61") + "esca " + m.group("Mssca_62") + "éis" in TEXT and not "s da " + m.group("Mssca_61") + "esca " + m.group("Mssca_62") + "éis" in TEXT and not " a " + m.group("Mssca_61") + "esca " + m.group("Mssca_62") + "éis" in TEXT and not m.group("Mssca_61") + "esca-" + m.group("Mssca_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_63>[a-zA-Zç]+)esca (?P<Mssca_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_64") in plvrFemel and not " e " + m.group("Mssca_63") + "esca " + m.group("Mssca_64") + "éis" in TEXT and not " ou " + m.group("Mssca_63") + "esca " + m.group("Mssca_64") + "éis" in TEXT and not "s de " + m.group("Mssca_63") + "esca " + m.group("Mssca_64") + "éis" in TEXT and not "s da " + m.group("Mssca_63") + "esca " + m.group("Mssca_64") + "éis" in TEXT and not " a " + m.group("Mssca_63") + "esca " + m.group("Mssca_64") + "éis" in TEXT and not m.group("Mssca_63") + "esca-" + m.group("Mssca_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_65>[a-zA-Zç]+)esca (?P<Mssca_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_66") in plvrMfeu and not " e " + m.group("Mssca_65") + "esca " + m.group("Mssca_66") + "us" in TEXT and not " ou " + m.group("Mssca_65") + "esca " + m.group("Mssca_66") + "us" in TEXT and not "s de " + m.group("Mssca_65") + "esca " + m.group("Mssca_66") + "us" in TEXT and not "s da " + m.group("Mssca_65") + "esca " + m.group("Mssca_66") + "us" in TEXT and not " a " + m.group("Mssca_65") + "esca " + m.group("Mssca_66") + "us" in TEXT and not m.group("Mssca_65") + "esca-" + m.group("Mssca_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_67>[a-zA-Zç]+)esca (?P<Mssca_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_68") in plvrFemu and not " e " + m.group("Mssca_67") + "esca " + m.group("Mssca_68") + "us" in TEXT and not " ou " + m.group("Mssca_67") + "esca " + m.group("Mssca_68") + "us" in TEXT and not "s de " + m.group("Mssca_67") + "esca " + m.group("Mssca_68") + "us" in TEXT and not "s da " + m.group("Mssca_67") + "esca " + m.group("Mssca_68") + "us" in TEXT and not " a " + m.group("Mssca_67") + "esca " + m.group("Mssca_68") + "us" in TEXT and not m.group("Mssca_67") + "esca-" + m.group("Mssca_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_69>[a-zA-Zç]+)esca (?P<Mssca_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_70") in plvrInvaz and not " e " + m.group("Mssca_69") + "esca " + m.group("Mssca_70") + "zes" in TEXT and not " ou " + m.group("Mssca_69") + "esca " + m.group("Mssca_70") + "zes" in TEXT and not "s de " + m.group("Mssca_69") + "esca " + m.group("Mssca_70") + "zes" in TEXT and not "s da " + m.group("Mssca_69") + "esca " + m.group("Mssca_70") + "zes" in TEXT and not " a " + m.group("Mssca_69") + "esca " + m.group("Mssca_70") + "zes" in TEXT and not m.group("Mssca_69") + "esca-" + m.group("Mssca_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_71>[a-zA-Zç]+)esca (?P<Mssca_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_72") in plvrFemz and not " e " + m.group("Mssca_71") + "esca " + m.group("Mssca_72") + "zes" in TEXT and not " ou " + m.group("Mssca_71") + "esca " + m.group("Mssca_72") + "zes" in TEXT and not "s de " + m.group("Mssca_71") + "esca " + m.group("Mssca_72") + "zes" in TEXT and not "s da " + m.group("Mssca_71") + "esca " + m.group("Mssca_72") + "zes" in TEXT and not " a " + m.group("Mssca_71") + "esca " + m.group("Mssca_72") + "zes" in TEXT and not m.group("Mssca_71") + "esca-" + m.group("Mssca_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_73>[a-zA-Zç]+)esca (?P<Mssca_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_74") in pvrFeman and not " e " + m.group("Mssca_73") + "esca " + m.group("Mssca_74") + "s" in TEXT and not " ou " + m.group("Mssca_73") + "esca " + m.group("Mssca_74") + "s" in TEXT and not "s de " + m.group("Mssca_73") + "esca " + m.group("Mssca_74") + "s" in TEXT and not "s da " + m.group("Mssca_73") + "esca " + m.group("Mssca_74") + "s" in TEXT and not " a " + m.group("Mssca_73") + "esca " + m.group("Mssca_74") + "s" in TEXT and not m.group("Mssca_73") + "esca-" + m.group("Mssca_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_99>[a-zA-Zç]+)esca (?P<Mssca_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_100") in plvrMFm and not " e " + m.group("Mssca_99") + "esca " + m.group("Mssca_100") + "ns" in TEXT and not " ou " + m.group("Mssca_99") + "esca " + m.group("Mssca_100") + "ns" in TEXT and not "s de " + m.group("Mssca_99") + "esca " + m.group("Mssca_100") + "ns" in TEXT and not "s da " + m.group("Mssca_99") + "esca " + m.group("Mssca_100") + "ns" in TEXT and not " a " + m.group("Mssca_99") + "esca " + m.group("Mssca_100") + "ns" in TEXT and not m.group("Mssca_99") + "esca-" + m.group("Mssca_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssca_101>[a-zA-Zç]+)esca (?P<Mssca_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "escas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssca_102") in plvrFemm and not " e " + m.group("Mssca_101") + "esca " + m.group("Mssca_102") + "ns" in TEXT and not " ou " + m.group("Mssca_101") + "esca " + m.group("Mssca_102") + "ns" in TEXT and not "s de " + m.group("Mssca_101") + "esca " + m.group("Mssca_102") + "ns" in TEXT and not "s da " + m.group("Mssca_101") + "esca " + m.group("Mssca_102") + "ns" in TEXT and not " a " + m.group("Mssca_101") + "esca " + m.group("Mssca_102") + "ns" in TEXT and not m.group("Mssca_101") + "esca-" + m.group("Mssca_102") + "ns" in tCompostops'],
# esco
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_1>[a-zA-Zç]+)esco (?P<Mssco_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_2").lower() in plvrMasca and not " e " + m.group("Mssco_1") + "esco " + m.group("Mssco_2") +"s" in TEXT and not " ou " + m.group("Mssco_1") + "esco " + m.group("Mssco_2") + "s" in TEXT and not "s de " + m.group("Mssco_1") + "esco " + m.group("Mssco_2") + "s" in TEXT and not "s do " + m.group("Mssco_1") + "esco " + m.group("Mssco_2") + "s" in TEXT and not " o " + m.group("Mssco_1") + "esco " + m.group("Mssco_2") + "s" in TEXT and not m.group("Mssco_1") + "esco-" + m.group("Mssco_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_3>[a-zA-Zç]+)esco (?P<Mssco_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_4").lower() in plvrMfoa and not " e " + m.group("Mssco_3") + "esco " + m.group("Mssco_4") + "os" in TEXT and not " ou " + m.group("Mssco_3") + "esco " + m.group("Mssco_4") + "os" in TEXT and not "s de " + m.group("Mssco_3") + "esco " + m.group("Mssco_4") + "os" in TEXT and not "s do " + m.group("Mssco_3") + "esco " + m.group("Mssco_4") + "os" in TEXT and not " o " + m.group("Mssco_3") + "esco " + m.group("Mssco_4") + "os" in TEXT and not m.group("Mssco_3") + "esco-" + m.group("Mssco_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_5>[a-zA-Zç]+)esco (?P<Mssco_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssco_6").lower() in excAdo and not " e " + m.group("Mssco_5") + "esco " + m.group("Mssco_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Mssco_5") + "esco " + m.group("Mssco_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Mssco_5") + "esco " + m.group("Mssco_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Mssco_5") + "esco " + m.group("Mssco_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Mssco_5") + "esco " + m.group("Mssco_6") + m.group(3) + "dos" in TEXT and not m.group("Mssco_5") + "esco-" + m.group("Mssco_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_7>[a-zA-Zç]+)esco (?P<Mssco_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssco_8").lower() in excIsta and not " e " + m.group("Mssco_7") + "esco " + m.group("Mssco_8") + "s" in TEXT and not " ou " + m.group("Mssco_7") + "esco " + m.group("Mssco_8") + "s" in TEXT and not "s de " + m.group("Mssco_7") + "esco " + m.group("Mssco_8") + "s" in TEXT and not "s do " + m.group("Mssco_7") + "esco " + m.group("Mssco_8") + "s" in TEXT and not " o " + m.group("Mssco_7") + "esco " + m.group("Mssco_8") + "s" in TEXT and not m.group("Mssco_7") + "esco-" + m.group("Mssco_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_9>[a-zA-Zç]+)esco (?P<Mssco_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_10").lower() in plvrInva and not " e " + m.group("Mssco_9") + "esco " + m.group("Mssco_10") + "s" in TEXT and not " ou " + m.group("Mssco_9") + "esco " + m.group("Mssco_10") + "s" in TEXT and not "s de " + m.group("Mssco_9") + "esco " + m.group("Mssco_10") + "s" in TEXT and not "s do " + m.group("Mssco_9") + "esco " + m.group("Mssco_10") + "s" in TEXT and not " a " + m.group("Mssco_9") + "esco " + m.group("Mssco_10") + "s" in TEXT and not m.group("Mssco_9") + "esco-" + m.group("Mssco_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_11>[a-zA-Zç]+)esco (?P<Mssco_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssco_12").lower() in excAdo and not " e " + m.group("Mssco_11") + "esco " + m.group("Mssco_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Mssco_11") + "esco " + m.group("Mssco_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Mssco_11") + "esco " + m.group("Mssco_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Mssco_11") + "esco " + m.group("Mssco_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Mssco_11") + "esco " + m.group("Mssco_12") + m.group(3) + "das" in TEXT and not m.group("Mssco_11") + "esco-" + m.group("Mssco_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_13>[a-zA-Zç]+)esco (?P<Mssco_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_13") + "esco " + m.group("Mssco_14") + "osos" in TEXT and not " ou " + m.group("Mssco_13") + "esco " + m.group("Mssco_14") + "osos" in TEXT and not "s de " + m.group("Mssco_13") + "esco " + m.group("Mssco_14") + "osos" in TEXT and not "s do " + m.group("Mssco_13") + "esco " + m.group("Mssco_14") + "osos" in TEXT and not " o " + m.group("Mssco_13") + "esco " + m.group("Mssco_14") + "osos" in TEXT and not m.group("Mssco_13") + "esco-" + m.group("Mssco_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_15>[a-zA-Zç]+)esco (?P<Mssco_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_15") + "esco " + m.group("Mssco_16") + "osas" in TEXT and not " ou " + m.group("Mssco_15") + "esco " + m.group("Mssco_16") + "osas" in TEXT and not "s de " + m.group("Mssco_15") + "esco " + m.group("Mssco_16") + "osas" in TEXT and not "s do " + m.group("Mssco_15") + "esco " + m.group("Mssco_16") + "osas" in TEXT and not " o " + m.group("Mssco_15") + "esco " + m.group("Mssco_16") + "osas" in TEXT and not m.group("Mssco_15") + "esco-" + m.group("Mssco_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_17>[a-zA-Zç]+)esco (?P<Mssco_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_17") + "esco " + m.group("Mssco_18") + "ivas" in TEXT and not " ou " + m.group("Mssco_17") + "esco " + m.group("Mssco_18") + "ivas" in TEXT and not "s de " + m.group("Mssco_17") + "esco " + m.group("Mssco_18") + "ivas" in TEXT and not "s do " + m.group("Mssco_17") + "esco " + m.group("Mssco_18") + "ivas" in TEXT and not " o " + m.group("Mssco_17") + "esco " + m.group("Mssco_18") + "ivas" in TEXT and not m.group("Mssco_17") + "esco-" + m.group("Mssco_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_19>[a-zA-Zç]+)esco (?P<Mssco_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_19") + "esco " + m.group("Mssco_20") + "ivas" in TEXT and not " ou " + m.group("Mssco_19") + "esco " + m.group("Mssco_20") + "ivas" in TEXT and not "s de " + m.group("Mssco_19") + "esco " + m.group("Mssco_20") + "ivas" in TEXT and not "s do " + m.group("Mssco_19") + "esco " + m.group("Mssco_20") + "ivas" in TEXT and not " o " + m.group("Mssco_19") + "esco " + m.group("Mssco_20") + "ivas" in TEXT and not m.group("Mssco_19") + "esco-" + m.group("Mssco_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_21>[a-zA-Zç]+)esco (?P<Mssco_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_21") + "esco " + m.group("Mssco_22") + "icos" in TEXT and not " ou " + m.group("Mssco_21") + "esco " + m.group("Mssco_22") + "icos" in TEXT and not "s de " + m.group("Mssco_21") + "esco " + m.group("Mssco_22") + "icos" in TEXT and not "s do " + m.group("Mssco_21") + "esco " + m.group("Mssco_22") + "icos" in TEXT and not " o " + m.group("Mssco_21") + "esco " + m.group("Mssco_22") + "icos" in TEXT and not m.group("Mssco_21") + "esco-" + m.group("Mssco_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_23>[a-zA-Zç]+)esco (?P<Mssco_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_23") + "esco " + m.group("Mssco_24") + "icos" in TEXT and not " ou " + m.group("Mssco_23") + "esco " + m.group("Mssco_24") + "icos" in TEXT and not "s de " + m.group("Mssco_23") + "esco " + m.group("Mssco_24") + "icos" in TEXT and not "s do " + m.group("Mssco_23") + "esco " + m.group("Mssco_24") + "icos" in TEXT and not " o " + m.group("Mssco_23") + "esco " + m.group("Mssco_24") + "icos" in TEXT and not m.group("Mssco_23") + "esco-" + m.group("Mssco_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_25>[a-zA-Zç]+)esco (?P<Mssco_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_25") + "esco " + m.group("Mssco_26") + "icos" in TEXT and not " ou " + m.group("Mssco_25") + "esco " + m.group("Mssco_26") + "icos" in TEXT and not "s de " + m.group("Mssco_25") + "esco " + m.group("Mssco_26") + "icos" in TEXT and not "s do " + m.group("Mssco_25") + "esco " + m.group("Mssco_26") + "icos" in TEXT and not " o " + m.group("Mssco_25") + "esco " + m.group("Mssco_26") + "icos" in TEXT and not m.group("Mssco_25") + "esco-" + m.group("Mssco_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_27>[a-zA-Zç]+)esco (?P<Mssco_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_27") + "esco " + m.group("Mssco_28") + "escos" in TEXT and not " ou " + m.group("Mssco_27") + "esco " + m.group("Mssco_28") + "escos" in TEXT and not "s de " + m.group("Mssco_27") + "esco " + m.group("Mssco_28") + "escos" in TEXT and not "s do " + m.group("Mssco_27") + "esco " + m.group("Mssco_28") + "escos" in TEXT and not " o " + m.group("Mssco_27") + "esco " + m.group("Mssco_28") + "escos" in TEXT and not m.group("Mssco_27") + "esco-" + m.group("Mssco_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_29>[a-zA-Zç]+)esco (?P<Mssco_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_29") + "esco " + m.group("Mssco_30") + "idos" in TEXT and not " ou " + m.group("Mssco_29") + "s " + m.group("Mssco_30") + "idos" in TEXT and not "s de " + m.group("Mssco_29") + "s " + m.group("Mssco_30") + "idos" in TEXT and not "s do " + m.group("Mssco_29") + "s " + m.group("Mssco_30") + "idos" in TEXT and not " o " + m.group("Mssco_29") + "s " + m.group("Mssco_30") + "idos" in TEXT and not m.group("Mssco_29") + "esco-" + m.group("Mssco_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_31>[a-zA-Zç]+)esco (?P<Mssco_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_31") + "esco " + m.group("Mssco_32") + "logos" in TEXT and not " ou " + m.group("Mssco_31") + "esco " + m.group("Mssco_32") + "logos" in TEXT and not "s de " + m.group("Mssco_31") + "esco " + m.group("Mssco_32") + "logos" in TEXT and not "s do " + m.group("Mssco_31") + "esco " + m.group("Mssco_32") + "logos" in TEXT and not " o " + m.group("Mssco_31") + "esco " + m.group("Mssco_32") + "logos" in TEXT and not m.group("Mssco_31") + "esco-" + m.group("Mssco_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_33>[a-zA-Zç]+)esco (?P<Mssco_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_33") + "esco " + m.group("Mssco_34") + "rios" in TEXT and not " ou " + m.group("Mssco_33") + "esco " + m.group("Mssco_34") + "rios" in TEXT and not "s de " + m.group("Mssco_33") + "esco " + m.group("Mssco_34") + "rios" in TEXT and not "s do " + m.group("Mssco_33") + "esco " + m.group("Mssco_34") + "rios" in TEXT and not " o " + m.group("Mssco_33") + "esco " + m.group("Mssco_34") + "rios" in TEXT and not m.group("Mssco_33") + "esco-" + m.group("Mssco_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_35>[a-zA-Zç]+)esco (?P<Mssco_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_35") + "esco " + m.group("Mssco_36") + "ssimos" in TEXT and not " ou " + m.group("Mssco_35") + "esco " + m.group("Mssco_36") + "ssimos" in TEXT and not "s de " + m.group("Mssco_35") + "esco " + m.group("Mssco_36") + "ssimos" in TEXT and not "s do " + m.group("Mssco_35") + "esco " + m.group("Mssco_36") + "ssimos" in TEXT and not " o " + m.group("Mssco_35") + "esco " + m.group("Mssco_36") + "ssimos" in TEXT and not m.group("Mssco_35") + "esco-" + m.group("Mssco_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_37>[a-zA-Zç]+)esco (?P<Mssco_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_37") + "esco " + m.group("Mssco_38") + "simos" in TEXT and not " ou " + m.group("Mssco_37") + "esco " + m.group("Mssco_38") + "simos" in TEXT and not "s de " + m.group("Mssco_37") + "esco " + m.group("Mssco_38") + "simos" in TEXT and not "s do " + m.group("Mssco_37") + "esco " + m.group("Mssco_38") + "simos" in TEXT and not " o " + m.group("Mssco_37") + "esco " + m.group("Mssco_38") + "simos" in TEXT and not m.group("Mssco_37") + "esco-" + m.group("Mssco_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_41>[a-zA-Zç]+)esco (?P<Mssco_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssco_42") in "D-d-" and not " e " + m.group("Mssco_41") + "esco " + m.group("Mssco_42") + "ores" in TEXT and not " ou " + m.group("Mssco_41") + "esco " + m.group("Mssco_42") + "ores" in TEXT and not "s de " + m.group("Mssco_41") + "esco " + m.group("Mssco_42") + "ores" in TEXT and not "s do " + m.group("Mssco_41") + "esco " + m.group("Mssco_42") + "ores" in TEXT and not " o " + m.group("Mssco_41") + "esco " + m.group("Mssco_42") + "ores" in TEXT and not m.group("Mssco_41") + "esco-" + m.group("Mssco_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_43>[a-zA-Zç]+)esco (?P<Mssco_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_44") in plvrMfr and not " e " + m.group("Mssco_43") + "esco " + m.group("Mssco_44") + "es" in TEXT and not " ou " + m.group("Mssco_43") + "esco " + m.group("Mssco_44") + "es" in TEXT and not "s de " + m.group("Mssco_43") + "esco " + m.group("Mssco_44") + "es" in TEXT and not "s do " + m.group("Mssco_43") + "esco " + m.group("Mssco_44") + "es" in TEXT and not " o " + m.group("Mssco_43") + "esco " + m.group("Mssco_44") + "es" in TEXT and not m.group("Mssco_43") + "esco-" + m.group("Mssco_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_45>[a-zA-Zç]+)esco (?P<Mssco_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_46") in plvrMascr and not " e " + m.group("Mssco_45") + "esco " + m.group("Mssco_46") + "es" in TEXT and not " ou " + m.group("Mssco_45") + "esco " + m.group("Mssco_46") + "es" in TEXT and not "s de " + m.group("Mssco_45") + "esco " + m.group("Mssco_46") + "es" in TEXT and not "s do " + m.group("Mssco_45") + "esco " + m.group("Mssco_46") + "es" in TEXT and not " o " + m.group("Mssco_45") + "esco " + m.group("Mssco_46") + "es" in TEXT and not m.group("Mssco_45") + "esco-" + m.group("Mssco_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_47>[a-zA-Zç]+)esco (?P<Mssco_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_48") in plvrMfal and not " e " + m.group("Mssco_47") + "esco " + m.group("Mssco_48") + "is" in TEXT and not " ou " + m.group("Mssco_47") + "esco " + m.group("Mssco_48") + "is" in TEXT and not "s de " + m.group("Mssco_47") + "esco " + m.group("Mssco_48") + "is" in TEXT and not "s do " + m.group("Mssco_47") + "esco " + m.group("Mssco_48") + "is" in TEXT and not " o " + m.group("Mssco_47") + "esco " + m.group("Mssco_48") + "is" in TEXT and not m.group("Mssco_47") + "esco-" + m.group("Mssco_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_49>[a-zA-Zç]+)esco (?P<Mssco_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_50") in plvrMfcao and not " e " + m.group("Mssco_49") + "esco " + m.group("Mssco_50") + "ões" in TEXT and not + " ou " + m.group("Mssco_49") + "esco " + m.group("Mssco_50") + "ões" in TEXT and not + "s de " + m.group("Mssco_49") + "esco " + m.group("Mssco_50") + "ões" in TEXT and not + "s do " + m.group("Mssco_49") + "esco " + m.group("Mssco_50") + "ões" in TEXT and not + " a " + m.group("Mssco_49") + "esco " + m.group("Mssco_50") + "ões" in TEXT and not m.group("Mssco_49") + "esco-" + m.group("Mssco_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_51>[a-zA-Zç]+)esco (?P<Mssco_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_52") in plvrNfemcao and not " e " + m.group("Mssco_51") + "esco " + m.group("Mssco_52") + "ões" in TEXT and not " ou " + m.group("Mssco_51") + "esco " + m.group("Mssco_52") + "ões" in TEXT and not "s de " + m.group("Mssco_51") + "esco " + m.group("Mssco_52") + "ões" in TEXT and not "s do " + m.group("Mssco_51") + "esco " + m.group("Mssco_52") + "ões" in TEXT and not " o " + m.group("Mssco_51") + "esco " + m.group("Mssco_52") + "ões" in TEXT and not m.group("Mssco_51") + "esco-" + m.group("Mssco_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_55>[a-zA-Zç]+)esco (?P<Mssco_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_55") + "esco " + m.group("Mssco_56") + "veis" in TEXT and not " ou " + m.group("Mssco_55") + "esco " + m.group("Mssco_56") + "veis" in TEXT and not "s de " + m.group("Mssco_55") + "esco " + m.group("Mssco_56") + "veis" in TEXT and not "s do " + m.group("Mssco_55") + "esco " + m.group("Mssco_56") + "veis" in TEXT and not " o " + m.group("Mssco_55") + "esco " + m.group("Mssco_56") + "veis" in TEXT and not m.group("Mssco_55") + "esco-" + m.group("Mssco_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_57>[a-zA-Zç]+)esco (?P<Mssco_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_58").lower() in plvrMfe and not " e " + m.group("Mssco_57") + "esco " + m.group("Mssco_58") + "es" in TEXT and not " ou " + m.group("Mssco_57") + "esco " + m.group("Mssco_58") + "es" in TEXT and not "s de " + m.group("Mssco_57") + "esco " + m.group("Mssco_58") + "es" in TEXT and not "s do " + m.group("Mssco_57") + "esco " + m.group("Mssco_58") + "es" in TEXT and not " o " + m.group("Mssco_57") + "esco " + m.group("Mssco_58") + "es" in TEXT and not m.group("Mssco_57") + "esco-" + m.group("Mssco_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_59>[a-zA-Zç]+)esco (?P<Mssco_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_60").lower() in plvrMasce and not " e " + m.group("Mssco_59") + "esco " + m.group("Mssco_60") + "es" in TEXT and not " ou " + m.group("Mssco_59") + "esco " + m.group("Mssco_60") + "es" in TEXT and not "s de " + m.group("Mssco_59") + "esco " + m.group("Mssco_60") + "es" in TEXT and not "s do " + m.group("Mssco_59") + "esco " + m.group("Mssco_60") + "es" in TEXT and not " o " + m.group("Mssco_59") + "esco " + m.group("Mssco_60") + "es" in TEXT and not m.group("Mssco_59") + "esco-" + m.group("Mssco_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_61>[a-zA-Zç]+)esco (?P<Mssco_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_62") in plvrMfel and not " e " + m.group("Mssco_61") + "esco " + m.group("Mssco_62") + "éis" in TEXT and not " ou " + m.group("Mssco_61") + "esco " + m.group("Mssco_62") + "éis" in TEXT and not "s de " + m.group("Mssco_61") + "esco " + m.group("Mssco_62") + "éis" in TEXT and not "s do " + m.group("Mssco_61") + "esco " + m.group("Mssco_62") + "éis" in TEXT and not " o " + m.group("Mssco_61") + "esco " + m.group("Mssco_62") + "éis" in TEXT and not m.group("Mssco_61") + "esco-" + m.group("Mssco_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_63>[a-zA-Zç]+)esco (?P<Mssco_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_64") in plvrMascel and not " e " + m.group("Mssco_63") + "esco " + m.group("Mssco_64") + "éis" in TEXT and not " ou " + m.group("Mssco_63") + "esco " + m.group("Mssco_64") + "éis" in TEXT and not "s de " + m.group("Mssco_63") + "esco " + m.group("Mssco_64") + "éis" in TEXT and not "s do " + m.group("Mssco_63") + "esco " + m.group("Mssco_64") + "éis" in TEXT and not " o " + m.group("Mssco_63") + "esco " + m.group("Mssco_64") + "éis" in TEXT and not m.group("Mssco_63") + "esco-" + m.group("Mssco_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_65>[a-zA-Zç]+)esco (?P<Mssco_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_66") in plvrMfeu and not " e " + m.group("Mssco_65") + "esco " + m.group("Mssco_66") + "us" in TEXT and not " ou " + m.group("Mssco_65") + "esco " + m.group("Mssco_66") + "us" in TEXT and not "s de " + m.group("Mssco_65") + "esco " + m.group("Mssco_66") + "us" in TEXT and not "s do " + m.group("Mssco_65") + "esco " + m.group("Mssco_66") + "us" in TEXT and not " o " + m.group("Mssco_65") + "esco " + m.group("Mssco_66") + "us" in TEXT and not m.group("Mssco_65") + "esco-" + m.group("Mssco_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_67>[a-zA-Zç]+)esco (?P<Mssco_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_68") in plvrMascu and not " e " + m.group("Mssco_67") + "esco " + m.group("Mssco_68") + "us" in TEXT and not " ou " + m.group("Mssco_67") + "esco " + m.group("Mssco_68") + "us" in TEXT and not "s de " + m.group("Mssco_67") + "esco " + m.group("Mssco_68") + "us" in TEXT and not "s do " + m.group("Mssco_67") + "esco " + m.group("Mssco_68") + "us" in TEXT and not " o " + m.group("Mssco_67") + "esco " + m.group("Mssco_68") + "us" in TEXT and not m.group("Mssco_67") + "esco-" + m.group("Mssco_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_69>[a-zA-Zç]+)esco (?P<Mssco_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_70") in plvrInvaz and not " e " + m.group("Mssco_69") + "esco " + m.group("Mssco_70") + "zes" in TEXT and not " ou " + m.group("Mssco_69") + "esco " + m.group("Mssco_70") + "zes" in TEXT and not "s de " + m.group("Mssco_69") + "esco " + m.group("Mssco_70") + "zes" in TEXT and not "s do " + m.group("Mssco_69") + "esco " + m.group("Mssco_70") + "zes" in TEXT and not " o " + m.group("Mssco_69") + "esco " + m.group("Mssco_70") + "zes" in TEXT and not m.group("Mssco_69") + "esco-" + m.group("Mssco_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_71>[a-zA-Zç]+)esco (?P<Mssco_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_72") in plvrMascz and not " e " + m.group("Mssco_71") + "esco " + m.group("Mssco_72") + "zes" in TEXT and not " ou " + m.group("Mssco_71") + "esco " + m.group("Mssco_72") + "zes" in TEXT and not "s de " + m.group("Mssco_71") + "esco " + m.group("Mssco_72") + "zes" in TEXT and not "s do " + m.group("Mssco_71") + "esco " + m.group("Mssco_72") + "zes" in TEXT and not " o " + m.group("Mssco_71") + "esco " + m.group("Mssco_72") + "zes" in TEXT and not m.group("Mssco_71") + "esco-" + m.group("Mssco_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_73>[a-zA-Zç]+)esco (?P<Mssco_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_74") in pvrMascan and not " e " + m.group("Mssco_73") + "esco " + m.group("Mssco_74") + "s" in TEXT and not " ou " + m.group("Mssco_73") + "esco " + m.group("Mssco_74") + "s" in TEXT and not "s de " + m.group("Mssco_73") + "esco " + m.group("Mssco_74") + "s" in TEXT and not "s do " + m.group("Mssco_73") + "esco " + m.group("Mssco_74") + "s" in TEXT and not " o " + m.group("Mssco_73") + "esco " + m.group("Mssco_74") + "s" in TEXT and not m.group("Mssco_73") + "esco-" + m.group("Mssco_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_75>[a-zA-Zç]+)esco (?P<Mssco_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_76").lower() in plvrMasco and not " e " + m.group("Mssco_75") + "esco " + m.group("Mssco_76") +"s" in TEXT and not " ou " + m.group("Mssco_75") + "esco " + m.group("Mssco_76") + "s" in TEXT and not "s de " + m.group("Mssco_75") + "esco " + m.group("Mssco_76") + "s" in TEXT and not "s do " + m.group("Mssco_75") + "esco " + m.group("Mssco_76") + "s" in TEXT and not " o " + m.group("Mssco_75") + "esco " + m.group("Mssco_76") + "s" in TEXT and not m.group("Mssco_75") + "esco-" + m.group("Mssco_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_77>[a-zA-Zç]+)esco (?P<Mssco_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_77") + "esco " + m.group("Mssco_78") + "inhos" in TEXT and not " ou " + m.group("Mssco_77") + "esco " + m.group("Mssco_78") + "inhos" in TEXT and not "s de " + m.group("Mssco_77") + "esco " + m.group("Mssco_78") + "inhos" in TEXT and not "s do " + m.group("Mssco_77") + "esco " + m.group("Mssco_78") + "inhos" in TEXT and not " o " + m.group("Mssco_77") + "esco " + m.group("Mssco_78") + "inhos" in TEXT and not m.group("Mssco_77") + "esco-" + m.group("Mssco_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_79>[a-zA-Zç]+)esco (?P<Mssco_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_79") + "esco " + m.group("Mssco_80") + "icas" in TEXT and not " ou " + m.group("Mssco_79") + "esco " + m.group("Mssco_80") + "icas" in TEXT and not "s de " + m.group("Mssco_79") + "esco " + m.group("Mssco_80") + "icas" in TEXT and not "s do " + m.group("Mssco_79") + "esco " + m.group("Mssco_80") + "icas" in TEXT and not " o " + m.group("Mssco_79") + "esco " + m.group("Mssco_80") + "icas" in TEXT and not m.group("Mssco_79") + "esco-" + m.group("Mssco_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_81>[a-zA-Zç]+)esco (?P<Mssco_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_81") + "esco " + m.group("Mssco_82") + "icas" in TEXT and not " ou " + m.group("Mssco_81") + "esco " + m.group("Mssco_82") + "icas" in TEXT and not "s de " + m.group("Mssco_81") + "esco " + m.group("Mssco_82") + "icas" in TEXT and not "s do " + m.group("Mssco_81") + "esco " + m.group("Mssco_82") + "icas" in TEXT and not " o " + m.group("Mssco_81") + "esco " + m.group("Mssco_82") + "icas" in TEXT and not m.group("Mssco_81") + "esco-" + m.group("Mssco_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_83>[a-zA-Zç]+)esco (?P<Mssco_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_83") + "esco " + m.group("Mssco_84") + "icas" in TEXT and not " ou " + m.group("Mssco_83") + "esco " + m.group("Mssco_84") + "icas" in TEXT and not "s de " + m.group("Mssco_83") + "esco " + m.group("Mssco_84") + "icas" in TEXT and not "s do " + m.group("Mssco_83") + "esco " + m.group("Mssco_84") + "icas" in TEXT and not " o " + m.group("Mssco_83") + "esco " + m.group("Mssco_84") + "icas" in TEXT and not m.group("Mssco_83") + "esco-" + m.group("Mssco_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_85>[a-zA-Zç]+)esco (?P<Mssco_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_85") + "esco " + m.group("Mssco_86") + "escas" in TEXT and not " ou " + m.group("Mssco_85") + "esco " + m.group("Mssco_86") + "escas" in TEXT and not "s de " + m.group("Mssco_85") + "esco " + m.group("Mssco_86") + "escas" in TEXT and not "s do " + m.group("Mssco_85") + "esco " + m.group("Mssco_86") + "escas" in TEXT and not " o " + m.group("Mssco_85") + "esco " + m.group("Mssco_86") + "escas" in TEXT and not m.group("Mssco_85") + "esco-" + m.group("Mssco_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_87>[a-zA-Zç]+)esco (?P<Mssco_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_87") + "esco " + m.group("Mssco_88") + "idas" in TEXT and not " ou " + m.group("Mssco_87") + "s " + m.group("Mssco_88") + "idas" in TEXT and not "s de " + m.group("Mssco_87") + "s " + m.group("Mssco_88") + "idas" in TEXT and not "s do " + m.group("Mssco_87") + "s " + m.group("Mssco_88") + "idas" in TEXT and not " o " + m.group("Mssco_87") + "s " + m.group("Mssco_88") + "idas" in TEXT and not m.group("Mssco_87") + "esco-" + m.group("Mssco_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_89>[a-zA-Zç]+)esco (?P<Mssco_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_89") + "esco " + m.group("Mssco_90") + "logas" in TEXT and not " ou " + m.group("Mssco_89") + "esco " + m.group("Mssco_90") + "logas" in TEXT and not "s de " + m.group("Mssco_89") + "esco " + m.group("Mssco_90") + "logas" in TEXT and not "s do " + m.group("Mssco_89") + "esco " + m.group("Mssco_90") + "logas" in TEXT and not " o " + m.group("Mssco_89") + "esco " + m.group("Mssco_90") + "logas" in TEXT and not m.group("Mssco_89") + "esco-" + m.group("Mssco_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_91>[a-zA-Zç]+)esco (?P<Mssco_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_91") + "esco " + m.group("Mssco_92") + "rias" in TEXT and not " ou " + m.group("Mssco_91") + "esco " + m.group("Mssco_92") + "rias" in TEXT and not "s de " + m.group("Mssco_91") + "esco " + m.group("Mssco_92") + "rias" in TEXT and not "s do " + m.group("Mssco_91") + "esco " + m.group("Mssco_92") + "rias" in TEXT and not " o " + m.group("Mssco_91") + "esco " + m.group("Mssco_92") + "rias" in TEXT and not m.group("Mssco_91") + "esco-" + m.group("Mssco_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_93>[a-zA-Zç]+)esco (?P<Mssco_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_93") + "esco " + m.group("Mssco_94") + "ssimas" in TEXT and not " ou " + m.group("Mssco_93") + "esco " + m.group("Mssco_94") + "ssimas" in TEXT and not "s de " + m.group("Mssco_93") + "esco " + m.group("Mssco_94") + "ssimas" in TEXT and not "s do " + m.group("Mssco_93") + "esco " + m.group("Mssco_94") + "ssimas" in TEXT and not " o " + m.group("Mssco_93") + "esco " + m.group("Mssco_94") + "ssimas" in TEXT and not m.group("Mssco_93") + "esco-" + m.group("Mssco_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_95>[a-zA-Zç]+)esco (?P<Mssco_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssco_95") + "esco " + m.group("Mssco_96") + "simas" in TEXT and not " ou " + m.group("Mssco_95") + "esco " + m.group("Mssco_96") + "simas" in TEXT and not "s de " + m.group("Mssco_95") + "esco " + m.group("Mssco_96") + "simas" in TEXT and not "s do " + m.group("Mssco_95") + "esco " + m.group("Mssco_96") + "simas" in TEXT and not " o " + m.group("Mssco_95") + "esco " + m.group("Mssco_96") + "simas" in TEXT and not m.group("Mssco_95") + "esco-" + m.group("Mssco_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_97>[a-zA-Zç]+)esco (?P<Mssco_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_98").lower() in plvrMfoa and not " e " + m.group("Mssco_97") + "esco " + m.group("Mssco_98") + "as" in TEXT and not " ou " + m.group("Mssco_97") + "esco " + m.group("Mssco_98") + "as" in TEXT and not "s de " + m.group("Mssco_97") + "esco " + m.group("Mssco_98") + "as" in TEXT and not "s do " + m.group("Mssco_97") + "esco " + m.group("Mssco_98") + "as" in TEXT and not " o " + m.group("Mssco_97") + "esco " + m.group("Mssco_98") + "as" in TEXT and not m.group("Mssco_97") + "esco-" + m.group("Mssco_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_99>[a-zA-Zç]+)esco (?P<Mssco_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_100") in plvrMFm and not " e " + m.group("Mssco_99") + "esco " + m.group("Mssco_100") + "ns" in TEXT and not " ou " + m.group("Mssco_99") + "esco " + m.group("Mssco_100") + "ns" in TEXT and not "s de " + m.group("Mssco_99") + "esco " + m.group("Mssco_100") + "ns" in TEXT and not "s da " + m.group("Mssco_99") + "esco " + m.group("Mssco_100") + "ns" in TEXT and not " a " + m.group("Mssco_99") + "esco " + m.group("Mssco_100") + "ns" in TEXT and not m.group("Mssco_99") + "esco-" + m.group("Mssco_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssco_101>[a-zA-Zç]+)esco (?P<Mssco_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "escos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssco_102") in plvrMascm and not " e " + m.group("Mssco_101") + "esco " + m.group("Mssco_102") + "ns" in TEXT and not " ou " + m.group("Mssco_101") + "esco " + m.group("Mssco_102") + "ns" in TEXT and not "s de " + m.group("Mssco_101") + "esco " + m.group("Mssco_102") + "ns" in TEXT and not "s da " + m.group("Mssco_101") + "esco " + m.group("Mssco_102") + "ns" in TEXT and not " a " + m.group("Mssco_101") + "esco " + m.group("Mssco_102") + "ns" in TEXT and not m.group("Mssco_101") + "esco-" + m.group("Mssco_102") + "ns" in tCompostops'],
# [mn]ica
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_1>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_2").lower() in plvrFema and not " e " + m.group("Msmca_1") + "ica " + m.group("Msmca_2") +"s" in TEXT and not " ou " + m.group("Msmca_1") + "ica " + m.group("Msmca_2") + "s" in TEXT and not "s de " + m.group("Msmca_1") + "ica " + m.group("Msmca_2") + "s" in TEXT and not "s da " + m.group("Msmca_1") + "ica " + m.group("Msmca_2") + "s" in TEXT and not " a " + m.group("Msmca_1") + "ica " + m.group("Msmca_2") + "s" in TEXT and not m.group("Msmca_1") + "ica-" + m.group("Msmca_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_3>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_4").lower() in plvrMfoa and not " e " + m.group("Msmca_3") + "ica " + m.group("Msmca_4") + "as" in TEXT and not " ou " + m.group("Msmca_3") + "ica " + m.group("Msmca_4") + "as" in TEXT and not "s de " + m.group("Msmca_3") + "ica " + m.group("Msmca_4") + "as" in TEXT and not "s da " + m.group("Msmca_3") + "ica " + m.group("Msmca_4") + "as" in TEXT and not " a " + m.group("Msmca_3") + "ica " + m.group("Msmca_4") + "as" in TEXT and not m.group("Msmca_3") + "ica-" + m.group("Msmca_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_5>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmca_6").lower() in excAdo and not " e " + m.group("Msmca_5") + "ica " + m.group("Msmca_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msmca_5") + "ica " + m.group("Msmca_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msmca_5") + "ica " + m.group("Msmca_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Msmca_5") + "ica " + m.group("Msmca_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Msmca_5") + "ica " + m.group("Msmca_6") + m.group(3) + "dos" in TEXT and not m.group("Msmca_5") + "ica-" + m.group("Msmca_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_7>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmca_8").lower() in excIsta and not " e " + m.group("Msmca_7") + "ica " + m.group("Msmca_8") + "s" in TEXT and not " ou " + m.group("Msmca_7") + "ica " + m.group("Msmca_8") + "s" in TEXT and not "s de " + m.group("Msmca_7") + "ica " + m.group("Msmca_8") + "s" in TEXT and not "s da " + m.group("Msmca_7") + "ica " + m.group("Msmca_8") + "s" in TEXT and not " a " + m.group("Msmca_7") + "ica " + m.group("Msmca_8") + "s" in TEXT and not m.group("Msmca_7") + "ica-" + m.group("Msmca_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_9>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_10").lower() in plvrInva and not " e " + m.group("Msmca_9") + "ica " + m.group("Msmca_10") + "s" in TEXT and not " ou " + m.group("Msmca_9") + "ica " + m.group("Msmca_10") + "s" in TEXT and not "s de " + m.group("Msmca_9") + "ica " + m.group("Msmca_10") + "s" in TEXT and not "s da " + m.group("Msmca_9") + "ica " + m.group("Msmca_10") + "s" in TEXT and not " a " + m.group("Msmca_9") + "ica " + m.group("Msmca_10") + "s" in TEXT and not m.group("Msmca_9") + "ica-" + m.group("Msmca_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_11>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmca_12").lower() in excAdo and not " e " + m.group("Msmca_11") + "ica " + m.group("Msmca_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msmca_11") + "ica " + m.group("Msmca_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msmca_11") + "ica " + m.group("Msmca_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Msmca_11") + "ica " + m.group("Msmca_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Msmca_11") + "ica " + m.group("Msmca_12") + m.group(3) + "das" in TEXT and not m.group("Msmca_11") + "ica-" + m.group("Msmca_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_13>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmca_13") + "ica " + m.group("Msmca_14") + "osos" in TEXT and not " ou " + m.group("Msmca_13") + "ica " + m.group("Msmca_14") + "osos" in TEXT and not "s de " + m.group("Msmca_13") + "ica " + m.group("Msmca_14") + "osos" in TEXT and not "s da " + m.group("Msmca_13") + "ica " + m.group("Msmca_14") + "osos" in TEXT and not " a " + m.group("Msmca_13") + "ica " + m.group("Msmca_14") + "osos" in TEXT and not m.group("Msmca_13") + "ica-" + m.group("Msmca_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_15>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmca_15") + "ica " + m.group("Msmca_16") + "osas" in TEXT and not " ou " + m.group("Msmca_15") + "ica " + m.group("Msmca_16") + "osas" in TEXT and not "s de " + m.group("Msmca_15") + "ica " + m.group("Msmca_16") + "osas" in TEXT and not "s da " + m.group("Msmca_15") + "ica " + m.group("Msmca_16") + "osas" in TEXT and not " a " + m.group("Msmca_15") + "ica " + m.group("Msmca_16") + "osas" in TEXT and not m.group("Msmca_15") + "ica-" + m.group("Msmca_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_17>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmca_17") + "ica " + m.group("Msmca_18") + "ivas" in TEXT and not " ou " + m.group("Msmca_17") + "ica " + m.group("Msmca_18") + "ivas" in TEXT and not "s de " + m.group("Msmca_17") + "ica " + m.group("Msmca_18") + "ivas" in TEXT and not "s da " + m.group("Msmca_17") + "ica " + m.group("Msmca_18") + "ivas" in TEXT and not " a " + m.group("Msmca_17") + "ica " + m.group("Msmca_18") + "ivas" in TEXT and not m.group("Msmca_17") + "ica-" + m.group("Msmca_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_19>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmca_19") + "ica " + m.group("Msmca_20") + "ivas" in TEXT and not " ou " + m.group("Msmca_19") + "ica " + m.group("Msmca_20") + "ivas" in TEXT and not "s de " + m.group("Msmca_19") + "ica " + m.group("Msmca_20") + "ivas" in TEXT and not "s da " + m.group("Msmca_19") + "ica " + m.group("Msmca_20") + "ivas" in TEXT and not " a " + m.group("Msmca_19") + "ica " + m.group("Msmca_20") + "ivas" in TEXT and not m.group("Msmca_19") + "ica-" + m.group("Msmca_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_21>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmca_21") + "ica " + m.group("Msmca_22") + "icas" in TEXT and not " ou " + m.group("Msmca_21") + "ica " + m.group("Msmca_22") + "icas" in TEXT and not "s de " + m.group("Msmca_21") + "ica " + m.group("Msmca_22") + "icas" in TEXT and not "s da " + m.group("Msmca_21") + "ica " + m.group("Msmca_22") + "icas" in TEXT and not " a " + m.group("Msmca_21") + "ica " + m.group("Msmca_22") + "icas" in TEXT and not m.group("Msmca_21") + "ica-" + m.group("Msmca_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_23>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmca_23") + "ica " + m.group("Msmca_24") + "icas" in TEXT and not " ou " + m.group("Msmca_23") + "ica " + m.group("Msmca_24") + "icas" in TEXT and not "s de " + m.group("Msmca_23") + "ica " + m.group("Msmca_24") + "icas" in TEXT and not "s da " + m.group("Msmca_23") + "ica " + m.group("Msmca_24") + "icas" in TEXT and not " a " + m.group("Msmca_23") + "ica " + m.group("Msmca_24") + "icas" in TEXT and not m.group("Msmca_23") + "ica-" + m.group("Msmca_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_25>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmca_25") + "ica " + m.group("Msmca_26") + "icas" in TEXT and not " ou " + m.group("Msmca_25") + "ica " + m.group("Msmca_26") + "icas" in TEXT and not "s de " + m.group("Msmca_25") + "ica " + m.group("Msmca_26") + "icas" in TEXT and not "s da " + m.group("Msmca_25") + "ica " + m.group("Msmca_26") + "icas" in TEXT and not " a " + m.group("Msmca_25") + "ica " + m.group("Msmca_26") + "icas" in TEXT and not m.group("Msmca_25") + "ica-" + m.group("Msmca_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_27>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmca_27") + "ica " + m.group("Msmca_28") + "escas" in TEXT and not " ou " + m.group("Msmca_27") + "ica " + m.group("Msmca_28") + "escas" in TEXT and not "s de " + m.group("Msmca_27") + "ica " + m.group("Msmca_28") + "escas" in TEXT and not "s da " + m.group("Msmca_27") + "ica " + m.group("Msmca_28") + "escas" in TEXT and not " a " + m.group("Msmca_27") + "ica " + m.group("Msmca_28") + "escas" in TEXT and not m.group("Msmca_27") + "ica-" + m.group("Msmca_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_29>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmca_29") + "ica " + m.group("Msmca_30") + "idas" in TEXT and not " ou " + m.group("Msmca_29") + "s " + m.group("Msmca_30") + "idas" in TEXT and not "s de " + m.group("Msmca_29") + "s " + m.group("Msmca_30") + "idas" in TEXT and not "s da " + m.group("Msmca_29") + "s " + m.group("Msmca_30") + "idas" in TEXT and not " a " + m.group("Msmca_29") + "s " + m.group("Msmca_30") + "idas" in TEXT and not m.group("Msmca_29") + "ica-" + m.group("Msmca_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_31>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmca_31") + "ica " + m.group("Msmca_32") + "logas" in TEXT and not " ou " + m.group("Msmca_31") + "ica " + m.group("Msmca_32") + "logas" in TEXT and not "s de " + m.group("Msmca_31") + "ica " + m.group("Msmca_32") + "logas" in TEXT and not "s da " + m.group("Msmca_31") + "ica " + m.group("Msmca_32") + "logas" in TEXT and not " a " + m.group("Msmca_31") + "ica " + m.group("Msmca_32") + "logas" in TEXT and not m.group("Msmca_31") + "ica-" + m.group("Msmca_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_33>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmca_33") + "ica " + m.group("Msmca_34") + "rias" in TEXT and not " ou " + m.group("Msmca_33") + "ica " + m.group("Msmca_34") + "rias" in TEXT and not "s de " + m.group("Msmca_33") + "ica " + m.group("Msmca_34") + "rias" in TEXT and not "s da " + m.group("Msmca_33") + "ica " + m.group("Msmca_34") + "rias" in TEXT and not " a " + m.group("Msmca_33") + "ica " + m.group("Msmca_34") + "rias" in TEXT and not m.group("Msmca_33") + "ica-" + m.group("Msmca_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_35>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmca_35") + "ica " + m.group("Msmca_36") + "ssimas" in TEXT and not " ou " + m.group("Msmca_35") + "ica " + m.group("Msmca_36") + "ssimas" in TEXT and not "s de " + m.group("Msmca_35") + "ica " + m.group("Msmca_36") + "ssimas" in TEXT and not "s da " + m.group("Msmca_35") + "ica " + m.group("Msmca_36") + "ssimas" in TEXT and not " a " + m.group("Msmca_35") + "ica " + m.group("Msmca_36") + "ssimas" in TEXT and not m.group("Msmca_35") + "ica-" + m.group("Msmca_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_37>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmca_37") + "ica " + m.group("Msmca_38") + "simas" in TEXT and not " ou " + m.group("Msmca_37") + "ica " + m.group("Msmca_38") + "simas" in TEXT and not "s de " + m.group("Msmca_37") + "ica " + m.group("Msmca_38") + "simas" in TEXT and not "s da " + m.group("Msmca_37") + "ica " + m.group("Msmca_38") + "simas" in TEXT and not " a " + m.group("Msmca_37") + "ica " + m.group("Msmca_38") + "simas" in TEXT and not m.group("Msmca_37") + "ica-" + m.group("Msmca_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_41>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmca_42") in "D-d-" and not " e " + m.group("Msmca_41") + "ica " + m.group("Msmca_42") + "oras" in TEXT and not " ou " + m.group("Msmca_41") + "ica " + m.group("Msmca_42") + "oras" in TEXT and not "s de " + m.group("Msmca_41") + "ica " + m.group("Msmca_42") + "oras" in TEXT and not "s da " + m.group("Msmca_41") + "ica " + m.group("Msmca_42") + "oras" in TEXT and not " a " + m.group("Msmca_41") + "ica " + m.group("Msmca_42") + "oras" in TEXT and not m.group("Msmca_41") + "ica-" + m.group("Msmca_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_43>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_44") in plvrMfr and not " e " + m.group("Msmca_43") + "ica " + m.group("Msmca_44") + "es" in TEXT and not " ou " + m.group("Msmca_43") + "ica " + m.group("Msmca_44") + "es" in TEXT and not "s de " + m.group("Msmca_43") + "ica " + m.group("Msmca_44") + "es" in TEXT and not "s da " + m.group("Msmca_43") + "ica " + m.group("Msmca_44") + "es" in TEXT and not " a " + m.group("Msmca_43") + "ica " + m.group("Msmca_44") + "es" in TEXT and not m.group("Msmca_43") + "ica-" + m.group("Msmca_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_45>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_46") in plvrFemr and not " e " + m.group("Msmca_45") + "ica " + m.group("Msmca_46") + "es" in TEXT and not " ou " + m.group("Msmca_45") + "ica " + m.group("Msmca_46") + "es" in TEXT and not "s de " + m.group("Msmca_45") + "ica " + m.group("Msmca_46") + "es" in TEXT and not "s da " + m.group("Msmca_45") + "ica " + m.group("Msmca_46") + "es" in TEXT and not " a " + m.group("Msmca_45") + "ica " + m.group("Msmca_46") + "es" in TEXT and not m.group("Msmca_45") + "ica-" + m.group("Msmca_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_47>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_48") in plvrMfal and not " e " + m.group("Msmca_47") + "ica " + m.group("Msmca_48") + "is" in TEXT and not " ou " + m.group("Msmca_47") + "ica " + m.group("Msmca_48") + "is" in TEXT and not "s de " + m.group("Msmca_47") + "ica " + m.group("Msmca_48") + "is" in TEXT and not "s da " + m.group("Msmca_47") + "ica " + m.group("Msmca_48") + "is" in TEXT and not " a " + m.group("Msmca_47") + "ica " + m.group("Msmca_48") + "is" in TEXT and not m.group("Msmca_47") + "ica-" + m.group("Msmca_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_49>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_50") in plvrMfcao and not " e " + m.group("Msmca_49") + "ica " + m.group("Msmca_50") + "ões" in TEXT and not + " ou " + m.group("Msmca_49") + "ica " + m.group("Msmca_50") + "ões" in TEXT and not + "s de " + m.group("Msmca_49") + "ica " + m.group("Msmca_50") + "ões" in TEXT and not + "s da " + m.group("Msmca_49") + "ica " + m.group("Msmca_50") + "ões" in TEXT and not + " a " + m.group("Msmca_49") + "ica " + m.group("Msmca_50") + "ões" in TEXT and not m.group("Msmca_49") + "ica-" + m.group("Msmca_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_51>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmca_52") in plvrMascao and not " e " + m.group("Msmca_51") + "ica " + m.group("Msmca_52") + "ões" in TEXT and not " ou " + m.group("Msmca_51") + "ica " + m.group("Msmca_52") + "ões" in TEXT and not "s de " + m.group("Msmca_51") + "ica " + m.group("Msmca_52") + "ões" in TEXT and not "s da " + m.group("Msmca_51") + "ica " + m.group("Msmca_52") + "ões" in TEXT and not " a " + m.group("Msmca_51") + "ica " + m.group("Msmca_52") + "ões" in TEXT and not m.group("Msmca_51") + "ica-" + m.group("Msmca_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_53>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_54") in plvrFemao and not " e " + m.group("Msmca_53") + "ica " + m.group("Msmca_54") + "ões" in TEXT and not " ou " + m.group("Msmca_53") + "ica " + m.group("Msmca_54") + "ões" in TEXT and not "s de " + m.group("Msmca_53") + "ica " + m.group("Msmca_54") + "ões" in TEXT and not "s da " + m.group("Msmca_53") + "ica " + m.group("Msmca_54") + "ões" in TEXT and not " a " + m.group("Msmca_53") + "ica " + m.group("Msmca_54") + "ões" in TEXT and not m.group("Msmca_53") + "ica-" + m.group("Msmca_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_55>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmca_55") + "ica " + m.group("Msmca_56") + "veis" in TEXT and not " ou " + m.group("Msmca_55") + "ica " + m.group("Msmca_56") + "veis" in TEXT and not "s de " + m.group("Msmca_55") + "ica " + m.group("Msmca_56") + "veis" in TEXT and not "s da " + m.group("Msmca_55") + "ica " + m.group("Msmca_56") + "veis" in TEXT and not " a " + m.group("Msmca_55") + "ica " + m.group("Msmca_56") + "veis" in TEXT and not m.group("Msmca_55") + "ica-" + m.group("Msmca_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_57>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_58").lower() in plvrMfe and not " e " + m.group("Msmca_57") + "ica " + m.group("Msmca_58") + "es" in TEXT and not " ou " + m.group("Msmca_57") + "ica " + m.group("Msmca_58") + "es" in TEXT and not "s de " + m.group("Msmca_57") + "ica " + m.group("Msmca_58") + "es" in TEXT and not "s da " + m.group("Msmca_57") + "ica " + m.group("Msmca_58") + "es" in TEXT and not " a " + m.group("Msmca_57") + "ica " + m.group("Msmca_58") + "es" in TEXT and not m.group("Msmca_57") + "ica-" + m.group("Msmca_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_59>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_60").lower() in plvrFeme and not " e " + m.group("Msmca_59") + "ica " + m.group("Msmca_60") + "es" in TEXT and not " ou " + m.group("Msmca_59") + "ica " + m.group("Msmca_60") + "es" in TEXT and not "s de " + m.group("Msmca_59") + "ica " + m.group("Msmca_60") + "es" in TEXT and not "s da " + m.group("Msmca_59") + "ica " + m.group("Msmca_60") + "es" in TEXT and not " a " + m.group("Msmca_59") + "ica " + m.group("Msmca_60") + "es" in TEXT and not m.group("Msmca_59") + "ica-" + m.group("Msmca_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_61>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_62") in plvrMfel and not " e " + m.group("Msmca_61") + "ica " + m.group("Msmca_62") + "éis" in TEXT and not " ou " + m.group("Msmca_61") + "ica " + m.group("Msmca_62") + "éis" in TEXT and not "s de " + m.group("Msmca_61") + "ica " + m.group("Msmca_62") + "éis" in TEXT and not "s da " + m.group("Msmca_61") + "ica " + m.group("Msmca_62") + "éis" in TEXT and not " a " + m.group("Msmca_61") + "ica " + m.group("Msmca_62") + "éis" in TEXT and not m.group("Msmca_61") + "ica-" + m.group("Msmca_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_63>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_64") in plvrFemel and not " e " + m.group("Msmca_63") + "ica " + m.group("Msmca_64") + "éis" in TEXT and not " ou " + m.group("Msmca_63") + "ica " + m.group("Msmca_64") + "éis" in TEXT and not "s de " + m.group("Msmca_63") + "ica " + m.group("Msmca_64") + "éis" in TEXT and not "s da " + m.group("Msmca_63") + "ica " + m.group("Msmca_64") + "éis" in TEXT and not " a " + m.group("Msmca_63") + "ica " + m.group("Msmca_64") + "éis" in TEXT and not m.group("Msmca_63") + "ica-" + m.group("Msmca_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_65>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_66") in plvrMfeu and not " e " + m.group("Msmca_65") + "ica " + m.group("Msmca_66") + "us" in TEXT and not " ou " + m.group("Msmca_65") + "ica " + m.group("Msmca_66") + "us" in TEXT and not "s de " + m.group("Msmca_65") + "ica " + m.group("Msmca_66") + "us" in TEXT and not "s da " + m.group("Msmca_65") + "ica " + m.group("Msmca_66") + "us" in TEXT and not " a " + m.group("Msmca_65") + "ica " + m.group("Msmca_66") + "us" in TEXT and not m.group("Msmca_65") + "ica-" + m.group("Msmca_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_67>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_68") in plvrFemu and not " e " + m.group("Msmca_67") + "ica " + m.group("Msmca_68") + "us" in TEXT and not " ou " + m.group("Msmca_67") + "ica " + m.group("Msmca_68") + "us" in TEXT and not "s de " + m.group("Msmca_67") + "ica " + m.group("Msmca_68") + "us" in TEXT and not "s da " + m.group("Msmca_67") + "ica " + m.group("Msmca_68") + "us" in TEXT and not " a " + m.group("Msmca_67") + "ica " + m.group("Msmca_68") + "us" in TEXT and not m.group("Msmca_67") + "ica-" + m.group("Msmca_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_69>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_70") in plvrInvaz and not " e " + m.group("Msmca_69") + "ica " + m.group("Msmca_70") + "zes" in TEXT and not " ou " + m.group("Msmca_69") + "ica " + m.group("Msmca_70") + "zes" in TEXT and not "s de " + m.group("Msmca_69") + "ica " + m.group("Msmca_70") + "zes" in TEXT and not "s da " + m.group("Msmca_69") + "ica " + m.group("Msmca_70") + "zes" in TEXT and not " a " + m.group("Msmca_69") + "ica " + m.group("Msmca_70") + "zes" in TEXT and not m.group("Msmca_69") + "ica-" + m.group("Msmca_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_71>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_72") in plvrFemz and not " e " + m.group("Msmca_71") + "ica " + m.group("Msmca_72") + "zes" in TEXT and not " ou " + m.group("Msmca_71") + "ica " + m.group("Msmca_72") + "zes" in TEXT and not "s de " + m.group("Msmca_71") + "ica " + m.group("Msmca_72") + "zes" in TEXT and not "s da " + m.group("Msmca_71") + "ica " + m.group("Msmca_72") + "zes" in TEXT and not " a " + m.group("Msmca_71") + "ica " + m.group("Msmca_72") + "zes" in TEXT and not m.group("Msmca_71") + "ica-" + m.group("Msmca_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_73>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_74") in pvrFeman and not " e " + m.group("Msmca_73") + "ica " + m.group("Msmca_74") + "s" in TEXT and not " ou " + m.group("Msmca_73") + "ica " + m.group("Msmca_74") + "s" in TEXT and not "s de " + m.group("Msmca_73") + "ica " + m.group("Msmca_74") + "s" in TEXT and not "s da " + m.group("Msmca_73") + "ica " + m.group("Msmca_74") + "s" in TEXT and not " a " + m.group("Msmca_73") + "ica " + m.group("Msmca_74") + "s" in TEXT and not m.group("Msmca_73") + "ica-" + m.group("Msmca_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_99>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_100") in plvrMFm and not " e " + m.group("Msmca_99") + "ica " + m.group("Msmca_100") + "ns" in TEXT and not " ou " + m.group("Msmca_99") + "ica " + m.group("Msmca_100") + "ns" in TEXT and not "s de " + m.group("Msmca_99") + "ica " + m.group("Msmca_100") + "ns" in TEXT and not "s da " + m.group("Msmca_99") + "ica " + m.group("Msmca_100") + "ns" in TEXT and not " a " + m.group("Msmca_99") + "ica " + m.group("Msmca_100") + "ns" in TEXT and not m.group("Msmca_99") + "ica-" + m.group("Msmca_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmca_101>[a-zA-Zç]+[âêô][mn])ica (?P<Msmca_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmca_102") in plvrFemm and not " e " + m.group("Msmca_101") + "ica " + m.group("Msmca_102") + "ns" in TEXT and not " ou " + m.group("Msmca_101") + "ica " + m.group("Msmca_102") + "ns" in TEXT and not "s de " + m.group("Msmca_101") + "ica " + m.group("Msmca_102") + "ns" in TEXT and not "s da " + m.group("Msmca_101") + "ica " + m.group("Msmca_102") + "ns" in TEXT and not " a " + m.group("Msmca_101") + "ica " + m.group("Msmca_102") + "ns" in TEXT and not m.group("Msmca_101") + "ica-" + m.group("Msmca_102") + "ns" in tCompostops'],
# [mn]ico
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_1>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_2").lower() in plvrMasca and not " e " + m.group("Msmco_1") + "ico " + m.group("Msmco_2") +"s" in TEXT and not " ou " + m.group("Msmco_1") + "ico " + m.group("Msmco_2") + "s" in TEXT and not "s de " + m.group("Msmco_1") + "ico " + m.group("Msmco_2") + "s" in TEXT and not "s do " + m.group("Msmco_1") + "ico " + m.group("Msmco_2") + "s" in TEXT and not " o " + m.group("Msmco_1") + "ico " + m.group("Msmco_2") + "s" in TEXT and not m.group("Msmco_1") + "ico-" + m.group("Msmco_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_3>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_4").lower() in plvrMfoa and not " e " + m.group("Msmco_3") + "ico " + m.group("Msmco_4") + "os" in TEXT and not " ou " + m.group("Msmco_3") + "ico " + m.group("Msmco_4") + "os" in TEXT and not "s de " + m.group("Msmco_3") + "ico " + m.group("Msmco_4") + "os" in TEXT and not "s do " + m.group("Msmco_3") + "ico " + m.group("Msmco_4") + "os" in TEXT and not " o " + m.group("Msmco_3") + "ico " + m.group("Msmco_4") + "os" in TEXT and not m.group("Msmco_3") + "ico-" + m.group("Msmco_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_5>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmco_6").lower() in excAdo and not " e " + m.group("Msmco_5") + "ico " + m.group("Msmco_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msmco_5") + "ico " + m.group("Msmco_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msmco_5") + "ico " + m.group("Msmco_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msmco_5") + "ico " + m.group("Msmco_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msmco_5") + "ico " + m.group("Msmco_6") + m.group(3) + "dos" in TEXT and not m.group("Msmco_5") + "ico-" + m.group("Msmco_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_7>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmco_8").lower() in excIsta and not " e " + m.group("Msmco_7") + "ico " + m.group("Msmco_8") + "s" in TEXT and not " ou " + m.group("Msmco_7") + "ico " + m.group("Msmco_8") + "s" in TEXT and not "s de " + m.group("Msmco_7") + "ico " + m.group("Msmco_8") + "s" in TEXT and not "s do " + m.group("Msmco_7") + "ico " + m.group("Msmco_8") + "s" in TEXT and not " o " + m.group("Msmco_7") + "ico " + m.group("Msmco_8") + "s" in TEXT and not m.group("Msmco_7") + "ico-" + m.group("Msmco_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_9>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_10").lower() in plvrInva and not " e " + m.group("Msmco_9") + "ico " + m.group("Msmco_10") + "s" in TEXT and not " ou " + m.group("Msmco_9") + "ico " + m.group("Msmco_10") + "s" in TEXT and not "s de " + m.group("Msmco_9") + "ico " + m.group("Msmco_10") + "s" in TEXT and not "s do " + m.group("Msmco_9") + "ico " + m.group("Msmco_10") + "s" in TEXT and not " a " + m.group("Msmco_9") + "ico " + m.group("Msmco_10") + "s" in TEXT and not m.group("Msmco_9") + "ico-" + m.group("Msmco_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_11>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmco_12").lower() in excAdo and not " e " + m.group("Msmco_11") + "ico " + m.group("Msmco_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msmco_11") + "ico " + m.group("Msmco_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msmco_11") + "ico " + m.group("Msmco_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Msmco_11") + "ico " + m.group("Msmco_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Msmco_11") + "ico " + m.group("Msmco_12") + m.group(3) + "das" in TEXT and not m.group("Msmco_11") + "ico-" + m.group("Msmco_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_13>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_13") + "ico " + m.group("Msmco_14") + "osos" in TEXT and not " ou " + m.group("Msmco_13") + "ico " + m.group("Msmco_14") + "osos" in TEXT and not "s de " + m.group("Msmco_13") + "ico " + m.group("Msmco_14") + "osos" in TEXT and not "s do " + m.group("Msmco_13") + "ico " + m.group("Msmco_14") + "osos" in TEXT and not " o " + m.group("Msmco_13") + "ico " + m.group("Msmco_14") + "osos" in TEXT and not m.group("Msmco_13") + "ico-" + m.group("Msmco_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_15>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_15") + "ico " + m.group("Msmco_16") + "osas" in TEXT and not " ou " + m.group("Msmco_15") + "ico " + m.group("Msmco_16") + "osas" in TEXT and not "s de " + m.group("Msmco_15") + "ico " + m.group("Msmco_16") + "osas" in TEXT and not "s do " + m.group("Msmco_15") + "ico " + m.group("Msmco_16") + "osas" in TEXT and not " o " + m.group("Msmco_15") + "ico " + m.group("Msmco_16") + "osas" in TEXT and not m.group("Msmco_15") + "ico-" + m.group("Msmco_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_17>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_17") + "ico " + m.group("Msmco_18") + "ivas" in TEXT and not " ou " + m.group("Msmco_17") + "ico " + m.group("Msmco_18") + "ivas" in TEXT and not "s de " + m.group("Msmco_17") + "ico " + m.group("Msmco_18") + "ivas" in TEXT and not "s do " + m.group("Msmco_17") + "ico " + m.group("Msmco_18") + "ivas" in TEXT and not " o " + m.group("Msmco_17") + "ico " + m.group("Msmco_18") + "ivas" in TEXT and not m.group("Msmco_17") + "ico-" + m.group("Msmco_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_19>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_19") + "ico " + m.group("Msmco_20") + "ivas" in TEXT and not " ou " + m.group("Msmco_19") + "ico " + m.group("Msmco_20") + "ivas" in TEXT and not "s de " + m.group("Msmco_19") + "ico " + m.group("Msmco_20") + "ivas" in TEXT and not "s do " + m.group("Msmco_19") + "ico " + m.group("Msmco_20") + "ivas" in TEXT and not " o " + m.group("Msmco_19") + "ico " + m.group("Msmco_20") + "ivas" in TEXT and not m.group("Msmco_19") + "ico-" + m.group("Msmco_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_21>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_21") + "ico " + m.group("Msmco_22") + "icos" in TEXT and not " ou " + m.group("Msmco_21") + "ico " + m.group("Msmco_22") + "icos" in TEXT and not "s de " + m.group("Msmco_21") + "ico " + m.group("Msmco_22") + "icos" in TEXT and not "s do " + m.group("Msmco_21") + "ico " + m.group("Msmco_22") + "icos" in TEXT and not " o " + m.group("Msmco_21") + "ico " + m.group("Msmco_22") + "icos" in TEXT and not m.group("Msmco_21") + "ico-" + m.group("Msmco_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_23>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_23") + "ico " + m.group("Msmco_24") + "icos" in TEXT and not " ou " + m.group("Msmco_23") + "ico " + m.group("Msmco_24") + "icos" in TEXT and not "s de " + m.group("Msmco_23") + "ico " + m.group("Msmco_24") + "icos" in TEXT and not "s do " + m.group("Msmco_23") + "ico " + m.group("Msmco_24") + "icos" in TEXT and not " o " + m.group("Msmco_23") + "ico " + m.group("Msmco_24") + "icos" in TEXT and not m.group("Msmco_23") + "ico-" + m.group("Msmco_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_25>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_25") + "ico " + m.group("Msmco_26") + "icos" in TEXT and not " ou " + m.group("Msmco_25") + "ico " + m.group("Msmco_26") + "icos" in TEXT and not "s de " + m.group("Msmco_25") + "ico " + m.group("Msmco_26") + "icos" in TEXT and not "s do " + m.group("Msmco_25") + "ico " + m.group("Msmco_26") + "icos" in TEXT and not " o " + m.group("Msmco_25") + "ico " + m.group("Msmco_26") + "icos" in TEXT and not m.group("Msmco_25") + "ico-" + m.group("Msmco_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_27>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_27") + "ico " + m.group("Msmco_28") + "escos" in TEXT and not " ou " + m.group("Msmco_27") + "ico " + m.group("Msmco_28") + "escos" in TEXT and not "s de " + m.group("Msmco_27") + "ico " + m.group("Msmco_28") + "escos" in TEXT and not "s do " + m.group("Msmco_27") + "ico " + m.group("Msmco_28") + "escos" in TEXT and not " o " + m.group("Msmco_27") + "ico " + m.group("Msmco_28") + "escos" in TEXT and not m.group("Msmco_27") + "ico-" + m.group("Msmco_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_29>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_29") + "ico " + m.group("Msmco_30") + "idos" in TEXT and not " ou " + m.group("Msmco_29") + "s " + m.group("Msmco_30") + "idos" in TEXT and not "s de " + m.group("Msmco_29") + "s " + m.group("Msmco_30") + "idos" in TEXT and not "s do " + m.group("Msmco_29") + "s " + m.group("Msmco_30") + "idos" in TEXT and not " o " + m.group("Msmco_29") + "s " + m.group("Msmco_30") + "idos" in TEXT and not m.group("Msmco_29") + "ico-" + m.group("Msmco_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_31>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_31") + "ico " + m.group("Msmco_32") + "logos" in TEXT and not " ou " + m.group("Msmco_31") + "ico " + m.group("Msmco_32") + "logos" in TEXT and not "s de " + m.group("Msmco_31") + "ico " + m.group("Msmco_32") + "logos" in TEXT and not "s do " + m.group("Msmco_31") + "ico " + m.group("Msmco_32") + "logos" in TEXT and not " o " + m.group("Msmco_31") + "ico " + m.group("Msmco_32") + "logos" in TEXT and not m.group("Msmco_31") + "ico-" + m.group("Msmco_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_33>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_33") + "ico " + m.group("Msmco_34") + "rios" in TEXT and not " ou " + m.group("Msmco_33") + "ico " + m.group("Msmco_34") + "rios" in TEXT and not "s de " + m.group("Msmco_33") + "ico " + m.group("Msmco_34") + "rios" in TEXT and not "s do " + m.group("Msmco_33") + "ico " + m.group("Msmco_34") + "rios" in TEXT and not " o " + m.group("Msmco_33") + "ico " + m.group("Msmco_34") + "rios" in TEXT and not m.group("Msmco_33") + "ico-" + m.group("Msmco_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_35>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_35") + "ico " + m.group("Msmco_36") + "ssimos" in TEXT and not " ou " + m.group("Msmco_35") + "ico " + m.group("Msmco_36") + "ssimos" in TEXT and not "s de " + m.group("Msmco_35") + "ico " + m.group("Msmco_36") + "ssimos" in TEXT and not "s do " + m.group("Msmco_35") + "ico " + m.group("Msmco_36") + "ssimos" in TEXT and not " o " + m.group("Msmco_35") + "ico " + m.group("Msmco_36") + "ssimos" in TEXT and not m.group("Msmco_35") + "ico-" + m.group("Msmco_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_37>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_37") + "ico " + m.group("Msmco_38") + "simos" in TEXT and not " ou " + m.group("Msmco_37") + "ico " + m.group("Msmco_38") + "simos" in TEXT and not "s de " + m.group("Msmco_37") + "ico " + m.group("Msmco_38") + "simos" in TEXT and not "s do " + m.group("Msmco_37") + "ico " + m.group("Msmco_38") + "simos" in TEXT and not " o " + m.group("Msmco_37") + "ico " + m.group("Msmco_38") + "simos" in TEXT and not m.group("Msmco_37") + "ico-" + m.group("Msmco_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_41>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmco_42") in "D-d-" and not " e " + m.group("Msmco_41") + "ico " + m.group("Msmco_42") + "ores" in TEXT and not " ou " + m.group("Msmco_41") + "ico " + m.group("Msmco_42") + "oras" in TEXT and not "s de " + m.group("Msmco_41") + "ico " + m.group("Msmco_42") + "ores" in TEXT and not "s do " + m.group("Msmco_41") + "ico " + m.group("Msmco_42") + "oras" in TEXT and not " o " + m.group("Msmco_41") + "ico " + m.group("Msmco_42") + "ores" in TEXT and not m.group("Msmco_41") + "ico-" + m.group("Msmco_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_43>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_44") in plvrMfr and not " e " + m.group("Msmco_43") + "ico " + m.group("Msmco_44") + "es" in TEXT and not " ou " + m.group("Msmco_43") + "ico " + m.group("Msmco_44") + "es" in TEXT and not "s de " + m.group("Msmco_43") + "ico " + m.group("Msmco_44") + "es" in TEXT and not "s do " + m.group("Msmco_43") + "ico " + m.group("Msmco_44") + "es" in TEXT and not " o " + m.group("Msmco_43") + "ico " + m.group("Msmco_44") + "es" in TEXT and not m.group("Msmco_43") + "ico-" + m.group("Msmco_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_45>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_46") in plvrMascr and not " e " + m.group("Msmco_45") + "ico " + m.group("Msmco_46") + "es" in TEXT and not " ou " + m.group("Msmco_45") + "ico " + m.group("Msmco_46") + "es" in TEXT and not "s de " + m.group("Msmco_45") + "ico " + m.group("Msmco_46") + "es" in TEXT and not "s do " + m.group("Msmco_45") + "ico " + m.group("Msmco_46") + "es" in TEXT and not " o " + m.group("Msmco_45") + "ico " + m.group("Msmco_46") + "es" in TEXT and not m.group("Msmco_45") + "ico-" + m.group("Msmco_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_47>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_48") in plvrMfal and not " e " + m.group("Msmco_47") + "ico " + m.group("Msmco_48") + "is" in TEXT and not " ou " + m.group("Msmco_47") + "ico " + m.group("Msmco_48") + "is" in TEXT and not "s de " + m.group("Msmco_47") + "ico " + m.group("Msmco_48") + "is" in TEXT and not "s do " + m.group("Msmco_47") + "ico " + m.group("Msmco_48") + "is" in TEXT and not " o " + m.group("Msmco_47") + "ico " + m.group("Msmco_48") + "is" in TEXT and not m.group("Msmco_47") + "ico-" + m.group("Msmco_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_49>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_50") in plvrMfcao and not " e " + m.group("Msmco_49") + "ico " + m.group("Msmco_50") + "ões" in TEXT and not + " ou " + m.group("Msmco_49") + "ico " + m.group("Msmco_50") + "ões" in TEXT and not + "s de " + m.group("Msmco_49") + "ico " + m.group("Msmco_50") + "ões" in TEXT and not + "s do " + m.group("Msmco_49") + "ico " + m.group("Msmco_50") + "ões" in TEXT and not + " a " + m.group("Msmco_49") + "ico " + m.group("Msmco_50") + "ões" in TEXT and not m.group("Msmco_49") + "ico-" + m.group("Msmco_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_51>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_52") in plvrNfemcao and not " e " + m.group("Msmco_51") + "ico " + m.group("Msmco_52") + "ões" in TEXT and not " ou " + m.group("Msmco_51") + "ico " + m.group("Msmco_52") + "ões" in TEXT and not "s de " + m.group("Msmco_51") + "ico " + m.group("Msmco_52") + "ões" in TEXT and not "s do " + m.group("Msmco_51") + "ico " + m.group("Msmco_52") + "ões" in TEXT and not " o " + m.group("Msmco_51") + "ico " + m.group("Msmco_52") + "ões" in TEXT and not m.group("Msmco_51") + "ico-" + m.group("Msmco_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_55>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_55") + "ico " + m.group("Msmco_56") + "veis" in TEXT and not " ou " + m.group("Msmco_55") + "ico " + m.group("Msmco_56") + "veis" in TEXT and not "s de " + m.group("Msmco_55") + "ico " + m.group("Msmco_56") + "veis" in TEXT and not "s do " + m.group("Msmco_55") + "ico " + m.group("Msmco_56") + "veis" in TEXT and not " o " + m.group("Msmco_55") + "ico " + m.group("Msmco_56") + "veis" in TEXT and not m.group("Msmco_55") + "ico-" + m.group("Msmco_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_57>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_58").lower() in plvrMfe and not " e " + m.group("Msmco_57") + "ico " + m.group("Msmco_58") + "es" in TEXT and not " ou " + m.group("Msmco_57") + "ico " + m.group("Msmco_58") + "es" in TEXT and not "s de " + m.group("Msmco_57") + "ico " + m.group("Msmco_58") + "es" in TEXT and not "s do " + m.group("Msmco_57") + "ico " + m.group("Msmco_58") + "es" in TEXT and not " o " + m.group("Msmco_57") + "ico " + m.group("Msmco_58") + "es" in TEXT and not m.group("Msmco_57") + "ico-" + m.group("Msmco_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_59>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_60").lower() in plvrMasce and not " e " + m.group("Msmco_59") + "ico " + m.group("Msmco_60") + "es" in TEXT and not " ou " + m.group("Msmco_59") + "ico " + m.group("Msmco_60") + "es" in TEXT and not "s de " + m.group("Msmco_59") + "ico " + m.group("Msmco_60") + "es" in TEXT and not "s do " + m.group("Msmco_59") + "ico " + m.group("Msmco_60") + "es" in TEXT and not " o " + m.group("Msmco_59") + "ico " + m.group("Msmco_60") + "es" in TEXT and not m.group("Msmco_59") + "ico-" + m.group("Msmco_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_61>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_62") in plvrMfel and not " e " + m.group("Msmco_61") + "ico " + m.group("Msmco_62") + "éis" in TEXT and not " ou " + m.group("Msmco_61") + "ico " + m.group("Msmco_62") + "éis" in TEXT and not "s de " + m.group("Msmco_61") + "ico " + m.group("Msmco_62") + "éis" in TEXT and not "s do " + m.group("Msmco_61") + "ico " + m.group("Msmco_62") + "éis" in TEXT and not " o " + m.group("Msmco_61") + "ico " + m.group("Msmco_62") + "éis" in TEXT and not m.group("Msmco_61") + "ico-" + m.group("Msmco_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_63>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_64") in plvrMascel and not " e " + m.group("Msmco_63") + "ico " + m.group("Msmco_64") + "éis" in TEXT and not " ou " + m.group("Msmco_63") + "ico " + m.group("Msmco_64") + "éis" in TEXT and not "s de " + m.group("Msmco_63") + "ico " + m.group("Msmco_64") + "éis" in TEXT and not "s do " + m.group("Msmco_63") + "ico " + m.group("Msmco_64") + "éis" in TEXT and not " o " + m.group("Msmco_63") + "ico " + m.group("Msmco_64") + "éis" in TEXT and not m.group("Msmco_63") + "ico-" + m.group("Msmco_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_65>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_66") in plvrMfeu and not " e " + m.group("Msmco_65") + "ico " + m.group("Msmco_66") + "us" in TEXT and not " ou " + m.group("Msmco_65") + "ico " + m.group("Msmco_66") + "us" in TEXT and not "s de " + m.group("Msmco_65") + "ico " + m.group("Msmco_66") + "us" in TEXT and not "s do " + m.group("Msmco_65") + "ico " + m.group("Msmco_66") + "us" in TEXT and not " o " + m.group("Msmco_65") + "ico " + m.group("Msmco_66") + "us" in TEXT and not m.group("Msmco_65") + "ico-" + m.group("Msmco_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_67>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_68") in plvrMascu and not " e " + m.group("Msmco_67") + "ico " + m.group("Msmco_68") + "us" in TEXT and not " ou " + m.group("Msmco_67") + "ico " + m.group("Msmco_68") + "us" in TEXT and not "s de " + m.group("Msmco_67") + "ico " + m.group("Msmco_68") + "us" in TEXT and not "s do " + m.group("Msmco_67") + "ico " + m.group("Msmco_68") + "us" in TEXT and not " o " + m.group("Msmco_67") + "ico " + m.group("Msmco_68") + "us" in TEXT and not m.group("Msmco_67") + "ico-" + m.group("Msmco_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_69>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_70") in plvrInvaz and not " e " + m.group("Msmco_69") + "ico " + m.group("Msmco_70") + "zes" in TEXT and not " ou " + m.group("Msmco_69") + "ico " + m.group("Msmco_70") + "zes" in TEXT and not "s de " + m.group("Msmco_69") + "ico " + m.group("Msmco_70") + "zes" in TEXT and not "s do " + m.group("Msmco_69") + "ico " + m.group("Msmco_70") + "zes" in TEXT and not " o " + m.group("Msmco_69") + "ico " + m.group("Msmco_70") + "zes" in TEXT and not m.group("Msmco_69") + "ico-" + m.group("Msmco_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_71>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_72") in plvrMascz and not " e " + m.group("Msmco_71") + "ico " + m.group("Msmco_72") + "zes" in TEXT and not " ou " + m.group("Msmco_71") + "ico " + m.group("Msmco_72") + "zes" in TEXT and not "s de " + m.group("Msmco_71") + "ico " + m.group("Msmco_72") + "zes" in TEXT and not "s do " + m.group("Msmco_71") + "ico " + m.group("Msmco_72") + "zes" in TEXT and not " o " + m.group("Msmco_71") + "ico " + m.group("Msmco_72") + "zes" in TEXT and not m.group("Msmco_71") + "ico-" + m.group("Msmco_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_73>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_74") in pvrMascan and not " e " + m.group("Msmco_73") + "ico " + m.group("Msmco_74") + "s" in TEXT and not " ou " + m.group("Msmco_73") + "ico " + m.group("Msmco_74") + "s" in TEXT and not "s de " + m.group("Msmco_73") + "ico " + m.group("Msmco_74") + "s" in TEXT and not "s do " + m.group("Msmco_73") + "ico " + m.group("Msmco_74") + "s" in TEXT and not " o " + m.group("Msmco_73") + "ico " + m.group("Msmco_74") + "s" in TEXT and not m.group("Msmco_73") + "ico-" + m.group("Msmco_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_75>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_76").lower() in plvrMasco and not " e " + m.group("Msmco_75") + "ico " + m.group("Msmco_76") +"s" in TEXT and not " ou " + m.group("Msmco_75") + "ico " + m.group("Msmco_76") + "s" in TEXT and not "s de " + m.group("Msmco_75") + "ico " + m.group("Msmco_76") + "s" in TEXT and not "s do " + m.group("Msmco_75") + "ico " + m.group("Msmco_76") + "s" in TEXT and not " o " + m.group("Msmco_75") + "ico " + m.group("Msmco_76") + "s" in TEXT and not m.group("Msmco_75") + "ico-" + m.group("Msmco_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_77>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_77") + "ico " + m.group("Msmco_78") + "inhos" in TEXT and not " ou " + m.group("Msmco_77") + "ico " + m.group("Msmco_78") + "inhos" in TEXT and not "s de " + m.group("Msmco_77") + "ico " + m.group("Msmco_78") + "inhos" in TEXT and not "s do " + m.group("Msmco_77") + "ico " + m.group("Msmco_78") + "inhos" in TEXT and not " o " + m.group("Msmco_77") + "ico " + m.group("Msmco_78") + "inhos" in TEXT and not m.group("Msmco_77") + "ico-" + m.group("Msmco_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_79>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_79") + "ico " + m.group("Msmco_80") + "icas" in TEXT and not " ou " + m.group("Msmco_79") + "ico " + m.group("Msmco_80") + "icas" in TEXT and not "s de " + m.group("Msmco_79") + "ico " + m.group("Msmco_80") + "icas" in TEXT and not "s do " + m.group("Msmco_79") + "ico " + m.group("Msmco_80") + "icas" in TEXT and not " o " + m.group("Msmco_79") + "ico " + m.group("Msmco_80") + "icas" in TEXT and not m.group("Msmco_79") + "ico-" + m.group("Msmco_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_81>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_81") + "ico " + m.group("Msmco_82") + "icas" in TEXT and not " ou " + m.group("Msmco_81") + "ico " + m.group("Msmco_82") + "icas" in TEXT and not "s de " + m.group("Msmco_81") + "ico " + m.group("Msmco_82") + "icas" in TEXT and not "s do " + m.group("Msmco_81") + "ico " + m.group("Msmco_82") + "icas" in TEXT and not " o " + m.group("Msmco_81") + "ico " + m.group("Msmco_82") + "icas" in TEXT and not m.group("Msmco_81") + "ico-" + m.group("Msmco_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_83>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_83") + "ico " + m.group("Msmco_84") + "icas" in TEXT and not " ou " + m.group("Msmco_83") + "ico " + m.group("Msmco_84") + "icas" in TEXT and not "s de " + m.group("Msmco_83") + "ico " + m.group("Msmco_84") + "icas" in TEXT and not "s do " + m.group("Msmco_83") + "ico " + m.group("Msmco_84") + "icas" in TEXT and not " o " + m.group("Msmco_83") + "ico " + m.group("Msmco_84") + "icas" in TEXT and not m.group("Msmco_83") + "ico-" + m.group("Msmco_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_85>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_85") + "ico " + m.group("Msmco_86") + "escas" in TEXT and not " ou " + m.group("Msmco_85") + "ico " + m.group("Msmco_86") + "escas" in TEXT and not "s de " + m.group("Msmco_85") + "ico " + m.group("Msmco_86") + "escas" in TEXT and not "s do " + m.group("Msmco_85") + "ico " + m.group("Msmco_86") + "escas" in TEXT and not " o " + m.group("Msmco_85") + "ico " + m.group("Msmco_86") + "escas" in TEXT and not m.group("Msmco_85") + "ico-" + m.group("Msmco_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_87>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_87") + "ico " + m.group("Msmco_88") + "idas" in TEXT and not " ou " + m.group("Msmco_87") + "s " + m.group("Msmco_88") + "idas" in TEXT and not "s de " + m.group("Msmco_87") + "s " + m.group("Msmco_88") + "idas" in TEXT and not "s do " + m.group("Msmco_87") + "s " + m.group("Msmco_88") + "idas" in TEXT and not " o " + m.group("Msmco_87") + "s " + m.group("Msmco_88") + "idas" in TEXT and not m.group("Msmco_87") + "ico-" + m.group("Msmco_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_89>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_89") + "ico " + m.group("Msmco_90") + "logas" in TEXT and not " ou " + m.group("Msmco_89") + "ico " + m.group("Msmco_90") + "logas" in TEXT and not "s de " + m.group("Msmco_89") + "ico " + m.group("Msmco_90") + "logas" in TEXT and not "s do " + m.group("Msmco_89") + "ico " + m.group("Msmco_90") + "logas" in TEXT and not " o " + m.group("Msmco_89") + "ico " + m.group("Msmco_90") + "logas" in TEXT and not m.group("Msmco_89") + "ico-" + m.group("Msmco_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_91>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_91") + "ico " + m.group("Msmco_92") + "rias" in TEXT and not " ou " + m.group("Msmco_91") + "ico " + m.group("Msmco_92") + "rias" in TEXT and not "s de " + m.group("Msmco_91") + "ico " + m.group("Msmco_92") + "rias" in TEXT and not "s do " + m.group("Msmco_91") + "ico " + m.group("Msmco_92") + "rias" in TEXT and not " o " + m.group("Msmco_91") + "ico " + m.group("Msmco_92") + "rias" in TEXT and not m.group("Msmco_91") + "ico-" + m.group("Msmco_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_93>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_93") + "ico " + m.group("Msmco_94") + "ssimas" in TEXT and not " ou " + m.group("Msmco_93") + "ico " + m.group("Msmco_94") + "ssimas" in TEXT and not "s de " + m.group("Msmco_93") + "ico " + m.group("Msmco_94") + "ssimas" in TEXT and not "s do " + m.group("Msmco_93") + "ico " + m.group("Msmco_94") + "ssimas" in TEXT and not " o " + m.group("Msmco_93") + "ico " + m.group("Msmco_94") + "ssimas" in TEXT and not m.group("Msmco_93") + "ico-" + m.group("Msmco_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_95>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmco_95") + "ico " + m.group("Msmco_96") + "simas" in TEXT and not " ou " + m.group("Msmco_95") + "ico " + m.group("Msmco_96") + "simas" in TEXT and not "s de " + m.group("Msmco_95") + "ico " + m.group("Msmco_96") + "simas" in TEXT and not "s do " + m.group("Msmco_95") + "ico " + m.group("Msmco_96") + "simas" in TEXT and not " o " + m.group("Msmco_95") + "ico " + m.group("Msmco_96") + "simas" in TEXT and not m.group("Msmco_95") + "ico-" + m.group("Msmco_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_97>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_98").lower() in plvrMfoa and not " e " + m.group("Msmco_97") + "ico " + m.group("Msmco_98") + "as" in TEXT and not " ou " + m.group("Msmco_97") + "ico " + m.group("Msmco_98") + "as" in TEXT and not "s de " + m.group("Msmco_97") + "ico " + m.group("Msmco_98") + "as" in TEXT and not "s do " + m.group("Msmco_97") + "ico " + m.group("Msmco_98") + "as" in TEXT and not " o " + m.group("Msmco_97") + "ico " + m.group("Msmco_98") + "as" in TEXT and not m.group("Msmco_97") + "ico-" + m.group("Msmco_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_99>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_100") in plvrMFm and not " e " + m.group("Msmco_99") + "ico " + m.group("Msmco_100") + "ns" in TEXT and not " ou " + m.group("Msmco_99") + "ico " + m.group("Msmco_100") + "ns" in TEXT and not "s de " + m.group("Msmco_99") + "ico " + m.group("Msmco_100") + "ns" in TEXT and not "s da " + m.group("Msmco_99") + "ico " + m.group("Msmco_100") + "ns" in TEXT and not " a " + m.group("Msmco_99") + "ico " + m.group("Msmco_100") + "ns" in TEXT and not m.group("Msmco_99") + "ico-" + m.group("Msmco_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmco_101>[a-zA-Zç]+[âêô][mn])ico (?P<Msmco_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmco_102") in plvrMascm and not " e " + m.group("Msmco_101") + "ico " + m.group("Msmco_102") + "ns" in TEXT and not " ou " + m.group("Msmco_101") + "ico " + m.group("Msmco_102") + "ns" in TEXT and not "s de " + m.group("Msmco_101") + "ico " + m.group("Msmco_102") + "ns" in TEXT and not "s da " + m.group("Msmco_101") + "ico " + m.group("Msmco_102") + "ns" in TEXT and not " a " + m.group("Msmco_101") + "ico " + m.group("Msmco_102") + "ns" in TEXT and not m.group("Msmco_101") + "ico-" + m.group("Msmco_102") + "ns" in tCompostops'],
# xxxica
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_1>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_2").lower() in plvrFema and not " e " + m.group("Mszca_1") + "ica " + m.group("Mszca_2") +"s" in TEXT and not " ou " + m.group("Mszca_1") + "ica " + m.group("Mszca_2") + "s" in TEXT and not "s de " + m.group("Mszca_1") + "ica " + m.group("Mszca_2") + "s" in TEXT and not "s da " + m.group("Mszca_1") + "ica " + m.group("Mszca_2") + "s" in TEXT and not " a " + m.group("Mszca_1") + "ica " + m.group("Mszca_2") + "s" in TEXT and not m.group("Mszca_1") + "ica-" + m.group("Mszca_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_3>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_4").lower() in plvrMfoa and not " e " + m.group("Mszca_3") + "ica " + m.group("Mszca_4") + "as" in TEXT and not " ou " + m.group("Mszca_3") + "ica " + m.group("Mszca_4") + "as" in TEXT and not "s de " + m.group("Mszca_3") + "ica " + m.group("Mszca_4") + "as" in TEXT and not "s da " + m.group("Mszca_3") + "ica " + m.group("Mszca_4") + "as" in TEXT and not " a " + m.group("Mszca_3") + "ica " + m.group("Mszca_4") + "as" in TEXT and not m.group("Mszca_3") + "ica-" + m.group("Mszca_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_5>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mszca_6").lower() in excAdo and not " e " + m.group("Mszca_5") + "ica " + m.group("Mszca_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Mszca_5") + "ica " + m.group("Mszca_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Mszca_5") + "ica " + m.group("Mszca_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Mszca_5") + "ica " + m.group("Mszca_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Mszca_5") + "ica " + m.group("Mszca_6") + m.group(3) + "dos" in TEXT and not m.group("Mszca_5") + "ica-" + m.group("Mszca_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_7>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mszca_8").lower() in excIsta and not " e " + m.group("Mszca_7") + "ica " + m.group("Mszca_8") + "s" in TEXT and not " ou " + m.group("Mszca_7") + "ica " + m.group("Mszca_8") + "s" in TEXT and not "s de " + m.group("Mszca_7") + "ica " + m.group("Mszca_8") + "s" in TEXT and not "s da " + m.group("Mszca_7") + "ica " + m.group("Mszca_8") + "s" in TEXT and not " a " + m.group("Mszca_7") + "ica " + m.group("Mszca_8") + "s" in TEXT and not m.group("Mszca_7") + "ica-" + m.group("Mszca_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_9>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_10").lower() in plvrInva and not " e " + m.group("Mszca_9") + "ica " + m.group("Mszca_10") + "s" in TEXT and not " ou " + m.group("Mszca_9") + "ica " + m.group("Mszca_10") + "s" in TEXT and not "s de " + m.group("Mszca_9") + "ica " + m.group("Mszca_10") + "s" in TEXT and not "s da " + m.group("Mszca_9") + "ica " + m.group("Mszca_10") + "s" in TEXT and not " a " + m.group("Mszca_9") + "ica " + m.group("Mszca_10") + "s" in TEXT and not m.group("Mszca_9") + "ica-" + m.group("Mszca_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_11>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mszca_12").lower() in excAdo and not " e " + m.group("Mszca_11") + "ica " + m.group("Mszca_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Mszca_11") + "ica " + m.group("Mszca_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Mszca_11") + "ica " + m.group("Mszca_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Mszca_11") + "ica " + m.group("Mszca_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Mszca_11") + "ica " + m.group("Mszca_12") + m.group(3) + "das" in TEXT and not m.group("Mszca_11") + "ica-" + m.group("Mszca_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_13>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszca_13") + "ica " + m.group("Mszca_14") + "osos" in TEXT and not " ou " + m.group("Mszca_13") + "ica " + m.group("Mszca_14") + "osos" in TEXT and not "s de " + m.group("Mszca_13") + "ica " + m.group("Mszca_14") + "osos" in TEXT and not "s da " + m.group("Mszca_13") + "ica " + m.group("Mszca_14") + "osos" in TEXT and not " a " + m.group("Mszca_13") + "ica " + m.group("Mszca_14") + "osos" in TEXT and not m.group("Mszca_13") + "ica-" + m.group("Mszca_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_15>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszca_15") + "ica " + m.group("Mszca_16") + "osas" in TEXT and not " ou " + m.group("Mszca_15") + "ica " + m.group("Mszca_16") + "osas" in TEXT and not "s de " + m.group("Mszca_15") + "ica " + m.group("Mszca_16") + "osas" in TEXT and not "s da " + m.group("Mszca_15") + "ica " + m.group("Mszca_16") + "osas" in TEXT and not " a " + m.group("Mszca_15") + "ica " + m.group("Mszca_16") + "osas" in TEXT and not m.group("Mszca_15") + "ica-" + m.group("Mszca_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_17>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszca_17") + "ica " + m.group("Mszca_18") + "ivas" in TEXT and not " ou " + m.group("Mszca_17") + "ica " + m.group("Mszca_18") + "ivas" in TEXT and not "s de " + m.group("Mszca_17") + "ica " + m.group("Mszca_18") + "ivas" in TEXT and not "s da " + m.group("Mszca_17") + "ica " + m.group("Mszca_18") + "ivas" in TEXT and not " a " + m.group("Mszca_17") + "ica " + m.group("Mszca_18") + "ivas" in TEXT and not m.group("Mszca_17") + "ica-" + m.group("Mszca_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_19>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszca_19") + "ica " + m.group("Mszca_20") + "ivas" in TEXT and not " ou " + m.group("Mszca_19") + "ica " + m.group("Mszca_20") + "ivas" in TEXT and not "s de " + m.group("Mszca_19") + "ica " + m.group("Mszca_20") + "ivas" in TEXT and not "s da " + m.group("Mszca_19") + "ica " + m.group("Mszca_20") + "ivas" in TEXT and not " a " + m.group("Mszca_19") + "ica " + m.group("Mszca_20") + "ivas" in TEXT and not m.group("Mszca_19") + "ica-" + m.group("Mszca_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_21>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszca_21") + "ica " + m.group("Mszca_22") + "icas" in TEXT and not " ou " + m.group("Mszca_21") + "ica " + m.group("Mszca_22") + "icas" in TEXT and not "s de " + m.group("Mszca_21") + "ica " + m.group("Mszca_22") + "icas" in TEXT and not "s da " + m.group("Mszca_21") + "ica " + m.group("Mszca_22") + "icas" in TEXT and not " a " + m.group("Mszca_21") + "ica " + m.group("Mszca_22") + "icas" in TEXT and not m.group("Mszca_21") + "ica-" + m.group("Mszca_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_23>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszca_23") + "ica " + m.group("Mszca_24") + "icas" in TEXT and not " ou " + m.group("Mszca_23") + "ica " + m.group("Mszca_24") + "icas" in TEXT and not "s de " + m.group("Mszca_23") + "ica " + m.group("Mszca_24") + "icas" in TEXT and not "s da " + m.group("Mszca_23") + "ica " + m.group("Mszca_24") + "icas" in TEXT and not " a " + m.group("Mszca_23") + "ica " + m.group("Mszca_24") + "icas" in TEXT and not m.group("Mszca_23") + "ica-" + m.group("Mszca_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_25>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszca_25") + "ica " + m.group("Mszca_26") + "icas" in TEXT and not " ou " + m.group("Mszca_25") + "ica " + m.group("Mszca_26") + "icas" in TEXT and not "s de " + m.group("Mszca_25") + "ica " + m.group("Mszca_26") + "icas" in TEXT and not "s da " + m.group("Mszca_25") + "ica " + m.group("Mszca_26") + "icas" in TEXT and not " a " + m.group("Mszca_25") + "ica " + m.group("Mszca_26") + "icas" in TEXT and not m.group("Mszca_25") + "ica-" + m.group("Mszca_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_27>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszca_27") + "ica " + m.group("Mszca_28") + "escas" in TEXT and not " ou " + m.group("Mszca_27") + "ica " + m.group("Mszca_28") + "escas" in TEXT and not "s de " + m.group("Mszca_27") + "ica " + m.group("Mszca_28") + "escas" in TEXT and not "s da " + m.group("Mszca_27") + "ica " + m.group("Mszca_28") + "escas" in TEXT and not " a " + m.group("Mszca_27") + "ica " + m.group("Mszca_28") + "escas" in TEXT and not m.group("Mszca_27") + "ica-" + m.group("Mszca_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_29>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszca_29") + "ica " + m.group("Mszca_30") + "idas" in TEXT and not " ou " + m.group("Mszca_29") + "s " + m.group("Mszca_30") + "idas" in TEXT and not "s de " + m.group("Mszca_29") + "s " + m.group("Mszca_30") + "idas" in TEXT and not "s da " + m.group("Mszca_29") + "s " + m.group("Mszca_30") + "idas" in TEXT and not " a " + m.group("Mszca_29") + "s " + m.group("Mszca_30") + "idas" in TEXT and not m.group("Mszca_29") + "ica-" + m.group("Mszca_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_31>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszca_31") + "ica " + m.group("Mszca_32") + "logas" in TEXT and not " ou " + m.group("Mszca_31") + "ica " + m.group("Mszca_32") + "logas" in TEXT and not "s de " + m.group("Mszca_31") + "ica " + m.group("Mszca_32") + "logas" in TEXT and not "s da " + m.group("Mszca_31") + "ica " + m.group("Mszca_32") + "logas" in TEXT and not " a " + m.group("Mszca_31") + "ica " + m.group("Mszca_32") + "logas" in TEXT and not m.group("Mszca_31") + "ica-" + m.group("Mszca_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_33>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszca_33") + "ica " + m.group("Mszca_34") + "rias" in TEXT and not " ou " + m.group("Mszca_33") + "ica " + m.group("Mszca_34") + "rias" in TEXT and not "s de " + m.group("Mszca_33") + "ica " + m.group("Mszca_34") + "rias" in TEXT and not "s da " + m.group("Mszca_33") + "ica " + m.group("Mszca_34") + "rias" in TEXT and not " a " + m.group("Mszca_33") + "ica " + m.group("Mszca_34") + "rias" in TEXT and not m.group("Mszca_33") + "ica-" + m.group("Mszca_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_35>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszca_35") + "ica " + m.group("Mszca_36") + "ssimas" in TEXT and not " ou " + m.group("Mszca_35") + "ica " + m.group("Mszca_36") + "ssimas" in TEXT and not "s de " + m.group("Mszca_35") + "ica " + m.group("Mszca_36") + "ssimas" in TEXT and not "s da " + m.group("Mszca_35") + "ica " + m.group("Mszca_36") + "ssimas" in TEXT and not " a " + m.group("Mszca_35") + "ica " + m.group("Mszca_36") + "ssimas" in TEXT and not m.group("Mszca_35") + "ica-" + m.group("Mszca_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_37>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszca_37") + "ica " + m.group("Mszca_38") + "simas" in TEXT and not " ou " + m.group("Mszca_37") + "ica " + m.group("Mszca_38") + "simas" in TEXT and not "s de " + m.group("Mszca_37") + "ica " + m.group("Mszca_38") + "simas" in TEXT and not "s da " + m.group("Mszca_37") + "ica " + m.group("Mszca_38") + "simas" in TEXT and not " a " + m.group("Mszca_37") + "ica " + m.group("Mszca_38") + "simas" in TEXT and not m.group("Mszca_37") + "ica-" + m.group("Mszca_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_41>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mszca_42") in "D-d-" and not " e " + m.group("Mszca_41") + "ica " + m.group("Mszca_42") + "oras" in TEXT and not " ou " + m.group("Mszca_41") + "ica " + m.group("Mszca_42") + "oras" in TEXT and not "s de " + m.group("Mszca_41") + "ica " + m.group("Mszca_42") + "oras" in TEXT and not "s da " + m.group("Mszca_41") + "ica " + m.group("Mszca_42") + "oras" in TEXT and not " a " + m.group("Mszca_41") + "ica " + m.group("Mszca_42") + "oras" in TEXT and not m.group("Mszca_41") + "ica-" + m.group("Mszca_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_43>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_44") in plvrMfr and not " e " + m.group("Mszca_43") + "ica " + m.group("Mszca_44") + "es" in TEXT and not " ou " + m.group("Mszca_43") + "ica " + m.group("Mszca_44") + "es" in TEXT and not "s de " + m.group("Mszca_43") + "ica " + m.group("Mszca_44") + "es" in TEXT and not "s da " + m.group("Mszca_43") + "ica " + m.group("Mszca_44") + "es" in TEXT and not " a " + m.group("Mszca_43") + "ica " + m.group("Mszca_44") + "es" in TEXT and not m.group("Mszca_43") + "ica-" + m.group("Mszca_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_45>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_46") in plvrFemr and not " e " + m.group("Mszca_45") + "ica " + m.group("Mszca_46") + "es" in TEXT and not " ou " + m.group("Mszca_45") + "ica " + m.group("Mszca_46") + "es" in TEXT and not "s de " + m.group("Mszca_45") + "ica " + m.group("Mszca_46") + "es" in TEXT and not "s da " + m.group("Mszca_45") + "ica " + m.group("Mszca_46") + "es" in TEXT and not " a " + m.group("Mszca_45") + "ica " + m.group("Mszca_46") + "es" in TEXT and not m.group("Mszca_45") + "ica-" + m.group("Mszca_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_47>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_48") in plvrMfal and not " e " + m.group("Mszca_47") + "ica " + m.group("Mszca_48") + "is" in TEXT and not " ou " + m.group("Mszca_47") + "ica " + m.group("Mszca_48") + "is" in TEXT and not "s de " + m.group("Mszca_47") + "ica " + m.group("Mszca_48") + "is" in TEXT and not "s da " + m.group("Mszca_47") + "ica " + m.group("Mszca_48") + "is" in TEXT and not " a " + m.group("Mszca_47") + "ica " + m.group("Mszca_48") + "is" in TEXT and not m.group("Mszca_47") + "ica-" + m.group("Mszca_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_49>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_50") in plvrMfcao and not " e " + m.group("Mszca_49") + "ica " + m.group("Mszca_50") + "ões" in TEXT and not + " ou " + m.group("Mszca_49") + "ica " + m.group("Mszca_50") + "ões" in TEXT and not + "s de " + m.group("Mszca_49") + "ica " + m.group("Mszca_50") + "ões" in TEXT and not + "s da " + m.group("Mszca_49") + "ica " + m.group("Mszca_50") + "ões" in TEXT and not + " a " + m.group("Mszca_49") + "ica " + m.group("Mszca_50") + "ões" in TEXT and not m.group("Mszca_49") + "ica-" + m.group("Mszca_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_51>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mszca_52") in plvrMascao and not " e " + m.group("Mszca_51") + "ica " + m.group("Mszca_52") + "ões" in TEXT and not " ou " + m.group("Mszca_51") + "ica " + m.group("Mszca_52") + "ões" in TEXT and not "s de " + m.group("Mszca_51") + "ica " + m.group("Mszca_52") + "ões" in TEXT and not "s da " + m.group("Mszca_51") + "ica " + m.group("Mszca_52") + "ões" in TEXT and not " a " + m.group("Mszca_51") + "ica " + m.group("Mszca_52") + "ões" in TEXT and not m.group("Mszca_51") + "ica-" + m.group("Mszca_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_53>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_54") in plvrFemao and not " e " + m.group("Mszca_53") + "ica " + m.group("Mszca_54") + "ões" in TEXT and not " ou " + m.group("Mszca_53") + "ica " + m.group("Mszca_54") + "ões" in TEXT and not "s de " + m.group("Mszca_53") + "ica " + m.group("Mszca_54") + "ões" in TEXT and not "s da " + m.group("Mszca_53") + "ica " + m.group("Mszca_54") + "ões" in TEXT and not " a " + m.group("Mszca_53") + "ica " + m.group("Mszca_54") + "ões" in TEXT and not m.group("Mszca_53") + "ica-" + m.group("Mszca_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_55>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszca_55") + "ica " + m.group("Mszca_56") + "veis" in TEXT and not " ou " + m.group("Mszca_55") + "ica " + m.group("Mszca_56") + "veis" in TEXT and not "s de " + m.group("Mszca_55") + "ica " + m.group("Mszca_56") + "veis" in TEXT and not "s da " + m.group("Mszca_55") + "ica " + m.group("Mszca_56") + "veis" in TEXT and not " a " + m.group("Mszca_55") + "ica " + m.group("Mszca_56") + "veis" in TEXT and not m.group("Mszca_55") + "ica-" + m.group("Mszca_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_57>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_58").lower() in plvrMfe and not " e " + m.group("Mszca_57") + "ica " + m.group("Mszca_58") + "es" in TEXT and not " ou " + m.group("Mszca_57") + "ica " + m.group("Mszca_58") + "es" in TEXT and not "s de " + m.group("Mszca_57") + "ica " + m.group("Mszca_58") + "es" in TEXT and not "s da " + m.group("Mszca_57") + "ica " + m.group("Mszca_58") + "es" in TEXT and not " a " + m.group("Mszca_57") + "ica " + m.group("Mszca_58") + "es" in TEXT and not m.group("Mszca_57") + "ica-" + m.group("Mszca_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_59>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_60").lower() in plvrFeme and not " e " + m.group("Mszca_59") + "ica " + m.group("Mszca_60") + "es" in TEXT and not " ou " + m.group("Mszca_59") + "ica " + m.group("Mszca_60") + "es" in TEXT and not "s de " + m.group("Mszca_59") + "ica " + m.group("Mszca_60") + "es" in TEXT and not "s da " + m.group("Mszca_59") + "ica " + m.group("Mszca_60") + "es" in TEXT and not " a " + m.group("Mszca_59") + "ica " + m.group("Mszca_60") + "es" in TEXT and not m.group("Mszca_59") + "ica-" + m.group("Mszca_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_61>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_62") in plvrMfel and not " e " + m.group("Mszca_61") + "ica " + m.group("Mszca_62") + "éis" in TEXT and not " ou " + m.group("Mszca_61") + "ica " + m.group("Mszca_62") + "éis" in TEXT and not "s de " + m.group("Mszca_61") + "ica " + m.group("Mszca_62") + "éis" in TEXT and not "s da " + m.group("Mszca_61") + "ica " + m.group("Mszca_62") + "éis" in TEXT and not " a " + m.group("Mszca_61") + "ica " + m.group("Mszca_62") + "éis" in TEXT and not m.group("Mszca_61") + "ica-" + m.group("Mszca_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_63>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_64") in plvrFemel and not " e " + m.group("Mszca_63") + "ica " + m.group("Mszca_64") + "éis" in TEXT and not " ou " + m.group("Mszca_63") + "ica " + m.group("Mszca_64") + "éis" in TEXT and not "s de " + m.group("Mszca_63") + "ica " + m.group("Mszca_64") + "éis" in TEXT and not "s da " + m.group("Mszca_63") + "ica " + m.group("Mszca_64") + "éis" in TEXT and not " a " + m.group("Mszca_63") + "ica " + m.group("Mszca_64") + "éis" in TEXT and not m.group("Mszca_63") + "ica-" + m.group("Mszca_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_65>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_66") in plvrMfeu and not " e " + m.group("Mszca_65") + "ica " + m.group("Mszca_66") + "us" in TEXT and not " ou " + m.group("Mszca_65") + "ica " + m.group("Mszca_66") + "us" in TEXT and not "s de " + m.group("Mszca_65") + "ica " + m.group("Mszca_66") + "us" in TEXT and not "s da " + m.group("Mszca_65") + "ica " + m.group("Mszca_66") + "us" in TEXT and not " a " + m.group("Mszca_65") + "ica " + m.group("Mszca_66") + "us" in TEXT and not m.group("Mszca_65") + "ica-" + m.group("Mszca_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_67>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_68") in plvrFemu and not " e " + m.group("Mszca_67") + "ica " + m.group("Mszca_68") + "us" in TEXT and not " ou " + m.group("Mszca_67") + "ica " + m.group("Mszca_68") + "us" in TEXT and not "s de " + m.group("Mszca_67") + "ica " + m.group("Mszca_68") + "us" in TEXT and not "s da " + m.group("Mszca_67") + "ica " + m.group("Mszca_68") + "us" in TEXT and not " a " + m.group("Mszca_67") + "ica " + m.group("Mszca_68") + "us" in TEXT and not m.group("Mszca_67") + "ica-" + m.group("Mszca_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_69>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_70") in plvrInvaz and not " e " + m.group("Mszca_69") + "ica " + m.group("Mszca_70") + "zes" in TEXT and not " ou " + m.group("Mszca_69") + "ica " + m.group("Mszca_70") + "zes" in TEXT and not "s de " + m.group("Mszca_69") + "ica " + m.group("Mszca_70") + "zes" in TEXT and not "s da " + m.group("Mszca_69") + "ica " + m.group("Mszca_70") + "zes" in TEXT and not " a " + m.group("Mszca_69") + "ica " + m.group("Mszca_70") + "zes" in TEXT and not m.group("Mszca_69") + "ica-" + m.group("Mszca_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_71>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_72") in plvrFemz and not " e " + m.group("Mszca_71") + "ica " + m.group("Mszca_72") + "zes" in TEXT and not " ou " + m.group("Mszca_71") + "ica " + m.group("Mszca_72") + "zes" in TEXT and not "s de " + m.group("Mszca_71") + "ica " + m.group("Mszca_72") + "zes" in TEXT and not "s da " + m.group("Mszca_71") + "ica " + m.group("Mszca_72") + "zes" in TEXT and not " a " + m.group("Mszca_71") + "ica " + m.group("Mszca_72") + "zes" in TEXT and not m.group("Mszca_71") + "ica-" + m.group("Mszca_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_73>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_74") in pvrFeman and not " e " + m.group("Mszca_73") + "ica " + m.group("Mszca_74") + "s" in TEXT and not " ou " + m.group("Mszca_73") + "ica " + m.group("Mszca_74") + "s" in TEXT and not "s de " + m.group("Mszca_73") + "ica " + m.group("Mszca_74") + "s" in TEXT and not "s da " + m.group("Mszca_73") + "ica " + m.group("Mszca_74") + "s" in TEXT and not " a " + m.group("Mszca_73") + "ica " + m.group("Mszca_74") + "s" in TEXT and not m.group("Mszca_73") + "ica-" + m.group("Mszca_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_99>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_100") in plvrMFm and not " e " + m.group("Mszca_99") + "ica " + m.group("Mszca_100") + "ns" in TEXT and not " ou " + m.group("Mszca_99") + "ica " + m.group("Mszca_100") + "ns" in TEXT and not "s de " + m.group("Mszca_99") + "ica " + m.group("Mszca_100") + "ns" in TEXT and not "s da " + m.group("Mszca_99") + "ica " + m.group("Mszca_100") + "ns" in TEXT and not " a " + m.group("Mszca_99") + "ica " + m.group("Mszca_100") + "ns" in TEXT and not m.group("Mszca_99") + "ica-" + m.group("Mszca_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszca_101>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica (?P<Mszca_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszca_102") in plvrFemm and not " e " + m.group("Mszca_101") + "ica " + m.group("Mszca_102") + "ns" in TEXT and not " ou " + m.group("Mszca_101") + "ica " + m.group("Mszca_102") + "ns" in TEXT and not "s de " + m.group("Mszca_101") + "ica " + m.group("Mszca_102") + "ns" in TEXT and not "s da " + m.group("Mszca_101") + "ica " + m.group("Mszca_102") + "ns" in TEXT and not " a " + m.group("Mszca_101") + "ica " + m.group("Mszca_102") + "ns" in TEXT and not m.group("Mszca_101") + "ica-" + m.group("Mszca_102") + "ns" in tCompostops'],
# xxxico
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_1>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_2").lower() in plvrMasca and not " e " + m.group("Mszco_1") + "ico " + m.group("Mszco_2") +"s" in TEXT and not " ou " + m.group("Mszco_1") + "ico " + m.group("Mszco_2") + "s" in TEXT and not "s de " + m.group("Mszco_1") + "ico " + m.group("Mszco_2") + "s" in TEXT and not "s do " + m.group("Mszco_1") + "ico " + m.group("Mszco_2") + "s" in TEXT and not " o " + m.group("Mszco_1") + "ico " + m.group("Mszco_2") + "s" in TEXT and not m.group("Mszco_1") + "ico-" + m.group("Mszco_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_3>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_4").lower() in plvrMfoa and not " e " + m.group("Mszco_3") + "ico " + m.group("Mszco_4") + "os" in TEXT and not " ou " + m.group("Mszco_3") + "ico " + m.group("Mszco_4") + "os" in TEXT and not "s de " + m.group("Mszco_3") + "ico " + m.group("Mszco_4") + "os" in TEXT and not "s do " + m.group("Mszco_3") + "ico " + m.group("Mszco_4") + "os" in TEXT and not " o " + m.group("Mszco_3") + "ico " + m.group("Mszco_4") + "os" in TEXT and not m.group("Mszco_3") + "ico-" + m.group("Mszco_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_5>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mszco_6").lower() in excAdo and not " e " + m.group("Mszco_5") + "ico " + m.group("Mszco_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Mszco_5") + "ico " + m.group("Mszco_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Mszco_5") + "ico " + m.group("Mszco_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Mszco_5") + "ico " + m.group("Mszco_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Mszco_5") + "ico " + m.group("Mszco_6") + m.group(3) + "dos" in TEXT and not m.group("Mszco_5") + "ico-" + m.group("Mszco_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_7>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mszco_8").lower() in excIsta and not " e " + m.group("Mszco_7") + "ico " + m.group("Mszco_8") + "s" in TEXT and not " ou " + m.group("Mszco_7") + "ico " + m.group("Mszco_8") + "s" in TEXT and not "s de " + m.group("Mszco_7") + "ico " + m.group("Mszco_8") + "s" in TEXT and not "s do " + m.group("Mszco_7") + "ico " + m.group("Mszco_8") + "s" in TEXT and not " o " + m.group("Mszco_7") + "ico " + m.group("Mszco_8") + "s" in TEXT and not m.group("Mszco_7") + "ico-" + m.group("Mszco_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_9>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_10").lower() in plvrInva and not " e " + m.group("Mszco_9") + "ico " + m.group("Mszco_10") + "s" in TEXT and not " ou " + m.group("Mszco_9") + "ico " + m.group("Mszco_10") + "s" in TEXT and not "s de " + m.group("Mszco_9") + "ico " + m.group("Mszco_10") + "s" in TEXT and not "s do " + m.group("Mszco_9") + "ico " + m.group("Mszco_10") + "s" in TEXT and not " a " + m.group("Mszco_9") + "ico " + m.group("Mszco_10") + "s" in TEXT and not m.group("Mszco_9") + "ico-" + m.group("Mszco_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_11>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mszco_12").lower() in excAdo and not " e " + m.group("Mszco_11") + "ico " + m.group("Mszco_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Mszco_11") + "ico " + m.group("Mszco_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Mszco_11") + "ico " + m.group("Mszco_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Mszco_11") + "ico " + m.group("Mszco_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Mszco_11") + "ico " + m.group("Mszco_12") + m.group(3) + "das" in TEXT and not m.group("Mszco_11") + "ico-" + m.group("Mszco_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_13>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_13") + "ico " + m.group("Mszco_14") + "osos" in TEXT and not " ou " + m.group("Mszco_13") + "ico " + m.group("Mszco_14") + "osos" in TEXT and not "s de " + m.group("Mszco_13") + "ico " + m.group("Mszco_14") + "osos" in TEXT and not "s do " + m.group("Mszco_13") + "ico " + m.group("Mszco_14") + "osos" in TEXT and not " o " + m.group("Mszco_13") + "ico " + m.group("Mszco_14") + "osos" in TEXT and not m.group("Mszco_13") + "ico-" + m.group("Mszco_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_15>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_15") + "ico " + m.group("Mszco_16") + "osas" in TEXT and not " ou " + m.group("Mszco_15") + "ico " + m.group("Mszco_16") + "osas" in TEXT and not "s de " + m.group("Mszco_15") + "ico " + m.group("Mszco_16") + "osas" in TEXT and not "s do " + m.group("Mszco_15") + "ico " + m.group("Mszco_16") + "osas" in TEXT and not " o " + m.group("Mszco_15") + "ico " + m.group("Mszco_16") + "osas" in TEXT and not m.group("Mszco_15") + "ico-" + m.group("Mszco_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_17>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_17") + "ico " + m.group("Mszco_18") + "ivas" in TEXT and not " ou " + m.group("Mszco_17") + "ico " + m.group("Mszco_18") + "ivas" in TEXT and not "s de " + m.group("Mszco_17") + "ico " + m.group("Mszco_18") + "ivas" in TEXT and not "s do " + m.group("Mszco_17") + "ico " + m.group("Mszco_18") + "ivas" in TEXT and not " o " + m.group("Mszco_17") + "ico " + m.group("Mszco_18") + "ivas" in TEXT and not m.group("Mszco_17") + "ico-" + m.group("Mszco_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_19>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_19") + "ico " + m.group("Mszco_20") + "ivas" in TEXT and not " ou " + m.group("Mszco_19") + "ico " + m.group("Mszco_20") + "ivas" in TEXT and not "s de " + m.group("Mszco_19") + "ico " + m.group("Mszco_20") + "ivas" in TEXT and not "s do " + m.group("Mszco_19") + "ico " + m.group("Mszco_20") + "ivas" in TEXT and not " o " + m.group("Mszco_19") + "ico " + m.group("Mszco_20") + "ivas" in TEXT and not m.group("Mszco_19") + "ico-" + m.group("Mszco_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_21>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_21") + "ico " + m.group("Mszco_22") + "icos" in TEXT and not " ou " + m.group("Mszco_21") + "ico " + m.group("Mszco_22") + "icos" in TEXT and not "s de " + m.group("Mszco_21") + "ico " + m.group("Mszco_22") + "icos" in TEXT and not "s do " + m.group("Mszco_21") + "ico " + m.group("Mszco_22") + "icos" in TEXT and not " o " + m.group("Mszco_21") + "ico " + m.group("Mszco_22") + "icos" in TEXT and not m.group("Mszco_21") + "ico-" + m.group("Mszco_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_23>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_23") + "ico " + m.group("Mszco_24") + "icos" in TEXT and not " ou " + m.group("Mszco_23") + "ico " + m.group("Mszco_24") + "icos" in TEXT and not "s de " + m.group("Mszco_23") + "ico " + m.group("Mszco_24") + "icos" in TEXT and not "s do " + m.group("Mszco_23") + "ico " + m.group("Mszco_24") + "icos" in TEXT and not " o " + m.group("Mszco_23") + "ico " + m.group("Mszco_24") + "icos" in TEXT and not m.group("Mszco_23") + "ico-" + m.group("Mszco_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_25>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_25") + "ico " + m.group("Mszco_26") + "icos" in TEXT and not " ou " + m.group("Mszco_25") + "ico " + m.group("Mszco_26") + "icos" in TEXT and not "s de " + m.group("Mszco_25") + "ico " + m.group("Mszco_26") + "icos" in TEXT and not "s do " + m.group("Mszco_25") + "ico " + m.group("Mszco_26") + "icos" in TEXT and not " o " + m.group("Mszco_25") + "ico " + m.group("Mszco_26") + "icos" in TEXT and not m.group("Mszco_25") + "ico-" + m.group("Mszco_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_27>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_27") + "ico " + m.group("Mszco_28") + "escos" in TEXT and not " ou " + m.group("Mszco_27") + "ico " + m.group("Mszco_28") + "escos" in TEXT and not "s de " + m.group("Mszco_27") + "ico " + m.group("Mszco_28") + "escos" in TEXT and not "s do " + m.group("Mszco_27") + "ico " + m.group("Mszco_28") + "escos" in TEXT and not " o " + m.group("Mszco_27") + "ico " + m.group("Mszco_28") + "escos" in TEXT and not m.group("Mszco_27") + "ico-" + m.group("Mszco_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_29>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_29") + "ico " + m.group("Mszco_30") + "idos" in TEXT and not " ou " + m.group("Mszco_29") + "s " + m.group("Mszco_30") + "idos" in TEXT and not "s de " + m.group("Mszco_29") + "s " + m.group("Mszco_30") + "idos" in TEXT and not "s do " + m.group("Mszco_29") + "s " + m.group("Mszco_30") + "idos" in TEXT and not " o " + m.group("Mszco_29") + "s " + m.group("Mszco_30") + "idos" in TEXT and not m.group("Mszco_29") + "ico-" + m.group("Mszco_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_31>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_31") + "ico " + m.group("Mszco_32") + "logos" in TEXT and not " ou " + m.group("Mszco_31") + "ico " + m.group("Mszco_32") + "logos" in TEXT and not "s de " + m.group("Mszco_31") + "ico " + m.group("Mszco_32") + "logos" in TEXT and not "s do " + m.group("Mszco_31") + "ico " + m.group("Mszco_32") + "logos" in TEXT and not " o " + m.group("Mszco_31") + "ico " + m.group("Mszco_32") + "logos" in TEXT and not m.group("Mszco_31") + "ico-" + m.group("Mszco_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_33>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_33") + "ico " + m.group("Mszco_34") + "rios" in TEXT and not " ou " + m.group("Mszco_33") + "ico " + m.group("Mszco_34") + "rios" in TEXT and not "s de " + m.group("Mszco_33") + "ico " + m.group("Mszco_34") + "rios" in TEXT and not "s do " + m.group("Mszco_33") + "ico " + m.group("Mszco_34") + "rios" in TEXT and not " o " + m.group("Mszco_33") + "ico " + m.group("Mszco_34") + "rios" in TEXT and not m.group("Mszco_33") + "ico-" + m.group("Mszco_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_35>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_35") + "ico " + m.group("Mszco_36") + "ssimos" in TEXT and not " ou " + m.group("Mszco_35") + "ico " + m.group("Mszco_36") + "ssimos" in TEXT and not "s de " + m.group("Mszco_35") + "ico " + m.group("Mszco_36") + "ssimos" in TEXT and not "s do " + m.group("Mszco_35") + "ico " + m.group("Mszco_36") + "ssimos" in TEXT and not " o " + m.group("Mszco_35") + "ico " + m.group("Mszco_36") + "ssimos" in TEXT and not m.group("Mszco_35") + "ico-" + m.group("Mszco_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_37>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_37") + "ico " + m.group("Mszco_38") + "simos" in TEXT and not " ou " + m.group("Mszco_37") + "ico " + m.group("Mszco_38") + "simos" in TEXT and not "s de " + m.group("Mszco_37") + "ico " + m.group("Mszco_38") + "simos" in TEXT and not "s do " + m.group("Mszco_37") + "ico " + m.group("Mszco_38") + "simos" in TEXT and not " o " + m.group("Mszco_37") + "ico " + m.group("Mszco_38") + "simos" in TEXT and not m.group("Mszco_37") + "ico-" + m.group("Mszco_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_41>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mszco_42") in "D-d-" and not " e " + m.group("Mszco_41") + "ico " + m.group("Mszco_42") + "ores" in TEXT and not " ou " + m.group("Mszco_41") + "ico " + m.group("Mszco_42") + "ores" in TEXT and not "s de " + m.group("Mszco_41") + "ico " + m.group("Mszco_42") + "ores" in TEXT and not "s do " + m.group("Mszco_41") + "ico " + m.group("Mszco_42") + "ores" in TEXT and not " o " + m.group("Mszco_41") + "ico " + m.group("Mszco_42") + "ores" in TEXT and not m.group("Mszco_41") + "ico-" + m.group("Mszco_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_43>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_44") in plvrMfr and not " e " + m.group("Mszco_43") + "ico " + m.group("Mszco_44") + "es" in TEXT and not " ou " + m.group("Mszco_43") + "ico " + m.group("Mszco_44") + "es" in TEXT and not "s de " + m.group("Mszco_43") + "ico " + m.group("Mszco_44") + "es" in TEXT and not "s do " + m.group("Mszco_43") + "ico " + m.group("Mszco_44") + "es" in TEXT and not " o " + m.group("Mszco_43") + "ico " + m.group("Mszco_44") + "es" in TEXT and not m.group("Mszco_43") + "ico-" + m.group("Mszco_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_45>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_46") in plvrMascr and not " e " + m.group("Mszco_45") + "ico " + m.group("Mszco_46") + "es" in TEXT and not " ou " + m.group("Mszco_45") + "ico " + m.group("Mszco_46") + "es" in TEXT and not "s de " + m.group("Mszco_45") + "ico " + m.group("Mszco_46") + "es" in TEXT and not "s do " + m.group("Mszco_45") + "ico " + m.group("Mszco_46") + "es" in TEXT and not " o " + m.group("Mszco_45") + "ico " + m.group("Mszco_46") + "es" in TEXT and not m.group("Mszco_45") + "ico-" + m.group("Mszco_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_47>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_48") in plvrMfal and not " e " + m.group("Mszco_47") + "ico " + m.group("Mszco_48") + "is" in TEXT and not " ou " + m.group("Mszco_47") + "ico " + m.group("Mszco_48") + "is" in TEXT and not "s de " + m.group("Mszco_47") + "ico " + m.group("Mszco_48") + "is" in TEXT and not "s do " + m.group("Mszco_47") + "ico " + m.group("Mszco_48") + "is" in TEXT and not " o " + m.group("Mszco_47") + "ico " + m.group("Mszco_48") + "is" in TEXT and not m.group("Mszco_47") + "ico-" + m.group("Mszco_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_49>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_50") in plvrMfcao and not " e " + m.group("Mszco_49") + "ico " + m.group("Mszco_50") + "ões" in TEXT and not + " ou " + m.group("Mszco_49") + "ico " + m.group("Mszco_50") + "ões" in TEXT and not + "s de " + m.group("Mszco_49") + "ico " + m.group("Mszco_50") + "ões" in TEXT and not + "s do " + m.group("Mszco_49") + "ico " + m.group("Mszco_50") + "ões" in TEXT and not + " a " + m.group("Mszco_49") + "ico " + m.group("Mszco_50") + "ões" in TEXT and not m.group("Mszco_49") + "ico-" + m.group("Mszco_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_51>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_52") in plvrNfemcao and not " e " + m.group("Mszco_51") + "ico " + m.group("Mszco_52") + "ões" in TEXT and not " ou " + m.group("Mszco_51") + "ico " + m.group("Mszco_52") + "ões" in TEXT and not "s de " + m.group("Mszco_51") + "ico " + m.group("Mszco_52") + "ões" in TEXT and not "s do " + m.group("Mszco_51") + "ico " + m.group("Mszco_52") + "ões" in TEXT and not " o " + m.group("Mszco_51") + "ico " + m.group("Mszco_52") + "ões" in TEXT and not m.group("Mszco_51") + "ico-" + m.group("Mszco_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_55>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_55") + "ico " + m.group("Mszco_56") + "veis" in TEXT and not " ou " + m.group("Mszco_55") + "ico " + m.group("Mszco_56") + "veis" in TEXT and not "s de " + m.group("Mszco_55") + "ico " + m.group("Mszco_56") + "veis" in TEXT and not "s do " + m.group("Mszco_55") + "ico " + m.group("Mszco_56") + "veis" in TEXT and not " o " + m.group("Mszco_55") + "ico " + m.group("Mszco_56") + "veis" in TEXT and not m.group("Mszco_55") + "ico-" + m.group("Mszco_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_57>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_58").lower() in plvrMfe and not " e " + m.group("Mszco_57") + "ico " + m.group("Mszco_58") + "es" in TEXT and not " ou " + m.group("Mszco_57") + "ico " + m.group("Mszco_58") + "es" in TEXT and not "s de " + m.group("Mszco_57") + "ico " + m.group("Mszco_58") + "es" in TEXT and not "s do " + m.group("Mszco_57") + "ico " + m.group("Mszco_58") + "es" in TEXT and not " o " + m.group("Mszco_57") + "ico " + m.group("Mszco_58") + "es" in TEXT and not m.group("Mszco_57") + "ico-" + m.group("Mszco_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_59>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_60").lower() in plvrMasce and not " e " + m.group("Mszco_59") + "ico " + m.group("Mszco_60") + "es" in TEXT and not " ou " + m.group("Mszco_59") + "ico " + m.group("Mszco_60") + "es" in TEXT and not "s de " + m.group("Mszco_59") + "ico " + m.group("Mszco_60") + "es" in TEXT and not "s do " + m.group("Mszco_59") + "ico " + m.group("Mszco_60") + "es" in TEXT and not " o " + m.group("Mszco_59") + "ico " + m.group("Mszco_60") + "es" in TEXT and not m.group("Mszco_59") + "ico-" + m.group("Mszco_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_61>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_62") in plvrMfel and not " e " + m.group("Mszco_61") + "ico " + m.group("Mszco_62") + "éis" in TEXT and not " ou " + m.group("Mszco_61") + "ico " + m.group("Mszco_62") + "éis" in TEXT and not "s de " + m.group("Mszco_61") + "ico " + m.group("Mszco_62") + "éis" in TEXT and not "s do " + m.group("Mszco_61") + "ico " + m.group("Mszco_62") + "éis" in TEXT and not " o " + m.group("Mszco_61") + "ico " + m.group("Mszco_62") + "éis" in TEXT and not m.group("Mszco_61") + "ico-" + m.group("Mszco_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_63>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_64") in plvrMascel and not " e " + m.group("Mszco_63") + "ico " + m.group("Mszco_64") + "éis" in TEXT and not " ou " + m.group("Mszco_63") + "ico " + m.group("Mszco_64") + "éis" in TEXT and not "s de " + m.group("Mszco_63") + "ico " + m.group("Mszco_64") + "éis" in TEXT and not "s do " + m.group("Mszco_63") + "ico " + m.group("Mszco_64") + "éis" in TEXT and not " o " + m.group("Mszco_63") + "ico " + m.group("Mszco_64") + "éis" in TEXT and not m.group("Mszco_63") + "ico-" + m.group("Mszco_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_65>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_66") in plvrMfeu and not " e " + m.group("Mszco_65") + "ico " + m.group("Mszco_66") + "us" in TEXT and not " ou " + m.group("Mszco_65") + "ico " + m.group("Mszco_66") + "us" in TEXT and not "s de " + m.group("Mszco_65") + "ico " + m.group("Mszco_66") + "us" in TEXT and not "s do " + m.group("Mszco_65") + "ico " + m.group("Mszco_66") + "us" in TEXT and not " o " + m.group("Mszco_65") + "ico " + m.group("Mszco_66") + "us" in TEXT and not m.group("Mszco_65") + "ico-" + m.group("Mszco_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_67>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_68") in plvrMascu and not " e " + m.group("Mszco_67") + "ico " + m.group("Mszco_68") + "us" in TEXT and not " ou " + m.group("Mszco_67") + "ico " + m.group("Mszco_68") + "us" in TEXT and not "s de " + m.group("Mszco_67") + "ico " + m.group("Mszco_68") + "us" in TEXT and not "s do " + m.group("Mszco_67") + "ico " + m.group("Mszco_68") + "us" in TEXT and not " o " + m.group("Mszco_67") + "ico " + m.group("Mszco_68") + "us" in TEXT and not m.group("Mszco_67") + "ico-" + m.group("Mszco_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_69>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_70") in plvrInvaz and not " e " + m.group("Mszco_69") + "ico " + m.group("Mszco_70") + "zes" in TEXT and not " ou " + m.group("Mszco_69") + "ico " + m.group("Mszco_70") + "zes" in TEXT and not "s de " + m.group("Mszco_69") + "ico " + m.group("Mszco_70") + "zes" in TEXT and not "s do " + m.group("Mszco_69") + "ico " + m.group("Mszco_70") + "zes" in TEXT and not " o " + m.group("Mszco_69") + "ico " + m.group("Mszco_70") + "zes" in TEXT and not m.group("Mszco_69") + "ico-" + m.group("Mszco_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_71>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_72") in plvrMascz and not " e " + m.group("Mszco_71") + "ico " + m.group("Mszco_72") + "zes" in TEXT and not " ou " + m.group("Mszco_71") + "ico " + m.group("Mszco_72") + "zes" in TEXT and not "s de " + m.group("Mszco_71") + "ico " + m.group("Mszco_72") + "zes" in TEXT and not "s do " + m.group("Mszco_71") + "ico " + m.group("Mszco_72") + "zes" in TEXT and not " o " + m.group("Mszco_71") + "ico " + m.group("Mszco_72") + "zes" in TEXT and not m.group("Mszco_71") + "ico-" + m.group("Mszco_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_73>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_74") in pvrMascan and not " e " + m.group("Mszco_73") + "ico " + m.group("Mszco_74") + "s" in TEXT and not " ou " + m.group("Mszco_73") + "ico " + m.group("Mszco_74") + "s" in TEXT and not "s de " + m.group("Mszco_73") + "ico " + m.group("Mszco_74") + "s" in TEXT and not "s do " + m.group("Mszco_73") + "ico " + m.group("Mszco_74") + "s" in TEXT and not " o " + m.group("Mszco_73") + "ico " + m.group("Mszco_74") + "s" in TEXT and not m.group("Mszco_73") + "ico-" + m.group("Mszco_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_75>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_76").lower() in plvrMasco and not " e " + m.group("Mszco_75") + "ico " + m.group("Mszco_76") +"s" in TEXT and not " ou " + m.group("Mszco_75") + "ico " + m.group("Mszco_76") + "s" in TEXT and not "s de " + m.group("Mszco_75") + "ico " + m.group("Mszco_76") + "s" in TEXT and not "s do " + m.group("Mszco_75") + "ico " + m.group("Mszco_76") + "s" in TEXT and not " o " + m.group("Mszco_75") + "ico " + m.group("Mszco_76") + "s" in TEXT and not m.group("Mszco_75") + "ico-" + m.group("Mszco_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_77>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_77") + "ico " + m.group("Mszco_78") + "inhos" in TEXT and not " ou " + m.group("Mszco_77") + "ico " + m.group("Mszco_78") + "inhos" in TEXT and not "s de " + m.group("Mszco_77") + "ico " + m.group("Mszco_78") + "inhos" in TEXT and not "s do " + m.group("Mszco_77") + "ico " + m.group("Mszco_78") + "inhos" in TEXT and not " o " + m.group("Mszco_77") + "ico " + m.group("Mszco_78") + "inhos" in TEXT and not m.group("Mszco_77") + "ico-" + m.group("Mszco_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_79>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_79") + "ico " + m.group("Mszco_80") + "icas" in TEXT and not " ou " + m.group("Mszco_79") + "ico " + m.group("Mszco_80") + "icas" in TEXT and not "s de " + m.group("Mszco_79") + "ico " + m.group("Mszco_80") + "icas" in TEXT and not "s do " + m.group("Mszco_79") + "ico " + m.group("Mszco_80") + "icas" in TEXT and not " o " + m.group("Mszco_79") + "ico " + m.group("Mszco_80") + "icas" in TEXT and not m.group("Mszco_79") + "ico-" + m.group("Mszco_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_81>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_81") + "ico " + m.group("Mszco_82") + "icas" in TEXT and not " ou " + m.group("Mszco_81") + "ico " + m.group("Mszco_82") + "icas" in TEXT and not "s de " + m.group("Mszco_81") + "ico " + m.group("Mszco_82") + "icas" in TEXT and not "s do " + m.group("Mszco_81") + "ico " + m.group("Mszco_82") + "icas" in TEXT and not " o " + m.group("Mszco_81") + "ico " + m.group("Mszco_82") + "icas" in TEXT and not m.group("Mszco_81") + "ico-" + m.group("Mszco_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_83>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_83") + "ico " + m.group("Mszco_84") + "icas" in TEXT and not " ou " + m.group("Mszco_83") + "ico " + m.group("Mszco_84") + "icas" in TEXT and not "s de " + m.group("Mszco_83") + "ico " + m.group("Mszco_84") + "icas" in TEXT and not "s do " + m.group("Mszco_83") + "ico " + m.group("Mszco_84") + "icas" in TEXT and not " o " + m.group("Mszco_83") + "ico " + m.group("Mszco_84") + "icas" in TEXT and not m.group("Mszco_83") + "ico-" + m.group("Mszco_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_85>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_85") + "ico " + m.group("Mszco_86") + "escas" in TEXT and not " ou " + m.group("Mszco_85") + "ico " + m.group("Mszco_86") + "escas" in TEXT and not "s de " + m.group("Mszco_85") + "ico " + m.group("Mszco_86") + "escas" in TEXT and not "s do " + m.group("Mszco_85") + "ico " + m.group("Mszco_86") + "escas" in TEXT and not " o " + m.group("Mszco_85") + "ico " + m.group("Mszco_86") + "escas" in TEXT and not m.group("Mszco_85") + "ico-" + m.group("Mszco_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_87>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_87") + "ico " + m.group("Mszco_88") + "idas" in TEXT and not " ou " + m.group("Mszco_87") + "s " + m.group("Mszco_88") + "idas" in TEXT and not "s de " + m.group("Mszco_87") + "s " + m.group("Mszco_88") + "idas" in TEXT and not "s do " + m.group("Mszco_87") + "s " + m.group("Mszco_88") + "idas" in TEXT and not " o " + m.group("Mszco_87") + "s " + m.group("Mszco_88") + "idas" in TEXT and not m.group("Mszco_87") + "ico-" + m.group("Mszco_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_89>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_89") + "ico " + m.group("Mszco_90") + "logas" in TEXT and not " ou " + m.group("Mszco_89") + "ico " + m.group("Mszco_90") + "logas" in TEXT and not "s de " + m.group("Mszco_89") + "ico " + m.group("Mszco_90") + "logas" in TEXT and not "s do " + m.group("Mszco_89") + "ico " + m.group("Mszco_90") + "logas" in TEXT and not " o " + m.group("Mszco_89") + "ico " + m.group("Mszco_90") + "logas" in TEXT and not m.group("Mszco_89") + "ico-" + m.group("Mszco_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_91>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_91") + "ico " + m.group("Mszco_92") + "rias" in TEXT and not " ou " + m.group("Mszco_91") + "ico " + m.group("Mszco_92") + "rias" in TEXT and not "s de " + m.group("Mszco_91") + "ico " + m.group("Mszco_92") + "rias" in TEXT and not "s do " + m.group("Mszco_91") + "ico " + m.group("Mszco_92") + "rias" in TEXT and not " o " + m.group("Mszco_91") + "ico " + m.group("Mszco_92") + "rias" in TEXT and not m.group("Mszco_91") + "ico-" + m.group("Mszco_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_93>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_93") + "ico " + m.group("Mszco_94") + "ssimas" in TEXT and not " ou " + m.group("Mszco_93") + "ico " + m.group("Mszco_94") + "ssimas" in TEXT and not "s de " + m.group("Mszco_93") + "ico " + m.group("Mszco_94") + "ssimas" in TEXT and not "s do " + m.group("Mszco_93") + "ico " + m.group("Mszco_94") + "ssimas" in TEXT and not " o " + m.group("Mszco_93") + "ico " + m.group("Mszco_94") + "ssimas" in TEXT and not m.group("Mszco_93") + "ico-" + m.group("Mszco_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_95>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mszco_95") + "ico " + m.group("Mszco_96") + "simas" in TEXT and not " ou " + m.group("Mszco_95") + "ico " + m.group("Mszco_96") + "simas" in TEXT and not "s de " + m.group("Mszco_95") + "ico " + m.group("Mszco_96") + "simas" in TEXT and not "s do " + m.group("Mszco_95") + "ico " + m.group("Mszco_96") + "simas" in TEXT and not " o " + m.group("Mszco_95") + "ico " + m.group("Mszco_96") + "simas" in TEXT and not m.group("Mszco_95") + "ico-" + m.group("Mszco_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_97>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_98").lower() in plvrMfoa and not " e " + m.group("Mszco_97") + "ico " + m.group("Mszco_98") + "as" in TEXT and not " ou " + m.group("Mszco_97") + "ico " + m.group("Mszco_98") + "as" in TEXT and not "s de " + m.group("Mszco_97") + "ico " + m.group("Mszco_98") + "as" in TEXT and not "s do " + m.group("Mszco_97") + "ico " + m.group("Mszco_98") + "as" in TEXT and not " o " + m.group("Mszco_97") + "ico " + m.group("Mszco_98") + "as" in TEXT and not m.group("Mszco_97") + "ico-" + m.group("Mszco_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_99>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_100") in plvrMFm and not " e " + m.group("Mszco_99") + "ico " + m.group("Mszco_100") + "ns" in TEXT and not " ou " + m.group("Mszco_99") + "ico " + m.group("Mszco_100") + "ns" in TEXT and not "s de " + m.group("Mszco_99") + "ico " + m.group("Mszco_100") + "ns" in TEXT and not "s da " + m.group("Mszco_99") + "ico " + m.group("Mszco_100") + "ns" in TEXT and not " a " + m.group("Mszco_99") + "ico " + m.group("Mszco_100") + "ns" in TEXT and not m.group("Mszco_99") + "ico-" + m.group("Mszco_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mszco_101>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico (?P<Mszco_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mszco_102") in plvrMascm and not " e " + m.group("Mszco_101") + "ico " + m.group("Mszco_102") + "ns" in TEXT and not " ou " + m.group("Mszco_101") + "ico " + m.group("Mszco_102") + "ns" in TEXT and not "s de " + m.group("Mszco_101") + "ico " + m.group("Mszco_102") + "ns" in TEXT and not "s da " + m.group("Mszco_101") + "ico " + m.group("Mszco_102") + "ns" in TEXT and not " a " + m.group("Mszco_101") + "ico " + m.group("Mszco_102") + "ns" in TEXT and not m.group("Mszco_101") + "ico-" + m.group("Mszco_102") + "ns" in tCompostops'],
# [bcdfglmnprstvx]ica
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_1>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_2").lower() in plvrFema and not " e " + m.group("Msxca_1") + "ica " + m.group("Msxca_2") +"s" in TEXT and not " ou " + m.group("Msxca_1") + "ica " + m.group("Msxca_2") + "s" in TEXT and not "s de " + m.group("Msxca_1") + "ica " + m.group("Msxca_2") + "s" in TEXT and not "s da " + m.group("Msxca_1") + "ica " + m.group("Msxca_2") + "s" in TEXT and not " a " + m.group("Msxca_1") + "ica " + m.group("Msxca_2") + "s" in TEXT and not m.group("Msxca_1") + "ica-" + m.group("Msxca_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_3>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_4").lower() in plvrMfoa and not " e " + m.group("Msxca_3") + "ica " + m.group("Msxca_4") + "as" in TEXT and not " ou " + m.group("Msxca_3") + "ica " + m.group("Msxca_4") + "as" in TEXT and not "s de " + m.group("Msxca_3") + "ica " + m.group("Msxca_4") + "as" in TEXT and not "s da " + m.group("Msxca_3") + "ica " + m.group("Msxca_4") + "as" in TEXT and not " a " + m.group("Msxca_3") + "ica " + m.group("Msxca_4") + "as" in TEXT and not m.group("Msxca_3") + "ica-" + m.group("Msxca_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_5>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msxca_6").lower() in excAdo and not " e " + m.group("Msxca_5") + "ica " + m.group("Msxca_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msxca_5") + "ica " + m.group("Msxca_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msxca_5") + "ica " + m.group("Msxca_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Msxca_5") + "ica " + m.group("Msxca_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Msxca_5") + "ica " + m.group("Msxca_6") + m.group(3) + "dos" in TEXT and not m.group("Msxca_5") + "ica-" + m.group("Msxca_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_7>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msxca_8").lower() in excIsta and not " e " + m.group("Msxca_7") + "ica " + m.group("Msxca_8") + "s" in TEXT and not " ou " + m.group("Msxca_7") + "ica " + m.group("Msxca_8") + "s" in TEXT and not "s de " + m.group("Msxca_7") + "ica " + m.group("Msxca_8") + "s" in TEXT and not "s da " + m.group("Msxca_7") + "ica " + m.group("Msxca_8") + "s" in TEXT and not " a " + m.group("Msxca_7") + "ica " + m.group("Msxca_8") + "s" in TEXT and not m.group("Msxca_7") + "ica-" + m.group("Msxca_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_9>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_10").lower() in plvrInva and not " e " + m.group("Msxca_9") + "ica " + m.group("Msxca_10") + "s" in TEXT and not " ou " + m.group("Msxca_9") + "ica " + m.group("Msxca_10") + "s" in TEXT and not "s de " + m.group("Msxca_9") + "ica " + m.group("Msxca_10") + "s" in TEXT and not "s da " + m.group("Msxca_9") + "ica " + m.group("Msxca_10") + "s" in TEXT and not " a " + m.group("Msxca_9") + "ica " + m.group("Msxca_10") + "s" in TEXT and not m.group("Msxca_9") + "ica-" + m.group("Msxca_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_11>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msxca_12").lower() in excAdo and not " e " + m.group("Msxca_11") + "ica " + m.group("Msxca_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msxca_11") + "ica " + m.group("Msxca_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msxca_11") + "ica " + m.group("Msxca_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Msxca_11") + "ica " + m.group("Msxca_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Msxca_11") + "ica " + m.group("Msxca_12") + m.group(3) + "das" in TEXT and not m.group("Msxca_11") + "ica-" + m.group("Msxca_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_13>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxca_13") + "ica " + m.group("Msxca_14") + "osos" in TEXT and not " ou " + m.group("Msxca_13") + "ica " + m.group("Msxca_14") + "osos" in TEXT and not "s de " + m.group("Msxca_13") + "ica " + m.group("Msxca_14") + "osos" in TEXT and not "s da " + m.group("Msxca_13") + "ica " + m.group("Msxca_14") + "osos" in TEXT and not " a " + m.group("Msxca_13") + "ica " + m.group("Msxca_14") + "osos" in TEXT and not m.group("Msxca_13") + "ica-" + m.group("Msxca_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_15>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxca_15") + "ica " + m.group("Msxca_16") + "osas" in TEXT and not " ou " + m.group("Msxca_15") + "ica " + m.group("Msxca_16") + "osas" in TEXT and not "s de " + m.group("Msxca_15") + "ica " + m.group("Msxca_16") + "osas" in TEXT and not "s da " + m.group("Msxca_15") + "ica " + m.group("Msxca_16") + "osas" in TEXT and not " a " + m.group("Msxca_15") + "ica " + m.group("Msxca_16") + "osas" in TEXT and not m.group("Msxca_15") + "ica-" + m.group("Msxca_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_17>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxca_17") + "ica " + m.group("Msxca_18") + "ivas" in TEXT and not " ou " + m.group("Msxca_17") + "ica " + m.group("Msxca_18") + "ivas" in TEXT and not "s de " + m.group("Msxca_17") + "ica " + m.group("Msxca_18") + "ivas" in TEXT and not "s da " + m.group("Msxca_17") + "ica " + m.group("Msxca_18") + "ivas" in TEXT and not " a " + m.group("Msxca_17") + "ica " + m.group("Msxca_18") + "ivas" in TEXT and not m.group("Msxca_17") + "ica-" + m.group("Msxca_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_19>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxca_19") + "ica " + m.group("Msxca_20") + "ivas" in TEXT and not " ou " + m.group("Msxca_19") + "ica " + m.group("Msxca_20") + "ivas" in TEXT and not "s de " + m.group("Msxca_19") + "ica " + m.group("Msxca_20") + "ivas" in TEXT and not "s da " + m.group("Msxca_19") + "ica " + m.group("Msxca_20") + "ivas" in TEXT and not " a " + m.group("Msxca_19") + "ica " + m.group("Msxca_20") + "ivas" in TEXT and not m.group("Msxca_19") + "ica-" + m.group("Msxca_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_21>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxca_21") + "ica " + m.group("Msxca_22") + "icas" in TEXT and not " ou " + m.group("Msxca_21") + "ica " + m.group("Msxca_22") + "icas" in TEXT and not "s de " + m.group("Msxca_21") + "ica " + m.group("Msxca_22") + "icas" in TEXT and not "s da " + m.group("Msxca_21") + "ica " + m.group("Msxca_22") + "icas" in TEXT and not " a " + m.group("Msxca_21") + "ica " + m.group("Msxca_22") + "icas" in TEXT and not m.group("Msxca_21") + "ica-" + m.group("Msxca_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_23>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxca_23") + "ica " + m.group("Msxca_24") + "icas" in TEXT and not " ou " + m.group("Msxca_23") + "ica " + m.group("Msxca_24") + "icas" in TEXT and not "s de " + m.group("Msxca_23") + "ica " + m.group("Msxca_24") + "icas" in TEXT and not "s da " + m.group("Msxca_23") + "ica " + m.group("Msxca_24") + "icas" in TEXT and not " a " + m.group("Msxca_23") + "ica " + m.group("Msxca_24") + "icas" in TEXT and not m.group("Msxca_23") + "ica-" + m.group("Msxca_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_25>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxca_25") + "ica " + m.group("Msxca_26") + "icas" in TEXT and not " ou " + m.group("Msxca_25") + "ica " + m.group("Msxca_26") + "icas" in TEXT and not "s de " + m.group("Msxca_25") + "ica " + m.group("Msxca_26") + "icas" in TEXT and not "s da " + m.group("Msxca_25") + "ica " + m.group("Msxca_26") + "icas" in TEXT and not " a " + m.group("Msxca_25") + "ica " + m.group("Msxca_26") + "icas" in TEXT and not m.group("Msxca_25") + "ica-" + m.group("Msxca_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_27>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxca_27") + "ica " + m.group("Msxca_28") + "escas" in TEXT and not " ou " + m.group("Msxca_27") + "ica " + m.group("Msxca_28") + "escas" in TEXT and not "s de " + m.group("Msxca_27") + "ica " + m.group("Msxca_28") + "escas" in TEXT and not "s da " + m.group("Msxca_27") + "ica " + m.group("Msxca_28") + "escas" in TEXT and not " a " + m.group("Msxca_27") + "ica " + m.group("Msxca_28") + "escas" in TEXT and not m.group("Msxca_27") + "ica-" + m.group("Msxca_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_29>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxca_29") + "ica " + m.group("Msxca_30") + "idas" in TEXT and not " ou " + m.group("Msxca_29") + "s " + m.group("Msxca_30") + "idas" in TEXT and not "s de " + m.group("Msxca_29") + "s " + m.group("Msxca_30") + "idas" in TEXT and not "s da " + m.group("Msxca_29") + "s " + m.group("Msxca_30") + "idas" in TEXT and not " a " + m.group("Msxca_29") + "s " + m.group("Msxca_30") + "idas" in TEXT and not m.group("Msxca_29") + "ica-" + m.group("Msxca_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_31>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxca_31") + "ica " + m.group("Msxca_32") + "logas" in TEXT and not " ou " + m.group("Msxca_31") + "ica " + m.group("Msxca_32") + "logas" in TEXT and not "s de " + m.group("Msxca_31") + "ica " + m.group("Msxca_32") + "logas" in TEXT and not "s da " + m.group("Msxca_31") + "ica " + m.group("Msxca_32") + "logas" in TEXT and not " a " + m.group("Msxca_31") + "ica " + m.group("Msxca_32") + "logas" in TEXT and not m.group("Msxca_31") + "ica-" + m.group("Msxca_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_33>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxca_33") + "ica " + m.group("Msxca_34") + "rias" in TEXT and not " ou " + m.group("Msxca_33") + "ica " + m.group("Msxca_34") + "rias" in TEXT and not "s de " + m.group("Msxca_33") + "ica " + m.group("Msxca_34") + "rias" in TEXT and not "s da " + m.group("Msxca_33") + "ica " + m.group("Msxca_34") + "rias" in TEXT and not " a " + m.group("Msxca_33") + "ica " + m.group("Msxca_34") + "rias" in TEXT and not m.group("Msxca_33") + "ica-" + m.group("Msxca_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_35>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxca_35") + "ica " + m.group("Msxca_36") + "ssimas" in TEXT and not " ou " + m.group("Msxca_35") + "ica " + m.group("Msxca_36") + "ssimas" in TEXT and not "s de " + m.group("Msxca_35") + "ica " + m.group("Msxca_36") + "ssimas" in TEXT and not "s da " + m.group("Msxca_35") + "ica " + m.group("Msxca_36") + "ssimas" in TEXT and not " a " + m.group("Msxca_35") + "ica " + m.group("Msxca_36") + "ssimas" in TEXT and not m.group("Msxca_35") + "ica-" + m.group("Msxca_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_37>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxca_37") + "ica " + m.group("Msxca_38") + "simas" in TEXT and not " ou " + m.group("Msxca_37") + "ica " + m.group("Msxca_38") + "simas" in TEXT and not "s de " + m.group("Msxca_37") + "ica " + m.group("Msxca_38") + "simas" in TEXT and not "s da " + m.group("Msxca_37") + "ica " + m.group("Msxca_38") + "simas" in TEXT and not " a " + m.group("Msxca_37") + "ica " + m.group("Msxca_38") + "simas" in TEXT and not m.group("Msxca_37") + "ica-" + m.group("Msxca_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_41>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msxca_42") in "D-d-" and not " e " + m.group("Msxca_41") + "ica " + m.group("Msxca_42") + "oras" in TEXT and not " ou " + m.group("Msxca_41") + "ica " + m.group("Msxca_42") + "oras" in TEXT and not "s de " + m.group("Msxca_41") + "ica " + m.group("Msxca_42") + "oras" in TEXT and not "s da " + m.group("Msxca_41") + "ica " + m.group("Msxca_42") + "oras" in TEXT and not " a " + m.group("Msxca_41") + "ica " + m.group("Msxca_42") + "oras" in TEXT and not m.group("Msxca_41") + "ica-" + m.group("Msxca_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_43>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_44") in plvrMfr and not " e " + m.group("Msxca_43") + "ica " + m.group("Msxca_44") + "es" in TEXT and not " ou " + m.group("Msxca_43") + "ica " + m.group("Msxca_44") + "es" in TEXT and not "s de " + m.group("Msxca_43") + "ica " + m.group("Msxca_44") + "es" in TEXT and not "s da " + m.group("Msxca_43") + "ica " + m.group("Msxca_44") + "es" in TEXT and not " a " + m.group("Msxca_43") + "ica " + m.group("Msxca_44") + "es" in TEXT and not m.group("Msxca_43") + "ica-" + m.group("Msxca_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_45>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_46") in plvrFemr and not " e " + m.group("Msxca_45") + "ica " + m.group("Msxca_46") + "es" in TEXT and not " ou " + m.group("Msxca_45") + "ica " + m.group("Msxca_46") + "es" in TEXT and not "s de " + m.group("Msxca_45") + "ica " + m.group("Msxca_46") + "es" in TEXT and not "s da " + m.group("Msxca_45") + "ica " + m.group("Msxca_46") + "es" in TEXT and not " a " + m.group("Msxca_45") + "ica " + m.group("Msxca_46") + "es" in TEXT and not m.group("Msxca_45") + "ica-" + m.group("Msxca_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_47>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_48") in plvrMfal and not " e " + m.group("Msxca_47") + "ica " + m.group("Msxca_48") + "is" in TEXT and not " ou " + m.group("Msxca_47") + "ica " + m.group("Msxca_48") + "is" in TEXT and not "s de " + m.group("Msxca_47") + "ica " + m.group("Msxca_48") + "is" in TEXT and not "s da " + m.group("Msxca_47") + "ica " + m.group("Msxca_48") + "is" in TEXT and not " a " + m.group("Msxca_47") + "ica " + m.group("Msxca_48") + "is" in TEXT and not m.group("Msxca_47") + "ica-" + m.group("Msxca_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_49>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_50") in plvrMfcao and not " e " + m.group("Msxca_49") + "ica " + m.group("Msxca_50") + "ões" in TEXT and not + " ou " + m.group("Msxca_49") + "ica " + m.group("Msxca_50") + "ões" in TEXT and not + "s de " + m.group("Msxca_49") + "ica " + m.group("Msxca_50") + "ões" in TEXT and not + "s da " + m.group("Msxca_49") + "ica " + m.group("Msxca_50") + "ões" in TEXT and not + " a " + m.group("Msxca_49") + "ica " + m.group("Msxca_50") + "ões" in TEXT and not m.group("Msxca_49") + "ica-" + m.group("Msxca_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_51>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msxca_52") in plvrMascao and not " e " + m.group("Msxca_51") + "ica " + m.group("Msxca_52") + "ões" in TEXT and not " ou " + m.group("Msxca_51") + "ica " + m.group("Msxca_52") + "ões" in TEXT and not "s de " + m.group("Msxca_51") + "ica " + m.group("Msxca_52") + "ões" in TEXT and not "s da " + m.group("Msxca_51") + "ica " + m.group("Msxca_52") + "ões" in TEXT and not " a " + m.group("Msxca_51") + "ica " + m.group("Msxca_52") + "ões" in TEXT and not m.group("Msxca_51") + "ica-" + m.group("Msxca_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_53>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_54") in plvrFemao and not " e " + m.group("Msxca_53") + "ica " + m.group("Msxca_54") + "ões" in TEXT and not " ou " + m.group("Msxca_53") + "ica " + m.group("Msxca_54") + "ões" in TEXT and not "s de " + m.group("Msxca_53") + "ica " + m.group("Msxca_54") + "ões" in TEXT and not "s da " + m.group("Msxca_53") + "ica " + m.group("Msxca_54") + "ões" in TEXT and not " a " + m.group("Msxca_53") + "ica " + m.group("Msxca_54") + "ões" in TEXT and not m.group("Msxca_53") + "ica-" + m.group("Msxca_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_55>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxca_55") + "ica " + m.group("Msxca_56") + "veis" in TEXT and not " ou " + m.group("Msxca_55") + "ica " + m.group("Msxca_56") + "veis" in TEXT and not "s de " + m.group("Msxca_55") + "ica " + m.group("Msxca_56") + "veis" in TEXT and not "s da " + m.group("Msxca_55") + "ica " + m.group("Msxca_56") + "veis" in TEXT and not " a " + m.group("Msxca_55") + "ica " + m.group("Msxca_56") + "veis" in TEXT and not m.group("Msxca_55") + "ica-" + m.group("Msxca_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_57>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_58").lower() in plvrMfe and not " e " + m.group("Msxca_57") + "ica " + m.group("Msxca_58") + "es" in TEXT and not " ou " + m.group("Msxca_57") + "ica " + m.group("Msxca_58") + "es" in TEXT and not "s de " + m.group("Msxca_57") + "ica " + m.group("Msxca_58") + "es" in TEXT and not "s da " + m.group("Msxca_57") + "ica " + m.group("Msxca_58") + "es" in TEXT and not " a " + m.group("Msxca_57") + "ica " + m.group("Msxca_58") + "es" in TEXT and not m.group("Msxca_57") + "ica-" + m.group("Msxca_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_59>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_60").lower() in plvrFeme and not " e " + m.group("Msxca_59") + "ica " + m.group("Msxca_60") + "es" in TEXT and not " ou " + m.group("Msxca_59") + "ica " + m.group("Msxca_60") + "es" in TEXT and not "s de " + m.group("Msxca_59") + "ica " + m.group("Msxca_60") + "es" in TEXT and not "s da " + m.group("Msxca_59") + "ica " + m.group("Msxca_60") + "es" in TEXT and not " a " + m.group("Msxca_59") + "ica " + m.group("Msxca_60") + "es" in TEXT and not m.group("Msxca_59") + "ica-" + m.group("Msxca_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_61>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_62") in plvrMfel and not " e " + m.group("Msxca_61") + "ica " + m.group("Msxca_62") + "éis" in TEXT and not " ou " + m.group("Msxca_61") + "ica " + m.group("Msxca_62") + "éis" in TEXT and not "s de " + m.group("Msxca_61") + "ica " + m.group("Msxca_62") + "éis" in TEXT and not "s da " + m.group("Msxca_61") + "ica " + m.group("Msxca_62") + "éis" in TEXT and not " a " + m.group("Msxca_61") + "ica " + m.group("Msxca_62") + "éis" in TEXT and not m.group("Msxca_61") + "ica-" + m.group("Msxca_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_63>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_64") in plvrFemel and not " e " + m.group("Msxca_63") + "ica " + m.group("Msxca_64") + "éis" in TEXT and not " ou " + m.group("Msxca_63") + "ica " + m.group("Msxca_64") + "éis" in TEXT and not "s de " + m.group("Msxca_63") + "ica " + m.group("Msxca_64") + "éis" in TEXT and not "s da " + m.group("Msxca_63") + "ica " + m.group("Msxca_64") + "éis" in TEXT and not " a " + m.group("Msxca_63") + "ica " + m.group("Msxca_64") + "éis" in TEXT and not m.group("Msxca_63") + "ica-" + m.group("Msxca_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_65>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_66") in plvrMfeu and not " e " + m.group("Msxca_65") + "ica " + m.group("Msxca_66") + "us" in TEXT and not " ou " + m.group("Msxca_65") + "ica " + m.group("Msxca_66") + "us" in TEXT and not "s de " + m.group("Msxca_65") + "ica " + m.group("Msxca_66") + "us" in TEXT and not "s da " + m.group("Msxca_65") + "ica " + m.group("Msxca_66") + "us" in TEXT and not " a " + m.group("Msxca_65") + "ica " + m.group("Msxca_66") + "us" in TEXT and not m.group("Msxca_65") + "ica-" + m.group("Msxca_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_67>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_68") in plvrFemu and not " e " + m.group("Msxca_67") + "ica " + m.group("Msxca_68") + "us" in TEXT and not " ou " + m.group("Msxca_67") + "ica " + m.group("Msxca_68") + "us" in TEXT and not "s de " + m.group("Msxca_67") + "ica " + m.group("Msxca_68") + "us" in TEXT and not "s da " + m.group("Msxca_67") + "ica " + m.group("Msxca_68") + "us" in TEXT and not " a " + m.group("Msxca_67") + "ica " + m.group("Msxca_68") + "us" in TEXT and not m.group("Msxca_67") + "ica-" + m.group("Msxca_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_69>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_70") in plvrInvaz and not " e " + m.group("Msxca_69") + "ica " + m.group("Msxca_70") + "zes" in TEXT and not " ou " + m.group("Msxca_69") + "ica " + m.group("Msxca_70") + "zes" in TEXT and not "s de " + m.group("Msxca_69") + "ica " + m.group("Msxca_70") + "zes" in TEXT and not "s da " + m.group("Msxca_69") + "ica " + m.group("Msxca_70") + "zes" in TEXT and not " a " + m.group("Msxca_69") + "ica " + m.group("Msxca_70") + "zes" in TEXT and not m.group("Msxca_69") + "ica-" + m.group("Msxca_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_71>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_72") in plvrFemz and not " e " + m.group("Msxca_71") + "ica " + m.group("Msxca_72") + "zes" in TEXT and not " ou " + m.group("Msxca_71") + "ica " + m.group("Msxca_72") + "zes" in TEXT and not "s de " + m.group("Msxca_71") + "ica " + m.group("Msxca_72") + "zes" in TEXT and not "s da " + m.group("Msxca_71") + "ica " + m.group("Msxca_72") + "zes" in TEXT and not " a " + m.group("Msxca_71") + "ica " + m.group("Msxca_72") + "zes" in TEXT and not m.group("Msxca_71") + "ica-" + m.group("Msxca_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_73>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_74") in pvrFeman and not " e " + m.group("Msxca_73") + "ica " + m.group("Msxca_74") + "s" in TEXT and not " ou " + m.group("Msxca_73") + "ica " + m.group("Msxca_74") + "s" in TEXT and not "s de " + m.group("Msxca_73") + "ica " + m.group("Msxca_74") + "s" in TEXT and not "s da " + m.group("Msxca_73") + "ica " + m.group("Msxca_74") + "s" in TEXT and not " a " + m.group("Msxca_73") + "ica " + m.group("Msxca_74") + "s" in TEXT and not m.group("Msxca_73") + "ica-" + m.group("Msxca_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_99>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_100") in plvrMFm and not " e " + m.group("Msxca_99") + "ica " + m.group("Msxca_100") + "ns" in TEXT and not " ou " + m.group("Msxca_99") + "ica " + m.group("Msxca_100") + "ns" in TEXT and not "s de " + m.group("Msxca_99") + "ica " + m.group("Msxca_100") + "ns" in TEXT and not "s da " + m.group("Msxca_99") + "ica " + m.group("Msxca_100") + "ns" in TEXT and not " a " + m.group("Msxca_99") + "ica " + m.group("Msxca_100") + "ns" in TEXT and not m.group("Msxca_99") + "ica-" + m.group("Msxca_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxca_101>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica (?P<Msxca_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "icas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxca_102") in plvrFemm and not " e " + m.group("Msxca_101") + "ica " + m.group("Msxca_102") + "ns" in TEXT and not " ou " + m.group("Msxca_101") + "ica " + m.group("Msxca_102") + "ns" in TEXT and not "s de " + m.group("Msxca_101") + "ica " + m.group("Msxca_102") + "ns" in TEXT and not "s da " + m.group("Msxca_101") + "ica " + m.group("Msxca_102") + "ns" in TEXT and not " a " + m.group("Msxca_101") + "ica " + m.group("Msxca_102") + "ns" in TEXT and not m.group("Msxca_101") + "ica-" + m.group("Msxca_102") + "ns" in tCompostops'],
# [bcdfglmnprstvx]ico
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_1>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_2").lower() in plvrMasca and not " e " + m.group("Msxco_1") + "ico " + m.group("Msxco_2") +"s" in TEXT and not " ou " + m.group("Msxco_1") + "ico " + m.group("Msxco_2") + "s" in TEXT and not "s de " + m.group("Msxco_1") + "ico " + m.group("Msxco_2") + "s" in TEXT and not "s do " + m.group("Msxco_1") + "ico " + m.group("Msxco_2") + "s" in TEXT and not " o " + m.group("Msxco_1") + "ico " + m.group("Msxco_2") + "s" in TEXT and not m.group("Msxco_1") + "ico-" + m.group("Msxco_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_3>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_4").lower() in plvrMfoa and not " e " + m.group("Msxco_3") + "ico " + m.group("Msxco_4") + "os" in TEXT and not " ou " + m.group("Msxco_3") + "ico " + m.group("Msxco_4") + "os" in TEXT and not "s de " + m.group("Msxco_3") + "ico " + m.group("Msxco_4") + "os" in TEXT and not "s do " + m.group("Msxco_3") + "ico " + m.group("Msxco_4") + "os" in TEXT and not " o " + m.group("Msxco_3") + "ico " + m.group("Msxco_4") + "os" in TEXT and not m.group("Msxco_3") + "ico-" + m.group("Msxco_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_5>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msxco_6").lower() in excAdo and not " e " + m.group("Msxco_5") + "ico " + m.group("Msxco_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msxco_5") + "ico " + m.group("Msxco_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msxco_5") + "ico " + m.group("Msxco_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msxco_5") + "ico " + m.group("Msxco_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msxco_5") + "ico " + m.group("Msxco_6") + m.group(3) + "dos" in TEXT and not m.group("Msxco_5") + "ico-" + m.group("Msxco_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_7>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msxco_8").lower() in excIsta and not " e " + m.group("Msxco_7") + "ico " + m.group("Msxco_8") + "s" in TEXT and not " ou " + m.group("Msxco_7") + "ico " + m.group("Msxco_8") + "s" in TEXT and not "s de " + m.group("Msxco_7") + "ico " + m.group("Msxco_8") + "s" in TEXT and not "s do " + m.group("Msxco_7") + "ico " + m.group("Msxco_8") + "s" in TEXT and not " o " + m.group("Msxco_7") + "ico " + m.group("Msxco_8") + "s" in TEXT and not m.group("Msxco_7") + "ico-" + m.group("Msxco_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_9>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_10").lower() in plvrInva and not " e " + m.group("Msxco_9") + "ico " + m.group("Msxco_10") + "s" in TEXT and not " ou " + m.group("Msxco_9") + "ico " + m.group("Msxco_10") + "s" in TEXT and not "s de " + m.group("Msxco_9") + "ico " + m.group("Msxco_10") + "s" in TEXT and not "s do " + m.group("Msxco_9") + "ico " + m.group("Msxco_10") + "s" in TEXT and not " a " + m.group("Msxco_9") + "ico " + m.group("Msxco_10") + "s" in TEXT and not m.group("Msxco_9") + "ico-" + m.group("Msxco_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_11>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msxco_12").lower() in excAdo and not " e " + m.group("Msxco_11") + "ico " + m.group("Msxco_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msxco_11") + "ico " + m.group("Msxco_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msxco_11") + "ico " + m.group("Msxco_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Msxco_11") + "ico " + m.group("Msxco_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Msxco_11") + "ico " + m.group("Msxco_12") + m.group(3) + "das" in TEXT and not m.group("Msxco_11") + "ico-" + m.group("Msxco_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_13>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_13") + "ico " + m.group("Msxco_14") + "osos" in TEXT and not " ou " + m.group("Msxco_13") + "ico " + m.group("Msxco_14") + "osos" in TEXT and not "s de " + m.group("Msxco_13") + "ico " + m.group("Msxco_14") + "osos" in TEXT and not "s do " + m.group("Msxco_13") + "ico " + m.group("Msxco_14") + "osos" in TEXT and not " o " + m.group("Msxco_13") + "ico " + m.group("Msxco_14") + "osos" in TEXT and not m.group("Msxco_13") + "ico-" + m.group("Msxco_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_15>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_15") + "ico " + m.group("Msxco_16") + "osas" in TEXT and not " ou " + m.group("Msxco_15") + "ico " + m.group("Msxco_16") + "osas" in TEXT and not "s de " + m.group("Msxco_15") + "ico " + m.group("Msxco_16") + "osas" in TEXT and not "s do " + m.group("Msxco_15") + "ico " + m.group("Msxco_16") + "osas" in TEXT and not " o " + m.group("Msxco_15") + "ico " + m.group("Msxco_16") + "osas" in TEXT and not m.group("Msxco_15") + "ico-" + m.group("Msxco_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_17>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_17") + "ico " + m.group("Msxco_18") + "ivas" in TEXT and not " ou " + m.group("Msxco_17") + "ico " + m.group("Msxco_18") + "ivas" in TEXT and not "s de " + m.group("Msxco_17") + "ico " + m.group("Msxco_18") + "ivas" in TEXT and not "s do " + m.group("Msxco_17") + "ico " + m.group("Msxco_18") + "ivas" in TEXT and not " o " + m.group("Msxco_17") + "ico " + m.group("Msxco_18") + "ivas" in TEXT and not m.group("Msxco_17") + "ico-" + m.group("Msxco_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_19>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_19") + "ico " + m.group("Msxco_20") + "ivas" in TEXT and not " ou " + m.group("Msxco_19") + "ico " + m.group("Msxco_20") + "ivas" in TEXT and not "s de " + m.group("Msxco_19") + "ico " + m.group("Msxco_20") + "ivas" in TEXT and not "s do " + m.group("Msxco_19") + "ico " + m.group("Msxco_20") + "ivas" in TEXT and not " o " + m.group("Msxco_19") + "ico " + m.group("Msxco_20") + "ivas" in TEXT and not m.group("Msxco_19") + "ico-" + m.group("Msxco_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_21>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_21") + "ico " + m.group("Msxco_22") + "icos" in TEXT and not " ou " + m.group("Msxco_21") + "ico " + m.group("Msxco_22") + "icos" in TEXT and not "s de " + m.group("Msxco_21") + "ico " + m.group("Msxco_22") + "icos" in TEXT and not "s do " + m.group("Msxco_21") + "ico " + m.group("Msxco_22") + "icos" in TEXT and not " o " + m.group("Msxco_21") + "ico " + m.group("Msxco_22") + "icos" in TEXT and not m.group("Msxco_21") + "ico-" + m.group("Msxco_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_23>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_23") + "ico " + m.group("Msxco_24") + "icos" in TEXT and not " ou " + m.group("Msxco_23") + "ico " + m.group("Msxco_24") + "icos" in TEXT and not "s de " + m.group("Msxco_23") + "ico " + m.group("Msxco_24") + "icos" in TEXT and not "s do " + m.group("Msxco_23") + "ico " + m.group("Msxco_24") + "icos" in TEXT and not " o " + m.group("Msxco_23") + "ico " + m.group("Msxco_24") + "icos" in TEXT and not m.group("Msxco_23") + "ico-" + m.group("Msxco_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_25>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_25") + "ico " + m.group("Msxco_26") + "icos" in TEXT and not " ou " + m.group("Msxco_25") + "ico " + m.group("Msxco_26") + "icos" in TEXT and not "s de " + m.group("Msxco_25") + "ico " + m.group("Msxco_26") + "icos" in TEXT and not "s do " + m.group("Msxco_25") + "ico " + m.group("Msxco_26") + "icos" in TEXT and not " o " + m.group("Msxco_25") + "ico " + m.group("Msxco_26") + "icos" in TEXT and not m.group("Msxco_25") + "ico-" + m.group("Msxco_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_27>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_27") + "ico " + m.group("Msxco_28") + "escos" in TEXT and not " ou " + m.group("Msxco_27") + "ico " + m.group("Msxco_28") + "escos" in TEXT and not "s de " + m.group("Msxco_27") + "ico " + m.group("Msxco_28") + "escos" in TEXT and not "s do " + m.group("Msxco_27") + "ico " + m.group("Msxco_28") + "escos" in TEXT and not " o " + m.group("Msxco_27") + "ico " + m.group("Msxco_28") + "escos" in TEXT and not m.group("Msxco_27") + "ico-" + m.group("Msxco_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_29>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_29") + "ico " + m.group("Msxco_30") + "idos" in TEXT and not " ou " + m.group("Msxco_29") + "s " + m.group("Msxco_30") + "idos" in TEXT and not "s de " + m.group("Msxco_29") + "s " + m.group("Msxco_30") + "idos" in TEXT and not "s do " + m.group("Msxco_29") + "s " + m.group("Msxco_30") + "idos" in TEXT and not " o " + m.group("Msxco_29") + "s " + m.group("Msxco_30") + "idos" in TEXT and not m.group("Msxco_29") + "ico-" + m.group("Msxco_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_31>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_31") + "ico " + m.group("Msxco_32") + "logos" in TEXT and not " ou " + m.group("Msxco_31") + "ico " + m.group("Msxco_32") + "logos" in TEXT and not "s de " + m.group("Msxco_31") + "ico " + m.group("Msxco_32") + "logos" in TEXT and not "s do " + m.group("Msxco_31") + "ico " + m.group("Msxco_32") + "logos" in TEXT and not " o " + m.group("Msxco_31") + "ico " + m.group("Msxco_32") + "logos" in TEXT and not m.group("Msxco_31") + "ico-" + m.group("Msxco_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_33>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_33") + "ico " + m.group("Msxco_34") + "rios" in TEXT and not " ou " + m.group("Msxco_33") + "ico " + m.group("Msxco_34") + "rios" in TEXT and not "s de " + m.group("Msxco_33") + "ico " + m.group("Msxco_34") + "rios" in TEXT and not "s do " + m.group("Msxco_33") + "ico " + m.group("Msxco_34") + "rios" in TEXT and not " o " + m.group("Msxco_33") + "ico " + m.group("Msxco_34") + "rios" in TEXT and not m.group("Msxco_33") + "ico-" + m.group("Msxco_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_35>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_35") + "ico " + m.group("Msxco_36") + "ssimos" in TEXT and not " ou " + m.group("Msxco_35") + "ico " + m.group("Msxco_36") + "ssimos" in TEXT and not "s de " + m.group("Msxco_35") + "ico " + m.group("Msxco_36") + "ssimos" in TEXT and not "s do " + m.group("Msxco_35") + "ico " + m.group("Msxco_36") + "ssimos" in TEXT and not " o " + m.group("Msxco_35") + "ico " + m.group("Msxco_36") + "ssimos" in TEXT and not m.group("Msxco_35") + "ico-" + m.group("Msxco_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_37>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_37") + "ico " + m.group("Msxco_38") + "simos" in TEXT and not " ou " + m.group("Msxco_37") + "ico " + m.group("Msxco_38") + "simos" in TEXT and not "s de " + m.group("Msxco_37") + "ico " + m.group("Msxco_38") + "simos" in TEXT and not "s do " + m.group("Msxco_37") + "ico " + m.group("Msxco_38") + "simos" in TEXT and not " o " + m.group("Msxco_37") + "ico " + m.group("Msxco_38") + "simos" in TEXT and not m.group("Msxco_37") + "ico-" + m.group("Msxco_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_41>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msxco_42") in "D-d-" and not " e " + m.group("Msxco_41") + "ico " + m.group("Msxco_42") + "ores" in TEXT and not " ou " + m.group("Msxco_41") + "ico " + m.group("Msxco_42") + "ores" in TEXT and not "s de " + m.group("Msxco_41") + "ico " + m.group("Msxco_42") + "ores" in TEXT and not "s do " + m.group("Msxco_41") + "ico " + m.group("Msxco_42") + "ores" in TEXT and not " o " + m.group("Msxco_41") + "ico " + m.group("Msxco_42") + "ores" in TEXT and not m.group("Msxco_41") + "ico-" + m.group("Msxco_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_43>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_44") in plvrMfr and not " e " + m.group("Msxco_43") + "ico " + m.group("Msxco_44") + "es" in TEXT and not " ou " + m.group("Msxco_43") + "ico " + m.group("Msxco_44") + "es" in TEXT and not "s de " + m.group("Msxco_43") + "ico " + m.group("Msxco_44") + "es" in TEXT and not "s do " + m.group("Msxco_43") + "ico " + m.group("Msxco_44") + "es" in TEXT and not " o " + m.group("Msxco_43") + "ico " + m.group("Msxco_44") + "es" in TEXT and not m.group("Msxco_43") + "ico-" + m.group("Msxco_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_45>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_46") in plvrMascr and not " e " + m.group("Msxco_45") + "ico " + m.group("Msxco_46") + "es" in TEXT and not " ou " + m.group("Msxco_45") + "ico " + m.group("Msxco_46") + "es" in TEXT and not "s de " + m.group("Msxco_45") + "ico " + m.group("Msxco_46") + "es" in TEXT and not "s do " + m.group("Msxco_45") + "ico " + m.group("Msxco_46") + "es" in TEXT and not " o " + m.group("Msxco_45") + "ico " + m.group("Msxco_46") + "es" in TEXT and not m.group("Msxco_45") + "ico-" + m.group("Msxco_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_47>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_48") in plvrMfal and not " e " + m.group("Msxco_47") + "ico " + m.group("Msxco_48") + "is" in TEXT and not " ou " + m.group("Msxco_47") + "ico " + m.group("Msxco_48") + "is" in TEXT and not "s de " + m.group("Msxco_47") + "ico " + m.group("Msxco_48") + "is" in TEXT and not "s do " + m.group("Msxco_47") + "ico " + m.group("Msxco_48") + "is" in TEXT and not " o " + m.group("Msxco_47") + "ico " + m.group("Msxco_48") + "is" in TEXT and not m.group("Msxco_47") + "ico-" + m.group("Msxco_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_49>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_50") in plvrMfcao and not " e " + m.group("Msxco_49") + "ico " + m.group("Msxco_50") + "ões" in TEXT and not + " ou " + m.group("Msxco_49") + "ico " + m.group("Msxco_50") + "ões" in TEXT and not + "s de " + m.group("Msxco_49") + "ico " + m.group("Msxco_50") + "ões" in TEXT and not + "s do " + m.group("Msxco_49") + "ico " + m.group("Msxco_50") + "ões" in TEXT and not + " a " + m.group("Msxco_49") + "ico " + m.group("Msxco_50") + "ões" in TEXT and not m.group("Msxco_49") + "ico-" + m.group("Msxco_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_51>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_52") in plvrNfemcao and not " e " + m.group("Msxco_51") + "ico " + m.group("Msxco_52") + "ões" in TEXT and not " ou " + m.group("Msxco_51") + "ico " + m.group("Msxco_52") + "ões" in TEXT and not "s de " + m.group("Msxco_51") + "ico " + m.group("Msxco_52") + "ões" in TEXT and not "s do " + m.group("Msxco_51") + "ico " + m.group("Msxco_52") + "ões" in TEXT and not " o " + m.group("Msxco_51") + "ico " + m.group("Msxco_52") + "ões" in TEXT and not m.group("Msxco_51") + "ico-" + m.group("Msxco_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_55>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_55") + "ico " + m.group("Msxco_56") + "veis" in TEXT and not " ou " + m.group("Msxco_55") + "ico " + m.group("Msxco_56") + "veis" in TEXT and not "s de " + m.group("Msxco_55") + "ico " + m.group("Msxco_56") + "veis" in TEXT and not "s do " + m.group("Msxco_55") + "ico " + m.group("Msxco_56") + "veis" in TEXT and not " o " + m.group("Msxco_55") + "ico " + m.group("Msxco_56") + "veis" in TEXT and not m.group("Msxco_55") + "ico-" + m.group("Msxco_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_57>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_58").lower() in plvrMfe and not " e " + m.group("Msxco_57") + "ico " + m.group("Msxco_58") + "es" in TEXT and not " ou " + m.group("Msxco_57") + "ico " + m.group("Msxco_58") + "es" in TEXT and not "s de " + m.group("Msxco_57") + "ico " + m.group("Msxco_58") + "es" in TEXT and not "s do " + m.group("Msxco_57") + "ico " + m.group("Msxco_58") + "es" in TEXT and not " o " + m.group("Msxco_57") + "ico " + m.group("Msxco_58") + "es" in TEXT and not m.group("Msxco_57") + "ico-" + m.group("Msxco_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_59>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_60").lower() in plvrMasce and not " e " + m.group("Msxco_59") + "ico " + m.group("Msxco_60") + "es" in TEXT and not " ou " + m.group("Msxco_59") + "ico " + m.group("Msxco_60") + "es" in TEXT and not "s de " + m.group("Msxco_59") + "ico " + m.group("Msxco_60") + "es" in TEXT and not "s do " + m.group("Msxco_59") + "ico " + m.group("Msxco_60") + "es" in TEXT and not " o " + m.group("Msxco_59") + "ico " + m.group("Msxco_60") + "es" in TEXT and not m.group("Msxco_59") + "ico-" + m.group("Msxco_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_61>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_62") in plvrMfel and not " e " + m.group("Msxco_61") + "ico " + m.group("Msxco_62") + "éis" in TEXT and not " ou " + m.group("Msxco_61") + "ico " + m.group("Msxco_62") + "éis" in TEXT and not "s de " + m.group("Msxco_61") + "ico " + m.group("Msxco_62") + "éis" in TEXT and not "s do " + m.group("Msxco_61") + "ico " + m.group("Msxco_62") + "éis" in TEXT and not " o " + m.group("Msxco_61") + "ico " + m.group("Msxco_62") + "éis" in TEXT and not m.group("Msxco_61") + "ico-" + m.group("Msxco_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_63>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_64") in plvrMascel and not " e " + m.group("Msxco_63") + "ico " + m.group("Msxco_64") + "éis" in TEXT and not " ou " + m.group("Msxco_63") + "ico " + m.group("Msxco_64") + "éis" in TEXT and not "s de " + m.group("Msxco_63") + "ico " + m.group("Msxco_64") + "éis" in TEXT and not "s do " + m.group("Msxco_63") + "ico " + m.group("Msxco_64") + "éis" in TEXT and not " o " + m.group("Msxco_63") + "ico " + m.group("Msxco_64") + "éis" in TEXT and not m.group("Msxco_63") + "ico-" + m.group("Msxco_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_65>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_66") in plvrMfeu and not " e " + m.group("Msxco_65") + "ico " + m.group("Msxco_66") + "us" in TEXT and not " ou " + m.group("Msxco_65") + "ico " + m.group("Msxco_66") + "us" in TEXT and not "s de " + m.group("Msxco_65") + "ico " + m.group("Msxco_66") + "us" in TEXT and not "s do " + m.group("Msxco_65") + "ico " + m.group("Msxco_66") + "us" in TEXT and not " o " + m.group("Msxco_65") + "ico " + m.group("Msxco_66") + "us" in TEXT and not m.group("Msxco_65") + "ico-" + m.group("Msxco_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_67>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_68") in plvrMascu and not " e " + m.group("Msxco_67") + "ico " + m.group("Msxco_68") + "us" in TEXT and not " ou " + m.group("Msxco_67") + "ico " + m.group("Msxco_68") + "us" in TEXT and not "s de " + m.group("Msxco_67") + "ico " + m.group("Msxco_68") + "us" in TEXT and not "s do " + m.group("Msxco_67") + "ico " + m.group("Msxco_68") + "us" in TEXT and not " o " + m.group("Msxco_67") + "ico " + m.group("Msxco_68") + "us" in TEXT and not m.group("Msxco_67") + "ico-" + m.group("Msxco_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_69>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_70") in plvrInvaz and not " e " + m.group("Msxco_69") + "ico " + m.group("Msxco_70") + "zes" in TEXT and not " ou " + m.group("Msxco_69") + "ico " + m.group("Msxco_70") + "zes" in TEXT and not "s de " + m.group("Msxco_69") + "ico " + m.group("Msxco_70") + "zes" in TEXT and not "s do " + m.group("Msxco_69") + "ico " + m.group("Msxco_70") + "zes" in TEXT and not " o " + m.group("Msxco_69") + "ico " + m.group("Msxco_70") + "zes" in TEXT and not m.group("Msxco_69") + "ico-" + m.group("Msxco_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_71>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_72") in plvrMascz and not " e " + m.group("Msxco_71") + "ico " + m.group("Msxco_72") + "zes" in TEXT and not " ou " + m.group("Msxco_71") + "ico " + m.group("Msxco_72") + "zes" in TEXT and not "s de " + m.group("Msxco_71") + "ico " + m.group("Msxco_72") + "zes" in TEXT and not "s do " + m.group("Msxco_71") + "ico " + m.group("Msxco_72") + "zes" in TEXT and not " o " + m.group("Msxco_71") + "ico " + m.group("Msxco_72") + "zes" in TEXT and not m.group("Msxco_71") + "ico-" + m.group("Msxco_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_73>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_74") in pvrMascan and not " e " + m.group("Msxco_73") + "ico " + m.group("Msxco_74") + "s" in TEXT and not " ou " + m.group("Msxco_73") + "ico " + m.group("Msxco_74") + "s" in TEXT and not "s de " + m.group("Msxco_73") + "ico " + m.group("Msxco_74") + "s" in TEXT and not "s do " + m.group("Msxco_73") + "ico " + m.group("Msxco_74") + "s" in TEXT and not " o " + m.group("Msxco_73") + "ico " + m.group("Msxco_74") + "s" in TEXT and not m.group("Msxco_73") + "ico-" + m.group("Msxco_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_75>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_76").lower() in plvrMasco and not " e " + m.group("Msxco_75") + "ico " + m.group("Msxco_76") +"s" in TEXT and not " ou " + m.group("Msxco_75") + "ico " + m.group("Msxco_76") + "s" in TEXT and not "s de " + m.group("Msxco_75") + "ico " + m.group("Msxco_76") + "s" in TEXT and not "s do " + m.group("Msxco_75") + "ico " + m.group("Msxco_76") + "s" in TEXT and not " o " + m.group("Msxco_75") + "ico " + m.group("Msxco_76") + "s" in TEXT and not m.group("Msxco_75") + "ico-" + m.group("Msxco_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_77>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_77") + "ico " + m.group("Msxco_78") + "inhos" in TEXT and not " ou " + m.group("Msxco_77") + "ico " + m.group("Msxco_78") + "inhos" in TEXT and not "s de " + m.group("Msxco_77") + "ico " + m.group("Msxco_78") + "inhos" in TEXT and not "s do " + m.group("Msxco_77") + "ico " + m.group("Msxco_78") + "inhos" in TEXT and not " o " + m.group("Msxco_77") + "ico " + m.group("Msxco_78") + "inhos" in TEXT and not m.group("Msxco_77") + "ico-" + m.group("Msxco_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_79>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_79") + "ico " + m.group("Msxco_80") + "icas" in TEXT and not " ou " + m.group("Msxco_79") + "ico " + m.group("Msxco_80") + "icas" in TEXT and not "s de " + m.group("Msxco_79") + "ico " + m.group("Msxco_80") + "icas" in TEXT and not "s do " + m.group("Msxco_79") + "ico " + m.group("Msxco_80") + "icas" in TEXT and not " o " + m.group("Msxco_79") + "ico " + m.group("Msxco_80") + "icas" in TEXT and not m.group("Msxco_79") + "ico-" + m.group("Msxco_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_81>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_81") + "ico " + m.group("Msxco_82") + "icas" in TEXT and not " ou " + m.group("Msxco_81") + "ico " + m.group("Msxco_82") + "icas" in TEXT and not "s de " + m.group("Msxco_81") + "ico " + m.group("Msxco_82") + "icas" in TEXT and not "s do " + m.group("Msxco_81") + "ico " + m.group("Msxco_82") + "icas" in TEXT and not " o " + m.group("Msxco_81") + "ico " + m.group("Msxco_82") + "icas" in TEXT and not m.group("Msxco_81") + "ico-" + m.group("Msxco_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_83>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_83") + "ico " + m.group("Msxco_84") + "icas" in TEXT and not " ou " + m.group("Msxco_83") + "ico " + m.group("Msxco_84") + "icas" in TEXT and not "s de " + m.group("Msxco_83") + "ico " + m.group("Msxco_84") + "icas" in TEXT and not "s do " + m.group("Msxco_83") + "ico " + m.group("Msxco_84") + "icas" in TEXT and not " o " + m.group("Msxco_83") + "ico " + m.group("Msxco_84") + "icas" in TEXT and not m.group("Msxco_83") + "ico-" + m.group("Msxco_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_85>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_85") + "ico " + m.group("Msxco_86") + "escas" in TEXT and not " ou " + m.group("Msxco_85") + "ico " + m.group("Msxco_86") + "escas" in TEXT and not "s de " + m.group("Msxco_85") + "ico " + m.group("Msxco_86") + "escas" in TEXT and not "s do " + m.group("Msxco_85") + "ico " + m.group("Msxco_86") + "escas" in TEXT and not " o " + m.group("Msxco_85") + "ico " + m.group("Msxco_86") + "escas" in TEXT and not m.group("Msxco_85") + "ico-" + m.group("Msxco_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_87>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_87") + "ico " + m.group("Msxco_88") + "idas" in TEXT and not " ou " + m.group("Msxco_87") + "s " + m.group("Msxco_88") + "idas" in TEXT and not "s de " + m.group("Msxco_87") + "s " + m.group("Msxco_88") + "idas" in TEXT and not "s do " + m.group("Msxco_87") + "s " + m.group("Msxco_88") + "idas" in TEXT and not " o " + m.group("Msxco_87") + "s " + m.group("Msxco_88") + "idas" in TEXT and not m.group("Msxco_87") + "ico-" + m.group("Msxco_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_89>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_89") + "ico " + m.group("Msxco_90") + "logas" in TEXT and not " ou " + m.group("Msxco_89") + "ico " + m.group("Msxco_90") + "logas" in TEXT and not "s de " + m.group("Msxco_89") + "ico " + m.group("Msxco_90") + "logas" in TEXT and not "s do " + m.group("Msxco_89") + "ico " + m.group("Msxco_90") + "logas" in TEXT and not " o " + m.group("Msxco_89") + "ico " + m.group("Msxco_90") + "logas" in TEXT and not m.group("Msxco_89") + "ico-" + m.group("Msxco_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_91>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_91") + "ico " + m.group("Msxco_92") + "rias" in TEXT and not " ou " + m.group("Msxco_91") + "ico " + m.group("Msxco_92") + "rias" in TEXT and not "s de " + m.group("Msxco_91") + "ico " + m.group("Msxco_92") + "rias" in TEXT and not "s do " + m.group("Msxco_91") + "ico " + m.group("Msxco_92") + "rias" in TEXT and not " o " + m.group("Msxco_91") + "ico " + m.group("Msxco_92") + "rias" in TEXT and not m.group("Msxco_91") + "ico-" + m.group("Msxco_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_93>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_93") + "ico " + m.group("Msxco_94") + "ssimas" in TEXT and not " ou " + m.group("Msxco_93") + "ico " + m.group("Msxco_94") + "ssimas" in TEXT and not "s de " + m.group("Msxco_93") + "ico " + m.group("Msxco_94") + "ssimas" in TEXT and not "s do " + m.group("Msxco_93") + "ico " + m.group("Msxco_94") + "ssimas" in TEXT and not " o " + m.group("Msxco_93") + "ico " + m.group("Msxco_94") + "ssimas" in TEXT and not m.group("Msxco_93") + "ico-" + m.group("Msxco_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_95>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msxco_95") + "ico " + m.group("Msxco_96") + "simas" in TEXT and not " ou " + m.group("Msxco_95") + "ico " + m.group("Msxco_96") + "simas" in TEXT and not "s de " + m.group("Msxco_95") + "ico " + m.group("Msxco_96") + "simas" in TEXT and not "s do " + m.group("Msxco_95") + "ico " + m.group("Msxco_96") + "simas" in TEXT and not " o " + m.group("Msxco_95") + "ico " + m.group("Msxco_96") + "simas" in TEXT and not m.group("Msxco_95") + "ico-" + m.group("Msxco_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_97>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_98").lower() in plvrMfoa and not " e " + m.group("Msxco_97") + "ico " + m.group("Msxco_98") + "as" in TEXT and not " ou " + m.group("Msxco_97") + "ico " + m.group("Msxco_98") + "as" in TEXT and not "s de " + m.group("Msxco_97") + "ico " + m.group("Msxco_98") + "as" in TEXT and not "s do " + m.group("Msxco_97") + "ico " + m.group("Msxco_98") + "as" in TEXT and not " o " + m.group("Msxco_97") + "ico " + m.group("Msxco_98") + "as" in TEXT and not m.group("Msxco_97") + "ico-" + m.group("Msxco_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_99>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_100") in plvrMFm and not " e " + m.group("Msxco_99") + "ico " + m.group("Msxco_100") + "ns" in TEXT and not " ou " + m.group("Msxco_99") + "ico " + m.group("Msxco_100") + "ns" in TEXT and not "s de " + m.group("Msxco_99") + "ico " + m.group("Msxco_100") + "ns" in TEXT and not "s da " + m.group("Msxco_99") + "ico " + m.group("Msxco_100") + "ns" in TEXT and not " a " + m.group("Msxco_99") + "ico " + m.group("Msxco_100") + "ns" in TEXT and not m.group("Msxco_99") + "ico-" + m.group("Msxco_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msxco_101>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico (?P<Msxco_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "icos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msxco_102") in plvrMascm and not " e " + m.group("Msxco_101") + "ico " + m.group("Msxco_102") + "ns" in TEXT and not " ou " + m.group("Msxco_101") + "ico " + m.group("Msxco_102") + "ns" in TEXT and not "s de " + m.group("Msxco_101") + "ico " + m.group("Msxco_102") + "ns" in TEXT and not "s da " + m.group("Msxco_101") + "ico " + m.group("Msxco_102") + "ns" in TEXT and not " a " + m.group("Msxco_101") + "ico " + m.group("Msxco_102") + "ns" in TEXT and not m.group("Msxco_101") + "ico-" + m.group("Msxco_102") + "ns" in tCompostops'],
# ida a
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_1>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_2").lower() in plvrFema and not " e " + m.group("Msida_1") + "ida " + m.group("Msida_2") +"s" in TEXT and not " ou " + m.group("Msida_1") + "ida " + m.group("Msida_2") + "s" in TEXT and not "s de " + m.group("Msida_1") + "ida " + m.group("Msida_2") + "s" in TEXT and not "s da " + m.group("Msida_1") + "ida " + m.group("Msida_2") + "s" in TEXT and not " a " + m.group("Msida_1") + "ida " + m.group("Msida_2") + "s" in TEXT and not m.group("Msida_1") + "ida-" + m.group("Msida_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_3>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_4").lower() in plvrMfoa and not " e " + m.group("Msida_3") + "ida " + m.group("Msida_4") + "as" in TEXT and not " ou " + m.group("Msida_3") + "ida " + m.group("Msida_4") + "as" in TEXT and not "s de " + m.group("Msida_3") + "ida " + m.group("Msida_4") + "as" in TEXT and not "s da " + m.group("Msida_3") + "ida " + m.group("Msida_4") + "as" in TEXT and not " a " + m.group("Msida_3") + "ida " + m.group("Msida_4") + "as" in TEXT and not m.group("Msida_3") + "ida-" + m.group("Msida_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_5>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msida_6").lower() in excAdo and not " e " + m.group("Msida_5") + "ida " + m.group("Msida_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msida_5") + "ida " + m.group("Msida_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msida_5") + "ida " + m.group("Msida_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Msida_5") + "ida " + m.group("Msida_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Msida_5") + "ida " + m.group("Msida_6") + m.group(3) + "dos" in TEXT and not m.group("Msida_5") + "ida-" + m.group("Msida_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_7>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msida_8").lower() in excIsta and not " e " + m.group("Msida_7") + "ida " + m.group("Msida_8") + "s" in TEXT and not " ou " + m.group("Msida_7") + "ida " + m.group("Msida_8") + "s" in TEXT and not "s de " + m.group("Msida_7") + "ida " + m.group("Msida_8") + "s" in TEXT and not "s da " + m.group("Msida_7") + "ida " + m.group("Msida_8") + "s" in TEXT and not " a " + m.group("Msida_7") + "ida " + m.group("Msida_8") + "s" in TEXT and not m.group("Msida_7") + "ida-" + m.group("Msida_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_9>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_10").lower() in plvrInva and not " e " + m.group("Msida_9") + "ida " + m.group("Msida_10") + "s" in TEXT and not " ou " + m.group("Msida_9") + "ida " + m.group("Msida_10") + "s" in TEXT and not "s de " + m.group("Msida_9") + "ida " + m.group("Msida_10") + "s" in TEXT and not "s da " + m.group("Msida_9") + "ida " + m.group("Msida_10") + "s" in TEXT and not " a " + m.group("Msida_9") + "ida " + m.group("Msida_10") + "s" in TEXT and not m.group("Msida_9") + "ida-" + m.group("Msida_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_11>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msida_12").lower() in excAdo and not " e " + m.group("Msida_11") + "ida " + m.group("Msida_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msida_11") + "ida " + m.group("Msida_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msida_11") + "ida " + m.group("Msida_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Msida_11") + "ida " + m.group("Msida_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Msida_11") + "ida " + m.group("Msida_12") + m.group(3) + "das" in TEXT and not m.group("Msida_11") + "ida-" + m.group("Msida_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_13>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msida_13") + "ida " + m.group("Msida_14") + "osos" in TEXT and not " ou " + m.group("Msida_13") + "ida " + m.group("Msida_14") + "osos" in TEXT and not "s de " + m.group("Msida_13") + "ida " + m.group("Msida_14") + "osos" in TEXT and not "s da " + m.group("Msida_13") + "ida " + m.group("Msida_14") + "osos" in TEXT and not " a " + m.group("Msida_13") + "ida " + m.group("Msida_14") + "osos" in TEXT and not m.group("Msida_13") + "ida-" + m.group("Msida_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_15>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msida_15") + "ida " + m.group("Msida_16") + "osas" in TEXT and not " ou " + m.group("Msida_15") + "ida " + m.group("Msida_16") + "osas" in TEXT and not "s de " + m.group("Msida_15") + "ida " + m.group("Msida_16") + "osas" in TEXT and not "s da " + m.group("Msida_15") + "ida " + m.group("Msida_16") + "osas" in TEXT and not " a " + m.group("Msida_15") + "ida " + m.group("Msida_16") + "osas" in TEXT and not m.group("Msida_15") + "ida-" + m.group("Msida_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_17>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msida_17") + "ida " + m.group("Msida_18") + "ivas" in TEXT and not " ou " + m.group("Msida_17") + "ida " + m.group("Msida_18") + "ivas" in TEXT and not "s de " + m.group("Msida_17") + "ida " + m.group("Msida_18") + "ivas" in TEXT and not "s da " + m.group("Msida_17") + "ida " + m.group("Msida_18") + "ivas" in TEXT and not " a " + m.group("Msida_17") + "ida " + m.group("Msida_18") + "ivas" in TEXT and not m.group("Msida_17") + "ida-" + m.group("Msida_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_19>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msida_19") + "ida " + m.group("Msida_20") + "ivas" in TEXT and not " ou " + m.group("Msida_19") + "ida " + m.group("Msida_20") + "ivas" in TEXT and not "s de " + m.group("Msida_19") + "ida " + m.group("Msida_20") + "ivas" in TEXT and not "s da " + m.group("Msida_19") + "ida " + m.group("Msida_20") + "ivas" in TEXT and not " a " + m.group("Msida_19") + "ida " + m.group("Msida_20") + "ivas" in TEXT and not m.group("Msida_19") + "ida-" + m.group("Msida_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_21>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msida_21") + "ida " + m.group("Msida_22") + "icas" in TEXT and not " ou " + m.group("Msida_21") + "ida " + m.group("Msida_22") + "icas" in TEXT and not "s de " + m.group("Msida_21") + "ida " + m.group("Msida_22") + "icas" in TEXT and not "s da " + m.group("Msida_21") + "ida " + m.group("Msida_22") + "icas" in TEXT and not " a " + m.group("Msida_21") + "ida " + m.group("Msida_22") + "icas" in TEXT and not m.group("Msida_21") + "ida-" + m.group("Msida_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_23>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msida_23") + "ida " + m.group("Msida_24") + "icas" in TEXT and not " ou " + m.group("Msida_23") + "ida " + m.group("Msida_24") + "icas" in TEXT and not "s de " + m.group("Msida_23") + "ida " + m.group("Msida_24") + "icas" in TEXT and not "s da " + m.group("Msida_23") + "ida " + m.group("Msida_24") + "icas" in TEXT and not " a " + m.group("Msida_23") + "ida " + m.group("Msida_24") + "icas" in TEXT and not m.group("Msida_23") + "ida-" + m.group("Msida_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_25>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msida_25") + "ida " + m.group("Msida_26") + "icas" in TEXT and not " ou " + m.group("Msida_25") + "ida " + m.group("Msida_26") + "icas" in TEXT and not "s de " + m.group("Msida_25") + "ida " + m.group("Msida_26") + "icas" in TEXT and not "s da " + m.group("Msida_25") + "ida " + m.group("Msida_26") + "icas" in TEXT and not " a " + m.group("Msida_25") + "ida " + m.group("Msida_26") + "icas" in TEXT and not m.group("Msida_25") + "ida-" + m.group("Msida_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_27>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msida_27") + "ida " + m.group("Msida_28") + "escas" in TEXT and not " ou " + m.group("Msida_27") + "ida " + m.group("Msida_28") + "escas" in TEXT and not "s de " + m.group("Msida_27") + "ida " + m.group("Msida_28") + "escas" in TEXT and not "s da " + m.group("Msida_27") + "ida " + m.group("Msida_28") + "escas" in TEXT and not " a " + m.group("Msida_27") + "ida " + m.group("Msida_28") + "escas" in TEXT and not m.group("Msida_27") + "ida-" + m.group("Msida_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_29>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msida_29") + "ida " + m.group("Msida_30") + "idas" in TEXT and not " ou " + m.group("Msida_29") + "s " + m.group("Msida_30") + "idas" in TEXT and not "s de " + m.group("Msida_29") + "s " + m.group("Msida_30") + "idas" in TEXT and not "s da " + m.group("Msida_29") + "s " + m.group("Msida_30") + "idas" in TEXT and not " a " + m.group("Msida_29") + "s " + m.group("Msida_30") + "idas" in TEXT and not m.group("Msida_29") + "ida-" + m.group("Msida_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_31>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msida_31") + "ida " + m.group("Msida_32") + "logas" in TEXT and not " ou " + m.group("Msida_31") + "ida " + m.group("Msida_32") + "logas" in TEXT and not "s de " + m.group("Msida_31") + "ida " + m.group("Msida_32") + "logas" in TEXT and not "s da " + m.group("Msida_31") + "ida " + m.group("Msida_32") + "logas" in TEXT and not " a " + m.group("Msida_31") + "ida " + m.group("Msida_32") + "logas" in TEXT and not m.group("Msida_31") + "ida-" + m.group("Msida_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_33>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msida_33") + "ida " + m.group("Msida_34") + "rias" in TEXT and not " ou " + m.group("Msida_33") + "ida " + m.group("Msida_34") + "rias" in TEXT and not "s de " + m.group("Msida_33") + "ida " + m.group("Msida_34") + "rias" in TEXT and not "s da " + m.group("Msida_33") + "ida " + m.group("Msida_34") + "rias" in TEXT and not " a " + m.group("Msida_33") + "ida " + m.group("Msida_34") + "rias" in TEXT and not m.group("Msida_33") + "ida-" + m.group("Msida_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_35>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msida_35") + "ida " + m.group("Msida_36") + "ssimas" in TEXT and not " ou " + m.group("Msida_35") + "ida " + m.group("Msida_36") + "ssimas" in TEXT and not "s de " + m.group("Msida_35") + "ida " + m.group("Msida_36") + "ssimas" in TEXT and not "s da " + m.group("Msida_35") + "ida " + m.group("Msida_36") + "ssimas" in TEXT and not " a " + m.group("Msida_35") + "ida " + m.group("Msida_36") + "ssimas" in TEXT and not m.group("Msida_35") + "ida-" + m.group("Msida_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_37>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msida_37") + "ida " + m.group("Msida_38") + "simas" in TEXT and not " ou " + m.group("Msida_37") + "ida " + m.group("Msida_38") + "simas" in TEXT and not "s de " + m.group("Msida_37") + "ida " + m.group("Msida_38") + "simas" in TEXT and not "s da " + m.group("Msida_37") + "ida " + m.group("Msida_38") + "simas" in TEXT and not " a " + m.group("Msida_37") + "ida " + m.group("Msida_38") + "simas" in TEXT and not m.group("Msida_37") + "ida-" + m.group("Msida_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_41>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msida_42") in "D-d-" and not " e " + m.group("Msida_41") + "ida " + m.group("Msida_42") + "oras" in TEXT and not " ou " + m.group("Msida_41") + "ida " + m.group("Msida_42") + "oras" in TEXT and not "s de " + m.group("Msida_41") + "ida " + m.group("Msida_42") + "oras" in TEXT and not "s da " + m.group("Msida_41") + "ida " + m.group("Msida_42") + "oras" in TEXT and not " a " + m.group("Msida_41") + "ida " + m.group("Msida_42") + "oras" in TEXT and not m.group("Msida_41") + "ida-" + m.group("Msida_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_43>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_44") in plvrMfr and not " e " + m.group("Msida_43") + "ida " + m.group("Msida_44") + "es" in TEXT and not " ou " + m.group("Msida_43") + "ida " + m.group("Msida_44") + "es" in TEXT and not "s de " + m.group("Msida_43") + "ida " + m.group("Msida_44") + "es" in TEXT and not "s da " + m.group("Msida_43") + "ida " + m.group("Msida_44") + "es" in TEXT and not " a " + m.group("Msida_43") + "ida " + m.group("Msida_44") + "es" in TEXT and not m.group("Msida_43") + "ida-" + m.group("Msida_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_45>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_46") in plvrFemr and not " e " + m.group("Msida_45") + "ida " + m.group("Msida_46") + "es" in TEXT and not " ou " + m.group("Msida_45") + "ida " + m.group("Msida_46") + "es" in TEXT and not "s de " + m.group("Msida_45") + "ida " + m.group("Msida_46") + "es" in TEXT and not "s da " + m.group("Msida_45") + "ida " + m.group("Msida_46") + "es" in TEXT and not " a " + m.group("Msida_45") + "ida " + m.group("Msida_46") + "es" in TEXT and not m.group("Msida_45") + "ida-" + m.group("Msida_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_47>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_48") in plvrMfal and not " e " + m.group("Msida_47") + "ida " + m.group("Msida_48") + "is" in TEXT and not " ou " + m.group("Msida_47") + "ida " + m.group("Msida_48") + "is" in TEXT and not "s de " + m.group("Msida_47") + "ida " + m.group("Msida_48") + "is" in TEXT and not "s da " + m.group("Msida_47") + "ida " + m.group("Msida_48") + "is" in TEXT and not " a " + m.group("Msida_47") + "ida " + m.group("Msida_48") + "is" in TEXT and not m.group("Msida_47") + "ida-" + m.group("Msida_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_49>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_50") in plvrMfcao and not " e " + m.group("Msida_49") + "ida " + m.group("Msida_50") + "ões" in TEXT and not + " ou " + m.group("Msida_49") + "ida " + m.group("Msida_50") + "ões" in TEXT and not + "s de " + m.group("Msida_49") + "ida " + m.group("Msida_50") + "ões" in TEXT and not + "s da " + m.group("Msida_49") + "ida " + m.group("Msida_50") + "ões" in TEXT and not + " a " + m.group("Msida_49") + "ida " + m.group("Msida_50") + "ões" in TEXT and not m.group("Msida_49") + "ida-" + m.group("Msida_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_51>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msida_52") in plvrMascao and not " e " + m.group("Msida_51") + "ida " + m.group("Msida_52") + "ões" in TEXT and not " ou " + m.group("Msida_51") + "ida " + m.group("Msida_52") + "ões" in TEXT and not "s de " + m.group("Msida_51") + "ida " + m.group("Msida_52") + "ões" in TEXT and not "s da " + m.group("Msida_51") + "ida " + m.group("Msida_52") + "ões" in TEXT and not " a " + m.group("Msida_51") + "ida " + m.group("Msida_52") + "ões" in TEXT and not m.group("Msida_51") + "ida-" + m.group("Msida_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_53>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_54") in plvrFemao and not " e " + m.group("Msida_53") + "ida " + m.group("Msida_54") + "ões" in TEXT and not " ou " + m.group("Msida_53") + "ida " + m.group("Msida_54") + "ões" in TEXT and not "s de " + m.group("Msida_53") + "ida " + m.group("Msida_54") + "ões" in TEXT and not "s da " + m.group("Msida_53") + "ida " + m.group("Msida_54") + "ões" in TEXT and not " a " + m.group("Msida_53") + "ida " + m.group("Msida_54") + "ões" in TEXT and not m.group("Msida_53") + "ida-" + m.group("Msida_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_55>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msida_55") + "ida " + m.group("Msida_56") + "veis" in TEXT and not " ou " + m.group("Msida_55") + "ida " + m.group("Msida_56") + "veis" in TEXT and not "s de " + m.group("Msida_55") + "ida " + m.group("Msida_56") + "veis" in TEXT and not "s da " + m.group("Msida_55") + "ida " + m.group("Msida_56") + "veis" in TEXT and not " a " + m.group("Msida_55") + "ida " + m.group("Msida_56") + "veis" in TEXT and not m.group("Msida_55") + "ida-" + m.group("Msida_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_57>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_58").lower() in plvrMfe and not " e " + m.group("Msida_57") + "ida " + m.group("Msida_58") + "es" in TEXT and not " ou " + m.group("Msida_57") + "ida " + m.group("Msida_58") + "es" in TEXT and not "s de " + m.group("Msida_57") + "ida " + m.group("Msida_58") + "es" in TEXT and not "s da " + m.group("Msida_57") + "ida " + m.group("Msida_58") + "es" in TEXT and not " a " + m.group("Msida_57") + "ida " + m.group("Msida_58") + "es" in TEXT and not m.group("Msida_57") + "ida-" + m.group("Msida_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_59>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_60").lower() in plvrFeme and not " e " + m.group("Msida_59") + "ida " + m.group("Msida_60") + "es" in TEXT and not " ou " + m.group("Msida_59") + "ida " + m.group("Msida_60") + "es" in TEXT and not "s de " + m.group("Msida_59") + "ida " + m.group("Msida_60") + "es" in TEXT and not "s da " + m.group("Msida_59") + "ida " + m.group("Msida_60") + "es" in TEXT and not " a " + m.group("Msida_59") + "ida " + m.group("Msida_60") + "es" in TEXT and not m.group("Msida_59") + "ida-" + m.group("Msida_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_61>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_62") in plvrMfel and not " e " + m.group("Msida_61") + "ida " + m.group("Msida_62") + "éis" in TEXT and not " ou " + m.group("Msida_61") + "ida " + m.group("Msida_62") + "éis" in TEXT and not "s de " + m.group("Msida_61") + "ida " + m.group("Msida_62") + "éis" in TEXT and not "s da " + m.group("Msida_61") + "ida " + m.group("Msida_62") + "éis" in TEXT and not " a " + m.group("Msida_61") + "ida " + m.group("Msida_62") + "éis" in TEXT and not m.group("Msida_61") + "ida-" + m.group("Msida_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_63>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_64") in plvrFemel and not " e " + m.group("Msida_63") + "ida " + m.group("Msida_64") + "éis" in TEXT and not " ou " + m.group("Msida_63") + "ida " + m.group("Msida_64") + "éis" in TEXT and not "s de " + m.group("Msida_63") + "ida " + m.group("Msida_64") + "éis" in TEXT and not "s da " + m.group("Msida_63") + "ida " + m.group("Msida_64") + "éis" in TEXT and not " a " + m.group("Msida_63") + "ida " + m.group("Msida_64") + "éis" in TEXT and not m.group("Msida_63") + "ida-" + m.group("Msida_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_65>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_66") in plvrMfeu and not " e " + m.group("Msida_65") + "ida " + m.group("Msida_66") + "us" in TEXT and not " ou " + m.group("Msida_65") + "ida " + m.group("Msida_66") + "us" in TEXT and not "s de " + m.group("Msida_65") + "ida " + m.group("Msida_66") + "us" in TEXT and not "s da " + m.group("Msida_65") + "ida " + m.group("Msida_66") + "us" in TEXT and not " a " + m.group("Msida_65") + "ida " + m.group("Msida_66") + "us" in TEXT and not m.group("Msida_65") + "ida-" + m.group("Msida_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_67>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_68") in plvrFemu and not " e " + m.group("Msida_67") + "ida " + m.group("Msida_68") + "us" in TEXT and not " ou " + m.group("Msida_67") + "ida " + m.group("Msida_68") + "us" in TEXT and not "s de " + m.group("Msida_67") + "ida " + m.group("Msida_68") + "us" in TEXT and not "s da " + m.group("Msida_67") + "ida " + m.group("Msida_68") + "us" in TEXT and not " a " + m.group("Msida_67") + "ida " + m.group("Msida_68") + "us" in TEXT and not m.group("Msida_67") + "ida-" + m.group("Msida_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_69>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_70") in plvrInvaz and not " e " + m.group("Msida_69") + "ida " + m.group("Msida_70") + "zes" in TEXT and not " ou " + m.group("Msida_69") + "ida " + m.group("Msida_70") + "zes" in TEXT and not "s de " + m.group("Msida_69") + "ida " + m.group("Msida_70") + "zes" in TEXT and not "s da " + m.group("Msida_69") + "ida " + m.group("Msida_70") + "zes" in TEXT and not " a " + m.group("Msida_69") + "ida " + m.group("Msida_70") + "zes" in TEXT and not m.group("Msida_69") + "ida-" + m.group("Msida_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_71>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_72") in plvrFemz and not " e " + m.group("Msida_71") + "ida " + m.group("Msida_72") + "zes" in TEXT and not " ou " + m.group("Msida_71") + "ida " + m.group("Msida_72") + "zes" in TEXT and not "s de " + m.group("Msida_71") + "ida " + m.group("Msida_72") + "zes" in TEXT and not "s da " + m.group("Msida_71") + "ida " + m.group("Msida_72") + "zes" in TEXT and not " a " + m.group("Msida_71") + "ida " + m.group("Msida_72") + "zes" in TEXT and not m.group("Msida_71") + "ida-" + m.group("Msida_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_73>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_74") in pvrFeman and not " e " + m.group("Msida_73") + "ida " + m.group("Msida_74") + "s" in TEXT and not " ou " + m.group("Msida_73") + "ida " + m.group("Msida_74") + "s" in TEXT and not "s de " + m.group("Msida_73") + "ida " + m.group("Msida_74") + "s" in TEXT and not "s da " + m.group("Msida_73") + "ida " + m.group("Msida_74") + "s" in TEXT and not " a " + m.group("Msida_73") + "ida " + m.group("Msida_74") + "s" in TEXT and not m.group("Msida_73") + "ida-" + m.group("Msida_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_99>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_100") in plvrMFm and not " e " + m.group("Msida_99") + "ida " + m.group("Msida_100") + "ns" in TEXT and not " ou " + m.group("Msida_99") + "ida " + m.group("Msida_100") + "ns" in TEXT and not "s de " + m.group("Msida_99") + "ida " + m.group("Msida_100") + "ns" in TEXT and not "s da " + m.group("Msida_99") + "ida " + m.group("Msida_100") + "ns" in TEXT and not " a " + m.group("Msida_99") + "ida " + m.group("Msida_100") + "ns" in TEXT and not m.group("Msida_99") + "ida-" + m.group("Msida_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msida_101>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])ida (?P<Msida_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "idas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msida_102") in plvrFemm and not " e " + m.group("Msida_101") + "ida " + m.group("Msida_102") + "ns" in TEXT and not " ou " + m.group("Msida_101") + "ida " + m.group("Msida_102") + "ns" in TEXT and not "s de " + m.group("Msida_101") + "ida " + m.group("Msida_102") + "ns" in TEXT and not "s da " + m.group("Msida_101") + "ida " + m.group("Msida_102") + "ns" in TEXT and not " a " + m.group("Msida_101") + "ida " + m.group("Msida_102") + "ns" in TEXT and not m.group("Msida_101") + "ida-" + m.group("Msida_102") + "ns" in tCompostops'],
# loga a
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_1>[a-zA-Zç]+[ó])loga (?P<Mslga_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_2").lower() in plvrFema and not " e " + m.group("Mslga_1") + "loga " + m.group("Mslga_2") +"s" in TEXT and not " ou " + m.group("Mslga_1") + "loga " + m.group("Mslga_2") + "s" in TEXT and not "s de " + m.group("Mslga_1") + "loga " + m.group("Mslga_2") + "s" in TEXT and not "s da " + m.group("Mslga_1") + "loga " + m.group("Mslga_2") + "s" in TEXT and not " a " + m.group("Mslga_1") + "loga " + m.group("Mslga_2") + "s" in TEXT and not m.group("Mslga_1") + "loga-" + m.group("Mslga_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_3>[a-zA-Zç]+[ó])loga (?P<Mslga_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_4").lower() in plvrMfoa and not " e " + m.group("Mslga_3") + "loga " + m.group("Mslga_4") + "as" in TEXT and not " ou " + m.group("Mslga_3") + "loga " + m.group("Mslga_4") + "as" in TEXT and not "s de " + m.group("Mslga_3") + "loga " + m.group("Mslga_4") + "as" in TEXT and not "s da " + m.group("Mslga_3") + "loga " + m.group("Mslga_4") + "as" in TEXT and not " a " + m.group("Mslga_3") + "loga " + m.group("Mslga_4") + "as" in TEXT and not m.group("Mslga_3") + "loga-" + m.group("Mslga_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_5>[a-zA-Zç]+[ó])loga (?P<Mslga_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mslga_6").lower() in excAdo and not " e " + m.group("Mslga_5") + "loga " + m.group("Mslga_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Mslga_5") + "loga " + m.group("Mslga_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Mslga_5") + "loga " + m.group("Mslga_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Mslga_5") + "loga " + m.group("Mslga_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Mslga_5") + "loga " + m.group("Mslga_6") + m.group(3) + "dos" in TEXT and not m.group("Mslga_5") + "loga-" + m.group("Mslga_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_7>[a-zA-Zç]+[ó])loga (?P<Mslga_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mslga_8").lower() in excIsta and not " e " + m.group("Mslga_7") + "loga " + m.group("Mslga_8") + "s" in TEXT and not " ou " + m.group("Mslga_7") + "loga " + m.group("Mslga_8") + "s" in TEXT and not "s de " + m.group("Mslga_7") + "loga " + m.group("Mslga_8") + "s" in TEXT and not "s da " + m.group("Mslga_7") + "loga " + m.group("Mslga_8") + "s" in TEXT and not " a " + m.group("Mslga_7") + "loga " + m.group("Mslga_8") + "s" in TEXT and not m.group("Mslga_7") + "loga-" + m.group("Mslga_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_9>[a-zA-Zç]+[ó])loga (?P<Mslga_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_10").lower() in plvrInva and not " e " + m.group("Mslga_9") + "loga " + m.group("Mslga_10") + "s" in TEXT and not " ou " + m.group("Mslga_9") + "loga " + m.group("Mslga_10") + "s" in TEXT and not "s de " + m.group("Mslga_9") + "loga " + m.group("Mslga_10") + "s" in TEXT and not "s da " + m.group("Mslga_9") + "loga " + m.group("Mslga_10") + "s" in TEXT and not " a " + m.group("Mslga_9") + "loga " + m.group("Mslga_10") + "s" in TEXT and not m.group("Mslga_9") + "loga-" + m.group("Mslga_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_11>[a-zA-Zç]+[ó])loga (?P<Mslga_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mslga_12").lower() in excAdo and not " e " + m.group("Mslga_11") + "loga " + m.group("Mslga_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Mslga_11") + "loga " + m.group("Mslga_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Mslga_11") + "loga " + m.group("Mslga_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Mslga_11") + "loga " + m.group("Mslga_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Mslga_11") + "loga " + m.group("Mslga_12") + m.group(3) + "das" in TEXT and not m.group("Mslga_11") + "loga-" + m.group("Mslga_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_13>[a-zA-Zç]+[ó])loga (?P<Mslga_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslga_13") + "loga " + m.group("Mslga_14") + "osos" in TEXT and not " ou " + m.group("Mslga_13") + "loga " + m.group("Mslga_14") + "osos" in TEXT and not "s de " + m.group("Mslga_13") + "loga " + m.group("Mslga_14") + "osos" in TEXT and not "s da " + m.group("Mslga_13") + "loga " + m.group("Mslga_14") + "osos" in TEXT and not " a " + m.group("Mslga_13") + "loga " + m.group("Mslga_14") + "osos" in TEXT and not m.group("Mslga_13") + "loga-" + m.group("Mslga_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_15>[a-zA-Zç]+[ó])loga (?P<Mslga_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslga_15") + "loga " + m.group("Mslga_16") + "osas" in TEXT and not " ou " + m.group("Mslga_15") + "loga " + m.group("Mslga_16") + "osas" in TEXT and not "s de " + m.group("Mslga_15") + "loga " + m.group("Mslga_16") + "osas" in TEXT and not "s da " + m.group("Mslga_15") + "loga " + m.group("Mslga_16") + "osas" in TEXT and not " a " + m.group("Mslga_15") + "loga " + m.group("Mslga_16") + "osas" in TEXT and not m.group("Mslga_15") + "loga-" + m.group("Mslga_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_17>[a-zA-Zç]+[ó])loga (?P<Mslga_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslga_17") + "loga " + m.group("Mslga_18") + "ivas" in TEXT and not " ou " + m.group("Mslga_17") + "loga " + m.group("Mslga_18") + "ivas" in TEXT and not "s de " + m.group("Mslga_17") + "loga " + m.group("Mslga_18") + "ivas" in TEXT and not "s da " + m.group("Mslga_17") + "loga " + m.group("Mslga_18") + "ivas" in TEXT and not " a " + m.group("Mslga_17") + "loga " + m.group("Mslga_18") + "ivas" in TEXT and not m.group("Mslga_17") + "loga-" + m.group("Mslga_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_19>[a-zA-Zç]+[ó])loga (?P<Mslga_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslga_19") + "loga " + m.group("Mslga_20") + "ivas" in TEXT and not " ou " + m.group("Mslga_19") + "loga " + m.group("Mslga_20") + "ivas" in TEXT and not "s de " + m.group("Mslga_19") + "loga " + m.group("Mslga_20") + "ivas" in TEXT and not "s da " + m.group("Mslga_19") + "loga " + m.group("Mslga_20") + "ivas" in TEXT and not " a " + m.group("Mslga_19") + "loga " + m.group("Mslga_20") + "ivas" in TEXT and not m.group("Mslga_19") + "loga-" + m.group("Mslga_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_21>[a-zA-Zç]+[ó])loga (?P<Mslga_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslga_21") + "loga " + m.group("Mslga_22") + "icas" in TEXT and not " ou " + m.group("Mslga_21") + "loga " + m.group("Mslga_22") + "icas" in TEXT and not "s de " + m.group("Mslga_21") + "loga " + m.group("Mslga_22") + "icas" in TEXT and not "s da " + m.group("Mslga_21") + "loga " + m.group("Mslga_22") + "icas" in TEXT and not " a " + m.group("Mslga_21") + "loga " + m.group("Mslga_22") + "icas" in TEXT and not m.group("Mslga_21") + "loga-" + m.group("Mslga_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_23>[a-zA-Zç]+[ó])loga (?P<Mslga_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslga_23") + "loga " + m.group("Mslga_24") + "icas" in TEXT and not " ou " + m.group("Mslga_23") + "loga " + m.group("Mslga_24") + "icas" in TEXT and not "s de " + m.group("Mslga_23") + "loga " + m.group("Mslga_24") + "icas" in TEXT and not "s da " + m.group("Mslga_23") + "loga " + m.group("Mslga_24") + "icas" in TEXT and not " a " + m.group("Mslga_23") + "loga " + m.group("Mslga_24") + "icas" in TEXT and not m.group("Mslga_23") + "loga-" + m.group("Mslga_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_25>[a-zA-Zç]+[ó])loga (?P<Mslga_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslga_25") + "loga " + m.group("Mslga_26") + "icas" in TEXT and not " ou " + m.group("Mslga_25") + "loga " + m.group("Mslga_26") + "icas" in TEXT and not "s de " + m.group("Mslga_25") + "loga " + m.group("Mslga_26") + "icas" in TEXT and not "s da " + m.group("Mslga_25") + "loga " + m.group("Mslga_26") + "icas" in TEXT and not " a " + m.group("Mslga_25") + "loga " + m.group("Mslga_26") + "icas" in TEXT and not m.group("Mslga_25") + "loga-" + m.group("Mslga_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_27>[a-zA-Zç]+[ó])loga (?P<Mslga_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslga_27") + "loga " + m.group("Mslga_28") + "escas" in TEXT and not " ou " + m.group("Mslga_27") + "loga " + m.group("Mslga_28") + "escas" in TEXT and not "s de " + m.group("Mslga_27") + "loga " + m.group("Mslga_28") + "escas" in TEXT and not "s da " + m.group("Mslga_27") + "loga " + m.group("Mslga_28") + "escas" in TEXT and not " a " + m.group("Mslga_27") + "loga " + m.group("Mslga_28") + "escas" in TEXT and not m.group("Mslga_27") + "loga-" + m.group("Mslga_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_29>[a-zA-Zç]+[ó])loga (?P<Mslga_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslga_29") + "loga " + m.group("Mslga_30") + "idas" in TEXT and not " ou " + m.group("Mslga_29") + "s " + m.group("Mslga_30") + "idas" in TEXT and not "s de " + m.group("Mslga_29") + "s " + m.group("Mslga_30") + "idas" in TEXT and not "s da " + m.group("Mslga_29") + "s " + m.group("Mslga_30") + "idas" in TEXT and not " a " + m.group("Mslga_29") + "s " + m.group("Mslga_30") + "idas" in TEXT and not m.group("Mslga_29") + "loga-" + m.group("Mslga_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_31>[a-zA-Zç]+[ó])loga (?P<Mslga_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslga_31") + "loga " + m.group("Mslga_32") + "logas" in TEXT and not " ou " + m.group("Mslga_31") + "loga " + m.group("Mslga_32") + "logas" in TEXT and not "s de " + m.group("Mslga_31") + "loga " + m.group("Mslga_32") + "logas" in TEXT and not "s da " + m.group("Mslga_31") + "loga " + m.group("Mslga_32") + "logas" in TEXT and not " a " + m.group("Mslga_31") + "loga " + m.group("Mslga_32") + "logas" in TEXT and not m.group("Mslga_31") + "loga-" + m.group("Mslga_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_33>[a-zA-Zç]+[ó])loga (?P<Mslga_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslga_33") + "loga " + m.group("Mslga_34") + "rias" in TEXT and not " ou " + m.group("Mslga_33") + "loga " + m.group("Mslga_34") + "rias" in TEXT and not "s de " + m.group("Mslga_33") + "loga " + m.group("Mslga_34") + "rias" in TEXT and not "s da " + m.group("Mslga_33") + "loga " + m.group("Mslga_34") + "rias" in TEXT and not " a " + m.group("Mslga_33") + "loga " + m.group("Mslga_34") + "rias" in TEXT and not m.group("Mslga_33") + "loga-" + m.group("Mslga_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_35>[a-zA-Zç]+[ó])loga (?P<Mslga_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslga_35") + "loga " + m.group("Mslga_36") + "ssimas" in TEXT and not " ou " + m.group("Mslga_35") + "loga " + m.group("Mslga_36") + "ssimas" in TEXT and not "s de " + m.group("Mslga_35") + "loga " + m.group("Mslga_36") + "ssimas" in TEXT and not "s da " + m.group("Mslga_35") + "loga " + m.group("Mslga_36") + "ssimas" in TEXT and not " a " + m.group("Mslga_35") + "loga " + m.group("Mslga_36") + "ssimas" in TEXT and not m.group("Mslga_35") + "loga-" + m.group("Mslga_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_37>[a-zA-Zç]+[ó])loga (?P<Mslga_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslga_37") + "loga " + m.group("Mslga_38") + "simas" in TEXT and not " ou " + m.group("Mslga_37") + "loga " + m.group("Mslga_38") + "simas" in TEXT and not "s de " + m.group("Mslga_37") + "loga " + m.group("Mslga_38") + "simas" in TEXT and not "s da " + m.group("Mslga_37") + "loga " + m.group("Mslga_38") + "simas" in TEXT and not " a " + m.group("Mslga_37") + "loga " + m.group("Mslga_38") + "simas" in TEXT and not m.group("Mslga_37") + "loga-" + m.group("Mslga_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_41>[a-zA-Zç]+[ó])loga (?P<Mslga_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mslga_42") in "D-d-" and not " e " + m.group("Mslga_41") + "loga " + m.group("Mslga_42") + "oras" in TEXT and not " ou " + m.group("Mslga_41") + "loga " + m.group("Mslga_42") + "oras" in TEXT and not "s de " + m.group("Mslga_41") + "loga " + m.group("Mslga_42") + "oras" in TEXT and not "s da " + m.group("Mslga_41") + "loga " + m.group("Mslga_42") + "oras" in TEXT and not " a " + m.group("Mslga_41") + "loga " + m.group("Mslga_42") + "oras" in TEXT and not m.group("Mslga_41") + "loga-" + m.group("Mslga_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_43>[a-zA-Zç]+[ó])loga (?P<Mslga_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_44") in plvrMfr and not " e " + m.group("Mslga_43") + "loga " + m.group("Mslga_44") + "es" in TEXT and not " ou " + m.group("Mslga_43") + "loga " + m.group("Mslga_44") + "es" in TEXT and not "s de " + m.group("Mslga_43") + "loga " + m.group("Mslga_44") + "es" in TEXT and not "s da " + m.group("Mslga_43") + "loga " + m.group("Mslga_44") + "es" in TEXT and not " a " + m.group("Mslga_43") + "loga " + m.group("Mslga_44") + "es" in TEXT and not m.group("Mslga_43") + "loga-" + m.group("Mslga_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_45>[a-zA-Zç]+[ó])loga (?P<Mslga_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_46") in plvrFemr and not " e " + m.group("Mslga_45") + "loga " + m.group("Mslga_46") + "es" in TEXT and not " ou " + m.group("Mslga_45") + "loga " + m.group("Mslga_46") + "es" in TEXT and not "s de " + m.group("Mslga_45") + "loga " + m.group("Mslga_46") + "es" in TEXT and not "s da " + m.group("Mslga_45") + "loga " + m.group("Mslga_46") + "es" in TEXT and not " a " + m.group("Mslga_45") + "loga " + m.group("Mslga_46") + "es" in TEXT and not m.group("Mslga_45") + "loga-" + m.group("Mslga_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_47>[a-zA-Zç]+[ó])loga (?P<Mslga_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_48") in plvrMfal and not " e " + m.group("Mslga_47") + "loga " + m.group("Mslga_48") + "is" in TEXT and not " ou " + m.group("Mslga_47") + "loga " + m.group("Mslga_48") + "is" in TEXT and not "s de " + m.group("Mslga_47") + "loga " + m.group("Mslga_48") + "is" in TEXT and not "s da " + m.group("Mslga_47") + "loga " + m.group("Mslga_48") + "is" in TEXT and not " a " + m.group("Mslga_47") + "loga " + m.group("Mslga_48") + "is" in TEXT and not m.group("Mslga_47") + "loga-" + m.group("Mslga_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_49>[a-zA-Zç]+[ó])loga (?P<Mslga_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_50") in plvrMfcao and not " e " + m.group("Mslga_49") + "loga " + m.group("Mslga_50") + "ões" in TEXT and not + " ou " + m.group("Mslga_49") + "loga " + m.group("Mslga_50") + "ões" in TEXT and not + "s de " + m.group("Mslga_49") + "loga " + m.group("Mslga_50") + "ões" in TEXT and not + "s da " + m.group("Mslga_49") + "loga " + m.group("Mslga_50") + "ões" in TEXT and not + " a " + m.group("Mslga_49") + "loga " + m.group("Mslga_50") + "ões" in TEXT and not m.group("Mslga_49") + "loga-" + m.group("Mslga_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_51>[a-zA-Zç]+[ó])loga (?P<Mslga_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mslga_52") in plvrMascao and not " e " + m.group("Mslga_51") + "loga " + m.group("Mslga_52") + "ões" in TEXT and not " ou " + m.group("Mslga_51") + "loga " + m.group("Mslga_52") + "ões" in TEXT and not "s de " + m.group("Mslga_51") + "loga " + m.group("Mslga_52") + "ões" in TEXT and not "s da " + m.group("Mslga_51") + "loga " + m.group("Mslga_52") + "ões" in TEXT and not " a " + m.group("Mslga_51") + "loga " + m.group("Mslga_52") + "ões" in TEXT and not m.group("Mslga_51") + "loga-" + m.group("Mslga_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_53>[a-zA-Zç]+[ó])loga (?P<Mslga_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_54") in plvrFemao and not " e " + m.group("Mslga_53") + "loga " + m.group("Mslga_54") + "ões" in TEXT and not " ou " + m.group("Mslga_53") + "loga " + m.group("Mslga_54") + "ões" in TEXT and not "s de " + m.group("Mslga_53") + "loga " + m.group("Mslga_54") + "ões" in TEXT and not "s da " + m.group("Mslga_53") + "loga " + m.group("Mslga_54") + "ões" in TEXT and not " a " + m.group("Mslga_53") + "loga " + m.group("Mslga_54") + "ões" in TEXT and not m.group("Mslga_53") + "loga-" + m.group("Mslga_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_55>[a-zA-Zç]+[ó])loga (?P<Mslga_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslga_55") + "loga " + m.group("Mslga_56") + "veis" in TEXT and not " ou " + m.group("Mslga_55") + "loga " + m.group("Mslga_56") + "veis" in TEXT and not "s de " + m.group("Mslga_55") + "loga " + m.group("Mslga_56") + "veis" in TEXT and not "s da " + m.group("Mslga_55") + "loga " + m.group("Mslga_56") + "veis" in TEXT and not " a " + m.group("Mslga_55") + "loga " + m.group("Mslga_56") + "veis" in TEXT and not m.group("Mslga_55") + "loga-" + m.group("Mslga_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_57>[a-zA-Zç]+[ó])loga (?P<Mslga_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_58").lower() in plvrMfe and not " e " + m.group("Mslga_57") + "loga " + m.group("Mslga_58") + "es" in TEXT and not " ou " + m.group("Mslga_57") + "loga " + m.group("Mslga_58") + "es" in TEXT and not "s de " + m.group("Mslga_57") + "loga " + m.group("Mslga_58") + "es" in TEXT and not "s da " + m.group("Mslga_57") + "loga " + m.group("Mslga_58") + "es" in TEXT and not " a " + m.group("Mslga_57") + "loga " + m.group("Mslga_58") + "es" in TEXT and not m.group("Mslga_57") + "loga-" + m.group("Mslga_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_59>[a-zA-Zç]+[ó])loga (?P<Mslga_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_60").lower() in plvrFeme and not " e " + m.group("Mslga_59") + "loga " + m.group("Mslga_60") + "es" in TEXT and not " ou " + m.group("Mslga_59") + "loga " + m.group("Mslga_60") + "es" in TEXT and not "s de " + m.group("Mslga_59") + "loga " + m.group("Mslga_60") + "es" in TEXT and not "s da " + m.group("Mslga_59") + "loga " + m.group("Mslga_60") + "es" in TEXT and not " a " + m.group("Mslga_59") + "loga " + m.group("Mslga_60") + "es" in TEXT and not m.group("Mslga_59") + "loga-" + m.group("Mslga_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_61>[a-zA-Zç]+[ó])loga (?P<Mslga_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_62") in plvrMfel and not " e " + m.group("Mslga_61") + "loga " + m.group("Mslga_62") + "éis" in TEXT and not " ou " + m.group("Mslga_61") + "loga " + m.group("Mslga_62") + "éis" in TEXT and not "s de " + m.group("Mslga_61") + "loga " + m.group("Mslga_62") + "éis" in TEXT and not "s da " + m.group("Mslga_61") + "loga " + m.group("Mslga_62") + "éis" in TEXT and not " a " + m.group("Mslga_61") + "loga " + m.group("Mslga_62") + "éis" in TEXT and not m.group("Mslga_61") + "loga-" + m.group("Mslga_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_63>[a-zA-Zç]+[ó])loga (?P<Mslga_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_64") in plvrFemel and not " e " + m.group("Mslga_63") + "loga " + m.group("Mslga_64") + "éis" in TEXT and not " ou " + m.group("Mslga_63") + "loga " + m.group("Mslga_64") + "éis" in TEXT and not "s de " + m.group("Mslga_63") + "loga " + m.group("Mslga_64") + "éis" in TEXT and not "s da " + m.group("Mslga_63") + "loga " + m.group("Mslga_64") + "éis" in TEXT and not " a " + m.group("Mslga_63") + "loga " + m.group("Mslga_64") + "éis" in TEXT and not m.group("Mslga_63") + "loga-" + m.group("Mslga_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_65>[a-zA-Zç]+[ó])loga (?P<Mslga_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_66") in plvrMfeu and not " e " + m.group("Mslga_65") + "loga " + m.group("Mslga_66") + "us" in TEXT and not " ou " + m.group("Mslga_65") + "loga " + m.group("Mslga_66") + "us" in TEXT and not "s de " + m.group("Mslga_65") + "loga " + m.group("Mslga_66") + "us" in TEXT and not "s da " + m.group("Mslga_65") + "loga " + m.group("Mslga_66") + "us" in TEXT and not " a " + m.group("Mslga_65") + "loga " + m.group("Mslga_66") + "us" in TEXT and not m.group("Mslga_65") + "loga-" + m.group("Mslga_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_67>[a-zA-Zç]+[ó])loga (?P<Mslga_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_68") in plvrFemu and not " e " + m.group("Mslga_67") + "loga " + m.group("Mslga_68") + "us" in TEXT and not " ou " + m.group("Mslga_67") + "loga " + m.group("Mslga_68") + "us" in TEXT and not "s de " + m.group("Mslga_67") + "loga " + m.group("Mslga_68") + "us" in TEXT and not "s da " + m.group("Mslga_67") + "loga " + m.group("Mslga_68") + "us" in TEXT and not " a " + m.group("Mslga_67") + "loga " + m.group("Mslga_68") + "us" in TEXT and not m.group("Mslga_67") + "loga-" + m.group("Mslga_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_69>[a-zA-Zç]+[ó])loga (?P<Mslga_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_70") in plvrInvaz and not " e " + m.group("Mslga_69") + "loga " + m.group("Mslga_70") + "zes" in TEXT and not " ou " + m.group("Mslga_69") + "loga " + m.group("Mslga_70") + "zes" in TEXT and not "s de " + m.group("Mslga_69") + "loga " + m.group("Mslga_70") + "zes" in TEXT and not "s da " + m.group("Mslga_69") + "loga " + m.group("Mslga_70") + "zes" in TEXT and not " a " + m.group("Mslga_69") + "loga " + m.group("Mslga_70") + "zes" in TEXT and not m.group("Mslga_69") + "loga-" + m.group("Mslga_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_71>[a-zA-Zç]+[ó])loga (?P<Mslga_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_72") in plvrFemz and not " e " + m.group("Mslga_71") + "loga " + m.group("Mslga_72") + "zes" in TEXT and not " ou " + m.group("Mslga_71") + "loga " + m.group("Mslga_72") + "zes" in TEXT and not "s de " + m.group("Mslga_71") + "loga " + m.group("Mslga_72") + "zes" in TEXT and not "s da " + m.group("Mslga_71") + "loga " + m.group("Mslga_72") + "zes" in TEXT and not " a " + m.group("Mslga_71") + "loga " + m.group("Mslga_72") + "zes" in TEXT and not m.group("Mslga_71") + "loga-" + m.group("Mslga_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_73>[a-zA-Zç]+[ó])loga (?P<Mslga_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_74") in pvrFeman and not " e " + m.group("Mslga_73") + "loga " + m.group("Mslga_74") + "s" in TEXT and not " ou " + m.group("Mslga_73") + "loga " + m.group("Mslga_74") + "s" in TEXT and not "s de " + m.group("Mslga_73") + "loga " + m.group("Mslga_74") + "s" in TEXT and not "s da " + m.group("Mslga_73") + "loga " + m.group("Mslga_74") + "s" in TEXT and not " a " + m.group("Mslga_73") + "loga " + m.group("Mslga_74") + "s" in TEXT and not m.group("Mslga_73") + "loga-" + m.group("Mslga_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_99>[a-zA-Zç]+[ó])loga (?P<Mslga_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_100") in plvrMFm and not " e " + m.group("Mslga_99") + "loga " + m.group("Mslga_100") + "ns" in TEXT and not " ou " + m.group("Mslga_99") + "loga " + m.group("Mslga_100") + "ns" in TEXT and not "s de " + m.group("Mslga_99") + "loga " + m.group("Mslga_100") + "ns" in TEXT and not "s da " + m.group("Mslga_99") + "loga " + m.group("Mslga_100") + "ns" in TEXT and not " a " + m.group("Mslga_99") + "loga " + m.group("Mslga_100") + "ns" in TEXT and not m.group("Mslga_99") + "loga-" + m.group("Mslga_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslga_101>[a-zA-Zç]+[ó])loga (?P<Mslga_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "logas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslga_102") in plvrFemm and not " e " + m.group("Mslga_101") + "loga " + m.group("Mslga_102") + "ns" in TEXT and not " ou " + m.group("Mslga_101") + "loga " + m.group("Mslga_102") + "ns" in TEXT and not "s de " + m.group("Mslga_101") + "loga " + m.group("Mslga_102") + "ns" in TEXT and not "s da " + m.group("Mslga_101") + "loga " + m.group("Mslga_102") + "ns" in TEXT and not " a " + m.group("Mslga_101") + "loga " + m.group("Mslga_102") + "ns" in TEXT and not m.group("Mslga_101") + "loga-" + m.group("Mslga_102") + "ns" in tCompostops'],
# logo o
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_1>[a-zA-Zç]+[ó])logo (?P<Mslgo_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_2").lower() in plvrMasca and not " e " + m.group("Mslgo_1") + "logo " + m.group("Mslgo_2") +"s" in TEXT and not " ou " + m.group("Mslgo_1") + "logo " + m.group("Mslgo_2") + "s" in TEXT and not "s de " + m.group("Mslgo_1") + "logo " + m.group("Mslgo_2") + "s" in TEXT and not "s do " + m.group("Mslgo_1") + "logo " + m.group("Mslgo_2") + "s" in TEXT and not " o " + m.group("Mslgo_1") + "logo " + m.group("Mslgo_2") + "s" in TEXT and not m.group("Mslgo_1") + "logo-" + m.group("Mslgo_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_3>[a-zA-Zç]+[ó])logo (?P<Mslgo_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_4").lower() in plvrMfoa and not " e " + m.group("Mslgo_3") + "logo " + m.group("Mslgo_4") + "os" in TEXT and not " ou " + m.group("Mslgo_3") + "logo " + m.group("Mslgo_4") + "os" in TEXT and not "s de " + m.group("Mslgo_3") + "logo " + m.group("Mslgo_4") + "os" in TEXT and not "s do " + m.group("Mslgo_3") + "logo " + m.group("Mslgo_4") + "os" in TEXT and not " o " + m.group("Mslgo_3") + "logo " + m.group("Mslgo_4") + "os" in TEXT and not m.group("Mslgo_3") + "logo-" + m.group("Mslgo_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_5>[a-zA-Zç]+[ó])logo (?P<Mslgo_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mslgo_6").lower() in excAdo and not " e " + m.group("Mslgo_5") + "logo " + m.group("Mslgo_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Mslgo_5") + "logo " + m.group("Mslgo_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Mslgo_5") + "logo " + m.group("Mslgo_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Mslgo_5") + "logo " + m.group("Mslgo_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Mslgo_5") + "logo " + m.group("Mslgo_6") + m.group(3) + "dos" in TEXT and not m.group("Mslgo_5") + "logo-" + m.group("Mslgo_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_7>[a-zA-Zç]+[ó])logo (?P<Mslgo_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mslgo_8").lower() in excIsta and not " e " + m.group("Mslgo_7") + "logo " + m.group("Mslgo_8") + "s" in TEXT and not " ou " + m.group("Mslgo_7") + "logo " + m.group("Mslgo_8") + "s" in TEXT and not "s de " + m.group("Mslgo_7") + "logo " + m.group("Mslgo_8") + "s" in TEXT and not "s do " + m.group("Mslgo_7") + "logo " + m.group("Mslgo_8") + "s" in TEXT and not " o " + m.group("Mslgo_7") + "logo " + m.group("Mslgo_8") + "s" in TEXT and not m.group("Mslgo_7") + "logo-" + m.group("Mslgo_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_9>[a-zA-Zç]+[ó])logo (?P<Mslgo_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_10").lower() in plvrInva and not " e " + m.group("Mslgo_9") + "logo " + m.group("Mslgo_10") + "s" in TEXT and not " ou " + m.group("Mslgo_9") + "logo " + m.group("Mslgo_10") + "s" in TEXT and not "s de " + m.group("Mslgo_9") + "logo " + m.group("Mslgo_10") + "s" in TEXT and not "s do " + m.group("Mslgo_9") + "logo " + m.group("Mslgo_10") + "s" in TEXT and not " a " + m.group("Mslgo_9") + "logo " + m.group("Mslgo_10") + "s" in TEXT and not m.group("Mslgo_9") + "logo-" + m.group("Mslgo_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_11>[a-zA-Zç]+[ó])logo (?P<Mslgo_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mslgo_12").lower() in excAdo and not " e " + m.group("Mslgo_11") + "logo " + m.group("Mslgo_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Mslgo_11") + "logo " + m.group("Mslgo_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Mslgo_11") + "logo " + m.group("Mslgo_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Mslgo_11") + "logo " + m.group("Mslgo_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Mslgo_11") + "logo " + m.group("Mslgo_12") + m.group(3) + "das" in TEXT and not m.group("Mslgo_11") + "logo-" + m.group("Mslgo_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_13>[a-zA-Zç]+[ó])logo (?P<Mslgo_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_13") + "logo " + m.group("Mslgo_14") + "osos" in TEXT and not " ou " + m.group("Mslgo_13") + "logo " + m.group("Mslgo_14") + "osos" in TEXT and not "s de " + m.group("Mslgo_13") + "logo " + m.group("Mslgo_14") + "osos" in TEXT and not "s do " + m.group("Mslgo_13") + "logo " + m.group("Mslgo_14") + "osos" in TEXT and not " o " + m.group("Mslgo_13") + "logo " + m.group("Mslgo_14") + "osos" in TEXT and not m.group("Mslgo_13") + "logo-" + m.group("Mslgo_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_15>[a-zA-Zç]+[ó])logo (?P<Mslgo_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_15") + "logo " + m.group("Mslgo_16") + "osas" in TEXT and not " ou " + m.group("Mslgo_15") + "logo " + m.group("Mslgo_16") + "osas" in TEXT and not "s de " + m.group("Mslgo_15") + "logo " + m.group("Mslgo_16") + "osas" in TEXT and not "s do " + m.group("Mslgo_15") + "logo " + m.group("Mslgo_16") + "osas" in TEXT and not " o " + m.group("Mslgo_15") + "logo " + m.group("Mslgo_16") + "osas" in TEXT and not m.group("Mslgo_15") + "logo-" + m.group("Mslgo_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_17>[a-zA-Zç]+[ó])logo (?P<Mslgo_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_17") + "logo " + m.group("Mslgo_18") + "ivas" in TEXT and not " ou " + m.group("Mslgo_17") + "logo " + m.group("Mslgo_18") + "ivas" in TEXT and not "s de " + m.group("Mslgo_17") + "logo " + m.group("Mslgo_18") + "ivas" in TEXT and not "s do " + m.group("Mslgo_17") + "logo " + m.group("Mslgo_18") + "ivas" in TEXT and not " o " + m.group("Mslgo_17") + "logo " + m.group("Mslgo_18") + "ivas" in TEXT and not m.group("Mslgo_17") + "logo-" + m.group("Mslgo_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_19>[a-zA-Zç]+[ó])logo (?P<Mslgo_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_19") + "logo " + m.group("Mslgo_20") + "ivas" in TEXT and not " ou " + m.group("Mslgo_19") + "logo " + m.group("Mslgo_20") + "ivas" in TEXT and not "s de " + m.group("Mslgo_19") + "logo " + m.group("Mslgo_20") + "ivas" in TEXT and not "s do " + m.group("Mslgo_19") + "logo " + m.group("Mslgo_20") + "ivas" in TEXT and not " o " + m.group("Mslgo_19") + "logo " + m.group("Mslgo_20") + "ivas" in TEXT and not m.group("Mslgo_19") + "logo-" + m.group("Mslgo_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_21>[a-zA-Zç]+[ó])logo (?P<Mslgo_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_21") + "logo " + m.group("Mslgo_22") + "icos" in TEXT and not " ou " + m.group("Mslgo_21") + "logo " + m.group("Mslgo_22") + "icos" in TEXT and not "s de " + m.group("Mslgo_21") + "logo " + m.group("Mslgo_22") + "icos" in TEXT and not "s do " + m.group("Mslgo_21") + "logo " + m.group("Mslgo_22") + "icos" in TEXT and not " o " + m.group("Mslgo_21") + "logo " + m.group("Mslgo_22") + "icos" in TEXT and not m.group("Mslgo_21") + "logo-" + m.group("Mslgo_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_23>[a-zA-Zç]+[ó])logo (?P<Mslgo_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_23") + "logo " + m.group("Mslgo_24") + "icos" in TEXT and not " ou " + m.group("Mslgo_23") + "logo " + m.group("Mslgo_24") + "icos" in TEXT and not "s de " + m.group("Mslgo_23") + "logo " + m.group("Mslgo_24") + "icos" in TEXT and not "s do " + m.group("Mslgo_23") + "logo " + m.group("Mslgo_24") + "icos" in TEXT and not " o " + m.group("Mslgo_23") + "logo " + m.group("Mslgo_24") + "icos" in TEXT and not m.group("Mslgo_23") + "logo-" + m.group("Mslgo_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_25>[a-zA-Zç]+[ó])logo (?P<Mslgo_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_25") + "logo " + m.group("Mslgo_26") + "icos" in TEXT and not " ou " + m.group("Mslgo_25") + "logo " + m.group("Mslgo_26") + "icos" in TEXT and not "s de " + m.group("Mslgo_25") + "logo " + m.group("Mslgo_26") + "icos" in TEXT and not "s do " + m.group("Mslgo_25") + "logo " + m.group("Mslgo_26") + "icos" in TEXT and not " o " + m.group("Mslgo_25") + "logo " + m.group("Mslgo_26") + "icos" in TEXT and not m.group("Mslgo_25") + "logo-" + m.group("Mslgo_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_27>[a-zA-Zç]+[ó])logo (?P<Mslgo_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_27") + "logo " + m.group("Mslgo_28") + "escos" in TEXT and not " ou " + m.group("Mslgo_27") + "logo " + m.group("Mslgo_28") + "escos" in TEXT and not "s de " + m.group("Mslgo_27") + "logo " + m.group("Mslgo_28") + "escos" in TEXT and not "s do " + m.group("Mslgo_27") + "logo " + m.group("Mslgo_28") + "escos" in TEXT and not " o " + m.group("Mslgo_27") + "logo " + m.group("Mslgo_28") + "escos" in TEXT and not m.group("Mslgo_27") + "logo-" + m.group("Mslgo_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_29>[a-zA-Zç]+[ó])logo (?P<Mslgo_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_29") + "logo " + m.group("Mslgo_30") + "idos" in TEXT and not " ou " + m.group("Mslgo_29") + "s " + m.group("Mslgo_30") + "idos" in TEXT and not "s de " + m.group("Mslgo_29") + "s " + m.group("Mslgo_30") + "idos" in TEXT and not "s do " + m.group("Mslgo_29") + "s " + m.group("Mslgo_30") + "idos" in TEXT and not " o " + m.group("Mslgo_29") + "s " + m.group("Mslgo_30") + "idos" in TEXT and not m.group("Mslgo_29") + "logo-" + m.group("Mslgo_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_31>[a-zA-Zç]+[ó])logo (?P<Mslgo_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_31") + "logo " + m.group("Mslgo_32") + "logos" in TEXT and not " ou " + m.group("Mslgo_31") + "logo " + m.group("Mslgo_32") + "logos" in TEXT and not "s de " + m.group("Mslgo_31") + "logo " + m.group("Mslgo_32") + "logos" in TEXT and not "s do " + m.group("Mslgo_31") + "logo " + m.group("Mslgo_32") + "logos" in TEXT and not " o " + m.group("Mslgo_31") + "logo " + m.group("Mslgo_32") + "logos" in TEXT and not m.group("Mslgo_31") + "logo-" + m.group("Mslgo_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_33>[a-zA-Zç]+[ó])logo (?P<Mslgo_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_33") + "logo " + m.group("Mslgo_34") + "rios" in TEXT and not " ou " + m.group("Mslgo_33") + "logo " + m.group("Mslgo_34") + "rios" in TEXT and not "s de " + m.group("Mslgo_33") + "logo " + m.group("Mslgo_34") + "rios" in TEXT and not "s do " + m.group("Mslgo_33") + "logo " + m.group("Mslgo_34") + "rios" in TEXT and not " o " + m.group("Mslgo_33") + "logo " + m.group("Mslgo_34") + "rios" in TEXT and not m.group("Mslgo_33") + "logo-" + m.group("Mslgo_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_35>[a-zA-Zç]+[ó])logo (?P<Mslgo_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_35") + "logo " + m.group("Mslgo_36") + "ssimos" in TEXT and not " ou " + m.group("Mslgo_35") + "logo " + m.group("Mslgo_36") + "ssimos" in TEXT and not "s de " + m.group("Mslgo_35") + "logo " + m.group("Mslgo_36") + "ssimos" in TEXT and not "s do " + m.group("Mslgo_35") + "logo " + m.group("Mslgo_36") + "ssimos" in TEXT and not " o " + m.group("Mslgo_35") + "logo " + m.group("Mslgo_36") + "ssimos" in TEXT and not m.group("Mslgo_35") + "logo-" + m.group("Mslgo_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_37>[a-zA-Zç]+[ó])logo (?P<Mslgo_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_37") + "logo " + m.group("Mslgo_38") + "simos" in TEXT and not " ou " + m.group("Mslgo_37") + "logo " + m.group("Mslgo_38") + "simos" in TEXT and not "s de " + m.group("Mslgo_37") + "logo " + m.group("Mslgo_38") + "simos" in TEXT and not "s do " + m.group("Mslgo_37") + "logo " + m.group("Mslgo_38") + "simos" in TEXT and not " o " + m.group("Mslgo_37") + "logo " + m.group("Mslgo_38") + "simos" in TEXT and not m.group("Mslgo_37") + "logo-" + m.group("Mslgo_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_41>[a-zA-Zç]+[ó])logo (?P<Mslgo_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mslgo_42") in "D-d-" and not " e " + m.group("Mslgo_41") + "logo " + m.group("Mslgo_42") + "ores" in TEXT and not " ou " + m.group("Mslgo_41") + "logo " + m.group("Mslgo_42") + "ores" in TEXT and not "s de " + m.group("Mslgo_41") + "logo " + m.group("Mslgo_42") + "ores" in TEXT and not "s do " + m.group("Mslgo_41") + "logo " + m.group("Mslgo_42") + "ores" in TEXT and not " o " + m.group("Mslgo_41") + "logo " + m.group("Mslgo_42") + "ores" in TEXT and not m.group("Mslgo_41") + "logo-" + m.group("Mslgo_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_43>[a-zA-Zç]+[ó])logo (?P<Mslgo_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_44") in plvrMfr and not " e " + m.group("Mslgo_43") + "logo " + m.group("Mslgo_44") + "es" in TEXT and not " ou " + m.group("Mslgo_43") + "logo " + m.group("Mslgo_44") + "es" in TEXT and not "s de " + m.group("Mslgo_43") + "logo " + m.group("Mslgo_44") + "es" in TEXT and not "s do " + m.group("Mslgo_43") + "logo " + m.group("Mslgo_44") + "es" in TEXT and not " o " + m.group("Mslgo_43") + "logo " + m.group("Mslgo_44") + "es" in TEXT and not m.group("Mslgo_43") + "logo-" + m.group("Mslgo_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_45>[a-zA-Zç]+[ó])logo (?P<Mslgo_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_46") in plvrMascr and not " e " + m.group("Mslgo_45") + "logo " + m.group("Mslgo_46") + "es" in TEXT and not " ou " + m.group("Mslgo_45") + "logo " + m.group("Mslgo_46") + "es" in TEXT and not "s de " + m.group("Mslgo_45") + "logo " + m.group("Mslgo_46") + "es" in TEXT and not "s do " + m.group("Mslgo_45") + "logo " + m.group("Mslgo_46") + "es" in TEXT and not " o " + m.group("Mslgo_45") + "logo " + m.group("Mslgo_46") + "es" in TEXT and not m.group("Mslgo_45") + "logo-" + m.group("Mslgo_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_47>[a-zA-Zç]+[ó])logo (?P<Mslgo_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_48") in plvrMfal and not " e " + m.group("Mslgo_47") + "logo " + m.group("Mslgo_48") + "is" in TEXT and not " ou " + m.group("Mslgo_47") + "logo " + m.group("Mslgo_48") + "is" in TEXT and not "s de " + m.group("Mslgo_47") + "logo " + m.group("Mslgo_48") + "is" in TEXT and not "s do " + m.group("Mslgo_47") + "logo " + m.group("Mslgo_48") + "is" in TEXT and not " o " + m.group("Mslgo_47") + "logo " + m.group("Mslgo_48") + "is" in TEXT and not m.group("Mslgo_47") + "logo-" + m.group("Mslgo_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_49>[a-zA-Zç]+[ó])logo (?P<Mslgo_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_50") in plvrMfcao and not " e " + m.group("Mslgo_49") + "logo " + m.group("Mslgo_50") + "ões" in TEXT and not + " ou " + m.group("Mslgo_49") + "logo " + m.group("Mslgo_50") + "ões" in TEXT and not + "s de " + m.group("Mslgo_49") + "logo " + m.group("Mslgo_50") + "ões" in TEXT and not + "s do " + m.group("Mslgo_49") + "logo " + m.group("Mslgo_50") + "ões" in TEXT and not + " a " + m.group("Mslgo_49") + "logo " + m.group("Mslgo_50") + "ões" in TEXT and not m.group("Mslgo_49") + "logo-" + m.group("Mslgo_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_51>[a-zA-Zç]+[ó])logo (?P<Mslgo_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_52") in plvrNfemcao and not " e " + m.group("Mslgo_51") + "logo " + m.group("Mslgo_52") + "ões" in TEXT and not " ou " + m.group("Mslgo_51") + "logo " + m.group("Mslgo_52") + "ões" in TEXT and not "s de " + m.group("Mslgo_51") + "logo " + m.group("Mslgo_52") + "ões" in TEXT and not "s do " + m.group("Mslgo_51") + "logo " + m.group("Mslgo_52") + "ões" in TEXT and not " o " + m.group("Mslgo_51") + "logo " + m.group("Mslgo_52") + "ões" in TEXT and not m.group("Mslgo_51") + "logo-" + m.group("Mslgo_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_55>[a-zA-Zç]+[ó])logo (?P<Mslgo_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_55") + "logo " + m.group("Mslgo_56") + "veis" in TEXT and not " ou " + m.group("Mslgo_55") + "logo " + m.group("Mslgo_56") + "veis" in TEXT and not "s de " + m.group("Mslgo_55") + "logo " + m.group("Mslgo_56") + "veis" in TEXT and not "s do " + m.group("Mslgo_55") + "logo " + m.group("Mslgo_56") + "veis" in TEXT and not " o " + m.group("Mslgo_55") + "logo " + m.group("Mslgo_56") + "veis" in TEXT and not m.group("Mslgo_55") + "logo-" + m.group("Mslgo_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_57>[a-zA-Zç]+[ó])logo (?P<Mslgo_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_58").lower() in plvrMfe and not " e " + m.group("Mslgo_57") + "logo " + m.group("Mslgo_58") + "es" in TEXT and not " ou " + m.group("Mslgo_57") + "logo " + m.group("Mslgo_58") + "es" in TEXT and not "s de " + m.group("Mslgo_57") + "logo " + m.group("Mslgo_58") + "es" in TEXT and not "s do " + m.group("Mslgo_57") + "logo " + m.group("Mslgo_58") + "es" in TEXT and not " o " + m.group("Mslgo_57") + "logo " + m.group("Mslgo_58") + "es" in TEXT and not m.group("Mslgo_57") + "logo-" + m.group("Mslgo_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_59>[a-zA-Zç]+[ó])logo (?P<Mslgo_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_60").lower() in plvrMasce and not " e " + m.group("Mslgo_59") + "logo " + m.group("Mslgo_60") + "es" in TEXT and not " ou " + m.group("Mslgo_59") + "logo " + m.group("Mslgo_60") + "es" in TEXT and not "s de " + m.group("Mslgo_59") + "logo " + m.group("Mslgo_60") + "es" in TEXT and not "s do " + m.group("Mslgo_59") + "logo " + m.group("Mslgo_60") + "es" in TEXT and not " o " + m.group("Mslgo_59") + "logo " + m.group("Mslgo_60") + "es" in TEXT and not m.group("Mslgo_59") + "logo-" + m.group("Mslgo_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_61>[a-zA-Zç]+[ó])logo (?P<Mslgo_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_62") in plvrMfel and not " e " + m.group("Mslgo_61") + "logo " + m.group("Mslgo_62") + "éis" in TEXT and not " ou " + m.group("Mslgo_61") + "logo " + m.group("Mslgo_62") + "éis" in TEXT and not "s de " + m.group("Mslgo_61") + "logo " + m.group("Mslgo_62") + "éis" in TEXT and not "s do " + m.group("Mslgo_61") + "logo " + m.group("Mslgo_62") + "éis" in TEXT and not " o " + m.group("Mslgo_61") + "logo " + m.group("Mslgo_62") + "éis" in TEXT and not m.group("Mslgo_61") + "logo-" + m.group("Mslgo_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_63>[a-zA-Zç]+[ó])logo (?P<Mslgo_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_64") in plvrMascel and not " e " + m.group("Mslgo_63") + "logo " + m.group("Mslgo_64") + "éis" in TEXT and not " ou " + m.group("Mslgo_63") + "logo " + m.group("Mslgo_64") + "éis" in TEXT and not "s de " + m.group("Mslgo_63") + "logo " + m.group("Mslgo_64") + "éis" in TEXT and not "s do " + m.group("Mslgo_63") + "logo " + m.group("Mslgo_64") + "éis" in TEXT and not " o " + m.group("Mslgo_63") + "logo " + m.group("Mslgo_64") + "éis" in TEXT and not m.group("Mslgo_63") + "logo-" + m.group("Mslgo_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_65>[a-zA-Zç]+[ó])logo (?P<Mslgo_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_66") in plvrMfeu and not " e " + m.group("Mslgo_65") + "logo " + m.group("Mslgo_66") + "us" in TEXT and not " ou " + m.group("Mslgo_65") + "logo " + m.group("Mslgo_66") + "us" in TEXT and not "s de " + m.group("Mslgo_65") + "logo " + m.group("Mslgo_66") + "us" in TEXT and not "s do " + m.group("Mslgo_65") + "logo " + m.group("Mslgo_66") + "us" in TEXT and not " o " + m.group("Mslgo_65") + "logo " + m.group("Mslgo_66") + "us" in TEXT and not m.group("Mslgo_65") + "logo-" + m.group("Mslgo_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_67>[a-zA-Zç]+[ó])logo (?P<Mslgo_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_68") in plvrMascu and not " e " + m.group("Mslgo_67") + "logo " + m.group("Mslgo_68") + "us" in TEXT and not " ou " + m.group("Mslgo_67") + "logo " + m.group("Mslgo_68") + "us" in TEXT and not "s de " + m.group("Mslgo_67") + "logo " + m.group("Mslgo_68") + "us" in TEXT and not "s do " + m.group("Mslgo_67") + "logo " + m.group("Mslgo_68") + "us" in TEXT and not " o " + m.group("Mslgo_67") + "logo " + m.group("Mslgo_68") + "us" in TEXT and not m.group("Mslgo_67") + "logo-" + m.group("Mslgo_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_69>[a-zA-Zç]+[ó])logo (?P<Mslgo_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_70") in plvrInvaz and not " e " + m.group("Mslgo_69") + "logo " + m.group("Mslgo_70") + "zes" in TEXT and not " ou " + m.group("Mslgo_69") + "logo " + m.group("Mslgo_70") + "zes" in TEXT and not "s de " + m.group("Mslgo_69") + "logo " + m.group("Mslgo_70") + "zes" in TEXT and not "s do " + m.group("Mslgo_69") + "logo " + m.group("Mslgo_70") + "zes" in TEXT and not " o " + m.group("Mslgo_69") + "logo " + m.group("Mslgo_70") + "zes" in TEXT and not m.group("Mslgo_69") + "logo-" + m.group("Mslgo_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_71>[a-zA-Zç]+[ó])logo (?P<Mslgo_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_72") in plvrMascz and not " e " + m.group("Mslgo_71") + "logo " + m.group("Mslgo_72") + "zes" in TEXT and not " ou " + m.group("Mslgo_71") + "logo " + m.group("Mslgo_72") + "zes" in TEXT and not "s de " + m.group("Mslgo_71") + "logo " + m.group("Mslgo_72") + "zes" in TEXT and not "s do " + m.group("Mslgo_71") + "logo " + m.group("Mslgo_72") + "zes" in TEXT and not " o " + m.group("Mslgo_71") + "logo " + m.group("Mslgo_72") + "zes" in TEXT and not m.group("Mslgo_71") + "logo-" + m.group("Mslgo_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_73>[a-zA-Zç]+[ó])logo (?P<Mslgo_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_74") in pvrMascan and not " e " + m.group("Mslgo_73") + "logo " + m.group("Mslgo_74") + "s" in TEXT and not " ou " + m.group("Mslgo_73") + "logo " + m.group("Mslgo_74") + "s" in TEXT and not "s de " + m.group("Mslgo_73") + "logo " + m.group("Mslgo_74") + "s" in TEXT and not "s do " + m.group("Mslgo_73") + "logo " + m.group("Mslgo_74") + "s" in TEXT and not " o " + m.group("Mslgo_73") + "logo " + m.group("Mslgo_74") + "s" in TEXT and not m.group("Mslgo_73") + "logo-" + m.group("Mslgo_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_75>[a-zA-Zç]+[ó])logo (?P<Mslgo_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_76").lower() in plvrMasco and not " e " + m.group("Mslgo_75") + "logo " + m.group("Mslgo_76") +"s" in TEXT and not " ou " + m.group("Mslgo_75") + "logo " + m.group("Mslgo_76") + "s" in TEXT and not "s de " + m.group("Mslgo_75") + "logo " + m.group("Mslgo_76") + "s" in TEXT and not "s do " + m.group("Mslgo_75") + "logo " + m.group("Mslgo_76") + "s" in TEXT and not " o " + m.group("Mslgo_75") + "logo " + m.group("Mslgo_76") + "s" in TEXT and not m.group("Mslgo_75") + "logo-" + m.group("Mslgo_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_77>[a-zA-Zç]+[ó])logo (?P<Mslgo_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_77") + "logo " + m.group("Mslgo_78") + "inhos" in TEXT and not " ou " + m.group("Mslgo_77") + "logo " + m.group("Mslgo_78") + "inhos" in TEXT and not "s de " + m.group("Mslgo_77") + "logo " + m.group("Mslgo_78") + "inhos" in TEXT and not "s do " + m.group("Mslgo_77") + "logo " + m.group("Mslgo_78") + "inhos" in TEXT and not " o " + m.group("Mslgo_77") + "logo " + m.group("Mslgo_78") + "inhos" in TEXT and not m.group("Mslgo_77") + "logo-" + m.group("Mslgo_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_79>[a-zA-Zç]+[ó])logo (?P<Mslgo_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_79") + "logo " + m.group("Mslgo_80") + "icas" in TEXT and not " ou " + m.group("Mslgo_79") + "logo " + m.group("Mslgo_80") + "icas" in TEXT and not "s de " + m.group("Mslgo_79") + "logo " + m.group("Mslgo_80") + "icas" in TEXT and not "s do " + m.group("Mslgo_79") + "logo " + m.group("Mslgo_80") + "icas" in TEXT and not " o " + m.group("Mslgo_79") + "logo " + m.group("Mslgo_80") + "icas" in TEXT and not m.group("Mslgo_79") + "logo-" + m.group("Mslgo_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_81>[a-zA-Zç]+[ó])logo (?P<Mslgo_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_81") + "logo " + m.group("Mslgo_82") + "icas" in TEXT and not " ou " + m.group("Mslgo_81") + "logo " + m.group("Mslgo_82") + "icas" in TEXT and not "s de " + m.group("Mslgo_81") + "logo " + m.group("Mslgo_82") + "icas" in TEXT and not "s do " + m.group("Mslgo_81") + "logo " + m.group("Mslgo_82") + "icas" in TEXT and not " o " + m.group("Mslgo_81") + "logo " + m.group("Mslgo_82") + "icas" in TEXT and not m.group("Mslgo_81") + "logo-" + m.group("Mslgo_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_83>[a-zA-Zç]+[ó])logo (?P<Mslgo_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_83") + "logo " + m.group("Mslgo_84") + "icas" in TEXT and not " ou " + m.group("Mslgo_83") + "logo " + m.group("Mslgo_84") + "icas" in TEXT and not "s de " + m.group("Mslgo_83") + "logo " + m.group("Mslgo_84") + "icas" in TEXT and not "s do " + m.group("Mslgo_83") + "logo " + m.group("Mslgo_84") + "icas" in TEXT and not " o " + m.group("Mslgo_83") + "logo " + m.group("Mslgo_84") + "icas" in TEXT and not m.group("Mslgo_83") + "logo-" + m.group("Mslgo_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_85>[a-zA-Zç]+[ó])logo (?P<Mslgo_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_85") + "logo " + m.group("Mslgo_86") + "escas" in TEXT and not " ou " + m.group("Mslgo_85") + "logo " + m.group("Mslgo_86") + "escas" in TEXT and not "s de " + m.group("Mslgo_85") + "logo " + m.group("Mslgo_86") + "escas" in TEXT and not "s do " + m.group("Mslgo_85") + "logo " + m.group("Mslgo_86") + "escas" in TEXT and not " o " + m.group("Mslgo_85") + "logo " + m.group("Mslgo_86") + "escas" in TEXT and not m.group("Mslgo_85") + "logo-" + m.group("Mslgo_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_87>[a-zA-Zç]+[ó])logo (?P<Mslgo_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_87") + "logo " + m.group("Mslgo_88") + "idas" in TEXT and not " ou " + m.group("Mslgo_87") + "s " + m.group("Mslgo_88") + "idas" in TEXT and not "s de " + m.group("Mslgo_87") + "s " + m.group("Mslgo_88") + "idas" in TEXT and not "s do " + m.group("Mslgo_87") + "s " + m.group("Mslgo_88") + "idas" in TEXT and not " o " + m.group("Mslgo_87") + "s " + m.group("Mslgo_88") + "idas" in TEXT and not m.group("Mslgo_87") + "logo-" + m.group("Mslgo_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_89>[a-zA-Zç]+[ó])logo (?P<Mslgo_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_89") + "logo " + m.group("Mslgo_90") + "logas" in TEXT and not " ou " + m.group("Mslgo_89") + "logo " + m.group("Mslgo_90") + "logas" in TEXT and not "s de " + m.group("Mslgo_89") + "logo " + m.group("Mslgo_90") + "logas" in TEXT and not "s do " + m.group("Mslgo_89") + "logo " + m.group("Mslgo_90") + "logas" in TEXT and not " o " + m.group("Mslgo_89") + "logo " + m.group("Mslgo_90") + "logas" in TEXT and not m.group("Mslgo_89") + "logo-" + m.group("Mslgo_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_91>[a-zA-Zç]+[ó])logo (?P<Mslgo_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_91") + "logo " + m.group("Mslgo_92") + "rias" in TEXT and not " ou " + m.group("Mslgo_91") + "logo " + m.group("Mslgo_92") + "rias" in TEXT and not "s de " + m.group("Mslgo_91") + "logo " + m.group("Mslgo_92") + "rias" in TEXT and not "s do " + m.group("Mslgo_91") + "logo " + m.group("Mslgo_92") + "rias" in TEXT and not " o " + m.group("Mslgo_91") + "logo " + m.group("Mslgo_92") + "rias" in TEXT and not m.group("Mslgo_91") + "logo-" + m.group("Mslgo_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_93>[a-zA-Zç]+[ó])logo (?P<Mslgo_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_93") + "logo " + m.group("Mslgo_94") + "ssimas" in TEXT and not " ou " + m.group("Mslgo_93") + "logo " + m.group("Mslgo_94") + "ssimas" in TEXT and not "s de " + m.group("Mslgo_93") + "logo " + m.group("Mslgo_94") + "ssimas" in TEXT and not "s do " + m.group("Mslgo_93") + "logo " + m.group("Mslgo_94") + "ssimas" in TEXT and not " o " + m.group("Mslgo_93") + "logo " + m.group("Mslgo_94") + "ssimas" in TEXT and not m.group("Mslgo_93") + "logo-" + m.group("Mslgo_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_95>[a-zA-Zç]+[ó])logo (?P<Mslgo_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mslgo_95") + "logo " + m.group("Mslgo_96") + "simas" in TEXT and not " ou " + m.group("Mslgo_95") + "logo " + m.group("Mslgo_96") + "simas" in TEXT and not "s de " + m.group("Mslgo_95") + "logo " + m.group("Mslgo_96") + "simas" in TEXT and not "s do " + m.group("Mslgo_95") + "logo " + m.group("Mslgo_96") + "simas" in TEXT and not " o " + m.group("Mslgo_95") + "logo " + m.group("Mslgo_96") + "simas" in TEXT and not m.group("Mslgo_95") + "logo-" + m.group("Mslgo_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_97>[a-zA-Zç]+[ó])logo (?P<Mslgo_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_98").lower() in plvrMfoa and not " e " + m.group("Mslgo_97") + "logo " + m.group("Mslgo_98") + "as" in TEXT and not " ou " + m.group("Mslgo_97") + "logo " + m.group("Mslgo_98") + "as" in TEXT and not "s de " + m.group("Mslgo_97") + "logo " + m.group("Mslgo_98") + "as" in TEXT and not "s do " + m.group("Mslgo_97") + "logo " + m.group("Mslgo_98") + "as" in TEXT and not " o " + m.group("Mslgo_97") + "logo " + m.group("Mslgo_98") + "as" in TEXT and not m.group("Mslgo_97") + "logo-" + m.group("Mslgo_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_99>[a-zA-Zç]+[ó])logo (?P<Mslgo_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_100") in plvrMFm and not " e " + m.group("Mslgo_99") + "logo " + m.group("Mslgo_100") + "ns" in TEXT and not " ou " + m.group("Mslgo_99") + "logo " + m.group("Mslgo_100") + "ns" in TEXT and not "s de " + m.group("Mslgo_99") + "logo " + m.group("Mslgo_100") + "ns" in TEXT and not "s da " + m.group("Mslgo_99") + "logo " + m.group("Mslgo_100") + "ns" in TEXT and not " a " + m.group("Mslgo_99") + "logo " + m.group("Mslgo_100") + "ns" in TEXT and not m.group("Mslgo_99") + "logo-" + m.group("Mslgo_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mslgo_101>[a-zA-Zç]+[ó])logo (?P<Mslgo_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "logos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mslgo_102") in plvrMascm and not " e " + m.group("Mslgo_101") + "logo " + m.group("Mslgo_102") + "ns" in TEXT and not " ou " + m.group("Mslgo_101") + "logo " + m.group("Mslgo_102") + "ns" in TEXT and not "s de " + m.group("Mslgo_101") + "logo " + m.group("Mslgo_102") + "ns" in TEXT and not "s da " + m.group("Mslgo_101") + "logo " + m.group("Mslgo_102") + "ns" in TEXT and not " a " + m.group("Mslgo_101") + "logo " + m.group("Mslgo_102") + "ns" in TEXT and not m.group("Mslgo_101") + "logo-" + m.group("Mslgo_102") + "ns" in tCompostops'],
# ria a
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_1>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_2").lower() in plvrFema and not " e " + m.group("Msria_1") + "ria " + m.group("Msria_2") +"s" in TEXT and not " ou " + m.group("Msria_1") + "ria " + m.group("Msria_2") + "s" in TEXT and not "s de " + m.group("Msria_1") + "ria " + m.group("Msria_2") + "s" in TEXT and not "s da " + m.group("Msria_1") + "ria " + m.group("Msria_2") + "s" in TEXT and not " a " + m.group("Msria_1") + "ria " + m.group("Msria_2") + "s" in TEXT and not m.group("Msria_1") + "ria-" + m.group("Msria_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_3>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_4").lower() in plvrMfoa and not " e " + m.group("Msria_3") + "ria " + m.group("Msria_4") + "as" in TEXT and not " ou " + m.group("Msria_3") + "ria " + m.group("Msria_4") + "as" in TEXT and not "s de " + m.group("Msria_3") + "ria " + m.group("Msria_4") + "as" in TEXT and not "s da " + m.group("Msria_3") + "ria " + m.group("Msria_4") + "as" in TEXT and not " a " + m.group("Msria_3") + "ria " + m.group("Msria_4") + "as" in TEXT and not m.group("Msria_3") + "ria-" + m.group("Msria_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_5>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msria_6").lower() in excAdo and not " e " + m.group("Msria_5") + "ria " + m.group("Msria_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msria_5") + "ria " + m.group("Msria_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msria_5") + "ria " + m.group("Msria_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Msria_5") + "ria " + m.group("Msria_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Msria_5") + "ria " + m.group("Msria_6") + m.group(3) + "dos" in TEXT and not m.group("Msria_5") + "ria-" + m.group("Msria_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_7>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msria_8").lower() in excIsta and not " e " + m.group("Msria_7") + "ria " + m.group("Msria_8") + "s" in TEXT and not " ou " + m.group("Msria_7") + "ria " + m.group("Msria_8") + "s" in TEXT and not "s de " + m.group("Msria_7") + "ria " + m.group("Msria_8") + "s" in TEXT and not "s da " + m.group("Msria_7") + "ria " + m.group("Msria_8") + "s" in TEXT and not " a " + m.group("Msria_7") + "ria " + m.group("Msria_8") + "s" in TEXT and not m.group("Msria_7") + "ria-" + m.group("Msria_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_9>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_10").lower() in plvrInva and not " e " + m.group("Msria_9") + "ria " + m.group("Msria_10") + "s" in TEXT and not " ou " + m.group("Msria_9") + "ria " + m.group("Msria_10") + "s" in TEXT and not "s de " + m.group("Msria_9") + "ria " + m.group("Msria_10") + "s" in TEXT and not "s da " + m.group("Msria_9") + "ria " + m.group("Msria_10") + "s" in TEXT and not " a " + m.group("Msria_9") + "ria " + m.group("Msria_10") + "s" in TEXT and not m.group("Msria_9") + "ria-" + m.group("Msria_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_11>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msria_12").lower() in excAdo and not " e " + m.group("Msria_11") + "ria " + m.group("Msria_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msria_11") + "ria " + m.group("Msria_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msria_11") + "ria " + m.group("Msria_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Msria_11") + "ria " + m.group("Msria_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Msria_11") + "ria " + m.group("Msria_12") + m.group(3) + "das" in TEXT and not m.group("Msria_11") + "ria-" + m.group("Msria_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_13>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msria_13") + "ria " + m.group("Msria_14") + "osos" in TEXT and not " ou " + m.group("Msria_13") + "ria " + m.group("Msria_14") + "osos" in TEXT and not "s de " + m.group("Msria_13") + "ria " + m.group("Msria_14") + "osos" in TEXT and not "s da " + m.group("Msria_13") + "ria " + m.group("Msria_14") + "osos" in TEXT and not " a " + m.group("Msria_13") + "ria " + m.group("Msria_14") + "osos" in TEXT and not m.group("Msria_13") + "ria-" + m.group("Msria_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_15>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msria_15") + "ria " + m.group("Msria_16") + "osas" in TEXT and not " ou " + m.group("Msria_15") + "ria " + m.group("Msria_16") + "osas" in TEXT and not "s de " + m.group("Msria_15") + "ria " + m.group("Msria_16") + "osas" in TEXT and not "s da " + m.group("Msria_15") + "ria " + m.group("Msria_16") + "osas" in TEXT and not " a " + m.group("Msria_15") + "ria " + m.group("Msria_16") + "osas" in TEXT and not m.group("Msria_15") + "ria-" + m.group("Msria_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_17>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msria_17") + "ria " + m.group("Msria_18") + "ivas" in TEXT and not " ou " + m.group("Msria_17") + "ria " + m.group("Msria_18") + "ivas" in TEXT and not "s de " + m.group("Msria_17") + "ria " + m.group("Msria_18") + "ivas" in TEXT and not "s da " + m.group("Msria_17") + "ria " + m.group("Msria_18") + "ivas" in TEXT and not " a " + m.group("Msria_17") + "ria " + m.group("Msria_18") + "ivas" in TEXT and not m.group("Msria_17") + "ria-" + m.group("Msria_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_19>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msria_19") + "ria " + m.group("Msria_20") + "ivas" in TEXT and not " ou " + m.group("Msria_19") + "ria " + m.group("Msria_20") + "ivas" in TEXT and not "s de " + m.group("Msria_19") + "ria " + m.group("Msria_20") + "ivas" in TEXT and not "s da " + m.group("Msria_19") + "ria " + m.group("Msria_20") + "ivas" in TEXT and not " a " + m.group("Msria_19") + "ria " + m.group("Msria_20") + "ivas" in TEXT and not m.group("Msria_19") + "ria-" + m.group("Msria_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_21>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msria_21") + "ria " + m.group("Msria_22") + "icas" in TEXT and not " ou " + m.group("Msria_21") + "ria " + m.group("Msria_22") + "icas" in TEXT and not "s de " + m.group("Msria_21") + "ria " + m.group("Msria_22") + "icas" in TEXT and not "s da " + m.group("Msria_21") + "ria " + m.group("Msria_22") + "icas" in TEXT and not " a " + m.group("Msria_21") + "ria " + m.group("Msria_22") + "icas" in TEXT and not m.group("Msria_21") + "ria-" + m.group("Msria_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_23>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msria_23") + "ria " + m.group("Msria_24") + "icas" in TEXT and not " ou " + m.group("Msria_23") + "ria " + m.group("Msria_24") + "icas" in TEXT and not "s de " + m.group("Msria_23") + "ria " + m.group("Msria_24") + "icas" in TEXT and not "s da " + m.group("Msria_23") + "ria " + m.group("Msria_24") + "icas" in TEXT and not " a " + m.group("Msria_23") + "ria " + m.group("Msria_24") + "icas" in TEXT and not m.group("Msria_23") + "ria-" + m.group("Msria_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_25>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msria_25") + "ria " + m.group("Msria_26") + "icas" in TEXT and not " ou " + m.group("Msria_25") + "ria " + m.group("Msria_26") + "icas" in TEXT and not "s de " + m.group("Msria_25") + "ria " + m.group("Msria_26") + "icas" in TEXT and not "s da " + m.group("Msria_25") + "ria " + m.group("Msria_26") + "icas" in TEXT and not " a " + m.group("Msria_25") + "ria " + m.group("Msria_26") + "icas" in TEXT and not m.group("Msria_25") + "ria-" + m.group("Msria_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_27>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msria_27") + "ria " + m.group("Msria_28") + "escas" in TEXT and not " ou " + m.group("Msria_27") + "ria " + m.group("Msria_28") + "escas" in TEXT and not "s de " + m.group("Msria_27") + "ria " + m.group("Msria_28") + "escas" in TEXT and not "s da " + m.group("Msria_27") + "ria " + m.group("Msria_28") + "escas" in TEXT and not " a " + m.group("Msria_27") + "ria " + m.group("Msria_28") + "escas" in TEXT and not m.group("Msria_27") + "ria-" + m.group("Msria_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_29>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msria_29") + "ria " + m.group("Msria_30") + "idas" in TEXT and not " ou " + m.group("Msria_29") + "s " + m.group("Msria_30") + "idas" in TEXT and not "s de " + m.group("Msria_29") + "s " + m.group("Msria_30") + "idas" in TEXT and not "s da " + m.group("Msria_29") + "s " + m.group("Msria_30") + "idas" in TEXT and not " a " + m.group("Msria_29") + "s " + m.group("Msria_30") + "idas" in TEXT and not m.group("Msria_29") + "ria-" + m.group("Msria_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_31>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msria_31") + "ria " + m.group("Msria_32") + "logas" in TEXT and not " ou " + m.group("Msria_31") + "ria " + m.group("Msria_32") + "logas" in TEXT and not "s de " + m.group("Msria_31") + "ria " + m.group("Msria_32") + "logas" in TEXT and not "s da " + m.group("Msria_31") + "ria " + m.group("Msria_32") + "logas" in TEXT and not " a " + m.group("Msria_31") + "ria " + m.group("Msria_32") + "logas" in TEXT and not m.group("Msria_31") + "ria-" + m.group("Msria_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_33>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msria_33") + "ria " + m.group("Msria_34") + "rias" in TEXT and not " ou " + m.group("Msria_33") + "ria " + m.group("Msria_34") + "rias" in TEXT and not "s de " + m.group("Msria_33") + "ria " + m.group("Msria_34") + "rias" in TEXT and not "s da " + m.group("Msria_33") + "ria " + m.group("Msria_34") + "rias" in TEXT and not " a " + m.group("Msria_33") + "ria " + m.group("Msria_34") + "rias" in TEXT and not m.group("Msria_33") + "ria-" + m.group("Msria_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_35>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msria_35") + "ria " + m.group("Msria_36") + "ssimas" in TEXT and not " ou " + m.group("Msria_35") + "ria " + m.group("Msria_36") + "ssimas" in TEXT and not "s de " + m.group("Msria_35") + "ria " + m.group("Msria_36") + "ssimas" in TEXT and not "s da " + m.group("Msria_35") + "ria " + m.group("Msria_36") + "ssimas" in TEXT and not " a " + m.group("Msria_35") + "ria " + m.group("Msria_36") + "ssimas" in TEXT and not m.group("Msria_35") + "ria-" + m.group("Msria_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_37>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msria_37") + "ria " + m.group("Msria_38") + "simas" in TEXT and not " ou " + m.group("Msria_37") + "ria " + m.group("Msria_38") + "simas" in TEXT and not "s de " + m.group("Msria_37") + "ria " + m.group("Msria_38") + "simas" in TEXT and not "s da " + m.group("Msria_37") + "ria " + m.group("Msria_38") + "simas" in TEXT and not " a " + m.group("Msria_37") + "ria " + m.group("Msria_38") + "simas" in TEXT and not m.group("Msria_37") + "ria-" + m.group("Msria_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_41>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msria_42") in "D-d-" and not " e " + m.group("Msria_41") + "ria " + m.group("Msria_42") + "oras" in TEXT and not " ou " + m.group("Msria_41") + "ria " + m.group("Msria_42") + "oras" in TEXT and not "s de " + m.group("Msria_41") + "ria " + m.group("Msria_42") + "oras" in TEXT and not "s da " + m.group("Msria_41") + "ria " + m.group("Msria_42") + "oras" in TEXT and not " a " + m.group("Msria_41") + "ria " + m.group("Msria_42") + "oras" in TEXT and not m.group("Msria_41") + "ria-" + m.group("Msria_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_43>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_44") in plvrMfr and not " e " + m.group("Msria_43") + "ria " + m.group("Msria_44") + "es" in TEXT and not " ou " + m.group("Msria_43") + "ria " + m.group("Msria_44") + "es" in TEXT and not "s de " + m.group("Msria_43") + "ria " + m.group("Msria_44") + "es" in TEXT and not "s da " + m.group("Msria_43") + "ria " + m.group("Msria_44") + "es" in TEXT and not " a " + m.group("Msria_43") + "ria " + m.group("Msria_44") + "es" in TEXT and not m.group("Msria_43") + "ria-" + m.group("Msria_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_45>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_46") in plvrFemr and not " e " + m.group("Msria_45") + "ria " + m.group("Msria_46") + "es" in TEXT and not " ou " + m.group("Msria_45") + "ria " + m.group("Msria_46") + "es" in TEXT and not "s de " + m.group("Msria_45") + "ria " + m.group("Msria_46") + "es" in TEXT and not "s da " + m.group("Msria_45") + "ria " + m.group("Msria_46") + "es" in TEXT and not " a " + m.group("Msria_45") + "ria " + m.group("Msria_46") + "es" in TEXT and not m.group("Msria_45") + "ria-" + m.group("Msria_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_47>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_48") in plvrMfal and not " e " + m.group("Msria_47") + "ria " + m.group("Msria_48") + "is" in TEXT and not " ou " + m.group("Msria_47") + "ria " + m.group("Msria_48") + "is" in TEXT and not "s de " + m.group("Msria_47") + "ria " + m.group("Msria_48") + "is" in TEXT and not "s da " + m.group("Msria_47") + "ria " + m.group("Msria_48") + "is" in TEXT and not " a " + m.group("Msria_47") + "ria " + m.group("Msria_48") + "is" in TEXT and not m.group("Msria_47") + "ria-" + m.group("Msria_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_49>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_50") in plvrMfcao and not " e " + m.group("Msria_49") + "ria " + m.group("Msria_50") + "ões" in TEXT and not + " ou " + m.group("Msria_49") + "ria " + m.group("Msria_50") + "ões" in TEXT and not + "s de " + m.group("Msria_49") + "ria " + m.group("Msria_50") + "ões" in TEXT and not + "s da " + m.group("Msria_49") + "ria " + m.group("Msria_50") + "ões" in TEXT and not + " a " + m.group("Msria_49") + "ria " + m.group("Msria_50") + "ões" in TEXT and not m.group("Msria_49") + "ria-" + m.group("Msria_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_51>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msria_52") in plvrMascao and not " e " + m.group("Msria_51") + "ria " + m.group("Msria_52") + "ões" in TEXT and not " ou " + m.group("Msria_51") + "ria " + m.group("Msria_52") + "ões" in TEXT and not "s de " + m.group("Msria_51") + "ria " + m.group("Msria_52") + "ões" in TEXT and not "s da " + m.group("Msria_51") + "ria " + m.group("Msria_52") + "ões" in TEXT and not " a " + m.group("Msria_51") + "ria " + m.group("Msria_52") + "ões" in TEXT and not m.group("Msria_51") + "ria-" + m.group("Msria_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_53>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_54") in plvrFemao and not " e " + m.group("Msria_53") + "ria " + m.group("Msria_54") + "ões" in TEXT and not " ou " + m.group("Msria_53") + "ria " + m.group("Msria_54") + "ões" in TEXT and not "s de " + m.group("Msria_53") + "ria " + m.group("Msria_54") + "ões" in TEXT and not "s da " + m.group("Msria_53") + "ria " + m.group("Msria_54") + "ões" in TEXT and not " a " + m.group("Msria_53") + "ria " + m.group("Msria_54") + "ões" in TEXT and not m.group("Msria_53") + "ria-" + m.group("Msria_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_55>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msria_55") + "ria " + m.group("Msria_56") + "veis" in TEXT and not " ou " + m.group("Msria_55") + "ria " + m.group("Msria_56") + "veis" in TEXT and not "s de " + m.group("Msria_55") + "ria " + m.group("Msria_56") + "veis" in TEXT and not "s da " + m.group("Msria_55") + "ria " + m.group("Msria_56") + "veis" in TEXT and not " a " + m.group("Msria_55") + "ria " + m.group("Msria_56") + "veis" in TEXT and not m.group("Msria_55") + "ria-" + m.group("Msria_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_57>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_58").lower() in plvrMfe and not " e " + m.group("Msria_57") + "ria " + m.group("Msria_58") + "es" in TEXT and not " ou " + m.group("Msria_57") + "ria " + m.group("Msria_58") + "es" in TEXT and not "s de " + m.group("Msria_57") + "ria " + m.group("Msria_58") + "es" in TEXT and not "s da " + m.group("Msria_57") + "ria " + m.group("Msria_58") + "es" in TEXT and not " a " + m.group("Msria_57") + "ria " + m.group("Msria_58") + "es" in TEXT and not m.group("Msria_57") + "ria-" + m.group("Msria_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_59>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_60").lower() in plvrFeme and not " e " + m.group("Msria_59") + "ria " + m.group("Msria_60") + "es" in TEXT and not " ou " + m.group("Msria_59") + "ria " + m.group("Msria_60") + "es" in TEXT and not "s de " + m.group("Msria_59") + "ria " + m.group("Msria_60") + "es" in TEXT and not "s da " + m.group("Msria_59") + "ria " + m.group("Msria_60") + "es" in TEXT and not " a " + m.group("Msria_59") + "ria " + m.group("Msria_60") + "es" in TEXT and not m.group("Msria_59") + "ria-" + m.group("Msria_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_61>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_62") in plvrMfel and not " e " + m.group("Msria_61") + "ria " + m.group("Msria_62") + "éis" in TEXT and not " ou " + m.group("Msria_61") + "ria " + m.group("Msria_62") + "éis" in TEXT and not "s de " + m.group("Msria_61") + "ria " + m.group("Msria_62") + "éis" in TEXT and not "s da " + m.group("Msria_61") + "ria " + m.group("Msria_62") + "éis" in TEXT and not " a " + m.group("Msria_61") + "ria " + m.group("Msria_62") + "éis" in TEXT and not m.group("Msria_61") + "ria-" + m.group("Msria_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_63>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_64") in plvrFemel and not " e " + m.group("Msria_63") + "ria " + m.group("Msria_64") + "éis" in TEXT and not " ou " + m.group("Msria_63") + "ria " + m.group("Msria_64") + "éis" in TEXT and not "s de " + m.group("Msria_63") + "ria " + m.group("Msria_64") + "éis" in TEXT and not "s da " + m.group("Msria_63") + "ria " + m.group("Msria_64") + "éis" in TEXT and not " a " + m.group("Msria_63") + "ria " + m.group("Msria_64") + "éis" in TEXT and not m.group("Msria_63") + "ria-" + m.group("Msria_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_65>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_66") in plvrMfeu and not " e " + m.group("Msria_65") + "ria " + m.group("Msria_66") + "us" in TEXT and not " ou " + m.group("Msria_65") + "ria " + m.group("Msria_66") + "us" in TEXT and not "s de " + m.group("Msria_65") + "ria " + m.group("Msria_66") + "us" in TEXT and not "s da " + m.group("Msria_65") + "ria " + m.group("Msria_66") + "us" in TEXT and not " a " + m.group("Msria_65") + "ria " + m.group("Msria_66") + "us" in TEXT and not m.group("Msria_65") + "ria-" + m.group("Msria_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_67>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_68") in plvrFemu and not " e " + m.group("Msria_67") + "ria " + m.group("Msria_68") + "us" in TEXT and not " ou " + m.group("Msria_67") + "ria " + m.group("Msria_68") + "us" in TEXT and not "s de " + m.group("Msria_67") + "ria " + m.group("Msria_68") + "us" in TEXT and not "s da " + m.group("Msria_67") + "ria " + m.group("Msria_68") + "us" in TEXT and not " a " + m.group("Msria_67") + "ria " + m.group("Msria_68") + "us" in TEXT and not m.group("Msria_67") + "ria-" + m.group("Msria_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_69>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_70") in plvrInvaz and not " e " + m.group("Msria_69") + "ria " + m.group("Msria_70") + "zes" in TEXT and not " ou " + m.group("Msria_69") + "ria " + m.group("Msria_70") + "zes" in TEXT and not "s de " + m.group("Msria_69") + "ria " + m.group("Msria_70") + "zes" in TEXT and not "s da " + m.group("Msria_69") + "ria " + m.group("Msria_70") + "zes" in TEXT and not " a " + m.group("Msria_69") + "ria " + m.group("Msria_70") + "zes" in TEXT and not m.group("Msria_69") + "ria-" + m.group("Msria_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_71>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_72") in plvrFemz and not " e " + m.group("Msria_71") + "ria " + m.group("Msria_72") + "zes" in TEXT and not " ou " + m.group("Msria_71") + "ria " + m.group("Msria_72") + "zes" in TEXT and not "s de " + m.group("Msria_71") + "ria " + m.group("Msria_72") + "zes" in TEXT and not "s da " + m.group("Msria_71") + "ria " + m.group("Msria_72") + "zes" in TEXT and not " a " + m.group("Msria_71") + "ria " + m.group("Msria_72") + "zes" in TEXT and not m.group("Msria_71") + "ria-" + m.group("Msria_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_73>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_74") in pvrFeman and not " e " + m.group("Msria_73") + "ria " + m.group("Msria_74") + "s" in TEXT and not " ou " + m.group("Msria_73") + "ria " + m.group("Msria_74") + "s" in TEXT and not "s de " + m.group("Msria_73") + "ria " + m.group("Msria_74") + "s" in TEXT and not "s da " + m.group("Msria_73") + "ria " + m.group("Msria_74") + "s" in TEXT and not " a " + m.group("Msria_73") + "ria " + m.group("Msria_74") + "s" in TEXT and not m.group("Msria_73") + "ria-" + m.group("Msria_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_99>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_100") in plvrMFm and not " e " + m.group("Msria_99") + "ria " + m.group("Msria_100") + "ns" in TEXT and not " ou " + m.group("Msria_99") + "ria " + m.group("Msria_100") + "ns" in TEXT and not "s de " + m.group("Msria_99") + "ria " + m.group("Msria_100") + "ns" in TEXT and not "s da " + m.group("Msria_99") + "ria " + m.group("Msria_100") + "ns" in TEXT and not " a " + m.group("Msria_99") + "ria " + m.group("Msria_100") + "ns" in TEXT and not m.group("Msria_99") + "ria-" + m.group("Msria_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msria_101>[a-zA-Zç]+[áéíóúâêô])ria (?P<Msria_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "rias " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msria_102") in plvrFemm and not " e " + m.group("Msria_101") + "ria " + m.group("Msria_102") + "ns" in TEXT and not " ou " + m.group("Msria_101") + "ria " + m.group("Msria_102") + "ns" in TEXT and not "s de " + m.group("Msria_101") + "ria " + m.group("Msria_102") + "ns" in TEXT and not "s da " + m.group("Msria_101") + "ria " + m.group("Msria_102") + "ns" in TEXT and not " a " + m.group("Msria_101") + "ria " + m.group("Msria_102") + "ns" in TEXT and not m.group("Msria_101") + "ria-" + m.group("Msria_102") + "ns" in tCompostops'],
# rio o
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_1>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_2").lower() in plvrMasca and not " e " + m.group("Msrio_1") + "rio " + m.group("Msrio_2") +"s" in TEXT and not " ou " + m.group("Msrio_1") + "rio " + m.group("Msrio_2") + "s" in TEXT and not "s de " + m.group("Msrio_1") + "rio " + m.group("Msrio_2") + "s" in TEXT and not "s do " + m.group("Msrio_1") + "rio " + m.group("Msrio_2") + "s" in TEXT and not " o " + m.group("Msrio_1") + "rio " + m.group("Msrio_2") + "s" in TEXT and not m.group("Msrio_1") + "rio-" + m.group("Msrio_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_3>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_4").lower() in plvrMfoa and not " e " + m.group("Msrio_3") + "rio " + m.group("Msrio_4") + "os" in TEXT and not " ou " + m.group("Msrio_3") + "rio " + m.group("Msrio_4") + "os" in TEXT and not "s de " + m.group("Msrio_3") + "rio " + m.group("Msrio_4") + "os" in TEXT and not "s do " + m.group("Msrio_3") + "rio " + m.group("Msrio_4") + "os" in TEXT and not " o " + m.group("Msrio_3") + "rio " + m.group("Msrio_4") + "os" in TEXT and not m.group("Msrio_3") + "rio-" + m.group("Msrio_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_5>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msrio_6").lower() in excAdo and not " e " + m.group("Msrio_5") + "rio " + m.group("Msrio_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msrio_5") + "rio " + m.group("Msrio_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msrio_5") + "rio " + m.group("Msrio_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msrio_5") + "rio " + m.group("Msrio_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msrio_5") + "rio " + m.group("Msrio_6") + m.group(3) + "dos" in TEXT and not m.group("Msrio_5") + "rio-" + m.group("Msrio_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_7>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msrio_8").lower() in excIsta and not " e " + m.group("Msrio_7") + "rio " + m.group("Msrio_8") + "s" in TEXT and not " ou " + m.group("Msrio_7") + "rio " + m.group("Msrio_8") + "s" in TEXT and not "s de " + m.group("Msrio_7") + "rio " + m.group("Msrio_8") + "s" in TEXT and not "s do " + m.group("Msrio_7") + "rio " + m.group("Msrio_8") + "s" in TEXT and not " o " + m.group("Msrio_7") + "rio " + m.group("Msrio_8") + "s" in TEXT and not m.group("Msrio_7") + "rio-" + m.group("Msrio_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_9>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_10").lower() in plvrInva and not " e " + m.group("Msrio_9") + "rio " + m.group("Msrio_10") + "s" in TEXT and not " ou " + m.group("Msrio_9") + "rio " + m.group("Msrio_10") + "s" in TEXT and not "s de " + m.group("Msrio_9") + "rio " + m.group("Msrio_10") + "s" in TEXT and not "s do " + m.group("Msrio_9") + "rio " + m.group("Msrio_10") + "s" in TEXT and not " a " + m.group("Msrio_9") + "rio " + m.group("Msrio_10") + "s" in TEXT and not m.group("Msrio_9") + "rio-" + m.group("Msrio_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_11>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msrio_12").lower() in excAdo and not " e " + m.group("Msrio_11") + "rio " + m.group("Msrio_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msrio_11") + "rio " + m.group("Msrio_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msrio_11") + "rio " + m.group("Msrio_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Msrio_11") + "rio " + m.group("Msrio_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Msrio_11") + "rio " + m.group("Msrio_12") + m.group(3) + "das" in TEXT and not m.group("Msrio_11") + "rio-" + m.group("Msrio_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_13>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_13") + "rio " + m.group("Msrio_14") + "osos" in TEXT and not " ou " + m.group("Msrio_13") + "rio " + m.group("Msrio_14") + "osos" in TEXT and not "s de " + m.group("Msrio_13") + "rio " + m.group("Msrio_14") + "osos" in TEXT and not "s do " + m.group("Msrio_13") + "rio " + m.group("Msrio_14") + "osos" in TEXT and not " o " + m.group("Msrio_13") + "rio " + m.group("Msrio_14") + "osos" in TEXT and not m.group("Msrio_13") + "rio-" + m.group("Msrio_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_15>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_15") + "rio " + m.group("Msrio_16") + "osas" in TEXT and not " ou " + m.group("Msrio_15") + "rio " + m.group("Msrio_16") + "osas" in TEXT and not "s de " + m.group("Msrio_15") + "rio " + m.group("Msrio_16") + "osas" in TEXT and not "s do " + m.group("Msrio_15") + "rio " + m.group("Msrio_16") + "osas" in TEXT and not " o " + m.group("Msrio_15") + "rio " + m.group("Msrio_16") + "osas" in TEXT and not m.group("Msrio_15") + "rio-" + m.group("Msrio_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_17>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_17") + "rio " + m.group("Msrio_18") + "ivas" in TEXT and not " ou " + m.group("Msrio_17") + "rio " + m.group("Msrio_18") + "ivas" in TEXT and not "s de " + m.group("Msrio_17") + "rio " + m.group("Msrio_18") + "ivas" in TEXT and not "s do " + m.group("Msrio_17") + "rio " + m.group("Msrio_18") + "ivas" in TEXT and not " o " + m.group("Msrio_17") + "rio " + m.group("Msrio_18") + "ivas" in TEXT and not m.group("Msrio_17") + "rio-" + m.group("Msrio_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_19>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_19") + "rio " + m.group("Msrio_20") + "ivas" in TEXT and not " ou " + m.group("Msrio_19") + "rio " + m.group("Msrio_20") + "ivas" in TEXT and not "s de " + m.group("Msrio_19") + "rio " + m.group("Msrio_20") + "ivas" in TEXT and not "s do " + m.group("Msrio_19") + "rio " + m.group("Msrio_20") + "ivas" in TEXT and not " o " + m.group("Msrio_19") + "rio " + m.group("Msrio_20") + "ivas" in TEXT and not m.group("Msrio_19") + "rio-" + m.group("Msrio_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_21>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_21") + "rio " + m.group("Msrio_22") + "icos" in TEXT and not " ou " + m.group("Msrio_21") + "rio " + m.group("Msrio_22") + "icos" in TEXT and not "s de " + m.group("Msrio_21") + "rio " + m.group("Msrio_22") + "icos" in TEXT and not "s do " + m.group("Msrio_21") + "rio " + m.group("Msrio_22") + "icos" in TEXT and not " o " + m.group("Msrio_21") + "rio " + m.group("Msrio_22") + "icos" in TEXT and not m.group("Msrio_21") + "rio-" + m.group("Msrio_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_23>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_23") + "rio " + m.group("Msrio_24") + "icos" in TEXT and not " ou " + m.group("Msrio_23") + "rio " + m.group("Msrio_24") + "icos" in TEXT and not "s de " + m.group("Msrio_23") + "rio " + m.group("Msrio_24") + "icos" in TEXT and not "s do " + m.group("Msrio_23") + "rio " + m.group("Msrio_24") + "icos" in TEXT and not " o " + m.group("Msrio_23") + "rio " + m.group("Msrio_24") + "icos" in TEXT and not m.group("Msrio_23") + "rio-" + m.group("Msrio_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_25>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_25") + "rio " + m.group("Msrio_26") + "icos" in TEXT and not " ou " + m.group("Msrio_25") + "rio " + m.group("Msrio_26") + "icos" in TEXT and not "s de " + m.group("Msrio_25") + "rio " + m.group("Msrio_26") + "icos" in TEXT and not "s do " + m.group("Msrio_25") + "rio " + m.group("Msrio_26") + "icos" in TEXT and not " o " + m.group("Msrio_25") + "rio " + m.group("Msrio_26") + "icos" in TEXT and not m.group("Msrio_25") + "rio-" + m.group("Msrio_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_27>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_27") + "rio " + m.group("Msrio_28") + "escos" in TEXT and not " ou " + m.group("Msrio_27") + "rio " + m.group("Msrio_28") + "escos" in TEXT and not "s de " + m.group("Msrio_27") + "rio " + m.group("Msrio_28") + "escos" in TEXT and not "s do " + m.group("Msrio_27") + "rio " + m.group("Msrio_28") + "escos" in TEXT and not " o " + m.group("Msrio_27") + "rio " + m.group("Msrio_28") + "escos" in TEXT and not m.group("Msrio_27") + "rio-" + m.group("Msrio_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_29>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_29") + "rio " + m.group("Msrio_30") + "idos" in TEXT and not " ou " + m.group("Msrio_29") + "s " + m.group("Msrio_30") + "idos" in TEXT and not "s de " + m.group("Msrio_29") + "s " + m.group("Msrio_30") + "idos" in TEXT and not "s do " + m.group("Msrio_29") + "s " + m.group("Msrio_30") + "idos" in TEXT and not " o " + m.group("Msrio_29") + "s " + m.group("Msrio_30") + "idos" in TEXT and not m.group("Msrio_29") + "rio-" + m.group("Msrio_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_31>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_31") + "rio " + m.group("Msrio_32") + "logos" in TEXT and not " ou " + m.group("Msrio_31") + "rio " + m.group("Msrio_32") + "logos" in TEXT and not "s de " + m.group("Msrio_31") + "rio " + m.group("Msrio_32") + "logos" in TEXT and not "s do " + m.group("Msrio_31") + "rio " + m.group("Msrio_32") + "logos" in TEXT and not " o " + m.group("Msrio_31") + "rio " + m.group("Msrio_32") + "logos" in TEXT and not m.group("Msrio_31") + "rio-" + m.group("Msrio_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_33>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_33") + "rio " + m.group("Msrio_34") + "rios" in TEXT and not " ou " + m.group("Msrio_33") + "rio " + m.group("Msrio_34") + "rios" in TEXT and not "s de " + m.group("Msrio_33") + "rio " + m.group("Msrio_34") + "rios" in TEXT and not "s do " + m.group("Msrio_33") + "rio " + m.group("Msrio_34") + "rios" in TEXT and not " o " + m.group("Msrio_33") + "rio " + m.group("Msrio_34") + "rios" in TEXT and not m.group("Msrio_33") + "rio-" + m.group("Msrio_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_35>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_35") + "rio " + m.group("Msrio_36") + "ssimos" in TEXT and not " ou " + m.group("Msrio_35") + "rio " + m.group("Msrio_36") + "ssimos" in TEXT and not "s de " + m.group("Msrio_35") + "rio " + m.group("Msrio_36") + "ssimos" in TEXT and not "s do " + m.group("Msrio_35") + "rio " + m.group("Msrio_36") + "ssimos" in TEXT and not " o " + m.group("Msrio_35") + "rio " + m.group("Msrio_36") + "ssimos" in TEXT and not m.group("Msrio_35") + "rio-" + m.group("Msrio_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_37>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_37") + "rio " + m.group("Msrio_38") + "simos" in TEXT and not " ou " + m.group("Msrio_37") + "rio " + m.group("Msrio_38") + "simos" in TEXT and not "s de " + m.group("Msrio_37") + "rio " + m.group("Msrio_38") + "simos" in TEXT and not "s do " + m.group("Msrio_37") + "rio " + m.group("Msrio_38") + "simos" in TEXT and not " o " + m.group("Msrio_37") + "rio " + m.group("Msrio_38") + "simos" in TEXT and not m.group("Msrio_37") + "rio-" + m.group("Msrio_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_41>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msrio_42") in "D-d-" and not " e " + m.group("Msrio_41") + "rio " + m.group("Msrio_42") + "ores" in TEXT and not " ou " + m.group("Msrio_41") + "rio " + m.group("Msrio_42") + "ores" in TEXT and not "s de " + m.group("Msrio_41") + "rio " + m.group("Msrio_42") + "ores" in TEXT and not "s do " + m.group("Msrio_41") + "rio " + m.group("Msrio_42") + "ores" in TEXT and not " o " + m.group("Msrio_41") + "rio " + m.group("Msrio_42") + "ores" in TEXT and not m.group("Msrio_41") + "rio-" + m.group("Msrio_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_43>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_44") in plvrMfr and not " e " + m.group("Msrio_43") + "rio " + m.group("Msrio_44") + "es" in TEXT and not " ou " + m.group("Msrio_43") + "rio " + m.group("Msrio_44") + "es" in TEXT and not "s de " + m.group("Msrio_43") + "rio " + m.group("Msrio_44") + "es" in TEXT and not "s do " + m.group("Msrio_43") + "rio " + m.group("Msrio_44") + "es" in TEXT and not " o " + m.group("Msrio_43") + "rio " + m.group("Msrio_44") + "es" in TEXT and not m.group("Msrio_43") + "rio-" + m.group("Msrio_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_45>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_46") in plvrMascr and not " e " + m.group("Msrio_45") + "rio " + m.group("Msrio_46") + "es" in TEXT and not " ou " + m.group("Msrio_45") + "rio " + m.group("Msrio_46") + "es" in TEXT and not "s de " + m.group("Msrio_45") + "rio " + m.group("Msrio_46") + "es" in TEXT and not "s do " + m.group("Msrio_45") + "rio " + m.group("Msrio_46") + "es" in TEXT and not " o " + m.group("Msrio_45") + "rio " + m.group("Msrio_46") + "es" in TEXT and not m.group("Msrio_45") + "rio-" + m.group("Msrio_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_47>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_48") in plvrMfal and not " e " + m.group("Msrio_47") + "rio " + m.group("Msrio_48") + "is" in TEXT and not " ou " + m.group("Msrio_47") + "rio " + m.group("Msrio_48") + "is" in TEXT and not "s de " + m.group("Msrio_47") + "rio " + m.group("Msrio_48") + "is" in TEXT and not "s do " + m.group("Msrio_47") + "rio " + m.group("Msrio_48") + "is" in TEXT and not " o " + m.group("Msrio_47") + "rio " + m.group("Msrio_48") + "is" in TEXT and not m.group("Msrio_47") + "rio-" + m.group("Msrio_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_49>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_50") in plvrMfcao and not " e " + m.group("Msrio_49") + "rio " + m.group("Msrio_50") + "ões" in TEXT and not + " ou " + m.group("Msrio_49") + "rio " + m.group("Msrio_50") + "ões" in TEXT and not + "s de " + m.group("Msrio_49") + "rio " + m.group("Msrio_50") + "ões" in TEXT and not + "s do " + m.group("Msrio_49") + "rio " + m.group("Msrio_50") + "ões" in TEXT and not + " a " + m.group("Msrio_49") + "rio " + m.group("Msrio_50") + "ões" in TEXT and not m.group("Msrio_49") + "rio-" + m.group("Msrio_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_51>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_52") in plvrNfemcao and not " e " + m.group("Msrio_51") + "rio " + m.group("Msrio_52") + "ões" in TEXT and not " ou " + m.group("Msrio_51") + "rio " + m.group("Msrio_52") + "ões" in TEXT and not "s de " + m.group("Msrio_51") + "rio " + m.group("Msrio_52") + "ões" in TEXT and not "s do " + m.group("Msrio_51") + "rio " + m.group("Msrio_52") + "ões" in TEXT and not " o " + m.group("Msrio_51") + "rio " + m.group("Msrio_52") + "ões" in TEXT and not m.group("Msrio_51") + "rio-" + m.group("Msrio_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_55>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_55") + "rio " + m.group("Msrio_56") + "veis" in TEXT and not " ou " + m.group("Msrio_55") + "rio " + m.group("Msrio_56") + "veis" in TEXT and not "s de " + m.group("Msrio_55") + "rio " + m.group("Msrio_56") + "veis" in TEXT and not "s do " + m.group("Msrio_55") + "rio " + m.group("Msrio_56") + "veis" in TEXT and not " o " + m.group("Msrio_55") + "rio " + m.group("Msrio_56") + "veis" in TEXT and not m.group("Msrio_55") + "rio-" + m.group("Msrio_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_57>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_58").lower() in plvrMfe and not " e " + m.group("Msrio_57") + "rio " + m.group("Msrio_58") + "es" in TEXT and not " ou " + m.group("Msrio_57") + "rio " + m.group("Msrio_58") + "es" in TEXT and not "s de " + m.group("Msrio_57") + "rio " + m.group("Msrio_58") + "es" in TEXT and not "s do " + m.group("Msrio_57") + "rio " + m.group("Msrio_58") + "es" in TEXT and not " o " + m.group("Msrio_57") + "rio " + m.group("Msrio_58") + "es" in TEXT and not m.group("Msrio_57") + "rio-" + m.group("Msrio_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_59>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_60").lower() in plvrMasce and not " e " + m.group("Msrio_59") + "rio " + m.group("Msrio_60") + "es" in TEXT and not " ou " + m.group("Msrio_59") + "rio " + m.group("Msrio_60") + "es" in TEXT and not "s de " + m.group("Msrio_59") + "rio " + m.group("Msrio_60") + "es" in TEXT and not "s do " + m.group("Msrio_59") + "rio " + m.group("Msrio_60") + "es" in TEXT and not " o " + m.group("Msrio_59") + "rio " + m.group("Msrio_60") + "es" in TEXT and not m.group("Msrio_59") + "rio-" + m.group("Msrio_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_61>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_62") in plvrMfel and not " e " + m.group("Msrio_61") + "rio " + m.group("Msrio_62") + "éis" in TEXT and not " ou " + m.group("Msrio_61") + "rio " + m.group("Msrio_62") + "éis" in TEXT and not "s de " + m.group("Msrio_61") + "rio " + m.group("Msrio_62") + "éis" in TEXT and not "s do " + m.group("Msrio_61") + "rio " + m.group("Msrio_62") + "éis" in TEXT and not " o " + m.group("Msrio_61") + "rio " + m.group("Msrio_62") + "éis" in TEXT and not m.group("Msrio_61") + "rio-" + m.group("Msrio_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_63>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_64") in plvrMascel and not " e " + m.group("Msrio_63") + "rio " + m.group("Msrio_64") + "éis" in TEXT and not " ou " + m.group("Msrio_63") + "rio " + m.group("Msrio_64") + "éis" in TEXT and not "s de " + m.group("Msrio_63") + "rio " + m.group("Msrio_64") + "éis" in TEXT and not "s do " + m.group("Msrio_63") + "rio " + m.group("Msrio_64") + "éis" in TEXT and not " o " + m.group("Msrio_63") + "rio " + m.group("Msrio_64") + "éis" in TEXT and not m.group("Msrio_63") + "rio-" + m.group("Msrio_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_65>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_66") in plvrMfeu and not " e " + m.group("Msrio_65") + "rio " + m.group("Msrio_66") + "us" in TEXT and not " ou " + m.group("Msrio_65") + "rio " + m.group("Msrio_66") + "us" in TEXT and not "s de " + m.group("Msrio_65") + "rio " + m.group("Msrio_66") + "us" in TEXT and not "s do " + m.group("Msrio_65") + "rio " + m.group("Msrio_66") + "us" in TEXT and not " o " + m.group("Msrio_65") + "rio " + m.group("Msrio_66") + "us" in TEXT and not m.group("Msrio_65") + "rio-" + m.group("Msrio_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_67>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_68") in plvrMascu and not " e " + m.group("Msrio_67") + "rio " + m.group("Msrio_68") + "us" in TEXT and not " ou " + m.group("Msrio_67") + "rio " + m.group("Msrio_68") + "us" in TEXT and not "s de " + m.group("Msrio_67") + "rio " + m.group("Msrio_68") + "us" in TEXT and not "s do " + m.group("Msrio_67") + "rio " + m.group("Msrio_68") + "us" in TEXT and not " o " + m.group("Msrio_67") + "rio " + m.group("Msrio_68") + "us" in TEXT and not m.group("Msrio_67") + "rio-" + m.group("Msrio_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_69>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_70") in plvrInvaz and not " e " + m.group("Msrio_69") + "rio " + m.group("Msrio_70") + "zes" in TEXT and not " ou " + m.group("Msrio_69") + "rio " + m.group("Msrio_70") + "zes" in TEXT and not "s de " + m.group("Msrio_69") + "rio " + m.group("Msrio_70") + "zes" in TEXT and not "s do " + m.group("Msrio_69") + "rio " + m.group("Msrio_70") + "zes" in TEXT and not " o " + m.group("Msrio_69") + "rio " + m.group("Msrio_70") + "zes" in TEXT and not m.group("Msrio_69") + "rio-" + m.group("Msrio_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_71>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_72") in plvrMascz and not " e " + m.group("Msrio_71") + "rio " + m.group("Msrio_72") + "zes" in TEXT and not " ou " + m.group("Msrio_71") + "rio " + m.group("Msrio_72") + "zes" in TEXT and not "s de " + m.group("Msrio_71") + "rio " + m.group("Msrio_72") + "zes" in TEXT and not "s do " + m.group("Msrio_71") + "rio " + m.group("Msrio_72") + "zes" in TEXT and not " o " + m.group("Msrio_71") + "rio " + m.group("Msrio_72") + "zes" in TEXT and not m.group("Msrio_71") + "rio-" + m.group("Msrio_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_73>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_74") in pvrMascan and not " e " + m.group("Msrio_73") + "rio " + m.group("Msrio_74") + "s" in TEXT and not " ou " + m.group("Msrio_73") + "rio " + m.group("Msrio_74") + "s" in TEXT and not "s de " + m.group("Msrio_73") + "rio " + m.group("Msrio_74") + "s" in TEXT and not "s do " + m.group("Msrio_73") + "rio " + m.group("Msrio_74") + "s" in TEXT and not " o " + m.group("Msrio_73") + "rio " + m.group("Msrio_74") + "s" in TEXT and not m.group("Msrio_73") + "rio-" + m.group("Msrio_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_75>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_76").lower() in plvrMasco and not " e " + m.group("Msrio_75") + "rio " + m.group("Msrio_76") +"s" in TEXT and not " ou " + m.group("Msrio_75") + "rio " + m.group("Msrio_76") + "s" in TEXT and not "s de " + m.group("Msrio_75") + "rio " + m.group("Msrio_76") + "s" in TEXT and not "s do " + m.group("Msrio_75") + "rio " + m.group("Msrio_76") + "s" in TEXT and not " o " + m.group("Msrio_75") + "rio " + m.group("Msrio_76") + "s" in TEXT and not m.group("Msrio_75") + "rio-" + m.group("Msrio_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_77>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_77") + "rio " + m.group("Msrio_78") + "inhos" in TEXT and not " ou " + m.group("Msrio_77") + "rio " + m.group("Msrio_78") + "inhos" in TEXT and not "s de " + m.group("Msrio_77") + "rio " + m.group("Msrio_78") + "inhos" in TEXT and not "s do " + m.group("Msrio_77") + "rio " + m.group("Msrio_78") + "inhos" in TEXT and not " o " + m.group("Msrio_77") + "rio " + m.group("Msrio_78") + "inhos" in TEXT and not m.group("Msrio_77") + "rio-" + m.group("Msrio_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_79>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_79") + "rio " + m.group("Msrio_80") + "icas" in TEXT and not " ou " + m.group("Msrio_79") + "rio " + m.group("Msrio_80") + "icas" in TEXT and not "s de " + m.group("Msrio_79") + "rio " + m.group("Msrio_80") + "icas" in TEXT and not "s do " + m.group("Msrio_79") + "rio " + m.group("Msrio_80") + "icas" in TEXT and not " o " + m.group("Msrio_79") + "rio " + m.group("Msrio_80") + "icas" in TEXT and not m.group("Msrio_79") + "rio-" + m.group("Msrio_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_81>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_81") + "rio " + m.group("Msrio_82") + "icas" in TEXT and not " ou " + m.group("Msrio_81") + "rio " + m.group("Msrio_82") + "icas" in TEXT and not "s de " + m.group("Msrio_81") + "rio " + m.group("Msrio_82") + "icas" in TEXT and not "s do " + m.group("Msrio_81") + "rio " + m.group("Msrio_82") + "icas" in TEXT and not " o " + m.group("Msrio_81") + "rio " + m.group("Msrio_82") + "icas" in TEXT and not m.group("Msrio_81") + "rio-" + m.group("Msrio_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_83>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_83") + "rio " + m.group("Msrio_84") + "icas" in TEXT and not " ou " + m.group("Msrio_83") + "rio " + m.group("Msrio_84") + "icas" in TEXT and not "s de " + m.group("Msrio_83") + "rio " + m.group("Msrio_84") + "icas" in TEXT and not "s do " + m.group("Msrio_83") + "rio " + m.group("Msrio_84") + "icas" in TEXT and not " o " + m.group("Msrio_83") + "rio " + m.group("Msrio_84") + "icas" in TEXT and not m.group("Msrio_83") + "rio-" + m.group("Msrio_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_85>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_85") + "rio " + m.group("Msrio_86") + "escas" in TEXT and not " ou " + m.group("Msrio_85") + "rio " + m.group("Msrio_86") + "escas" in TEXT and not "s de " + m.group("Msrio_85") + "rio " + m.group("Msrio_86") + "escas" in TEXT and not "s do " + m.group("Msrio_85") + "rio " + m.group("Msrio_86") + "escas" in TEXT and not " o " + m.group("Msrio_85") + "rio " + m.group("Msrio_86") + "escas" in TEXT and not m.group("Msrio_85") + "rio-" + m.group("Msrio_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_87>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_87") + "rio " + m.group("Msrio_88") + "idas" in TEXT and not " ou " + m.group("Msrio_87") + "s " + m.group("Msrio_88") + "idas" in TEXT and not "s de " + m.group("Msrio_87") + "s " + m.group("Msrio_88") + "idas" in TEXT and not "s do " + m.group("Msrio_87") + "s " + m.group("Msrio_88") + "idas" in TEXT and not " o " + m.group("Msrio_87") + "s " + m.group("Msrio_88") + "idas" in TEXT and not m.group("Msrio_87") + "rio-" + m.group("Msrio_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_89>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_89") + "rio " + m.group("Msrio_90") + "logas" in TEXT and not " ou " + m.group("Msrio_89") + "rio " + m.group("Msrio_90") + "logas" in TEXT and not "s de " + m.group("Msrio_89") + "rio " + m.group("Msrio_90") + "logas" in TEXT and not "s do " + m.group("Msrio_89") + "rio " + m.group("Msrio_90") + "logas" in TEXT and not " o " + m.group("Msrio_89") + "rio " + m.group("Msrio_90") + "logas" in TEXT and not m.group("Msrio_89") + "rio-" + m.group("Msrio_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_91>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_91") + "rio " + m.group("Msrio_92") + "rias" in TEXT and not " ou " + m.group("Msrio_91") + "rio " + m.group("Msrio_92") + "rias" in TEXT and not "s de " + m.group("Msrio_91") + "rio " + m.group("Msrio_92") + "rias" in TEXT and not "s do " + m.group("Msrio_91") + "rio " + m.group("Msrio_92") + "rias" in TEXT and not " o " + m.group("Msrio_91") + "rio " + m.group("Msrio_92") + "rias" in TEXT and not m.group("Msrio_91") + "rio-" + m.group("Msrio_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_93>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_93") + "rio " + m.group("Msrio_94") + "ssimas" in TEXT and not " ou " + m.group("Msrio_93") + "rio " + m.group("Msrio_94") + "ssimas" in TEXT and not "s de " + m.group("Msrio_93") + "rio " + m.group("Msrio_94") + "ssimas" in TEXT and not "s do " + m.group("Msrio_93") + "rio " + m.group("Msrio_94") + "ssimas" in TEXT and not " o " + m.group("Msrio_93") + "rio " + m.group("Msrio_94") + "ssimas" in TEXT and not m.group("Msrio_93") + "rio-" + m.group("Msrio_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_95>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msrio_95") + "rio " + m.group("Msrio_96") + "simas" in TEXT and not " ou " + m.group("Msrio_95") + "rio " + m.group("Msrio_96") + "simas" in TEXT and not "s de " + m.group("Msrio_95") + "rio " + m.group("Msrio_96") + "simas" in TEXT and not "s do " + m.group("Msrio_95") + "rio " + m.group("Msrio_96") + "simas" in TEXT and not " o " + m.group("Msrio_95") + "rio " + m.group("Msrio_96") + "simas" in TEXT and not m.group("Msrio_95") + "rio-" + m.group("Msrio_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_97>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_98").lower() in plvrMfoa and not " e " + m.group("Msrio_97") + "rio " + m.group("Msrio_98") + "as" in TEXT and not " ou " + m.group("Msrio_97") + "rio " + m.group("Msrio_98") + "as" in TEXT and not "s de " + m.group("Msrio_97") + "rio " + m.group("Msrio_98") + "as" in TEXT and not "s do " + m.group("Msrio_97") + "rio " + m.group("Msrio_98") + "as" in TEXT and not " o " + m.group("Msrio_97") + "rio " + m.group("Msrio_98") + "as" in TEXT and not m.group("Msrio_97") + "rio-" + m.group("Msrio_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_99>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_100") in plvrMFm and not " e " + m.group("Msrio_99") + "rio " + m.group("Msrio_100") + "ns" in TEXT and not " ou " + m.group("Msrio_99") + "rio " + m.group("Msrio_100") + "ns" in TEXT and not "s de " + m.group("Msrio_99") + "rio " + m.group("Msrio_100") + "ns" in TEXT and not "s da " + m.group("Msrio_99") + "rio " + m.group("Msrio_100") + "ns" in TEXT and not " a " + m.group("Msrio_99") + "rio " + m.group("Msrio_100") + "ns" in TEXT and not m.group("Msrio_99") + "rio-" + m.group("Msrio_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msrio_101>[a-zA-Zç]+[áéíóúâêô])rio (?P<Msrio_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "rios " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msrio_102") in plvrMascm and not " e " + m.group("Msrio_101") + "rio " + m.group("Msrio_102") + "ns" in TEXT and not " ou " + m.group("Msrio_101") + "rio " + m.group("Msrio_102") + "ns" in TEXT and not "s de " + m.group("Msrio_101") + "rio " + m.group("Msrio_102") + "ns" in TEXT and not "s da " + m.group("Msrio_101") + "rio " + m.group("Msrio_102") + "ns" in TEXT and not " a " + m.group("Msrio_101") + "rio " + m.group("Msrio_102") + "ns" in TEXT and not m.group("Msrio_101") + "rio-" + m.group("Msrio_102") + "ns" in tCompostops'],
# issima a
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_1>[a-zA-Zç]+[í])ssima (?P<Mssma_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_2").lower() in plvrFema and not " e " + m.group("Mssma_1") + "ssima " + m.group("Mssma_2") +"s" in TEXT and not " ou " + m.group("Mssma_1") + "ssima " + m.group("Mssma_2") + "s" in TEXT and not "s de " + m.group("Mssma_1") + "ssima " + m.group("Mssma_2") + "s" in TEXT and not "s da " + m.group("Mssma_1") + "ssima " + m.group("Mssma_2") + "s" in TEXT and not " a " + m.group("Mssma_1") + "ssima " + m.group("Mssma_2") + "s" in TEXT and not m.group("Mssma_1") + "ssima-" + m.group("Mssma_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_3>[a-zA-Zç]+[í])ssima (?P<Mssma_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_4").lower() in plvrMfoa and not " e " + m.group("Mssma_3") + "ssima " + m.group("Mssma_4") + "as" in TEXT and not " ou " + m.group("Mssma_3") + "ssima " + m.group("Mssma_4") + "as" in TEXT and not "s de " + m.group("Mssma_3") + "ssima " + m.group("Mssma_4") + "as" in TEXT and not "s da " + m.group("Mssma_3") + "ssima " + m.group("Mssma_4") + "as" in TEXT and not " a " + m.group("Mssma_3") + "ssima " + m.group("Mssma_4") + "as" in TEXT and not m.group("Mssma_3") + "ssima-" + m.group("Mssma_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_5>[a-zA-Zç]+[í])ssima (?P<Mssma_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssma_6").lower() in excAdo and not " e " + m.group("Mssma_5") + "ssima " + m.group("Mssma_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Mssma_5") + "ssima " + m.group("Mssma_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Mssma_5") + "ssima " + m.group("Mssma_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Mssma_5") + "ssima " + m.group("Mssma_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Mssma_5") + "ssima " + m.group("Mssma_6") + m.group(3) + "dos" in TEXT and not m.group("Mssma_5") + "ssima-" + m.group("Mssma_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_7>[a-zA-Zç]+[í])ssima (?P<Mssma_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssma_8").lower() in excIsta and not " e " + m.group("Mssma_7") + "ssima " + m.group("Mssma_8") + "s" in TEXT and not " ou " + m.group("Mssma_7") + "ssima " + m.group("Mssma_8") + "s" in TEXT and not "s de " + m.group("Mssma_7") + "ssima " + m.group("Mssma_8") + "s" in TEXT and not "s da " + m.group("Mssma_7") + "ssima " + m.group("Mssma_8") + "s" in TEXT and not " a " + m.group("Mssma_7") + "ssima " + m.group("Mssma_8") + "s" in TEXT and not m.group("Mssma_7") + "ssima-" + m.group("Mssma_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_9>[a-zA-Zç]+[í])ssima (?P<Mssma_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_10").lower() in plvrInva and not " e " + m.group("Mssma_9") + "ssima " + m.group("Mssma_10") + "s" in TEXT and not " ou " + m.group("Mssma_9") + "ssima " + m.group("Mssma_10") + "s" in TEXT and not "s de " + m.group("Mssma_9") + "ssima " + m.group("Mssma_10") + "s" in TEXT and not "s da " + m.group("Mssma_9") + "ssima " + m.group("Mssma_10") + "s" in TEXT and not " a " + m.group("Mssma_9") + "ssima " + m.group("Mssma_10") + "s" in TEXT and not m.group("Mssma_9") + "ssima-" + m.group("Mssma_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_11>[a-zA-Zç]+[í])ssima (?P<Mssma_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssma_12").lower() in excAdo and not " e " + m.group("Mssma_11") + "ssima " + m.group("Mssma_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Mssma_11") + "ssima " + m.group("Mssma_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Mssma_11") + "ssima " + m.group("Mssma_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Mssma_11") + "ssima " + m.group("Mssma_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Mssma_11") + "ssima " + m.group("Mssma_12") + m.group(3) + "das" in TEXT and not m.group("Mssma_11") + "ssima-" + m.group("Mssma_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_13>[a-zA-Zç]+[í])ssima (?P<Mssma_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssma_13") + "ssima " + m.group("Mssma_14") + "osos" in TEXT and not " ou " + m.group("Mssma_13") + "ssima " + m.group("Mssma_14") + "osos" in TEXT and not "s de " + m.group("Mssma_13") + "ssima " + m.group("Mssma_14") + "osos" in TEXT and not "s da " + m.group("Mssma_13") + "ssima " + m.group("Mssma_14") + "osos" in TEXT and not " a " + m.group("Mssma_13") + "ssima " + m.group("Mssma_14") + "osos" in TEXT and not m.group("Mssma_13") + "ssima-" + m.group("Mssma_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_15>[a-zA-Zç]+[í])ssima (?P<Mssma_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssma_15") + "ssima " + m.group("Mssma_16") + "osas" in TEXT and not " ou " + m.group("Mssma_15") + "ssima " + m.group("Mssma_16") + "osas" in TEXT and not "s de " + m.group("Mssma_15") + "ssima " + m.group("Mssma_16") + "osas" in TEXT and not "s da " + m.group("Mssma_15") + "ssima " + m.group("Mssma_16") + "osas" in TEXT and not " a " + m.group("Mssma_15") + "ssima " + m.group("Mssma_16") + "osas" in TEXT and not m.group("Mssma_15") + "ssima-" + m.group("Mssma_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_17>[a-zA-Zç]+[í])ssima (?P<Mssma_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssma_17") + "ssima " + m.group("Mssma_18") + "ivas" in TEXT and not " ou " + m.group("Mssma_17") + "ssima " + m.group("Mssma_18") + "ivas" in TEXT and not "s de " + m.group("Mssma_17") + "ssima " + m.group("Mssma_18") + "ivas" in TEXT and not "s da " + m.group("Mssma_17") + "ssima " + m.group("Mssma_18") + "ivas" in TEXT and not " a " + m.group("Mssma_17") + "ssima " + m.group("Mssma_18") + "ivas" in TEXT and not m.group("Mssma_17") + "ssima-" + m.group("Mssma_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_19>[a-zA-Zç]+[í])ssima (?P<Mssma_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssma_19") + "ssima " + m.group("Mssma_20") + "ivas" in TEXT and not " ou " + m.group("Mssma_19") + "ssima " + m.group("Mssma_20") + "ivas" in TEXT and not "s de " + m.group("Mssma_19") + "ssima " + m.group("Mssma_20") + "ivas" in TEXT and not "s da " + m.group("Mssma_19") + "ssima " + m.group("Mssma_20") + "ivas" in TEXT and not " a " + m.group("Mssma_19") + "ssima " + m.group("Mssma_20") + "ivas" in TEXT and not m.group("Mssma_19") + "ssima-" + m.group("Mssma_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_21>[a-zA-Zç]+[í])ssima (?P<Mssma_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssma_21") + "ssima " + m.group("Mssma_22") + "icas" in TEXT and not " ou " + m.group("Mssma_21") + "ssima " + m.group("Mssma_22") + "icas" in TEXT and not "s de " + m.group("Mssma_21") + "ssima " + m.group("Mssma_22") + "icas" in TEXT and not "s da " + m.group("Mssma_21") + "ssima " + m.group("Mssma_22") + "icas" in TEXT and not " a " + m.group("Mssma_21") + "ssima " + m.group("Mssma_22") + "icas" in TEXT and not m.group("Mssma_21") + "ssima-" + m.group("Mssma_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_23>[a-zA-Zç]+[í])ssima (?P<Mssma_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssma_23") + "ssima " + m.group("Mssma_24") + "icas" in TEXT and not " ou " + m.group("Mssma_23") + "ssima " + m.group("Mssma_24") + "icas" in TEXT and not "s de " + m.group("Mssma_23") + "ssima " + m.group("Mssma_24") + "icas" in TEXT and not "s da " + m.group("Mssma_23") + "ssima " + m.group("Mssma_24") + "icas" in TEXT and not " a " + m.group("Mssma_23") + "ssima " + m.group("Mssma_24") + "icas" in TEXT and not m.group("Mssma_23") + "ssima-" + m.group("Mssma_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_25>[a-zA-Zç]+[í])ssima (?P<Mssma_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssma_25") + "ssima " + m.group("Mssma_26") + "icas" in TEXT and not " ou " + m.group("Mssma_25") + "ssima " + m.group("Mssma_26") + "icas" in TEXT and not "s de " + m.group("Mssma_25") + "ssima " + m.group("Mssma_26") + "icas" in TEXT and not "s da " + m.group("Mssma_25") + "ssima " + m.group("Mssma_26") + "icas" in TEXT and not " a " + m.group("Mssma_25") + "ssima " + m.group("Mssma_26") + "icas" in TEXT and not m.group("Mssma_25") + "ssima-" + m.group("Mssma_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_27>[a-zA-Zç]+[í])ssima (?P<Mssma_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssma_27") + "ssima " + m.group("Mssma_28") + "escas" in TEXT and not " ou " + m.group("Mssma_27") + "ssima " + m.group("Mssma_28") + "escas" in TEXT and not "s de " + m.group("Mssma_27") + "ssima " + m.group("Mssma_28") + "escas" in TEXT and not "s da " + m.group("Mssma_27") + "ssima " + m.group("Mssma_28") + "escas" in TEXT and not " a " + m.group("Mssma_27") + "ssima " + m.group("Mssma_28") + "escas" in TEXT and not m.group("Mssma_27") + "ssima-" + m.group("Mssma_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_29>[a-zA-Zç]+[í])ssima (?P<Mssma_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssma_29") + "ssima " + m.group("Mssma_30") + "idas" in TEXT and not " ou " + m.group("Mssma_29") + "s " + m.group("Mssma_30") + "idas" in TEXT and not "s de " + m.group("Mssma_29") + "s " + m.group("Mssma_30") + "idas" in TEXT and not "s da " + m.group("Mssma_29") + "s " + m.group("Mssma_30") + "idas" in TEXT and not " a " + m.group("Mssma_29") + "s " + m.group("Mssma_30") + "idas" in TEXT and not m.group("Mssma_29") + "ssima-" + m.group("Mssma_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_31>[a-zA-Zç]+[í])ssima (?P<Mssma_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssma_31") + "ssima " + m.group("Mssma_32") + "logas" in TEXT and not " ou " + m.group("Mssma_31") + "ssima " + m.group("Mssma_32") + "logas" in TEXT and not "s de " + m.group("Mssma_31") + "ssima " + m.group("Mssma_32") + "logas" in TEXT and not "s da " + m.group("Mssma_31") + "ssima " + m.group("Mssma_32") + "logas" in TEXT and not " a " + m.group("Mssma_31") + "ssima " + m.group("Mssma_32") + "logas" in TEXT and not m.group("Mssma_31") + "ssima-" + m.group("Mssma_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_33>[a-zA-Zç]+[í])ssima (?P<Mssma_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssma_33") + "ssima " + m.group("Mssma_34") + "rias" in TEXT and not " ou " + m.group("Mssma_33") + "ssima " + m.group("Mssma_34") + "rias" in TEXT and not "s de " + m.group("Mssma_33") + "ssima " + m.group("Mssma_34") + "rias" in TEXT and not "s da " + m.group("Mssma_33") + "ssima " + m.group("Mssma_34") + "rias" in TEXT and not " a " + m.group("Mssma_33") + "ssima " + m.group("Mssma_34") + "rias" in TEXT and not m.group("Mssma_33") + "ssima-" + m.group("Mssma_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_35>[a-zA-Zç]+[í])ssima (?P<Mssma_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssma_35") + "ssima " + m.group("Mssma_36") + "ssimas" in TEXT and not " ou " + m.group("Mssma_35") + "ssima " + m.group("Mssma_36") + "ssimas" in TEXT and not "s de " + m.group("Mssma_35") + "ssima " + m.group("Mssma_36") + "ssimas" in TEXT and not "s da " + m.group("Mssma_35") + "ssima " + m.group("Mssma_36") + "ssimas" in TEXT and not " a " + m.group("Mssma_35") + "ssima " + m.group("Mssma_36") + "ssimas" in TEXT and not m.group("Mssma_35") + "ssima-" + m.group("Mssma_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_37>[a-zA-Zç]+[í])ssima (?P<Mssma_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssma_37") + "ssima " + m.group("Mssma_38") + "simas" in TEXT and not " ou " + m.group("Mssma_37") + "ssima " + m.group("Mssma_38") + "simas" in TEXT and not "s de " + m.group("Mssma_37") + "ssima " + m.group("Mssma_38") + "simas" in TEXT and not "s da " + m.group("Mssma_37") + "ssima " + m.group("Mssma_38") + "simas" in TEXT and not " a " + m.group("Mssma_37") + "ssima " + m.group("Mssma_38") + "simas" in TEXT and not m.group("Mssma_37") + "ssima-" + m.group("Mssma_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_41>[a-zA-Zç]+[í])ssima (?P<Mssma_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssma_42") in "D-d-" and not " e " + m.group("Mssma_41") + "ssima " + m.group("Mssma_42") + "oras" in TEXT and not " ou " + m.group("Mssma_41") + "ssima " + m.group("Mssma_42") + "oras" in TEXT and not "s de " + m.group("Mssma_41") + "ssima " + m.group("Mssma_42") + "oras" in TEXT and not "s da " + m.group("Mssma_41") + "ssima " + m.group("Mssma_42") + "oras" in TEXT and not " a " + m.group("Mssma_41") + "ssima " + m.group("Mssma_42") + "oras" in TEXT and not m.group("Mssma_41") + "ssima-" + m.group("Mssma_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_43>[a-zA-Zç]+[í])ssima (?P<Mssma_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_44") in plvrMfr and not " e " + m.group("Mssma_43") + "ssima " + m.group("Mssma_44") + "es" in TEXT and not " ou " + m.group("Mssma_43") + "ssima " + m.group("Mssma_44") + "es" in TEXT and not "s de " + m.group("Mssma_43") + "ssima " + m.group("Mssma_44") + "es" in TEXT and not "s da " + m.group("Mssma_43") + "ssima " + m.group("Mssma_44") + "es" in TEXT and not " a " + m.group("Mssma_43") + "ssima " + m.group("Mssma_44") + "es" in TEXT and not m.group("Mssma_43") + "ssima-" + m.group("Mssma_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_45>[a-zA-Zç]+[í])ssima (?P<Mssma_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_46") in plvrFemr and not " e " + m.group("Mssma_45") + "ssima " + m.group("Mssma_46") + "es" in TEXT and not " ou " + m.group("Mssma_45") + "ssima " + m.group("Mssma_46") + "es" in TEXT and not "s de " + m.group("Mssma_45") + "ssima " + m.group("Mssma_46") + "es" in TEXT and not "s da " + m.group("Mssma_45") + "ssima " + m.group("Mssma_46") + "es" in TEXT and not " a " + m.group("Mssma_45") + "ssima " + m.group("Mssma_46") + "es" in TEXT and not m.group("Mssma_45") + "ssima-" + m.group("Mssma_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_47>[a-zA-Zç]+[í])ssima (?P<Mssma_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_48") in plvrMfal and not " e " + m.group("Mssma_47") + "ssima " + m.group("Mssma_48") + "is" in TEXT and not " ou " + m.group("Mssma_47") + "ssima " + m.group("Mssma_48") + "is" in TEXT and not "s de " + m.group("Mssma_47") + "ssima " + m.group("Mssma_48") + "is" in TEXT and not "s da " + m.group("Mssma_47") + "ssima " + m.group("Mssma_48") + "is" in TEXT and not " a " + m.group("Mssma_47") + "ssima " + m.group("Mssma_48") + "is" in TEXT and not m.group("Mssma_47") + "ssima-" + m.group("Mssma_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_49>[a-zA-Zç]+[í])ssima (?P<Mssma_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_50") in plvrMfcao and not " e " + m.group("Mssma_49") + "ssima " + m.group("Mssma_50") + "ões" in TEXT and not + " ou " + m.group("Mssma_49") + "ssima " + m.group("Mssma_50") + "ões" in TEXT and not + "s de " + m.group("Mssma_49") + "ssima " + m.group("Mssma_50") + "ões" in TEXT and not + "s da " + m.group("Mssma_49") + "ssima " + m.group("Mssma_50") + "ões" in TEXT and not + " a " + m.group("Mssma_49") + "ssima " + m.group("Mssma_50") + "ões" in TEXT and not m.group("Mssma_49") + "ssima-" + m.group("Mssma_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_51>[a-zA-Zç]+[í])ssima (?P<Mssma_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssma_52") in plvrMascao and not " e " + m.group("Mssma_51") + "ssima " + m.group("Mssma_52") + "ões" in TEXT and not " ou " + m.group("Mssma_51") + "ssima " + m.group("Mssma_52") + "ões" in TEXT and not "s de " + m.group("Mssma_51") + "ssima " + m.group("Mssma_52") + "ões" in TEXT and not "s da " + m.group("Mssma_51") + "ssima " + m.group("Mssma_52") + "ões" in TEXT and not " a " + m.group("Mssma_51") + "ssima " + m.group("Mssma_52") + "ões" in TEXT and not m.group("Mssma_51") + "ssima-" + m.group("Mssma_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_53>[a-zA-Zç]+[í])ssima (?P<Mssma_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_54") in plvrFemao and not " e " + m.group("Mssma_53") + "ssima " + m.group("Mssma_54") + "ões" in TEXT and not " ou " + m.group("Mssma_53") + "ssima " + m.group("Mssma_54") + "ões" in TEXT and not "s de " + m.group("Mssma_53") + "ssima " + m.group("Mssma_54") + "ões" in TEXT and not "s da " + m.group("Mssma_53") + "ssima " + m.group("Mssma_54") + "ões" in TEXT and not " a " + m.group("Mssma_53") + "ssima " + m.group("Mssma_54") + "ões" in TEXT and not m.group("Mssma_53") + "ssima-" + m.group("Mssma_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_55>[a-zA-Zç]+[í])ssima (?P<Mssma_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssma_55") + "ssima " + m.group("Mssma_56") + "veis" in TEXT and not " ou " + m.group("Mssma_55") + "ssima " + m.group("Mssma_56") + "veis" in TEXT and not "s de " + m.group("Mssma_55") + "ssima " + m.group("Mssma_56") + "veis" in TEXT and not "s da " + m.group("Mssma_55") + "ssima " + m.group("Mssma_56") + "veis" in TEXT and not " a " + m.group("Mssma_55") + "ssima " + m.group("Mssma_56") + "veis" in TEXT and not m.group("Mssma_55") + "ssima-" + m.group("Mssma_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_57>[a-zA-Zç]+[í])ssima (?P<Mssma_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_58").lower() in plvrMfe and not " e " + m.group("Mssma_57") + "ssima " + m.group("Mssma_58") + "es" in TEXT and not " ou " + m.group("Mssma_57") + "ssima " + m.group("Mssma_58") + "es" in TEXT and not "s de " + m.group("Mssma_57") + "ssima " + m.group("Mssma_58") + "es" in TEXT and not "s da " + m.group("Mssma_57") + "ssima " + m.group("Mssma_58") + "es" in TEXT and not " a " + m.group("Mssma_57") + "ssima " + m.group("Mssma_58") + "es" in TEXT and not m.group("Mssma_57") + "ssima-" + m.group("Mssma_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_59>[a-zA-Zç]+[í])ssima (?P<Mssma_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_60").lower() in plvrFeme and not " e " + m.group("Mssma_59") + "ssima " + m.group("Mssma_60") + "es" in TEXT and not " ou " + m.group("Mssma_59") + "ssima " + m.group("Mssma_60") + "es" in TEXT and not "s de " + m.group("Mssma_59") + "ssima " + m.group("Mssma_60") + "es" in TEXT and not "s da " + m.group("Mssma_59") + "ssima " + m.group("Mssma_60") + "es" in TEXT and not " a " + m.group("Mssma_59") + "ssima " + m.group("Mssma_60") + "es" in TEXT and not m.group("Mssma_59") + "ssima-" + m.group("Mssma_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_61>[a-zA-Zç]+[í])ssima (?P<Mssma_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_62") in plvrMfel and not " e " + m.group("Mssma_61") + "ssima " + m.group("Mssma_62") + "éis" in TEXT and not " ou " + m.group("Mssma_61") + "ssima " + m.group("Mssma_62") + "éis" in TEXT and not "s de " + m.group("Mssma_61") + "ssima " + m.group("Mssma_62") + "éis" in TEXT and not "s da " + m.group("Mssma_61") + "ssima " + m.group("Mssma_62") + "éis" in TEXT and not " a " + m.group("Mssma_61") + "ssima " + m.group("Mssma_62") + "éis" in TEXT and not m.group("Mssma_61") + "ssima-" + m.group("Mssma_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_63>[a-zA-Zç]+[í])ssima (?P<Mssma_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_64") in plvrFemel and not " e " + m.group("Mssma_63") + "ssima " + m.group("Mssma_64") + "éis" in TEXT and not " ou " + m.group("Mssma_63") + "ssima " + m.group("Mssma_64") + "éis" in TEXT and not "s de " + m.group("Mssma_63") + "ssima " + m.group("Mssma_64") + "éis" in TEXT and not "s da " + m.group("Mssma_63") + "ssima " + m.group("Mssma_64") + "éis" in TEXT and not " a " + m.group("Mssma_63") + "ssima " + m.group("Mssma_64") + "éis" in TEXT and not m.group("Mssma_63") + "ssima-" + m.group("Mssma_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_65>[a-zA-Zç]+[í])ssima (?P<Mssma_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_66") in plvrMfeu and not " e " + m.group("Mssma_65") + "ssima " + m.group("Mssma_66") + "us" in TEXT and not " ou " + m.group("Mssma_65") + "ssima " + m.group("Mssma_66") + "us" in TEXT and not "s de " + m.group("Mssma_65") + "ssima " + m.group("Mssma_66") + "us" in TEXT and not "s da " + m.group("Mssma_65") + "ssima " + m.group("Mssma_66") + "us" in TEXT and not " a " + m.group("Mssma_65") + "ssima " + m.group("Mssma_66") + "us" in TEXT and not m.group("Mssma_65") + "ssima-" + m.group("Mssma_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_67>[a-zA-Zç]+[í])ssima (?P<Mssma_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_68") in plvrFemu and not " e " + m.group("Mssma_67") + "ssima " + m.group("Mssma_68") + "us" in TEXT and not " ou " + m.group("Mssma_67") + "ssima " + m.group("Mssma_68") + "us" in TEXT and not "s de " + m.group("Mssma_67") + "ssima " + m.group("Mssma_68") + "us" in TEXT and not "s da " + m.group("Mssma_67") + "ssima " + m.group("Mssma_68") + "us" in TEXT and not " a " + m.group("Mssma_67") + "ssima " + m.group("Mssma_68") + "us" in TEXT and not m.group("Mssma_67") + "ssima-" + m.group("Mssma_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_69>[a-zA-Zç]+[í])ssima (?P<Mssma_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_70") in plvrInvaz and not " e " + m.group("Mssma_69") + "ssima " + m.group("Mssma_70") + "zes" in TEXT and not " ou " + m.group("Mssma_69") + "ssima " + m.group("Mssma_70") + "zes" in TEXT and not "s de " + m.group("Mssma_69") + "ssima " + m.group("Mssma_70") + "zes" in TEXT and not "s da " + m.group("Mssma_69") + "ssima " + m.group("Mssma_70") + "zes" in TEXT and not " a " + m.group("Mssma_69") + "ssima " + m.group("Mssma_70") + "zes" in TEXT and not m.group("Mssma_69") + "ssima-" + m.group("Mssma_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_71>[a-zA-Zç]+[í])ssima (?P<Mssma_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_72") in plvrFemz and not " e " + m.group("Mssma_71") + "ssima " + m.group("Mssma_72") + "zes" in TEXT and not " ou " + m.group("Mssma_71") + "ssima " + m.group("Mssma_72") + "zes" in TEXT and not "s de " + m.group("Mssma_71") + "ssima " + m.group("Mssma_72") + "zes" in TEXT and not "s da " + m.group("Mssma_71") + "ssima " + m.group("Mssma_72") + "zes" in TEXT and not " a " + m.group("Mssma_71") + "ssima " + m.group("Mssma_72") + "zes" in TEXT and not m.group("Mssma_71") + "ssima-" + m.group("Mssma_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_73>[a-zA-Zç]+[í])ssima (?P<Mssma_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_74") in pvrFeman and not " e " + m.group("Mssma_73") + "ssima " + m.group("Mssma_74") + "s" in TEXT and not " ou " + m.group("Mssma_73") + "ssima " + m.group("Mssma_74") + "s" in TEXT and not "s de " + m.group("Mssma_73") + "ssima " + m.group("Mssma_74") + "s" in TEXT and not "s da " + m.group("Mssma_73") + "ssima " + m.group("Mssma_74") + "s" in TEXT and not " a " + m.group("Mssma_73") + "ssima " + m.group("Mssma_74") + "s" in TEXT and not m.group("Mssma_73") + "ssima-" + m.group("Mssma_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_99>[a-zA-Zç]+[í])ssima (?P<Mssma_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_100") in plvrMFm and not " e " + m.group("Mssma_99") + "ssima " + m.group("Mssma_100") + "ns" in TEXT and not " ou " + m.group("Mssma_99") + "ssima " + m.group("Mssma_100") + "ns" in TEXT and not "s de " + m.group("Mssma_99") + "ssima " + m.group("Mssma_100") + "ns" in TEXT and not "s da " + m.group("Mssma_99") + "ssima " + m.group("Mssma_100") + "ns" in TEXT and not " a " + m.group("Mssma_99") + "ssima " + m.group("Mssma_100") + "ns" in TEXT and not m.group("Mssma_99") + "ssima-" + m.group("Mssma_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssma_101>[a-zA-Zç]+[í])ssima (?P<Mssma_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ssimas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssma_102") in plvrFemm and not " e " + m.group("Mssma_101") + "ssima " + m.group("Mssma_102") + "ns" in TEXT and not " ou " + m.group("Mssma_101") + "ssima " + m.group("Mssma_102") + "ns" in TEXT and not "s de " + m.group("Mssma_101") + "ssima " + m.group("Mssma_102") + "ns" in TEXT and not "s da " + m.group("Mssma_101") + "ssima " + m.group("Mssma_102") + "ns" in TEXT and not " a " + m.group("Mssma_101") + "ssima " + m.group("Mssma_102") + "ns" in TEXT and not m.group("Mssma_101") + "ssima-" + m.group("Mssma_102") + "ns" in tCompostops'],
# issimo o
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_1>[a-zA-Zç]+[í])ssimo (?P<Mssmo_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_2").lower() in plvrMasca and not " e " + m.group("Mssmo_1") + "ssimo " + m.group("Mssmo_2") +"s" in TEXT and not " ou " + m.group("Mssmo_1") + "ssimo " + m.group("Mssmo_2") + "s" in TEXT and not "s de " + m.group("Mssmo_1") + "ssimo " + m.group("Mssmo_2") + "s" in TEXT and not "s do " + m.group("Mssmo_1") + "ssimo " + m.group("Mssmo_2") + "s" in TEXT and not " o " + m.group("Mssmo_1") + "ssimo " + m.group("Mssmo_2") + "s" in TEXT and not m.group("Mssmo_1") + "ssimo-" + m.group("Mssmo_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_3>[a-zA-Zç]+[í])ssimo (?P<Mssmo_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_4").lower() in plvrMfoa and not " e " + m.group("Mssmo_3") + "ssimo " + m.group("Mssmo_4") + "os" in TEXT and not " ou " + m.group("Mssmo_3") + "ssimo " + m.group("Mssmo_4") + "os" in TEXT and not "s de " + m.group("Mssmo_3") + "ssimo " + m.group("Mssmo_4") + "os" in TEXT and not "s do " + m.group("Mssmo_3") + "ssimo " + m.group("Mssmo_4") + "os" in TEXT and not " o " + m.group("Mssmo_3") + "ssimo " + m.group("Mssmo_4") + "os" in TEXT and not m.group("Mssmo_3") + "ssimo-" + m.group("Mssmo_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_5>[a-zA-Zç]+[í])ssimo (?P<Mssmo_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssmo_6").lower() in excAdo and not " e " + m.group("Mssmo_5") + "ssimo " + m.group("Mssmo_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Mssmo_5") + "ssimo " + m.group("Mssmo_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Mssmo_5") + "ssimo " + m.group("Mssmo_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Mssmo_5") + "ssimo " + m.group("Mssmo_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Mssmo_5") + "ssimo " + m.group("Mssmo_6") + m.group(3) + "dos" in TEXT and not m.group("Mssmo_5") + "ssimo-" + m.group("Mssmo_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_7>[a-zA-Zç]+[í])ssimo (?P<Mssmo_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssmo_8").lower() in excIsta and not " e " + m.group("Mssmo_7") + "ssimo " + m.group("Mssmo_8") + "s" in TEXT and not " ou " + m.group("Mssmo_7") + "ssimo " + m.group("Mssmo_8") + "s" in TEXT and not "s de " + m.group("Mssmo_7") + "ssimo " + m.group("Mssmo_8") + "s" in TEXT and not "s do " + m.group("Mssmo_7") + "ssimo " + m.group("Mssmo_8") + "s" in TEXT and not " o " + m.group("Mssmo_7") + "ssimo " + m.group("Mssmo_8") + "s" in TEXT and not m.group("Mssmo_7") + "ssimo-" + m.group("Mssmo_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_9>[a-zA-Zç]+[í])ssimo (?P<Mssmo_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_10").lower() in plvrInva and not " e " + m.group("Mssmo_9") + "ssimo " + m.group("Mssmo_10") + "s" in TEXT and not " ou " + m.group("Mssmo_9") + "ssimo " + m.group("Mssmo_10") + "s" in TEXT and not "s de " + m.group("Mssmo_9") + "ssimo " + m.group("Mssmo_10") + "s" in TEXT and not "s do " + m.group("Mssmo_9") + "ssimo " + m.group("Mssmo_10") + "s" in TEXT and not " a " + m.group("Mssmo_9") + "ssimo " + m.group("Mssmo_10") + "s" in TEXT and not m.group("Mssmo_9") + "ssimo-" + m.group("Mssmo_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_11>[a-zA-Zç]+[í])ssimo (?P<Mssmo_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssmo_12").lower() in excAdo and not " e " + m.group("Mssmo_11") + "ssimo " + m.group("Mssmo_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Mssmo_11") + "ssimo " + m.group("Mssmo_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Mssmo_11") + "ssimo " + m.group("Mssmo_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Mssmo_11") + "ssimo " + m.group("Mssmo_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Mssmo_11") + "ssimo " + m.group("Mssmo_12") + m.group(3) + "das" in TEXT and not m.group("Mssmo_11") + "ssimo-" + m.group("Mssmo_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_13>[a-zA-Zç]+[í])ssimo (?P<Mssmo_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_13") + "ssimo " + m.group("Mssmo_14") + "osos" in TEXT and not " ou " + m.group("Mssmo_13") + "ssimo " + m.group("Mssmo_14") + "osos" in TEXT and not "s de " + m.group("Mssmo_13") + "ssimo " + m.group("Mssmo_14") + "osos" in TEXT and not "s do " + m.group("Mssmo_13") + "ssimo " + m.group("Mssmo_14") + "osos" in TEXT and not " o " + m.group("Mssmo_13") + "ssimo " + m.group("Mssmo_14") + "osos" in TEXT and not m.group("Mssmo_13") + "ssimo-" + m.group("Mssmo_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_15>[a-zA-Zç]+[í])ssimo (?P<Mssmo_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_15") + "ssimo " + m.group("Mssmo_16") + "osas" in TEXT and not " ou " + m.group("Mssmo_15") + "ssimo " + m.group("Mssmo_16") + "osas" in TEXT and not "s de " + m.group("Mssmo_15") + "ssimo " + m.group("Mssmo_16") + "osas" in TEXT and not "s do " + m.group("Mssmo_15") + "ssimo " + m.group("Mssmo_16") + "osas" in TEXT and not " o " + m.group("Mssmo_15") + "ssimo " + m.group("Mssmo_16") + "osas" in TEXT and not m.group("Mssmo_15") + "ssimo-" + m.group("Mssmo_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_17>[a-zA-Zç]+[í])ssimo (?P<Mssmo_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_17") + "ssimo " + m.group("Mssmo_18") + "ivas" in TEXT and not " ou " + m.group("Mssmo_17") + "ssimo " + m.group("Mssmo_18") + "ivas" in TEXT and not "s de " + m.group("Mssmo_17") + "ssimo " + m.group("Mssmo_18") + "ivas" in TEXT and not "s do " + m.group("Mssmo_17") + "ssimo " + m.group("Mssmo_18") + "ivas" in TEXT and not " o " + m.group("Mssmo_17") + "ssimo " + m.group("Mssmo_18") + "ivas" in TEXT and not m.group("Mssmo_17") + "ssimo-" + m.group("Mssmo_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_19>[a-zA-Zç]+[í])ssimo (?P<Mssmo_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_19") + "ssimo " + m.group("Mssmo_20") + "ivas" in TEXT and not " ou " + m.group("Mssmo_19") + "ssimo " + m.group("Mssmo_20") + "ivas" in TEXT and not "s de " + m.group("Mssmo_19") + "ssimo " + m.group("Mssmo_20") + "ivas" in TEXT and not "s do " + m.group("Mssmo_19") + "ssimo " + m.group("Mssmo_20") + "ivas" in TEXT and not " o " + m.group("Mssmo_19") + "ssimo " + m.group("Mssmo_20") + "ivas" in TEXT and not m.group("Mssmo_19") + "ssimo-" + m.group("Mssmo_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_21>[a-zA-Zç]+[í])ssimo (?P<Mssmo_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_21") + "ssimo " + m.group("Mssmo_22") + "icos" in TEXT and not " ou " + m.group("Mssmo_21") + "ssimo " + m.group("Mssmo_22") + "icos" in TEXT and not "s de " + m.group("Mssmo_21") + "ssimo " + m.group("Mssmo_22") + "icos" in TEXT and not "s do " + m.group("Mssmo_21") + "ssimo " + m.group("Mssmo_22") + "icos" in TEXT and not " o " + m.group("Mssmo_21") + "ssimo " + m.group("Mssmo_22") + "icos" in TEXT and not m.group("Mssmo_21") + "ssimo-" + m.group("Mssmo_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_23>[a-zA-Zç]+[í])ssimo (?P<Mssmo_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_23") + "ssimo " + m.group("Mssmo_24") + "icos" in TEXT and not " ou " + m.group("Mssmo_23") + "ssimo " + m.group("Mssmo_24") + "icos" in TEXT and not "s de " + m.group("Mssmo_23") + "ssimo " + m.group("Mssmo_24") + "icos" in TEXT and not "s do " + m.group("Mssmo_23") + "ssimo " + m.group("Mssmo_24") + "icos" in TEXT and not " o " + m.group("Mssmo_23") + "ssimo " + m.group("Mssmo_24") + "icos" in TEXT and not m.group("Mssmo_23") + "ssimo-" + m.group("Mssmo_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_25>[a-zA-Zç]+[í])ssimo (?P<Mssmo_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_25") + "ssimo " + m.group("Mssmo_26") + "icos" in TEXT and not " ou " + m.group("Mssmo_25") + "ssimo " + m.group("Mssmo_26") + "icos" in TEXT and not "s de " + m.group("Mssmo_25") + "ssimo " + m.group("Mssmo_26") + "icos" in TEXT and not "s do " + m.group("Mssmo_25") + "ssimo " + m.group("Mssmo_26") + "icos" in TEXT and not " o " + m.group("Mssmo_25") + "ssimo " + m.group("Mssmo_26") + "icos" in TEXT and not m.group("Mssmo_25") + "ssimo-" + m.group("Mssmo_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_27>[a-zA-Zç]+[í])ssimo (?P<Mssmo_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_27") + "ssimo " + m.group("Mssmo_28") + "escos" in TEXT and not " ou " + m.group("Mssmo_27") + "ssimo " + m.group("Mssmo_28") + "escos" in TEXT and not "s de " + m.group("Mssmo_27") + "ssimo " + m.group("Mssmo_28") + "escos" in TEXT and not "s do " + m.group("Mssmo_27") + "ssimo " + m.group("Mssmo_28") + "escos" in TEXT and not " o " + m.group("Mssmo_27") + "ssimo " + m.group("Mssmo_28") + "escos" in TEXT and not m.group("Mssmo_27") + "ssimo-" + m.group("Mssmo_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_29>[a-zA-Zç]+[í])ssimo (?P<Mssmo_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_29") + "ssimo " + m.group("Mssmo_30") + "idos" in TEXT and not " ou " + m.group("Mssmo_29") + "s " + m.group("Mssmo_30") + "idos" in TEXT and not "s de " + m.group("Mssmo_29") + "s " + m.group("Mssmo_30") + "idos" in TEXT and not "s do " + m.group("Mssmo_29") + "s " + m.group("Mssmo_30") + "idos" in TEXT and not " o " + m.group("Mssmo_29") + "s " + m.group("Mssmo_30") + "idos" in TEXT and not m.group("Mssmo_29") + "ssimo-" + m.group("Mssmo_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_31>[a-zA-Zç]+[í])ssimo (?P<Mssmo_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_31") + "ssimo " + m.group("Mssmo_32") + "logos" in TEXT and not " ou " + m.group("Mssmo_31") + "ssimo " + m.group("Mssmo_32") + "logos" in TEXT and not "s de " + m.group("Mssmo_31") + "ssimo " + m.group("Mssmo_32") + "logos" in TEXT and not "s do " + m.group("Mssmo_31") + "ssimo " + m.group("Mssmo_32") + "logos" in TEXT and not " o " + m.group("Mssmo_31") + "ssimo " + m.group("Mssmo_32") + "logos" in TEXT and not m.group("Mssmo_31") + "ssimo-" + m.group("Mssmo_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_33>[a-zA-Zç]+[í])ssimo (?P<Mssmo_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_33") + "ssimo " + m.group("Mssmo_34") + "rios" in TEXT and not " ou " + m.group("Mssmo_33") + "ssimo " + m.group("Mssmo_34") + "rios" in TEXT and not "s de " + m.group("Mssmo_33") + "ssimo " + m.group("Mssmo_34") + "rios" in TEXT and not "s do " + m.group("Mssmo_33") + "ssimo " + m.group("Mssmo_34") + "rios" in TEXT and not " o " + m.group("Mssmo_33") + "ssimo " + m.group("Mssmo_34") + "rios" in TEXT and not m.group("Mssmo_33") + "ssimo-" + m.group("Mssmo_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_35>[a-zA-Zç]+[í])ssimo (?P<Mssmo_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_35") + "ssimo " + m.group("Mssmo_36") + "ssimos" in TEXT and not " ou " + m.group("Mssmo_35") + "ssimo " + m.group("Mssmo_36") + "ssimos" in TEXT and not "s de " + m.group("Mssmo_35") + "ssimo " + m.group("Mssmo_36") + "ssimos" in TEXT and not "s do " + m.group("Mssmo_35") + "ssimo " + m.group("Mssmo_36") + "ssimos" in TEXT and not " o " + m.group("Mssmo_35") + "ssimo " + m.group("Mssmo_36") + "ssimos" in TEXT and not m.group("Mssmo_35") + "ssimo-" + m.group("Mssmo_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_37>[a-zA-Zç]+[í])ssimo (?P<Mssmo_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_37") + "ssimo " + m.group("Mssmo_38") + "simos" in TEXT and not " ou " + m.group("Mssmo_37") + "ssimo " + m.group("Mssmo_38") + "simos" in TEXT and not "s de " + m.group("Mssmo_37") + "ssimo " + m.group("Mssmo_38") + "simos" in TEXT and not "s do " + m.group("Mssmo_37") + "ssimo " + m.group("Mssmo_38") + "simos" in TEXT and not " o " + m.group("Mssmo_37") + "ssimo " + m.group("Mssmo_38") + "simos" in TEXT and not m.group("Mssmo_37") + "ssimo-" + m.group("Mssmo_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_41>[a-zA-Zç]+[í])ssimo (?P<Mssmo_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mssmo_42") in "D-d-" and not " e " + m.group("Mssmo_41") + "ssimo " + m.group("Mssmo_42") + "ores" in TEXT and not " ou " + m.group("Mssmo_41") + "ssimo " + m.group("Mssmo_42") + "ores" in TEXT and not "s de " + m.group("Mssmo_41") + "ssimo " + m.group("Mssmo_42") + "ores" in TEXT and not "s do " + m.group("Mssmo_41") + "ssimo " + m.group("Mssmo_42") + "ores" in TEXT and not " o " + m.group("Mssmo_41") + "ssimo " + m.group("Mssmo_42") + "ores" in TEXT and not m.group("Mssmo_41") + "ssimo-" + m.group("Mssmo_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_43>[a-zA-Zç]+[í])ssimo (?P<Mssmo_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_44") in plvrMfr and not " e " + m.group("Mssmo_43") + "ssimo " + m.group("Mssmo_44") + "es" in TEXT and not " ou " + m.group("Mssmo_43") + "ssimo " + m.group("Mssmo_44") + "es" in TEXT and not "s de " + m.group("Mssmo_43") + "ssimo " + m.group("Mssmo_44") + "es" in TEXT and not "s do " + m.group("Mssmo_43") + "ssimo " + m.group("Mssmo_44") + "es" in TEXT and not " o " + m.group("Mssmo_43") + "ssimo " + m.group("Mssmo_44") + "es" in TEXT and not m.group("Mssmo_43") + "ssimo-" + m.group("Mssmo_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_45>[a-zA-Zç]+[í])ssimo (?P<Mssmo_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_46") in plvrMascr and not " e " + m.group("Mssmo_45") + "ssimo " + m.group("Mssmo_46") + "es" in TEXT and not " ou " + m.group("Mssmo_45") + "ssimo " + m.group("Mssmo_46") + "es" in TEXT and not "s de " + m.group("Mssmo_45") + "ssimo " + m.group("Mssmo_46") + "es" in TEXT and not "s do " + m.group("Mssmo_45") + "ssimo " + m.group("Mssmo_46") + "es" in TEXT and not " o " + m.group("Mssmo_45") + "ssimo " + m.group("Mssmo_46") + "es" in TEXT and not m.group("Mssmo_45") + "ssimo-" + m.group("Mssmo_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_47>[a-zA-Zç]+[í])ssimo (?P<Mssmo_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_48") in plvrMfal and not " e " + m.group("Mssmo_47") + "ssimo " + m.group("Mssmo_48") + "is" in TEXT and not " ou " + m.group("Mssmo_47") + "ssimo " + m.group("Mssmo_48") + "is" in TEXT and not "s de " + m.group("Mssmo_47") + "ssimo " + m.group("Mssmo_48") + "is" in TEXT and not "s do " + m.group("Mssmo_47") + "ssimo " + m.group("Mssmo_48") + "is" in TEXT and not " o " + m.group("Mssmo_47") + "ssimo " + m.group("Mssmo_48") + "is" in TEXT and not m.group("Mssmo_47") + "ssimo-" + m.group("Mssmo_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_49>[a-zA-Zç]+[í])ssimo (?P<Mssmo_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_50") in plvrMfcao and not " e " + m.group("Mssmo_49") + "ssimo " + m.group("Mssmo_50") + "ões" in TEXT and not + " ou " + m.group("Mssmo_49") + "ssimo " + m.group("Mssmo_50") + "ões" in TEXT and not + "s de " + m.group("Mssmo_49") + "ssimo " + m.group("Mssmo_50") + "ões" in TEXT and not + "s do " + m.group("Mssmo_49") + "ssimo " + m.group("Mssmo_50") + "ões" in TEXT and not + " a " + m.group("Mssmo_49") + "ssimo " + m.group("Mssmo_50") + "ões" in TEXT and not m.group("Mssmo_49") + "ssimo-" + m.group("Mssmo_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_51>[a-zA-Zç]+[í])ssimo (?P<Mssmo_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_52") in plvrNfemcao and not " e " + m.group("Mssmo_51") + "ssimo " + m.group("Mssmo_52") + "ões" in TEXT and not " ou " + m.group("Mssmo_51") + "ssimo " + m.group("Mssmo_52") + "ões" in TEXT and not "s de " + m.group("Mssmo_51") + "ssimo " + m.group("Mssmo_52") + "ões" in TEXT and not "s do " + m.group("Mssmo_51") + "ssimo " + m.group("Mssmo_52") + "ões" in TEXT and not " o " + m.group("Mssmo_51") + "ssimo " + m.group("Mssmo_52") + "ões" in TEXT and not m.group("Mssmo_51") + "ssimo-" + m.group("Mssmo_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_55>[a-zA-Zç]+[í])ssimo (?P<Mssmo_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_55") + "ssimo " + m.group("Mssmo_56") + "veis" in TEXT and not " ou " + m.group("Mssmo_55") + "ssimo " + m.group("Mssmo_56") + "veis" in TEXT and not "s de " + m.group("Mssmo_55") + "ssimo " + m.group("Mssmo_56") + "veis" in TEXT and not "s do " + m.group("Mssmo_55") + "ssimo " + m.group("Mssmo_56") + "veis" in TEXT and not " o " + m.group("Mssmo_55") + "ssimo " + m.group("Mssmo_56") + "veis" in TEXT and not m.group("Mssmo_55") + "ssimo-" + m.group("Mssmo_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_57>[a-zA-Zç]+[í])ssimo (?P<Mssmo_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_58").lower() in plvrMfe and not " e " + m.group("Mssmo_57") + "ssimo " + m.group("Mssmo_58") + "es" in TEXT and not " ou " + m.group("Mssmo_57") + "ssimo " + m.group("Mssmo_58") + "es" in TEXT and not "s de " + m.group("Mssmo_57") + "ssimo " + m.group("Mssmo_58") + "es" in TEXT and not "s do " + m.group("Mssmo_57") + "ssimo " + m.group("Mssmo_58") + "es" in TEXT and not " o " + m.group("Mssmo_57") + "ssimo " + m.group("Mssmo_58") + "es" in TEXT and not m.group("Mssmo_57") + "ssimo-" + m.group("Mssmo_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_59>[a-zA-Zç]+[í])ssimo (?P<Mssmo_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_60").lower() in plvrMasce and not " e " + m.group("Mssmo_59") + "ssimo " + m.group("Mssmo_60") + "es" in TEXT and not " ou " + m.group("Mssmo_59") + "ssimo " + m.group("Mssmo_60") + "es" in TEXT and not "s de " + m.group("Mssmo_59") + "ssimo " + m.group("Mssmo_60") + "es" in TEXT and not "s do " + m.group("Mssmo_59") + "ssimo " + m.group("Mssmo_60") + "es" in TEXT and not " o " + m.group("Mssmo_59") + "ssimo " + m.group("Mssmo_60") + "es" in TEXT and not m.group("Mssmo_59") + "ssimo-" + m.group("Mssmo_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_61>[a-zA-Zç]+[í])ssimo (?P<Mssmo_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_62") in plvrMfel and not " e " + m.group("Mssmo_61") + "ssimo " + m.group("Mssmo_62") + "éis" in TEXT and not " ou " + m.group("Mssmo_61") + "ssimo " + m.group("Mssmo_62") + "éis" in TEXT and not "s de " + m.group("Mssmo_61") + "ssimo " + m.group("Mssmo_62") + "éis" in TEXT and not "s do " + m.group("Mssmo_61") + "ssimo " + m.group("Mssmo_62") + "éis" in TEXT and not " o " + m.group("Mssmo_61") + "ssimo " + m.group("Mssmo_62") + "éis" in TEXT and not m.group("Mssmo_61") + "ssimo-" + m.group("Mssmo_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_63>[a-zA-Zç]+[í])ssimo (?P<Mssmo_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_64") in plvrMascel and not " e " + m.group("Mssmo_63") + "ssimo " + m.group("Mssmo_64") + "éis" in TEXT and not " ou " + m.group("Mssmo_63") + "ssimo " + m.group("Mssmo_64") + "éis" in TEXT and not "s de " + m.group("Mssmo_63") + "ssimo " + m.group("Mssmo_64") + "éis" in TEXT and not "s do " + m.group("Mssmo_63") + "ssimo " + m.group("Mssmo_64") + "éis" in TEXT and not " o " + m.group("Mssmo_63") + "ssimo " + m.group("Mssmo_64") + "éis" in TEXT and not m.group("Mssmo_63") + "ssimo-" + m.group("Mssmo_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_65>[a-zA-Zç]+[í])ssimo (?P<Mssmo_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_66") in plvrMfeu and not " e " + m.group("Mssmo_65") + "ssimo " + m.group("Mssmo_66") + "us" in TEXT and not " ou " + m.group("Mssmo_65") + "ssimo " + m.group("Mssmo_66") + "us" in TEXT and not "s de " + m.group("Mssmo_65") + "ssimo " + m.group("Mssmo_66") + "us" in TEXT and not "s do " + m.group("Mssmo_65") + "ssimo " + m.group("Mssmo_66") + "us" in TEXT and not " o " + m.group("Mssmo_65") + "ssimo " + m.group("Mssmo_66") + "us" in TEXT and not m.group("Mssmo_65") + "ssimo-" + m.group("Mssmo_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_67>[a-zA-Zç]+[í])ssimo (?P<Mssmo_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_68") in plvrMascu and not " e " + m.group("Mssmo_67") + "ssimo " + m.group("Mssmo_68") + "us" in TEXT and not " ou " + m.group("Mssmo_67") + "ssimo " + m.group("Mssmo_68") + "us" in TEXT and not "s de " + m.group("Mssmo_67") + "ssimo " + m.group("Mssmo_68") + "us" in TEXT and not "s do " + m.group("Mssmo_67") + "ssimo " + m.group("Mssmo_68") + "us" in TEXT and not " o " + m.group("Mssmo_67") + "ssimo " + m.group("Mssmo_68") + "us" in TEXT and not m.group("Mssmo_67") + "ssimo-" + m.group("Mssmo_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_69>[a-zA-Zç]+[í])ssimo (?P<Mssmo_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_70") in plvrInvaz and not " e " + m.group("Mssmo_69") + "ssimo " + m.group("Mssmo_70") + "zes" in TEXT and not " ou " + m.group("Mssmo_69") + "ssimo " + m.group("Mssmo_70") + "zes" in TEXT and not "s de " + m.group("Mssmo_69") + "ssimo " + m.group("Mssmo_70") + "zes" in TEXT and not "s do " + m.group("Mssmo_69") + "ssimo " + m.group("Mssmo_70") + "zes" in TEXT and not " o " + m.group("Mssmo_69") + "ssimo " + m.group("Mssmo_70") + "zes" in TEXT and not m.group("Mssmo_69") + "ssimo-" + m.group("Mssmo_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_71>[a-zA-Zç]+[í])ssimo (?P<Mssmo_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_72") in plvrMascz and not " e " + m.group("Mssmo_71") + "ssimo " + m.group("Mssmo_72") + "zes" in TEXT and not " ou " + m.group("Mssmo_71") + "ssimo " + m.group("Mssmo_72") + "zes" in TEXT and not "s de " + m.group("Mssmo_71") + "ssimo " + m.group("Mssmo_72") + "zes" in TEXT and not "s do " + m.group("Mssmo_71") + "ssimo " + m.group("Mssmo_72") + "zes" in TEXT and not " o " + m.group("Mssmo_71") + "ssimo " + m.group("Mssmo_72") + "zes" in TEXT and not m.group("Mssmo_71") + "ssimo-" + m.group("Mssmo_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_73>[a-zA-Zç]+[í])ssimo (?P<Mssmo_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_74") in pvrMascan and not " e " + m.group("Mssmo_73") + "ssimo " + m.group("Mssmo_74") + "s" in TEXT and not " ou " + m.group("Mssmo_73") + "ssimo " + m.group("Mssmo_74") + "s" in TEXT and not "s de " + m.group("Mssmo_73") + "ssimo " + m.group("Mssmo_74") + "s" in TEXT and not "s do " + m.group("Mssmo_73") + "ssimo " + m.group("Mssmo_74") + "s" in TEXT and not " o " + m.group("Mssmo_73") + "ssimo " + m.group("Mssmo_74") + "s" in TEXT and not m.group("Mssmo_73") + "ssimo-" + m.group("Mssmo_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_75>[a-zA-Zç]+[í])ssimo (?P<Mssmo_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_76").lower() in plvrMasco and not " e " + m.group("Mssmo_75") + "ssimo " + m.group("Mssmo_76") +"s" in TEXT and not " ou " + m.group("Mssmo_75") + "ssimo " + m.group("Mssmo_76") + "s" in TEXT and not "s de " + m.group("Mssmo_75") + "ssimo " + m.group("Mssmo_76") + "s" in TEXT and not "s do " + m.group("Mssmo_75") + "ssimo " + m.group("Mssmo_76") + "s" in TEXT and not " o " + m.group("Mssmo_75") + "ssimo " + m.group("Mssmo_76") + "s" in TEXT and not m.group("Mssmo_75") + "ssimo-" + m.group("Mssmo_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_77>[a-zA-Zç]+[í])ssimo (?P<Mssmo_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_77") + "ssimo " + m.group("Mssmo_78") + "inhos" in TEXT and not " ou " + m.group("Mssmo_77") + "ssimo " + m.group("Mssmo_78") + "inhos" in TEXT and not "s de " + m.group("Mssmo_77") + "ssimo " + m.group("Mssmo_78") + "inhos" in TEXT and not "s do " + m.group("Mssmo_77") + "ssimo " + m.group("Mssmo_78") + "inhos" in TEXT and not " o " + m.group("Mssmo_77") + "ssimo " + m.group("Mssmo_78") + "inhos" in TEXT and not m.group("Mssmo_77") + "ssimo-" + m.group("Mssmo_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_79>[a-zA-Zç]+[í])ssimo (?P<Mssmo_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_79") + "ssimo " + m.group("Mssmo_80") + "icas" in TEXT and not " ou " + m.group("Mssmo_79") + "ssimo " + m.group("Mssmo_80") + "icas" in TEXT and not "s de " + m.group("Mssmo_79") + "ssimo " + m.group("Mssmo_80") + "icas" in TEXT and not "s do " + m.group("Mssmo_79") + "ssimo " + m.group("Mssmo_80") + "icas" in TEXT and not " o " + m.group("Mssmo_79") + "ssimo " + m.group("Mssmo_80") + "icas" in TEXT and not m.group("Mssmo_79") + "ssimo-" + m.group("Mssmo_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_81>[a-zA-Zç]+[í])ssimo (?P<Mssmo_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_81") + "ssimo " + m.group("Mssmo_82") + "icas" in TEXT and not " ou " + m.group("Mssmo_81") + "ssimo " + m.group("Mssmo_82") + "icas" in TEXT and not "s de " + m.group("Mssmo_81") + "ssimo " + m.group("Mssmo_82") + "icas" in TEXT and not "s do " + m.group("Mssmo_81") + "ssimo " + m.group("Mssmo_82") + "icas" in TEXT and not " o " + m.group("Mssmo_81") + "ssimo " + m.group("Mssmo_82") + "icas" in TEXT and not m.group("Mssmo_81") + "ssimo-" + m.group("Mssmo_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_83>[a-zA-Zç]+[í])ssimo (?P<Mssmo_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_83") + "ssimo " + m.group("Mssmo_84") + "icas" in TEXT and not " ou " + m.group("Mssmo_83") + "ssimo " + m.group("Mssmo_84") + "icas" in TEXT and not "s de " + m.group("Mssmo_83") + "ssimo " + m.group("Mssmo_84") + "icas" in TEXT and not "s do " + m.group("Mssmo_83") + "ssimo " + m.group("Mssmo_84") + "icas" in TEXT and not " o " + m.group("Mssmo_83") + "ssimo " + m.group("Mssmo_84") + "icas" in TEXT and not m.group("Mssmo_83") + "ssimo-" + m.group("Mssmo_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_85>[a-zA-Zç]+[í])ssimo (?P<Mssmo_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_85") + "ssimo " + m.group("Mssmo_86") + "escas" in TEXT and not " ou " + m.group("Mssmo_85") + "ssimo " + m.group("Mssmo_86") + "escas" in TEXT and not "s de " + m.group("Mssmo_85") + "ssimo " + m.group("Mssmo_86") + "escas" in TEXT and not "s do " + m.group("Mssmo_85") + "ssimo " + m.group("Mssmo_86") + "escas" in TEXT and not " o " + m.group("Mssmo_85") + "ssimo " + m.group("Mssmo_86") + "escas" in TEXT and not m.group("Mssmo_85") + "ssimo-" + m.group("Mssmo_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_87>[a-zA-Zç]+[í])ssimo (?P<Mssmo_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_87") + "ssimo " + m.group("Mssmo_88") + "idas" in TEXT and not " ou " + m.group("Mssmo_87") + "s " + m.group("Mssmo_88") + "idas" in TEXT and not "s de " + m.group("Mssmo_87") + "s " + m.group("Mssmo_88") + "idas" in TEXT and not "s do " + m.group("Mssmo_87") + "s " + m.group("Mssmo_88") + "idas" in TEXT and not " o " + m.group("Mssmo_87") + "s " + m.group("Mssmo_88") + "idas" in TEXT and not m.group("Mssmo_87") + "ssimo-" + m.group("Mssmo_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_89>[a-zA-Zç]+[í])ssimo (?P<Mssmo_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_89") + "ssimo " + m.group("Mssmo_90") + "logas" in TEXT and not " ou " + m.group("Mssmo_89") + "ssimo " + m.group("Mssmo_90") + "logas" in TEXT and not "s de " + m.group("Mssmo_89") + "ssimo " + m.group("Mssmo_90") + "logas" in TEXT and not "s do " + m.group("Mssmo_89") + "ssimo " + m.group("Mssmo_90") + "logas" in TEXT and not " o " + m.group("Mssmo_89") + "ssimo " + m.group("Mssmo_90") + "logas" in TEXT and not m.group("Mssmo_89") + "ssimo-" + m.group("Mssmo_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_91>[a-zA-Zç]+[í])ssimo (?P<Mssmo_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_91") + "ssimo " + m.group("Mssmo_92") + "rias" in TEXT and not " ou " + m.group("Mssmo_91") + "ssimo " + m.group("Mssmo_92") + "rias" in TEXT and not "s de " + m.group("Mssmo_91") + "ssimo " + m.group("Mssmo_92") + "rias" in TEXT and not "s do " + m.group("Mssmo_91") + "ssimo " + m.group("Mssmo_92") + "rias" in TEXT and not " o " + m.group("Mssmo_91") + "ssimo " + m.group("Mssmo_92") + "rias" in TEXT and not m.group("Mssmo_91") + "ssimo-" + m.group("Mssmo_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_93>[a-zA-Zç]+[í])ssimo (?P<Mssmo_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_93") + "ssimo " + m.group("Mssmo_94") + "ssimas" in TEXT and not " ou " + m.group("Mssmo_93") + "ssimo " + m.group("Mssmo_94") + "ssimas" in TEXT and not "s de " + m.group("Mssmo_93") + "ssimo " + m.group("Mssmo_94") + "ssimas" in TEXT and not "s do " + m.group("Mssmo_93") + "ssimo " + m.group("Mssmo_94") + "ssimas" in TEXT and not " o " + m.group("Mssmo_93") + "ssimo " + m.group("Mssmo_94") + "ssimas" in TEXT and not m.group("Mssmo_93") + "ssimo-" + m.group("Mssmo_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_95>[a-zA-Zç]+[í])ssimo (?P<Mssmo_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mssmo_95") + "ssimo " + m.group("Mssmo_96") + "simas" in TEXT and not " ou " + m.group("Mssmo_95") + "ssimo " + m.group("Mssmo_96") + "simas" in TEXT and not "s de " + m.group("Mssmo_95") + "ssimo " + m.group("Mssmo_96") + "simas" in TEXT and not "s do " + m.group("Mssmo_95") + "ssimo " + m.group("Mssmo_96") + "simas" in TEXT and not " o " + m.group("Mssmo_95") + "ssimo " + m.group("Mssmo_96") + "simas" in TEXT and not m.group("Mssmo_95") + "ssimo-" + m.group("Mssmo_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_97>[a-zA-Zç]+[í])ssimo (?P<Mssmo_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_98").lower() in plvrMfoa and not " e " + m.group("Mssmo_97") + "ssimo " + m.group("Mssmo_98") + "as" in TEXT and not " ou " + m.group("Mssmo_97") + "ssimo " + m.group("Mssmo_98") + "as" in TEXT and not "s de " + m.group("Mssmo_97") + "ssimo " + m.group("Mssmo_98") + "as" in TEXT and not "s do " + m.group("Mssmo_97") + "ssimo " + m.group("Mssmo_98") + "as" in TEXT and not " o " + m.group("Mssmo_97") + "ssimo " + m.group("Mssmo_98") + "as" in TEXT and not m.group("Mssmo_97") + "ssimo-" + m.group("Mssmo_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_99>[a-zA-Zç]+[í])ssimo (?P<Mssmo_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_100") in plvrMFm and not " e " + m.group("Mssmo_99") + "ssimo " + m.group("Mssmo_100") + "ns" in TEXT and not " ou " + m.group("Mssmo_99") + "ssimo " + m.group("Mssmo_100") + "ns" in TEXT and not "s de " + m.group("Mssmo_99") + "ssimo " + m.group("Mssmo_100") + "ns" in TEXT and not "s da " + m.group("Mssmo_99") + "ssimo " + m.group("Mssmo_100") + "ns" in TEXT and not " a " + m.group("Mssmo_99") + "ssimo " + m.group("Mssmo_100") + "ns" in TEXT and not m.group("Mssmo_99") + "ssimo-" + m.group("Mssmo_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mssmo_101>[a-zA-Zç]+[í])ssimo (?P<Mssmo_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ssimos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mssmo_102") in plvrMascm and not " e " + m.group("Mssmo_101") + "ssimo " + m.group("Mssmo_102") + "ns" in TEXT and not " ou " + m.group("Mssmo_101") + "ssimo " + m.group("Mssmo_102") + "ns" in TEXT and not "s de " + m.group("Mssmo_101") + "ssimo " + m.group("Mssmo_102") + "ns" in TEXT and not "s da " + m.group("Mssmo_101") + "ssimo " + m.group("Mssmo_102") + "ns" in TEXT and not " a " + m.group("Mssmo_101") + "ssimo " + m.group("Mssmo_102") + "ns" in TEXT and not m.group("Mssmo_101") + "ssimo-" + m.group("Mssmo_102") + "ns" in tCompostops'],
# esima a
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_1>[a-zA-Zç]+[é])sima (?P<Msmma_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_2").lower() in plvrFema and not " e " + m.group("Msmma_1") + "sima " + m.group("Msmma_2") +"s" in TEXT and not " ou " + m.group("Msmma_1") + "sima " + m.group("Msmma_2") + "s" in TEXT and not "s de " + m.group("Msmma_1") + "sima " + m.group("Msmma_2") + "s" in TEXT and not "s da " + m.group("Msmma_1") + "sima " + m.group("Msmma_2") + "s" in TEXT and not " a " + m.group("Msmma_1") + "sima " + m.group("Msmma_2") + "s" in TEXT and not m.group("Msmma_1") + "sima-" + m.group("Msmma_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_3>[a-zA-Zç]+[é])sima (?P<Msmma_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_4").lower() in plvrMfoa and not " e " + m.group("Msmma_3") + "sima " + m.group("Msmma_4") + "as" in TEXT and not " ou " + m.group("Msmma_3") + "sima " + m.group("Msmma_4") + "as" in TEXT and not "s de " + m.group("Msmma_3") + "sima " + m.group("Msmma_4") + "as" in TEXT and not "s da " + m.group("Msmma_3") + "sima " + m.group("Msmma_4") + "as" in TEXT and not " a " + m.group("Msmma_3") + "sima " + m.group("Msmma_4") + "as" in TEXT and not m.group("Msmma_3") + "sima-" + m.group("Msmma_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_5>[a-zA-Zç]+[é])sima (?P<Msmma_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmma_6").lower() in excAdo and not " e " + m.group("Msmma_5") + "sima " + m.group("Msmma_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msmma_5") + "sima " + m.group("Msmma_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msmma_5") + "sima " + m.group("Msmma_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Msmma_5") + "sima " + m.group("Msmma_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Msmma_5") + "sima " + m.group("Msmma_6") + m.group(3) + "dos" in TEXT and not m.group("Msmma_5") + "sima-" + m.group("Msmma_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_7>[a-zA-Zç]+[é])sima (?P<Msmma_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmma_8").lower() in excIsta and not " e " + m.group("Msmma_7") + "sima " + m.group("Msmma_8") + "s" in TEXT and not " ou " + m.group("Msmma_7") + "sima " + m.group("Msmma_8") + "s" in TEXT and not "s de " + m.group("Msmma_7") + "sima " + m.group("Msmma_8") + "s" in TEXT and not "s da " + m.group("Msmma_7") + "sima " + m.group("Msmma_8") + "s" in TEXT and not " a " + m.group("Msmma_7") + "sima " + m.group("Msmma_8") + "s" in TEXT and not m.group("Msmma_7") + "sima-" + m.group("Msmma_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_9>[a-zA-Zç]+[é])sima (?P<Msmma_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_10").lower() in plvrInva and not " e " + m.group("Msmma_9") + "sima " + m.group("Msmma_10") + "s" in TEXT and not " ou " + m.group("Msmma_9") + "sima " + m.group("Msmma_10") + "s" in TEXT and not "s de " + m.group("Msmma_9") + "sima " + m.group("Msmma_10") + "s" in TEXT and not "s da " + m.group("Msmma_9") + "sima " + m.group("Msmma_10") + "s" in TEXT and not " a " + m.group("Msmma_9") + "sima " + m.group("Msmma_10") + "s" in TEXT and not m.group("Msmma_9") + "sima-" + m.group("Msmma_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_11>[a-zA-Zç]+[é])sima (?P<Msmma_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmma_12").lower() in excAdo and not " e " + m.group("Msmma_11") + "sima " + m.group("Msmma_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msmma_11") + "sima " + m.group("Msmma_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msmma_11") + "sima " + m.group("Msmma_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Msmma_11") + "sima " + m.group("Msmma_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Msmma_11") + "sima " + m.group("Msmma_12") + m.group(3) + "das" in TEXT and not m.group("Msmma_11") + "sima-" + m.group("Msmma_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_13>[a-zA-Zç]+[é])sima (?P<Msmma_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmma_13") + "sima " + m.group("Msmma_14") + "osos" in TEXT and not " ou " + m.group("Msmma_13") + "sima " + m.group("Msmma_14") + "osos" in TEXT and not "s de " + m.group("Msmma_13") + "sima " + m.group("Msmma_14") + "osos" in TEXT and not "s da " + m.group("Msmma_13") + "sima " + m.group("Msmma_14") + "osos" in TEXT and not " a " + m.group("Msmma_13") + "sima " + m.group("Msmma_14") + "osos" in TEXT and not m.group("Msmma_13") + "sima-" + m.group("Msmma_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_15>[a-zA-Zç]+[é])sima (?P<Msmma_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmma_15") + "sima " + m.group("Msmma_16") + "osas" in TEXT and not " ou " + m.group("Msmma_15") + "sima " + m.group("Msmma_16") + "osas" in TEXT and not "s de " + m.group("Msmma_15") + "sima " + m.group("Msmma_16") + "osas" in TEXT and not "s da " + m.group("Msmma_15") + "sima " + m.group("Msmma_16") + "osas" in TEXT and not " a " + m.group("Msmma_15") + "sima " + m.group("Msmma_16") + "osas" in TEXT and not m.group("Msmma_15") + "sima-" + m.group("Msmma_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_17>[a-zA-Zç]+[é])sima (?P<Msmma_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmma_17") + "sima " + m.group("Msmma_18") + "ivas" in TEXT and not " ou " + m.group("Msmma_17") + "sima " + m.group("Msmma_18") + "ivas" in TEXT and not "s de " + m.group("Msmma_17") + "sima " + m.group("Msmma_18") + "ivas" in TEXT and not "s da " + m.group("Msmma_17") + "sima " + m.group("Msmma_18") + "ivas" in TEXT and not " a " + m.group("Msmma_17") + "sima " + m.group("Msmma_18") + "ivas" in TEXT and not m.group("Msmma_17") + "sima-" + m.group("Msmma_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_19>[a-zA-Zç]+[é])sima (?P<Msmma_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmma_19") + "sima " + m.group("Msmma_20") + "ivas" in TEXT and not " ou " + m.group("Msmma_19") + "sima " + m.group("Msmma_20") + "ivas" in TEXT and not "s de " + m.group("Msmma_19") + "sima " + m.group("Msmma_20") + "ivas" in TEXT and not "s da " + m.group("Msmma_19") + "sima " + m.group("Msmma_20") + "ivas" in TEXT and not " a " + m.group("Msmma_19") + "sima " + m.group("Msmma_20") + "ivas" in TEXT and not m.group("Msmma_19") + "sima-" + m.group("Msmma_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_21>[a-zA-Zç]+[é])sima (?P<Msmma_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmma_21") + "sima " + m.group("Msmma_22") + "icas" in TEXT and not " ou " + m.group("Msmma_21") + "sima " + m.group("Msmma_22") + "icas" in TEXT and not "s de " + m.group("Msmma_21") + "sima " + m.group("Msmma_22") + "icas" in TEXT and not "s da " + m.group("Msmma_21") + "sima " + m.group("Msmma_22") + "icas" in TEXT and not " a " + m.group("Msmma_21") + "sima " + m.group("Msmma_22") + "icas" in TEXT and not m.group("Msmma_21") + "sima-" + m.group("Msmma_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_23>[a-zA-Zç]+[é])sima (?P<Msmma_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmma_23") + "sima " + m.group("Msmma_24") + "icas" in TEXT and not " ou " + m.group("Msmma_23") + "sima " + m.group("Msmma_24") + "icas" in TEXT and not "s de " + m.group("Msmma_23") + "sima " + m.group("Msmma_24") + "icas" in TEXT and not "s da " + m.group("Msmma_23") + "sima " + m.group("Msmma_24") + "icas" in TEXT and not " a " + m.group("Msmma_23") + "sima " + m.group("Msmma_24") + "icas" in TEXT and not m.group("Msmma_23") + "sima-" + m.group("Msmma_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_25>[a-zA-Zç]+[é])sima (?P<Msmma_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmma_25") + "sima " + m.group("Msmma_26") + "icas" in TEXT and not " ou " + m.group("Msmma_25") + "sima " + m.group("Msmma_26") + "icas" in TEXT and not "s de " + m.group("Msmma_25") + "sima " + m.group("Msmma_26") + "icas" in TEXT and not "s da " + m.group("Msmma_25") + "sima " + m.group("Msmma_26") + "icas" in TEXT and not " a " + m.group("Msmma_25") + "sima " + m.group("Msmma_26") + "icas" in TEXT and not m.group("Msmma_25") + "sima-" + m.group("Msmma_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_27>[a-zA-Zç]+[é])sima (?P<Msmma_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmma_27") + "sima " + m.group("Msmma_28") + "escas" in TEXT and not " ou " + m.group("Msmma_27") + "sima " + m.group("Msmma_28") + "escas" in TEXT and not "s de " + m.group("Msmma_27") + "sima " + m.group("Msmma_28") + "escas" in TEXT and not "s da " + m.group("Msmma_27") + "sima " + m.group("Msmma_28") + "escas" in TEXT and not " a " + m.group("Msmma_27") + "sima " + m.group("Msmma_28") + "escas" in TEXT and not m.group("Msmma_27") + "sima-" + m.group("Msmma_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_29>[a-zA-Zç]+[é])sima (?P<Msmma_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmma_29") + "sima " + m.group("Msmma_30") + "idas" in TEXT and not " ou " + m.group("Msmma_29") + "s " + m.group("Msmma_30") + "idas" in TEXT and not "s de " + m.group("Msmma_29") + "s " + m.group("Msmma_30") + "idas" in TEXT and not "s da " + m.group("Msmma_29") + "s " + m.group("Msmma_30") + "idas" in TEXT and not " a " + m.group("Msmma_29") + "s " + m.group("Msmma_30") + "idas" in TEXT and not m.group("Msmma_29") + "sima-" + m.group("Msmma_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_31>[a-zA-Zç]+[é])sima (?P<Msmma_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmma_31") + "sima " + m.group("Msmma_32") + "logas" in TEXT and not " ou " + m.group("Msmma_31") + "sima " + m.group("Msmma_32") + "logas" in TEXT and not "s de " + m.group("Msmma_31") + "sima " + m.group("Msmma_32") + "logas" in TEXT and not "s da " + m.group("Msmma_31") + "sima " + m.group("Msmma_32") + "logas" in TEXT and not " a " + m.group("Msmma_31") + "sima " + m.group("Msmma_32") + "logas" in TEXT and not m.group("Msmma_31") + "sima-" + m.group("Msmma_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_33>[a-zA-Zç]+[é])sima (?P<Msmma_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmma_33") + "sima " + m.group("Msmma_34") + "rias" in TEXT and not " ou " + m.group("Msmma_33") + "sima " + m.group("Msmma_34") + "rias" in TEXT and not "s de " + m.group("Msmma_33") + "sima " + m.group("Msmma_34") + "rias" in TEXT and not "s da " + m.group("Msmma_33") + "sima " + m.group("Msmma_34") + "rias" in TEXT and not " a " + m.group("Msmma_33") + "sima " + m.group("Msmma_34") + "rias" in TEXT and not m.group("Msmma_33") + "sima-" + m.group("Msmma_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_35>[a-zA-Zç]+[é])sima (?P<Msmma_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmma_35") + "sima " + m.group("Msmma_36") + "ssimas" in TEXT and not " ou " + m.group("Msmma_35") + "sima " + m.group("Msmma_36") + "ssimas" in TEXT and not "s de " + m.group("Msmma_35") + "sima " + m.group("Msmma_36") + "ssimas" in TEXT and not "s da " + m.group("Msmma_35") + "sima " + m.group("Msmma_36") + "ssimas" in TEXT and not " a " + m.group("Msmma_35") + "sima " + m.group("Msmma_36") + "ssimas" in TEXT and not m.group("Msmma_35") + "sima-" + m.group("Msmma_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_37>[a-zA-Zç]+[é])sima (?P<Msmma_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmma_37") + "sima " + m.group("Msmma_38") + "simas" in TEXT and not " ou " + m.group("Msmma_37") + "sima " + m.group("Msmma_38") + "simas" in TEXT and not "s de " + m.group("Msmma_37") + "sima " + m.group("Msmma_38") + "simas" in TEXT and not "s da " + m.group("Msmma_37") + "sima " + m.group("Msmma_38") + "simas" in TEXT and not " a " + m.group("Msmma_37") + "sima " + m.group("Msmma_38") + "simas" in TEXT and not m.group("Msmma_37") + "sima-" + m.group("Msmma_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_41>[a-zA-Zç]+[é])sima (?P<Msmma_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmma_42") in "D-d-" and not " e " + m.group("Msmma_41") + "sima " + m.group("Msmma_42") + "oras" in TEXT and not " ou " + m.group("Msmma_41") + "sima " + m.group("Msmma_42") + "oras" in TEXT and not "s de " + m.group("Msmma_41") + "sima " + m.group("Msmma_42") + "oras" in TEXT and not "s da " + m.group("Msmma_41") + "sima " + m.group("Msmma_42") + "oras" in TEXT and not " a " + m.group("Msmma_41") + "sima " + m.group("Msmma_42") + "oras" in TEXT and not m.group("Msmma_41") + "sima-" + m.group("Msmma_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_43>[a-zA-Zç]+[é])sima (?P<Msmma_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_44") in plvrMfr and not " e " + m.group("Msmma_43") + "sima " + m.group("Msmma_44") + "es" in TEXT and not " ou " + m.group("Msmma_43") + "sima " + m.group("Msmma_44") + "es" in TEXT and not "s de " + m.group("Msmma_43") + "sima " + m.group("Msmma_44") + "es" in TEXT and not "s da " + m.group("Msmma_43") + "sima " + m.group("Msmma_44") + "es" in TEXT and not " a " + m.group("Msmma_43") + "sima " + m.group("Msmma_44") + "es" in TEXT and not m.group("Msmma_43") + "sima-" + m.group("Msmma_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_45>[a-zA-Zç]+[é])sima (?P<Msmma_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_46") in plvrFemr and not " e " + m.group("Msmma_45") + "sima " + m.group("Msmma_46") + "es" in TEXT and not " ou " + m.group("Msmma_45") + "sima " + m.group("Msmma_46") + "es" in TEXT and not "s de " + m.group("Msmma_45") + "sima " + m.group("Msmma_46") + "es" in TEXT and not "s da " + m.group("Msmma_45") + "sima " + m.group("Msmma_46") + "es" in TEXT and not " a " + m.group("Msmma_45") + "sima " + m.group("Msmma_46") + "es" in TEXT and not m.group("Msmma_45") + "sima-" + m.group("Msmma_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_47>[a-zA-Zç]+[é])sima (?P<Msmma_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_48") in plvrMfal and not " e " + m.group("Msmma_47") + "sima " + m.group("Msmma_48") + "is" in TEXT and not " ou " + m.group("Msmma_47") + "sima " + m.group("Msmma_48") + "is" in TEXT and not "s de " + m.group("Msmma_47") + "sima " + m.group("Msmma_48") + "is" in TEXT and not "s da " + m.group("Msmma_47") + "sima " + m.group("Msmma_48") + "is" in TEXT and not " a " + m.group("Msmma_47") + "sima " + m.group("Msmma_48") + "is" in TEXT and not m.group("Msmma_47") + "sima-" + m.group("Msmma_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_49>[a-zA-Zç]+[é])sima (?P<Msmma_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_50") in plvrMfcao and not " e " + m.group("Msmma_49") + "sima " + m.group("Msmma_50") + "ões" in TEXT and not + " ou " + m.group("Msmma_49") + "sima " + m.group("Msmma_50") + "ões" in TEXT and not + "s de " + m.group("Msmma_49") + "sima " + m.group("Msmma_50") + "ões" in TEXT and not + "s da " + m.group("Msmma_49") + "sima " + m.group("Msmma_50") + "ões" in TEXT and not + " a " + m.group("Msmma_49") + "sima " + m.group("Msmma_50") + "ões" in TEXT and not m.group("Msmma_49") + "sima-" + m.group("Msmma_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_51>[a-zA-Zç]+[é])sima (?P<Msmma_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmma_52") in plvrMascao and not " e " + m.group("Msmma_51") + "sima " + m.group("Msmma_52") + "ões" in TEXT and not " ou " + m.group("Msmma_51") + "sima " + m.group("Msmma_52") + "ões" in TEXT and not "s de " + m.group("Msmma_51") + "sima " + m.group("Msmma_52") + "ões" in TEXT and not "s da " + m.group("Msmma_51") + "sima " + m.group("Msmma_52") + "ões" in TEXT and not " a " + m.group("Msmma_51") + "sima " + m.group("Msmma_52") + "ões" in TEXT and not m.group("Msmma_51") + "sima-" + m.group("Msmma_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_53>[a-zA-Zç]+[é])sima (?P<Msmma_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_54") in plvrFemao and not " e " + m.group("Msmma_53") + "sima " + m.group("Msmma_54") + "ões" in TEXT and not " ou " + m.group("Msmma_53") + "sima " + m.group("Msmma_54") + "ões" in TEXT and not "s de " + m.group("Msmma_53") + "sima " + m.group("Msmma_54") + "ões" in TEXT and not "s da " + m.group("Msmma_53") + "sima " + m.group("Msmma_54") + "ões" in TEXT and not " a " + m.group("Msmma_53") + "sima " + m.group("Msmma_54") + "ões" in TEXT and not m.group("Msmma_53") + "sima-" + m.group("Msmma_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_55>[a-zA-Zç]+[é])sima (?P<Msmma_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmma_55") + "sima " + m.group("Msmma_56") + "veis" in TEXT and not " ou " + m.group("Msmma_55") + "sima " + m.group("Msmma_56") + "veis" in TEXT and not "s de " + m.group("Msmma_55") + "sima " + m.group("Msmma_56") + "veis" in TEXT and not "s da " + m.group("Msmma_55") + "sima " + m.group("Msmma_56") + "veis" in TEXT and not " a " + m.group("Msmma_55") + "sima " + m.group("Msmma_56") + "veis" in TEXT and not m.group("Msmma_55") + "sima-" + m.group("Msmma_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_57>[a-zA-Zç]+[é])sima (?P<Msmma_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_58").lower() in plvrMfe and not " e " + m.group("Msmma_57") + "sima " + m.group("Msmma_58") + "es" in TEXT and not " ou " + m.group("Msmma_57") + "sima " + m.group("Msmma_58") + "es" in TEXT and not "s de " + m.group("Msmma_57") + "sima " + m.group("Msmma_58") + "es" in TEXT and not "s da " + m.group("Msmma_57") + "sima " + m.group("Msmma_58") + "es" in TEXT and not " a " + m.group("Msmma_57") + "sima " + m.group("Msmma_58") + "es" in TEXT and not m.group("Msmma_57") + "sima-" + m.group("Msmma_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_59>[a-zA-Zç]+[é])sima (?P<Msmma_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_60").lower() in plvrFeme and not " e " + m.group("Msmma_59") + "sima " + m.group("Msmma_60") + "es" in TEXT and not " ou " + m.group("Msmma_59") + "sima " + m.group("Msmma_60") + "es" in TEXT and not "s de " + m.group("Msmma_59") + "sima " + m.group("Msmma_60") + "es" in TEXT and not "s da " + m.group("Msmma_59") + "sima " + m.group("Msmma_60") + "es" in TEXT and not " a " + m.group("Msmma_59") + "sima " + m.group("Msmma_60") + "es" in TEXT and not m.group("Msmma_59") + "sima-" + m.group("Msmma_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_61>[a-zA-Zç]+[é])sima (?P<Msmma_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_62") in plvrMfel and not " e " + m.group("Msmma_61") + "sima " + m.group("Msmma_62") + "éis" in TEXT and not " ou " + m.group("Msmma_61") + "sima " + m.group("Msmma_62") + "éis" in TEXT and not "s de " + m.group("Msmma_61") + "sima " + m.group("Msmma_62") + "éis" in TEXT and not "s da " + m.group("Msmma_61") + "sima " + m.group("Msmma_62") + "éis" in TEXT and not " a " + m.group("Msmma_61") + "sima " + m.group("Msmma_62") + "éis" in TEXT and not m.group("Msmma_61") + "sima-" + m.group("Msmma_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_63>[a-zA-Zç]+[é])sima (?P<Msmma_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_64") in plvrFemel and not " e " + m.group("Msmma_63") + "sima " + m.group("Msmma_64") + "éis" in TEXT and not " ou " + m.group("Msmma_63") + "sima " + m.group("Msmma_64") + "éis" in TEXT and not "s de " + m.group("Msmma_63") + "sima " + m.group("Msmma_64") + "éis" in TEXT and not "s da " + m.group("Msmma_63") + "sima " + m.group("Msmma_64") + "éis" in TEXT and not " a " + m.group("Msmma_63") + "sima " + m.group("Msmma_64") + "éis" in TEXT and not m.group("Msmma_63") + "sima-" + m.group("Msmma_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_65>[a-zA-Zç]+[é])sima (?P<Msmma_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_66") in plvrMfeu and not " e " + m.group("Msmma_65") + "sima " + m.group("Msmma_66") + "us" in TEXT and not " ou " + m.group("Msmma_65") + "sima " + m.group("Msmma_66") + "us" in TEXT and not "s de " + m.group("Msmma_65") + "sima " + m.group("Msmma_66") + "us" in TEXT and not "s da " + m.group("Msmma_65") + "sima " + m.group("Msmma_66") + "us" in TEXT and not " a " + m.group("Msmma_65") + "sima " + m.group("Msmma_66") + "us" in TEXT and not m.group("Msmma_65") + "sima-" + m.group("Msmma_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_67>[a-zA-Zç]+[é])sima (?P<Msmma_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_68") in plvrFemu and not " e " + m.group("Msmma_67") + "sima " + m.group("Msmma_68") + "us" in TEXT and not " ou " + m.group("Msmma_67") + "sima " + m.group("Msmma_68") + "us" in TEXT and not "s de " + m.group("Msmma_67") + "sima " + m.group("Msmma_68") + "us" in TEXT and not "s da " + m.group("Msmma_67") + "sima " + m.group("Msmma_68") + "us" in TEXT and not " a " + m.group("Msmma_67") + "sima " + m.group("Msmma_68") + "us" in TEXT and not m.group("Msmma_67") + "sima-" + m.group("Msmma_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_69>[a-zA-Zç]+[é])sima (?P<Msmma_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_70") in plvrInvaz and not " e " + m.group("Msmma_69") + "sima " + m.group("Msmma_70") + "zes" in TEXT and not " ou " + m.group("Msmma_69") + "sima " + m.group("Msmma_70") + "zes" in TEXT and not "s de " + m.group("Msmma_69") + "sima " + m.group("Msmma_70") + "zes" in TEXT and not "s da " + m.group("Msmma_69") + "sima " + m.group("Msmma_70") + "zes" in TEXT and not " a " + m.group("Msmma_69") + "sima " + m.group("Msmma_70") + "zes" in TEXT and not m.group("Msmma_69") + "sima-" + m.group("Msmma_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_71>[a-zA-Zç]+[é])sima (?P<Msmma_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_72") in plvrFemz and not " e " + m.group("Msmma_71") + "sima " + m.group("Msmma_72") + "zes" in TEXT and not " ou " + m.group("Msmma_71") + "sima " + m.group("Msmma_72") + "zes" in TEXT and not "s de " + m.group("Msmma_71") + "sima " + m.group("Msmma_72") + "zes" in TEXT and not "s da " + m.group("Msmma_71") + "sima " + m.group("Msmma_72") + "zes" in TEXT and not " a " + m.group("Msmma_71") + "sima " + m.group("Msmma_72") + "zes" in TEXT and not m.group("Msmma_71") + "sima-" + m.group("Msmma_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_73>[a-zA-Zç]+[é])sima (?P<Msmma_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_74") in pvrFeman and not " e " + m.group("Msmma_73") + "sima " + m.group("Msmma_74") + "s" in TEXT and not " ou " + m.group("Msmma_73") + "sima " + m.group("Msmma_74") + "s" in TEXT and not "s de " + m.group("Msmma_73") + "sima " + m.group("Msmma_74") + "s" in TEXT and not "s da " + m.group("Msmma_73") + "sima " + m.group("Msmma_74") + "s" in TEXT and not " a " + m.group("Msmma_73") + "sima " + m.group("Msmma_74") + "s" in TEXT and not m.group("Msmma_73") + "sima-" + m.group("Msmma_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_99>[a-zA-Zç]+[é])sima (?P<Msmma_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_100") in plvrMFm and not " e " + m.group("Msmma_99") + "sima " + m.group("Msmma_100") + "ns" in TEXT and not " ou " + m.group("Msmma_99") + "sima " + m.group("Msmma_100") + "ns" in TEXT and not "s de " + m.group("Msmma_99") + "sima " + m.group("Msmma_100") + "ns" in TEXT and not "s da " + m.group("Msmma_99") + "sima " + m.group("Msmma_100") + "ns" in TEXT and not " a " + m.group("Msmma_99") + "sima " + m.group("Msmma_100") + "ns" in TEXT and not m.group("Msmma_99") + "sima-" + m.group("Msmma_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmma_101>[a-zA-Zç]+[é])sima (?P<Msmma_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "simas " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmma_102") in plvrFemm and not " e " + m.group("Msmma_101") + "sima " + m.group("Msmma_102") + "ns" in TEXT and not " ou " + m.group("Msmma_101") + "sima " + m.group("Msmma_102") + "ns" in TEXT and not "s de " + m.group("Msmma_101") + "sima " + m.group("Msmma_102") + "ns" in TEXT and not "s da " + m.group("Msmma_101") + "sima " + m.group("Msmma_102") + "ns" in TEXT and not " a " + m.group("Msmma_101") + "sima " + m.group("Msmma_102") + "ns" in TEXT and not m.group("Msmma_101") + "sima-" + m.group("Msmma_102") + "ns" in tCompostops'],
# esimo o
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_1>[a-zA-Zç]+[é])simo (?P<Msmmo_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_2").lower() in plvrMasca and not " e " + m.group("Msmmo_1") + "simo " + m.group("Msmmo_2") +"s" in TEXT and not " ou " + m.group("Msmmo_1") + "simo " + m.group("Msmmo_2") + "s" in TEXT and not "s de " + m.group("Msmmo_1") + "simo " + m.group("Msmmo_2") + "s" in TEXT and not "s do " + m.group("Msmmo_1") + "simo " + m.group("Msmmo_2") + "s" in TEXT and not " o " + m.group("Msmmo_1") + "simo " + m.group("Msmmo_2") + "s" in TEXT and not m.group("Msmmo_1") + "simo-" + m.group("Msmmo_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_3>[a-zA-Zç]+[é])simo (?P<Msmmo_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_4").lower() in plvrMfoa and not " e " + m.group("Msmmo_3") + "simo " + m.group("Msmmo_4") + "os" in TEXT and not " ou " + m.group("Msmmo_3") + "simo " + m.group("Msmmo_4") + "os" in TEXT and not "s de " + m.group("Msmmo_3") + "simo " + m.group("Msmmo_4") + "os" in TEXT and not "s do " + m.group("Msmmo_3") + "simo " + m.group("Msmmo_4") + "os" in TEXT and not " o " + m.group("Msmmo_3") + "simo " + m.group("Msmmo_4") + "os" in TEXT and not m.group("Msmmo_3") + "simo-" + m.group("Msmmo_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_5>[a-zA-Zç]+[é])simo (?P<Msmmo_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmmo_6").lower() in excAdo and not " e " + m.group("Msmmo_5") + "simo " + m.group("Msmmo_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msmmo_5") + "simo " + m.group("Msmmo_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msmmo_5") + "simo " + m.group("Msmmo_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msmmo_5") + "simo " + m.group("Msmmo_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msmmo_5") + "simo " + m.group("Msmmo_6") + m.group(3) + "dos" in TEXT and not m.group("Msmmo_5") + "simo-" + m.group("Msmmo_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_7>[a-zA-Zç]+[é])simo (?P<Msmmo_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmmo_8").lower() in excIsta and not " e " + m.group("Msmmo_7") + "simo " + m.group("Msmmo_8") + "s" in TEXT and not " ou " + m.group("Msmmo_7") + "simo " + m.group("Msmmo_8") + "s" in TEXT and not "s de " + m.group("Msmmo_7") + "simo " + m.group("Msmmo_8") + "s" in TEXT and not "s do " + m.group("Msmmo_7") + "simo " + m.group("Msmmo_8") + "s" in TEXT and not " o " + m.group("Msmmo_7") + "simo " + m.group("Msmmo_8") + "s" in TEXT and not m.group("Msmmo_7") + "simo-" + m.group("Msmmo_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_9>[a-zA-Zç]+[é])simo (?P<Msmmo_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_10").lower() in plvrInva and not " e " + m.group("Msmmo_9") + "simo " + m.group("Msmmo_10") + "s" in TEXT and not " ou " + m.group("Msmmo_9") + "simo " + m.group("Msmmo_10") + "s" in TEXT and not "s de " + m.group("Msmmo_9") + "simo " + m.group("Msmmo_10") + "s" in TEXT and not "s do " + m.group("Msmmo_9") + "simo " + m.group("Msmmo_10") + "s" in TEXT and not " a " + m.group("Msmmo_9") + "simo " + m.group("Msmmo_10") + "s" in TEXT and not m.group("Msmmo_9") + "simo-" + m.group("Msmmo_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_11>[a-zA-Zç]+[é])simo (?P<Msmmo_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmmo_12").lower() in excAdo and not " e " + m.group("Msmmo_11") + "simo " + m.group("Msmmo_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msmmo_11") + "simo " + m.group("Msmmo_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msmmo_11") + "simo " + m.group("Msmmo_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Msmmo_11") + "simo " + m.group("Msmmo_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Msmmo_11") + "simo " + m.group("Msmmo_12") + m.group(3) + "das" in TEXT and not m.group("Msmmo_11") + "simo-" + m.group("Msmmo_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_13>[a-zA-Zç]+[é])simo (?P<Msmmo_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_13") + "simo " + m.group("Msmmo_14") + "osos" in TEXT and not " ou " + m.group("Msmmo_13") + "simo " + m.group("Msmmo_14") + "osos" in TEXT and not "s de " + m.group("Msmmo_13") + "simo " + m.group("Msmmo_14") + "osos" in TEXT and not "s do " + m.group("Msmmo_13") + "simo " + m.group("Msmmo_14") + "osos" in TEXT and not " o " + m.group("Msmmo_13") + "simo " + m.group("Msmmo_14") + "osos" in TEXT and not m.group("Msmmo_13") + "simo-" + m.group("Msmmo_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_15>[a-zA-Zç]+[é])simo (?P<Msmmo_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_15") + "simo " + m.group("Msmmo_16") + "osas" in TEXT and not " ou " + m.group("Msmmo_15") + "simo " + m.group("Msmmo_16") + "osas" in TEXT and not "s de " + m.group("Msmmo_15") + "simo " + m.group("Msmmo_16") + "osas" in TEXT and not "s do " + m.group("Msmmo_15") + "simo " + m.group("Msmmo_16") + "osas" in TEXT and not " o " + m.group("Msmmo_15") + "simo " + m.group("Msmmo_16") + "osas" in TEXT and not m.group("Msmmo_15") + "simo-" + m.group("Msmmo_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_17>[a-zA-Zç]+[é])simo (?P<Msmmo_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_17") + "simo " + m.group("Msmmo_18") + "ivas" in TEXT and not " ou " + m.group("Msmmo_17") + "simo " + m.group("Msmmo_18") + "ivas" in TEXT and not "s de " + m.group("Msmmo_17") + "simo " + m.group("Msmmo_18") + "ivas" in TEXT and not "s do " + m.group("Msmmo_17") + "simo " + m.group("Msmmo_18") + "ivas" in TEXT and not " o " + m.group("Msmmo_17") + "simo " + m.group("Msmmo_18") + "ivas" in TEXT and not m.group("Msmmo_17") + "simo-" + m.group("Msmmo_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_19>[a-zA-Zç]+[é])simo (?P<Msmmo_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_19") + "simo " + m.group("Msmmo_20") + "ivas" in TEXT and not " ou " + m.group("Msmmo_19") + "simo " + m.group("Msmmo_20") + "ivas" in TEXT and not "s de " + m.group("Msmmo_19") + "simo " + m.group("Msmmo_20") + "ivas" in TEXT and not "s do " + m.group("Msmmo_19") + "simo " + m.group("Msmmo_20") + "ivas" in TEXT and not " o " + m.group("Msmmo_19") + "simo " + m.group("Msmmo_20") + "ivas" in TEXT and not m.group("Msmmo_19") + "simo-" + m.group("Msmmo_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_21>[a-zA-Zç]+[é])simo (?P<Msmmo_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_21") + "simo " + m.group("Msmmo_22") + "icos" in TEXT and not " ou " + m.group("Msmmo_21") + "simo " + m.group("Msmmo_22") + "icos" in TEXT and not "s de " + m.group("Msmmo_21") + "simo " + m.group("Msmmo_22") + "icos" in TEXT and not "s do " + m.group("Msmmo_21") + "simo " + m.group("Msmmo_22") + "icos" in TEXT and not " o " + m.group("Msmmo_21") + "simo " + m.group("Msmmo_22") + "icos" in TEXT and not m.group("Msmmo_21") + "simo-" + m.group("Msmmo_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_23>[a-zA-Zç]+[é])simo (?P<Msmmo_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_23") + "simo " + m.group("Msmmo_24") + "icos" in TEXT and not " ou " + m.group("Msmmo_23") + "simo " + m.group("Msmmo_24") + "icos" in TEXT and not "s de " + m.group("Msmmo_23") + "simo " + m.group("Msmmo_24") + "icos" in TEXT and not "s do " + m.group("Msmmo_23") + "simo " + m.group("Msmmo_24") + "icos" in TEXT and not " o " + m.group("Msmmo_23") + "simo " + m.group("Msmmo_24") + "icos" in TEXT and not m.group("Msmmo_23") + "simo-" + m.group("Msmmo_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_25>[a-zA-Zç]+[é])simo (?P<Msmmo_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_25") + "simo " + m.group("Msmmo_26") + "icos" in TEXT and not " ou " + m.group("Msmmo_25") + "simo " + m.group("Msmmo_26") + "icos" in TEXT and not "s de " + m.group("Msmmo_25") + "simo " + m.group("Msmmo_26") + "icos" in TEXT and not "s do " + m.group("Msmmo_25") + "simo " + m.group("Msmmo_26") + "icos" in TEXT and not " o " + m.group("Msmmo_25") + "simo " + m.group("Msmmo_26") + "icos" in TEXT and not m.group("Msmmo_25") + "simo-" + m.group("Msmmo_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_27>[a-zA-Zç]+[é])simo (?P<Msmmo_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_27") + "simo " + m.group("Msmmo_28") + "escos" in TEXT and not " ou " + m.group("Msmmo_27") + "simo " + m.group("Msmmo_28") + "escos" in TEXT and not "s de " + m.group("Msmmo_27") + "simo " + m.group("Msmmo_28") + "escos" in TEXT and not "s do " + m.group("Msmmo_27") + "simo " + m.group("Msmmo_28") + "escos" in TEXT and not " o " + m.group("Msmmo_27") + "simo " + m.group("Msmmo_28") + "escos" in TEXT and not m.group("Msmmo_27") + "simo-" + m.group("Msmmo_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_29>[a-zA-Zç]+[é])simo (?P<Msmmo_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_29") + "simo " + m.group("Msmmo_30") + "idos" in TEXT and not " ou " + m.group("Msmmo_29") + "s " + m.group("Msmmo_30") + "idos" in TEXT and not "s de " + m.group("Msmmo_29") + "s " + m.group("Msmmo_30") + "idos" in TEXT and not "s do " + m.group("Msmmo_29") + "s " + m.group("Msmmo_30") + "idos" in TEXT and not " o " + m.group("Msmmo_29") + "s " + m.group("Msmmo_30") + "idos" in TEXT and not m.group("Msmmo_29") + "simo-" + m.group("Msmmo_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_31>[a-zA-Zç]+[é])simo (?P<Msmmo_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_31") + "simo " + m.group("Msmmo_32") + "logos" in TEXT and not " ou " + m.group("Msmmo_31") + "simo " + m.group("Msmmo_32") + "logos" in TEXT and not "s de " + m.group("Msmmo_31") + "simo " + m.group("Msmmo_32") + "logos" in TEXT and not "s do " + m.group("Msmmo_31") + "simo " + m.group("Msmmo_32") + "logos" in TEXT and not " o " + m.group("Msmmo_31") + "simo " + m.group("Msmmo_32") + "logos" in TEXT and not m.group("Msmmo_31") + "simo-" + m.group("Msmmo_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_33>[a-zA-Zç]+[é])simo (?P<Msmmo_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_33") + "simo " + m.group("Msmmo_34") + "rios" in TEXT and not " ou " + m.group("Msmmo_33") + "simo " + m.group("Msmmo_34") + "rios" in TEXT and not "s de " + m.group("Msmmo_33") + "simo " + m.group("Msmmo_34") + "rios" in TEXT and not "s do " + m.group("Msmmo_33") + "simo " + m.group("Msmmo_34") + "rios" in TEXT and not " o " + m.group("Msmmo_33") + "simo " + m.group("Msmmo_34") + "rios" in TEXT and not m.group("Msmmo_33") + "simo-" + m.group("Msmmo_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_35>[a-zA-Zç]+[é])simo (?P<Msmmo_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_35") + "simo " + m.group("Msmmo_36") + "ssimos" in TEXT and not " ou " + m.group("Msmmo_35") + "simo " + m.group("Msmmo_36") + "ssimos" in TEXT and not "s de " + m.group("Msmmo_35") + "simo " + m.group("Msmmo_36") + "ssimos" in TEXT and not "s do " + m.group("Msmmo_35") + "simo " + m.group("Msmmo_36") + "ssimos" in TEXT and not " o " + m.group("Msmmo_35") + "simo " + m.group("Msmmo_36") + "ssimos" in TEXT and not m.group("Msmmo_35") + "simo-" + m.group("Msmmo_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_37>[a-zA-Zç]+[é])simo (?P<Msmmo_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_37") + "simo " + m.group("Msmmo_38") + "simos" in TEXT and not " ou " + m.group("Msmmo_37") + "simo " + m.group("Msmmo_38") + "simos" in TEXT and not "s de " + m.group("Msmmo_37") + "simo " + m.group("Msmmo_38") + "simos" in TEXT and not "s do " + m.group("Msmmo_37") + "simo " + m.group("Msmmo_38") + "simos" in TEXT and not " o " + m.group("Msmmo_37") + "simo " + m.group("Msmmo_38") + "simos" in TEXT and not m.group("Msmmo_37") + "simo-" + m.group("Msmmo_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_41>[a-zA-Zç]+[é])simo (?P<Msmmo_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msmmo_42") in "D-d-" and not " e " + m.group("Msmmo_41") + "simo " + m.group("Msmmo_42") + "ores" in TEXT and not " ou " + m.group("Msmmo_41") + "simo " + m.group("Msmmo_42") + "ores" in TEXT and not "s de " + m.group("Msmmo_41") + "simo " + m.group("Msmmo_42") + "ores" in TEXT and not "s do " + m.group("Msmmo_41") + "simo " + m.group("Msmmo_42") + "ores" in TEXT and not " o " + m.group("Msmmo_41") + "simo " + m.group("Msmmo_42") + "ores" in TEXT and not m.group("Msmmo_41") + "simo-" + m.group("Msmmo_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_43>[a-zA-Zç]+[é])simo (?P<Msmmo_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_44") in plvrMfr and not " e " + m.group("Msmmo_43") + "simo " + m.group("Msmmo_44") + "es" in TEXT and not " ou " + m.group("Msmmo_43") + "simo " + m.group("Msmmo_44") + "es" in TEXT and not "s de " + m.group("Msmmo_43") + "simo " + m.group("Msmmo_44") + "es" in TEXT and not "s do " + m.group("Msmmo_43") + "simo " + m.group("Msmmo_44") + "es" in TEXT and not " o " + m.group("Msmmo_43") + "simo " + m.group("Msmmo_44") + "es" in TEXT and not m.group("Msmmo_43") + "simo-" + m.group("Msmmo_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_45>[a-zA-Zç]+[é])simo (?P<Msmmo_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_46") in plvrMascr and not " e " + m.group("Msmmo_45") + "simo " + m.group("Msmmo_46") + "es" in TEXT and not " ou " + m.group("Msmmo_45") + "simo " + m.group("Msmmo_46") + "es" in TEXT and not "s de " + m.group("Msmmo_45") + "simo " + m.group("Msmmo_46") + "es" in TEXT and not "s do " + m.group("Msmmo_45") + "simo " + m.group("Msmmo_46") + "es" in TEXT and not " o " + m.group("Msmmo_45") + "simo " + m.group("Msmmo_46") + "es" in TEXT and not m.group("Msmmo_45") + "simo-" + m.group("Msmmo_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_47>[a-zA-Zç]+[é])simo (?P<Msmmo_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_48") in plvrMfal and not " e " + m.group("Msmmo_47") + "simo " + m.group("Msmmo_48") + "is" in TEXT and not " ou " + m.group("Msmmo_47") + "simo " + m.group("Msmmo_48") + "is" in TEXT and not "s de " + m.group("Msmmo_47") + "simo " + m.group("Msmmo_48") + "is" in TEXT and not "s do " + m.group("Msmmo_47") + "simo " + m.group("Msmmo_48") + "is" in TEXT and not " o " + m.group("Msmmo_47") + "simo " + m.group("Msmmo_48") + "is" in TEXT and not m.group("Msmmo_47") + "simo-" + m.group("Msmmo_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_49>[a-zA-Zç]+[é])simo (?P<Msmmo_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_50") in plvrMfcao and not " e " + m.group("Msmmo_49") + "simo " + m.group("Msmmo_50") + "ões" in TEXT and not + " ou " + m.group("Msmmo_49") + "simo " + m.group("Msmmo_50") + "ões" in TEXT and not + "s de " + m.group("Msmmo_49") + "simo " + m.group("Msmmo_50") + "ões" in TEXT and not + "s do " + m.group("Msmmo_49") + "simo " + m.group("Msmmo_50") + "ões" in TEXT and not + " a " + m.group("Msmmo_49") + "simo " + m.group("Msmmo_50") + "ões" in TEXT and not m.group("Msmmo_49") + "simo-" + m.group("Msmmo_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_51>[a-zA-Zç]+[é])simo (?P<Msmmo_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_52") in plvrNfemcao and not " e " + m.group("Msmmo_51") + "simo " + m.group("Msmmo_52") + "ões" in TEXT and not " ou " + m.group("Msmmo_51") + "simo " + m.group("Msmmo_52") + "ões" in TEXT and not "s de " + m.group("Msmmo_51") + "simo " + m.group("Msmmo_52") + "ões" in TEXT and not "s do " + m.group("Msmmo_51") + "simo " + m.group("Msmmo_52") + "ões" in TEXT and not " o " + m.group("Msmmo_51") + "simo " + m.group("Msmmo_52") + "ões" in TEXT and not m.group("Msmmo_51") + "simo-" + m.group("Msmmo_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_55>[a-zA-Zç]+[é])simo (?P<Msmmo_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_55") + "simo " + m.group("Msmmo_56") + "veis" in TEXT and not " ou " + m.group("Msmmo_55") + "simo " + m.group("Msmmo_56") + "veis" in TEXT and not "s de " + m.group("Msmmo_55") + "simo " + m.group("Msmmo_56") + "veis" in TEXT and not "s do " + m.group("Msmmo_55") + "simo " + m.group("Msmmo_56") + "veis" in TEXT and not " o " + m.group("Msmmo_55") + "simo " + m.group("Msmmo_56") + "veis" in TEXT and not m.group("Msmmo_55") + "simo-" + m.group("Msmmo_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_57>[a-zA-Zç]+[é])simo (?P<Msmmo_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_58").lower() in plvrMfe and not " e " + m.group("Msmmo_57") + "simo " + m.group("Msmmo_58") + "es" in TEXT and not " ou " + m.group("Msmmo_57") + "simo " + m.group("Msmmo_58") + "es" in TEXT and not "s de " + m.group("Msmmo_57") + "simo " + m.group("Msmmo_58") + "es" in TEXT and not "s do " + m.group("Msmmo_57") + "simo " + m.group("Msmmo_58") + "es" in TEXT and not " o " + m.group("Msmmo_57") + "simo " + m.group("Msmmo_58") + "es" in TEXT and not m.group("Msmmo_57") + "simo-" + m.group("Msmmo_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_59>[a-zA-Zç]+[é])simo (?P<Msmmo_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_60").lower() in plvrMasce and not " e " + m.group("Msmmo_59") + "simo " + m.group("Msmmo_60") + "es" in TEXT and not " ou " + m.group("Msmmo_59") + "simo " + m.group("Msmmo_60") + "es" in TEXT and not "s de " + m.group("Msmmo_59") + "simo " + m.group("Msmmo_60") + "es" in TEXT and not "s do " + m.group("Msmmo_59") + "simo " + m.group("Msmmo_60") + "es" in TEXT and not " o " + m.group("Msmmo_59") + "simo " + m.group("Msmmo_60") + "es" in TEXT and not m.group("Msmmo_59") + "simo-" + m.group("Msmmo_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_61>[a-zA-Zç]+[é])simo (?P<Msmmo_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_62") in plvrMfel and not " e " + m.group("Msmmo_61") + "simo " + m.group("Msmmo_62") + "éis" in TEXT and not " ou " + m.group("Msmmo_61") + "simo " + m.group("Msmmo_62") + "éis" in TEXT and not "s de " + m.group("Msmmo_61") + "simo " + m.group("Msmmo_62") + "éis" in TEXT and not "s do " + m.group("Msmmo_61") + "simo " + m.group("Msmmo_62") + "éis" in TEXT and not " o " + m.group("Msmmo_61") + "simo " + m.group("Msmmo_62") + "éis" in TEXT and not m.group("Msmmo_61") + "simo-" + m.group("Msmmo_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_63>[a-zA-Zç]+[é])simo (?P<Msmmo_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_64") in plvrMascel and not " e " + m.group("Msmmo_63") + "simo " + m.group("Msmmo_64") + "éis" in TEXT and not " ou " + m.group("Msmmo_63") + "simo " + m.group("Msmmo_64") + "éis" in TEXT and not "s de " + m.group("Msmmo_63") + "simo " + m.group("Msmmo_64") + "éis" in TEXT and not "s do " + m.group("Msmmo_63") + "simo " + m.group("Msmmo_64") + "éis" in TEXT and not " o " + m.group("Msmmo_63") + "simo " + m.group("Msmmo_64") + "éis" in TEXT and not m.group("Msmmo_63") + "simo-" + m.group("Msmmo_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_65>[a-zA-Zç]+[é])simo (?P<Msmmo_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_66") in plvrMfeu and not " e " + m.group("Msmmo_65") + "simo " + m.group("Msmmo_66") + "us" in TEXT and not " ou " + m.group("Msmmo_65") + "simo " + m.group("Msmmo_66") + "us" in TEXT and not "s de " + m.group("Msmmo_65") + "simo " + m.group("Msmmo_66") + "us" in TEXT and not "s do " + m.group("Msmmo_65") + "simo " + m.group("Msmmo_66") + "us" in TEXT and not " o " + m.group("Msmmo_65") + "simo " + m.group("Msmmo_66") + "us" in TEXT and not m.group("Msmmo_65") + "simo-" + m.group("Msmmo_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_67>[a-zA-Zç]+[é])simo (?P<Msmmo_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_68") in plvrMascu and not " e " + m.group("Msmmo_67") + "simo " + m.group("Msmmo_68") + "us" in TEXT and not " ou " + m.group("Msmmo_67") + "simo " + m.group("Msmmo_68") + "us" in TEXT and not "s de " + m.group("Msmmo_67") + "simo " + m.group("Msmmo_68") + "us" in TEXT and not "s do " + m.group("Msmmo_67") + "simo " + m.group("Msmmo_68") + "us" in TEXT and not " o " + m.group("Msmmo_67") + "simo " + m.group("Msmmo_68") + "us" in TEXT and not m.group("Msmmo_67") + "simo-" + m.group("Msmmo_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_69>[a-zA-Zç]+[é])simo (?P<Msmmo_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_70") in plvrInvaz and not " e " + m.group("Msmmo_69") + "simo " + m.group("Msmmo_70") + "zes" in TEXT and not " ou " + m.group("Msmmo_69") + "simo " + m.group("Msmmo_70") + "zes" in TEXT and not "s de " + m.group("Msmmo_69") + "simo " + m.group("Msmmo_70") + "zes" in TEXT and not "s do " + m.group("Msmmo_69") + "simo " + m.group("Msmmo_70") + "zes" in TEXT and not " o " + m.group("Msmmo_69") + "simo " + m.group("Msmmo_70") + "zes" in TEXT and not m.group("Msmmo_69") + "simo-" + m.group("Msmmo_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_71>[a-zA-Zç]+[é])simo (?P<Msmmo_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_72") in plvrMascz and not " e " + m.group("Msmmo_71") + "simo " + m.group("Msmmo_72") + "zes" in TEXT and not " ou " + m.group("Msmmo_71") + "simo " + m.group("Msmmo_72") + "zes" in TEXT and not "s de " + m.group("Msmmo_71") + "simo " + m.group("Msmmo_72") + "zes" in TEXT and not "s do " + m.group("Msmmo_71") + "simo " + m.group("Msmmo_72") + "zes" in TEXT and not " o " + m.group("Msmmo_71") + "simo " + m.group("Msmmo_72") + "zes" in TEXT and not m.group("Msmmo_71") + "simo-" + m.group("Msmmo_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_73>[a-zA-Zç]+[é])simo (?P<Msmmo_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_74") in pvrMascan and not " e " + m.group("Msmmo_73") + "simo " + m.group("Msmmo_74") + "s" in TEXT and not " ou " + m.group("Msmmo_73") + "simo " + m.group("Msmmo_74") + "s" in TEXT and not "s de " + m.group("Msmmo_73") + "simo " + m.group("Msmmo_74") + "s" in TEXT and not "s do " + m.group("Msmmo_73") + "simo " + m.group("Msmmo_74") + "s" in TEXT and not " o " + m.group("Msmmo_73") + "simo " + m.group("Msmmo_74") + "s" in TEXT and not m.group("Msmmo_73") + "simo-" + m.group("Msmmo_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_75>[a-zA-Zç]+[é])simo (?P<Msmmo_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_76").lower() in plvrMasco and not " e " + m.group("Msmmo_75") + "simo " + m.group("Msmmo_76") +"s" in TEXT and not " ou " + m.group("Msmmo_75") + "simo " + m.group("Msmmo_76") + "s" in TEXT and not "s de " + m.group("Msmmo_75") + "simo " + m.group("Msmmo_76") + "s" in TEXT and not "s do " + m.group("Msmmo_75") + "simo " + m.group("Msmmo_76") + "s" in TEXT and not " o " + m.group("Msmmo_75") + "simo " + m.group("Msmmo_76") + "s" in TEXT and not m.group("Msmmo_75") + "simo-" + m.group("Msmmo_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_77>[a-zA-Zç]+[é])simo (?P<Msmmo_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_77") + "simo " + m.group("Msmmo_78") + "inhos" in TEXT and not " ou " + m.group("Msmmo_77") + "simo " + m.group("Msmmo_78") + "inhos" in TEXT and not "s de " + m.group("Msmmo_77") + "simo " + m.group("Msmmo_78") + "inhos" in TEXT and not "s do " + m.group("Msmmo_77") + "simo " + m.group("Msmmo_78") + "inhos" in TEXT and not " o " + m.group("Msmmo_77") + "simo " + m.group("Msmmo_78") + "inhos" in TEXT and not m.group("Msmmo_77") + "simo-" + m.group("Msmmo_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_79>[a-zA-Zç]+[é])simo (?P<Msmmo_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_79") + "simo " + m.group("Msmmo_80") + "icas" in TEXT and not " ou " + m.group("Msmmo_79") + "simo " + m.group("Msmmo_80") + "icas" in TEXT and not "s de " + m.group("Msmmo_79") + "simo " + m.group("Msmmo_80") + "icas" in TEXT and not "s do " + m.group("Msmmo_79") + "simo " + m.group("Msmmo_80") + "icas" in TEXT and not " o " + m.group("Msmmo_79") + "simo " + m.group("Msmmo_80") + "icas" in TEXT and not m.group("Msmmo_79") + "simo-" + m.group("Msmmo_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_81>[a-zA-Zç]+[é])simo (?P<Msmmo_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_81") + "simo " + m.group("Msmmo_82") + "icas" in TEXT and not " ou " + m.group("Msmmo_81") + "simo " + m.group("Msmmo_82") + "icas" in TEXT and not "s de " + m.group("Msmmo_81") + "simo " + m.group("Msmmo_82") + "icas" in TEXT and not "s do " + m.group("Msmmo_81") + "simo " + m.group("Msmmo_82") + "icas" in TEXT and not " o " + m.group("Msmmo_81") + "simo " + m.group("Msmmo_82") + "icas" in TEXT and not m.group("Msmmo_81") + "simo-" + m.group("Msmmo_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_83>[a-zA-Zç]+[é])simo (?P<Msmmo_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_83") + "simo " + m.group("Msmmo_84") + "icas" in TEXT and not " ou " + m.group("Msmmo_83") + "simo " + m.group("Msmmo_84") + "icas" in TEXT and not "s de " + m.group("Msmmo_83") + "simo " + m.group("Msmmo_84") + "icas" in TEXT and not "s do " + m.group("Msmmo_83") + "simo " + m.group("Msmmo_84") + "icas" in TEXT and not " o " + m.group("Msmmo_83") + "simo " + m.group("Msmmo_84") + "icas" in TEXT and not m.group("Msmmo_83") + "simo-" + m.group("Msmmo_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_85>[a-zA-Zç]+[é])simo (?P<Msmmo_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_85") + "simo " + m.group("Msmmo_86") + "escas" in TEXT and not " ou " + m.group("Msmmo_85") + "simo " + m.group("Msmmo_86") + "escas" in TEXT and not "s de " + m.group("Msmmo_85") + "simo " + m.group("Msmmo_86") + "escas" in TEXT and not "s do " + m.group("Msmmo_85") + "simo " + m.group("Msmmo_86") + "escas" in TEXT and not " o " + m.group("Msmmo_85") + "simo " + m.group("Msmmo_86") + "escas" in TEXT and not m.group("Msmmo_85") + "simo-" + m.group("Msmmo_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_87>[a-zA-Zç]+[é])simo (?P<Msmmo_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_87") + "simo " + m.group("Msmmo_88") + "idas" in TEXT and not " ou " + m.group("Msmmo_87") + "s " + m.group("Msmmo_88") + "idas" in TEXT and not "s de " + m.group("Msmmo_87") + "s " + m.group("Msmmo_88") + "idas" in TEXT and not "s do " + m.group("Msmmo_87") + "s " + m.group("Msmmo_88") + "idas" in TEXT and not " o " + m.group("Msmmo_87") + "s " + m.group("Msmmo_88") + "idas" in TEXT and not m.group("Msmmo_87") + "simo-" + m.group("Msmmo_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_89>[a-zA-Zç]+[é])simo (?P<Msmmo_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_89") + "simo " + m.group("Msmmo_90") + "logas" in TEXT and not " ou " + m.group("Msmmo_89") + "simo " + m.group("Msmmo_90") + "logas" in TEXT and not "s de " + m.group("Msmmo_89") + "simo " + m.group("Msmmo_90") + "logas" in TEXT and not "s do " + m.group("Msmmo_89") + "simo " + m.group("Msmmo_90") + "logas" in TEXT and not " o " + m.group("Msmmo_89") + "simo " + m.group("Msmmo_90") + "logas" in TEXT and not m.group("Msmmo_89") + "simo-" + m.group("Msmmo_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_91>[a-zA-Zç]+[é])simo (?P<Msmmo_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_91") + "simo " + m.group("Msmmo_92") + "rias" in TEXT and not " ou " + m.group("Msmmo_91") + "simo " + m.group("Msmmo_92") + "rias" in TEXT and not "s de " + m.group("Msmmo_91") + "simo " + m.group("Msmmo_92") + "rias" in TEXT and not "s do " + m.group("Msmmo_91") + "simo " + m.group("Msmmo_92") + "rias" in TEXT and not " o " + m.group("Msmmo_91") + "simo " + m.group("Msmmo_92") + "rias" in TEXT and not m.group("Msmmo_91") + "simo-" + m.group("Msmmo_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_93>[a-zA-Zç]+[é])simo (?P<Msmmo_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_93") + "simo " + m.group("Msmmo_94") + "ssimas" in TEXT and not " ou " + m.group("Msmmo_93") + "simo " + m.group("Msmmo_94") + "ssimas" in TEXT and not "s de " + m.group("Msmmo_93") + "simo " + m.group("Msmmo_94") + "ssimas" in TEXT and not "s do " + m.group("Msmmo_93") + "simo " + m.group("Msmmo_94") + "ssimas" in TEXT and not " o " + m.group("Msmmo_93") + "simo " + m.group("Msmmo_94") + "ssimas" in TEXT and not m.group("Msmmo_93") + "simo-" + m.group("Msmmo_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_95>[a-zA-Zç]+[é])simo (?P<Msmmo_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Msmmo_95") + "simo " + m.group("Msmmo_96") + "simas" in TEXT and not " ou " + m.group("Msmmo_95") + "simo " + m.group("Msmmo_96") + "simas" in TEXT and not "s de " + m.group("Msmmo_95") + "simo " + m.group("Msmmo_96") + "simas" in TEXT and not "s do " + m.group("Msmmo_95") + "simo " + m.group("Msmmo_96") + "simas" in TEXT and not " o " + m.group("Msmmo_95") + "simo " + m.group("Msmmo_96") + "simas" in TEXT and not m.group("Msmmo_95") + "simo-" + m.group("Msmmo_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_97>[a-zA-Zç]+[é])simo (?P<Msmmo_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_98").lower() in plvrMfoa and not " e " + m.group("Msmmo_97") + "simo " + m.group("Msmmo_98") + "as" in TEXT and not " ou " + m.group("Msmmo_97") + "simo " + m.group("Msmmo_98") + "as" in TEXT and not "s de " + m.group("Msmmo_97") + "simo " + m.group("Msmmo_98") + "as" in TEXT and not "s do " + m.group("Msmmo_97") + "simo " + m.group("Msmmo_98") + "as" in TEXT and not " o " + m.group("Msmmo_97") + "simo " + m.group("Msmmo_98") + "as" in TEXT and not m.group("Msmmo_97") + "simo-" + m.group("Msmmo_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_99>[a-zA-Zç]+[é])simo (?P<Msmmo_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_100") in plvrMFm and not " e " + m.group("Msmmo_99") + "simo " + m.group("Msmmo_100") + "ns" in TEXT and not " ou " + m.group("Msmmo_99") + "simo " + m.group("Msmmo_100") + "ns" in TEXT and not "s de " + m.group("Msmmo_99") + "simo " + m.group("Msmmo_100") + "ns" in TEXT and not "s da " + m.group("Msmmo_99") + "simo " + m.group("Msmmo_100") + "ns" in TEXT and not " a " + m.group("Msmmo_99") + "simo " + m.group("Msmmo_100") + "ns" in TEXT and not m.group("Msmmo_99") + "simo-" + m.group("Msmmo_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmmo_101>[a-zA-Zç]+[é])simo (?P<Msmmo_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "simos " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmmo_102") in plvrMascm and not " e " + m.group("Msmmo_101") + "simo " + m.group("Msmmo_102") + "ns" in TEXT and not " ou " + m.group("Msmmo_101") + "simo " + m.group("Msmmo_102") + "ns" in TEXT and not "s de " + m.group("Msmmo_101") + "simo " + m.group("Msmmo_102") + "ns" in TEXT and not "s da " + m.group("Msmmo_101") + "simo " + m.group("Msmmo_102") + "ns" in TEXT and not " a " + m.group("Msmmo_101") + "simo " + m.group("Msmmo_102") + "ns" in TEXT and not m.group("Msmmo_101") + "simo-" + m.group("Msmmo_102") + "ns" in tCompostops'],
# ora a
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_1>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_2").lower() in plvrFema and not " e " + m.group("Mstda_1") + "ora " + m.group("Mstda_2") +"s" in TEXT and not " ou " + m.group("Mstda_1") + "ora " + m.group("Mstda_2") + "s" in TEXT and not "s de " + m.group("Mstda_1") + "ora " + m.group("Mstda_2") + "s" in TEXT and not "s da " + m.group("Mstda_1") + "ora " + m.group("Mstda_2") + "s" in TEXT and not " a " + m.group("Mstda_1") + "ora " + m.group("Mstda_2") + "s" in TEXT and not m.group("Mstda_1") + "ora-" + m.group("Mstda_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_3>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_4").lower() in plvrMfoa and not " e " + m.group("Mstda_3") + "ora " + m.group("Mstda_4") + "as" in TEXT and not " ou " + m.group("Mstda_3") + "ora " + m.group("Mstda_4") + "as" in TEXT and not "s de " + m.group("Mstda_3") + "ora " + m.group("Mstda_4") + "as" in TEXT and not "s da " + m.group("Mstda_3") + "ora " + m.group("Mstda_4") + "as" in TEXT and not " a " + m.group("Mstda_3") + "ora " + m.group("Mstda_4") + "as" in TEXT and not m.group("Mstda_3") + "ora-" + m.group("Mstda_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_5>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mstda_6").lower() in excAdo and not " e " + m.group("Mstda_5") + "ora " + m.group("Mstda_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Mstda_5") + "ora " + m.group("Mstda_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Mstda_5") + "ora " + m.group("Mstda_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Mstda_5") + "ora " + m.group("Mstda_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Mstda_5") + "ora " + m.group("Mstda_6") + m.group(3) + "dos" in TEXT and not m.group("Mstda_5") + "ora-" + m.group("Mstda_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_7>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mstda_8").lower() in excIsta and not " e " + m.group("Mstda_7") + "ora " + m.group("Mstda_8") + "s" in TEXT and not " ou " + m.group("Mstda_7") + "ora " + m.group("Mstda_8") + "s" in TEXT and not "s de " + m.group("Mstda_7") + "ora " + m.group("Mstda_8") + "s" in TEXT and not "s da " + m.group("Mstda_7") + "ora " + m.group("Mstda_8") + "s" in TEXT and not " a " + m.group("Mstda_7") + "ora " + m.group("Mstda_8") + "s" in TEXT and not m.group("Mstda_7") + "ora-" + m.group("Mstda_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_9>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_10").lower() in plvrInva and not " e " + m.group("Mstda_9") + "ora " + m.group("Mstda_10") + "s" in TEXT and not " ou " + m.group("Mstda_9") + "ora " + m.group("Mstda_10") + "s" in TEXT and not "s de " + m.group("Mstda_9") + "ora " + m.group("Mstda_10") + "s" in TEXT and not "s da " + m.group("Mstda_9") + "ora " + m.group("Mstda_10") + "s" in TEXT and not " a " + m.group("Mstda_9") + "ora " + m.group("Mstda_10") + "s" in TEXT and not m.group("Mstda_9") + "ora-" + m.group("Mstda_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_11>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mstda_12").lower() in excAdo and not " e " + m.group("Mstda_11") + "ora " + m.group("Mstda_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Mstda_11") + "ora " + m.group("Mstda_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Mstda_11") + "ora " + m.group("Mstda_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Mstda_11") + "ora " + m.group("Mstda_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Mstda_11") + "ora " + m.group("Mstda_12") + m.group(3) + "das" in TEXT and not m.group("Mstda_11") + "ora-" + m.group("Mstda_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_13>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstda_13") + "ora " + m.group("Mstda_14") + "osos" in TEXT and not " ou " + m.group("Mstda_13") + "ora " + m.group("Mstda_14") + "osos" in TEXT and not "s de " + m.group("Mstda_13") + "ora " + m.group("Mstda_14") + "osos" in TEXT and not "s da " + m.group("Mstda_13") + "ora " + m.group("Mstda_14") + "osos" in TEXT and not " a " + m.group("Mstda_13") + "ora " + m.group("Mstda_14") + "osos" in TEXT and not m.group("Mstda_13") + "ora-" + m.group("Mstda_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_15>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstda_15") + "ora " + m.group("Mstda_16") + "osas" in TEXT and not " ou " + m.group("Mstda_15") + "ora " + m.group("Mstda_16") + "osas" in TEXT and not "s de " + m.group("Mstda_15") + "ora " + m.group("Mstda_16") + "osas" in TEXT and not "s da " + m.group("Mstda_15") + "ora " + m.group("Mstda_16") + "osas" in TEXT and not " a " + m.group("Mstda_15") + "ora " + m.group("Mstda_16") + "osas" in TEXT and not m.group("Mstda_15") + "ora-" + m.group("Mstda_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_17>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstda_17") + "ora " + m.group("Mstda_18") + "ivas" in TEXT and not " ou " + m.group("Mstda_17") + "ora " + m.group("Mstda_18") + "ivas" in TEXT and not "s de " + m.group("Mstda_17") + "ora " + m.group("Mstda_18") + "ivas" in TEXT and not "s da " + m.group("Mstda_17") + "ora " + m.group("Mstda_18") + "ivas" in TEXT and not " a " + m.group("Mstda_17") + "ora " + m.group("Mstda_18") + "ivas" in TEXT and not m.group("Mstda_17") + "ora-" + m.group("Mstda_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_19>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstda_19") + "ora " + m.group("Mstda_20") + "ivas" in TEXT and not " ou " + m.group("Mstda_19") + "ora " + m.group("Mstda_20") + "ivas" in TEXT and not "s de " + m.group("Mstda_19") + "ora " + m.group("Mstda_20") + "ivas" in TEXT and not "s da " + m.group("Mstda_19") + "ora " + m.group("Mstda_20") + "ivas" in TEXT and not " a " + m.group("Mstda_19") + "ora " + m.group("Mstda_20") + "ivas" in TEXT and not m.group("Mstda_19") + "ora-" + m.group("Mstda_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_21>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstda_21") + "ora " + m.group("Mstda_22") + "icas" in TEXT and not " ou " + m.group("Mstda_21") + "ora " + m.group("Mstda_22") + "icas" in TEXT and not "s de " + m.group("Mstda_21") + "ora " + m.group("Mstda_22") + "icas" in TEXT and not "s da " + m.group("Mstda_21") + "ora " + m.group("Mstda_22") + "icas" in TEXT and not " a " + m.group("Mstda_21") + "ora " + m.group("Mstda_22") + "icas" in TEXT and not m.group("Mstda_21") + "ora-" + m.group("Mstda_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_23>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstda_23") + "ora " + m.group("Mstda_24") + "icas" in TEXT and not " ou " + m.group("Mstda_23") + "ora " + m.group("Mstda_24") + "icas" in TEXT and not "s de " + m.group("Mstda_23") + "ora " + m.group("Mstda_24") + "icas" in TEXT and not "s da " + m.group("Mstda_23") + "ora " + m.group("Mstda_24") + "icas" in TEXT and not " a " + m.group("Mstda_23") + "ora " + m.group("Mstda_24") + "icas" in TEXT and not m.group("Mstda_23") + "ora-" + m.group("Mstda_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_25>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstda_25") + "ora " + m.group("Mstda_26") + "icas" in TEXT and not " ou " + m.group("Mstda_25") + "ora " + m.group("Mstda_26") + "icas" in TEXT and not "s de " + m.group("Mstda_25") + "ora " + m.group("Mstda_26") + "icas" in TEXT and not "s da " + m.group("Mstda_25") + "ora " + m.group("Mstda_26") + "icas" in TEXT and not " a " + m.group("Mstda_25") + "ora " + m.group("Mstda_26") + "icas" in TEXT and not m.group("Mstda_25") + "ora-" + m.group("Mstda_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_27>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstda_27") + "ora " + m.group("Mstda_28") + "escas" in TEXT and not " ou " + m.group("Mstda_27") + "ora " + m.group("Mstda_28") + "escas" in TEXT and not "s de " + m.group("Mstda_27") + "ora " + m.group("Mstda_28") + "escas" in TEXT and not "s da " + m.group("Mstda_27") + "ora " + m.group("Mstda_28") + "escas" in TEXT and not " a " + m.group("Mstda_27") + "ora " + m.group("Mstda_28") + "escas" in TEXT and not m.group("Mstda_27") + "ora-" + m.group("Mstda_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_29>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstda_29") + "ora " + m.group("Mstda_30") + "idas" in TEXT and not " ou " + m.group("Mstda_29") + "s " + m.group("Mstda_30") + "idas" in TEXT and not "s de " + m.group("Mstda_29") + "s " + m.group("Mstda_30") + "idas" in TEXT and not "s da " + m.group("Mstda_29") + "s " + m.group("Mstda_30") + "idas" in TEXT and not " a " + m.group("Mstda_29") + "s " + m.group("Mstda_30") + "idas" in TEXT and not m.group("Mstda_29") + "ora-" + m.group("Mstda_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_31>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstda_31") + "ora " + m.group("Mstda_32") + "logas" in TEXT and not " ou " + m.group("Mstda_31") + "ora " + m.group("Mstda_32") + "logas" in TEXT and not "s de " + m.group("Mstda_31") + "ora " + m.group("Mstda_32") + "logas" in TEXT and not "s da " + m.group("Mstda_31") + "ora " + m.group("Mstda_32") + "logas" in TEXT and not " a " + m.group("Mstda_31") + "ora " + m.group("Mstda_32") + "logas" in TEXT and not m.group("Mstda_31") + "ora-" + m.group("Mstda_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_33>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstda_33") + "ora " + m.group("Mstda_34") + "rias" in TEXT and not " ou " + m.group("Mstda_33") + "ora " + m.group("Mstda_34") + "rias" in TEXT and not "s de " + m.group("Mstda_33") + "ora " + m.group("Mstda_34") + "rias" in TEXT and not "s da " + m.group("Mstda_33") + "ora " + m.group("Mstda_34") + "rias" in TEXT and not " a " + m.group("Mstda_33") + "ora " + m.group("Mstda_34") + "rias" in TEXT and not m.group("Mstda_33") + "ora-" + m.group("Mstda_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_35>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstda_35") + "ora " + m.group("Mstda_36") + "ssimas" in TEXT and not " ou " + m.group("Mstda_35") + "ora " + m.group("Mstda_36") + "ssimas" in TEXT and not "s de " + m.group("Mstda_35") + "ora " + m.group("Mstda_36") + "ssimas" in TEXT and not "s da " + m.group("Mstda_35") + "ora " + m.group("Mstda_36") + "ssimas" in TEXT and not " a " + m.group("Mstda_35") + "ora " + m.group("Mstda_36") + "ssimas" in TEXT and not m.group("Mstda_35") + "ora-" + m.group("Mstda_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_37>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstda_37") + "ora " + m.group("Mstda_38") + "simas" in TEXT and not " ou " + m.group("Mstda_37") + "ora " + m.group("Mstda_38") + "simas" in TEXT and not "s de " + m.group("Mstda_37") + "ora " + m.group("Mstda_38") + "simas" in TEXT and not "s da " + m.group("Mstda_37") + "ora " + m.group("Mstda_38") + "simas" in TEXT and not " a " + m.group("Mstda_37") + "ora " + m.group("Mstda_38") + "simas" in TEXT and not m.group("Mstda_37") + "ora-" + m.group("Mstda_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_41>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mstda_42") in "D-d-" and not " e " + m.group("Mstda_41") + "ora " + m.group("Mstda_42") + "oras" in TEXT and not " ou " + m.group("Mstda_41") + "ora " + m.group("Mstda_42") + "oras" in TEXT and not "s de " + m.group("Mstda_41") + "ora " + m.group("Mstda_42") + "oras" in TEXT and not "s da " + m.group("Mstda_41") + "ora " + m.group("Mstda_42") + "oras" in TEXT and not " a " + m.group("Mstda_41") + "ora " + m.group("Mstda_42") + "oras" in TEXT and not m.group("Mstda_41") + "ora-" + m.group("Mstda_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_43>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_44") in plvrMfr and not " e " + m.group("Mstda_43") + "ora " + m.group("Mstda_44") + "es" in TEXT and not " ou " + m.group("Mstda_43") + "ora " + m.group("Mstda_44") + "es" in TEXT and not "s de " + m.group("Mstda_43") + "ora " + m.group("Mstda_44") + "es" in TEXT and not "s da " + m.group("Mstda_43") + "ora " + m.group("Mstda_44") + "es" in TEXT and not " a " + m.group("Mstda_43") + "ora " + m.group("Mstda_44") + "es" in TEXT and not m.group("Mstda_43") + "ora-" + m.group("Mstda_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_45>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_46") in plvrFemr and not " e " + m.group("Mstda_45") + "ora " + m.group("Mstda_46") + "es" in TEXT and not " ou " + m.group("Mstda_45") + "ora " + m.group("Mstda_46") + "es" in TEXT and not "s de " + m.group("Mstda_45") + "ora " + m.group("Mstda_46") + "es" in TEXT and not "s da " + m.group("Mstda_45") + "ora " + m.group("Mstda_46") + "es" in TEXT and not " a " + m.group("Mstda_45") + "ora " + m.group("Mstda_46") + "es" in TEXT and not m.group("Mstda_45") + "ora-" + m.group("Mstda_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_47>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_48") in plvrMfal and not " e " + m.group("Mstda_47") + "ora " + m.group("Mstda_48") + "is" in TEXT and not " ou " + m.group("Mstda_47") + "ora " + m.group("Mstda_48") + "is" in TEXT and not "s de " + m.group("Mstda_47") + "ora " + m.group("Mstda_48") + "is" in TEXT and not "s da " + m.group("Mstda_47") + "ora " + m.group("Mstda_48") + "is" in TEXT and not " a " + m.group("Mstda_47") + "ora " + m.group("Mstda_48") + "is" in TEXT and not m.group("Mstda_47") + "ora-" + m.group("Mstda_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_49>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_50") in plvrMfcao and not " e " + m.group("Mstda_49") + "ora " + m.group("Mstda_50") + "ões" in TEXT and not + " ou " + m.group("Mstda_49") + "ora " + m.group("Mstda_50") + "ões" in TEXT and not + "s de " + m.group("Mstda_49") + "ora " + m.group("Mstda_50") + "ões" in TEXT and not + "s da " + m.group("Mstda_49") + "ora " + m.group("Mstda_50") + "ões" in TEXT and not + " a " + m.group("Mstda_49") + "ora " + m.group("Mstda_50") + "ões" in TEXT and not m.group("Mstda_49") + "ora-" + m.group("Mstda_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_51>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mstda_52") in plvrMascao and not " e " + m.group("Mstda_51") + "ora " + m.group("Mstda_52") + "ões" in TEXT and not " ou " + m.group("Mstda_51") + "ora " + m.group("Mstda_52") + "ões" in TEXT and not "s de " + m.group("Mstda_51") + "ora " + m.group("Mstda_52") + "ões" in TEXT and not "s da " + m.group("Mstda_51") + "ora " + m.group("Mstda_52") + "ões" in TEXT and not " a " + m.group("Mstda_51") + "ora " + m.group("Mstda_52") + "ões" in TEXT and not m.group("Mstda_51") + "ora-" + m.group("Mstda_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_53>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_54") in plvrFemao and not " e " + m.group("Mstda_53") + "ora " + m.group("Mstda_54") + "ões" in TEXT and not " ou " + m.group("Mstda_53") + "ora " + m.group("Mstda_54") + "ões" in TEXT and not "s de " + m.group("Mstda_53") + "ora " + m.group("Mstda_54") + "ões" in TEXT and not "s da " + m.group("Mstda_53") + "ora " + m.group("Mstda_54") + "ões" in TEXT and not " a " + m.group("Mstda_53") + "ora " + m.group("Mstda_54") + "ões" in TEXT and not m.group("Mstda_53") + "ora-" + m.group("Mstda_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_55>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstda_55") + "ora " + m.group("Mstda_56") + "veis" in TEXT and not " ou " + m.group("Mstda_55") + "ora " + m.group("Mstda_56") + "veis" in TEXT and not "s de " + m.group("Mstda_55") + "ora " + m.group("Mstda_56") + "veis" in TEXT and not "s da " + m.group("Mstda_55") + "ora " + m.group("Mstda_56") + "veis" in TEXT and not " a " + m.group("Mstda_55") + "ora " + m.group("Mstda_56") + "veis" in TEXT and not m.group("Mstda_55") + "ora-" + m.group("Mstda_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_57>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_58").lower() in plvrMfe and not " e " + m.group("Mstda_57") + "ora " + m.group("Mstda_58") + "es" in TEXT and not " ou " + m.group("Mstda_57") + "ora " + m.group("Mstda_58") + "es" in TEXT and not "s de " + m.group("Mstda_57") + "ora " + m.group("Mstda_58") + "es" in TEXT and not "s da " + m.group("Mstda_57") + "ora " + m.group("Mstda_58") + "es" in TEXT and not " a " + m.group("Mstda_57") + "ora " + m.group("Mstda_58") + "es" in TEXT and not m.group("Mstda_57") + "ora-" + m.group("Mstda_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_59>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_60").lower() in plvrFeme and not " e " + m.group("Mstda_59") + "ora " + m.group("Mstda_60") + "es" in TEXT and not " ou " + m.group("Mstda_59") + "ora " + m.group("Mstda_60") + "es" in TEXT and not "s de " + m.group("Mstda_59") + "ora " + m.group("Mstda_60") + "es" in TEXT and not "s da " + m.group("Mstda_59") + "ora " + m.group("Mstda_60") + "es" in TEXT and not " a " + m.group("Mstda_59") + "ora " + m.group("Mstda_60") + "es" in TEXT and not m.group("Mstda_59") + "ora-" + m.group("Mstda_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_61>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_62") in plvrMfel and not " e " + m.group("Mstda_61") + "ora " + m.group("Mstda_62") + "éis" in TEXT and not " ou " + m.group("Mstda_61") + "ora " + m.group("Mstda_62") + "éis" in TEXT and not "s de " + m.group("Mstda_61") + "ora " + m.group("Mstda_62") + "éis" in TEXT and not "s da " + m.group("Mstda_61") + "ora " + m.group("Mstda_62") + "éis" in TEXT and not " a " + m.group("Mstda_61") + "ora " + m.group("Mstda_62") + "éis" in TEXT and not m.group("Mstda_61") + "ora-" + m.group("Mstda_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_63>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_64") in plvrFemel and not " e " + m.group("Mstda_63") + "ora " + m.group("Mstda_64") + "éis" in TEXT and not " ou " + m.group("Mstda_63") + "ora " + m.group("Mstda_64") + "éis" in TEXT and not "s de " + m.group("Mstda_63") + "ora " + m.group("Mstda_64") + "éis" in TEXT and not "s da " + m.group("Mstda_63") + "ora " + m.group("Mstda_64") + "éis" in TEXT and not " a " + m.group("Mstda_63") + "ora " + m.group("Mstda_64") + "éis" in TEXT and not m.group("Mstda_63") + "ora-" + m.group("Mstda_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_65>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_66") in plvrMfeu and not " e " + m.group("Mstda_65") + "ora " + m.group("Mstda_66") + "us" in TEXT and not " ou " + m.group("Mstda_65") + "ora " + m.group("Mstda_66") + "us" in TEXT and not "s de " + m.group("Mstda_65") + "ora " + m.group("Mstda_66") + "us" in TEXT and not "s da " + m.group("Mstda_65") + "ora " + m.group("Mstda_66") + "us" in TEXT and not " a " + m.group("Mstda_65") + "ora " + m.group("Mstda_66") + "us" in TEXT and not m.group("Mstda_65") + "ora-" + m.group("Mstda_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_67>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_68") in plvrFemu and not " e " + m.group("Mstda_67") + "ora " + m.group("Mstda_68") + "us" in TEXT and not " ou " + m.group("Mstda_67") + "ora " + m.group("Mstda_68") + "us" in TEXT and not "s de " + m.group("Mstda_67") + "ora " + m.group("Mstda_68") + "us" in TEXT and not "s da " + m.group("Mstda_67") + "ora " + m.group("Mstda_68") + "us" in TEXT and not " a " + m.group("Mstda_67") + "ora " + m.group("Mstda_68") + "us" in TEXT and not m.group("Mstda_67") + "ora-" + m.group("Mstda_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_69>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_70") in plvrInvaz and not " e " + m.group("Mstda_69") + "ora " + m.group("Mstda_70") + "zes" in TEXT and not " ou " + m.group("Mstda_69") + "ora " + m.group("Mstda_70") + "zes" in TEXT and not "s de " + m.group("Mstda_69") + "ora " + m.group("Mstda_70") + "zes" in TEXT and not "s da " + m.group("Mstda_69") + "ora " + m.group("Mstda_70") + "zes" in TEXT and not " a " + m.group("Mstda_69") + "ora " + m.group("Mstda_70") + "zes" in TEXT and not m.group("Mstda_69") + "ora-" + m.group("Mstda_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_71>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_72") in plvrFemz and not " e " + m.group("Mstda_71") + "ora " + m.group("Mstda_72") + "zes" in TEXT and not " ou " + m.group("Mstda_71") + "ora " + m.group("Mstda_72") + "zes" in TEXT and not "s de " + m.group("Mstda_71") + "ora " + m.group("Mstda_72") + "zes" in TEXT and not "s da " + m.group("Mstda_71") + "ora " + m.group("Mstda_72") + "zes" in TEXT and not " a " + m.group("Mstda_71") + "ora " + m.group("Mstda_72") + "zes" in TEXT and not m.group("Mstda_71") + "ora-" + m.group("Mstda_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_73>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_74") in pvrFeman and not " e " + m.group("Mstda_73") + "ora " + m.group("Mstda_74") + "s" in TEXT and not " ou " + m.group("Mstda_73") + "ora " + m.group("Mstda_74") + "s" in TEXT and not "s de " + m.group("Mstda_73") + "ora " + m.group("Mstda_74") + "s" in TEXT and not "s da " + m.group("Mstda_73") + "ora " + m.group("Mstda_74") + "s" in TEXT and not " a " + m.group("Mstda_73") + "ora " + m.group("Mstda_74") + "s" in TEXT and not m.group("Mstda_73") + "ora-" + m.group("Mstda_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_99>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_100") in plvrMFm and not " e " + m.group("Mstda_99") + "ora " + m.group("Mstda_100") + "ns" in TEXT and not " ou " + m.group("Mstda_99") + "ora " + m.group("Mstda_100") + "ns" in TEXT and not "s de " + m.group("Mstda_99") + "ora " + m.group("Mstda_100") + "ns" in TEXT and not "s da " + m.group("Mstda_99") + "ora " + m.group("Mstda_100") + "ns" in TEXT and not " a " + m.group("Mstda_99") + "ora " + m.group("Mstda_100") + "ns" in TEXT and not m.group("Mstda_99") + "ora-" + m.group("Mstda_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstda_101>[a-zA-Zçáéíóúâêô]+[dst])ora (?P<Mstda_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "oras " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstda_102") in plvrFemm and not " e " + m.group("Mstda_101") + "ora " + m.group("Mstda_102") + "ns" in TEXT and not " ou " + m.group("Mstda_101") + "ora " + m.group("Mstda_102") + "ns" in TEXT and not "s de " + m.group("Mstda_101") + "ora " + m.group("Mstda_102") + "ns" in TEXT and not "s da " + m.group("Mstda_101") + "ora " + m.group("Mstda_102") + "ns" in TEXT and not " a " + m.group("Mstda_101") + "ora " + m.group("Mstda_102") + "ns" in TEXT and not m.group("Mstda_101") + "ora-" + m.group("Mstda_102") + "ns" in tCompostops'],
# or o
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_1>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_2").lower() in plvrMasca and not " e " + m.group("Mstdo_1") + "or " + m.group("Mstdo_2") +"s" in TEXT and not " ou " + m.group("Mstdo_1") + "or " + m.group("Mstdo_2") + "s" in TEXT and not "s de " + m.group("Mstdo_1") + "or " + m.group("Mstdo_2") + "s" in TEXT and not "s do " + m.group("Mstdo_1") + "or " + m.group("Mstdo_2") + "s" in TEXT and not " o " + m.group("Mstdo_1") + "or " + m.group("Mstdo_2") + "s" in TEXT and not m.group("Mstdo_1") + "or-" + m.group("Mstdo_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_3>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_4").lower() in plvrMfoa and not " e " + m.group("Mstdo_3") + "or " + m.group("Mstdo_4") + "os" in TEXT and not " ou " + m.group("Mstdo_3") + "or " + m.group("Mstdo_4") + "os" in TEXT and not "s de " + m.group("Mstdo_3") + "or " + m.group("Mstdo_4") + "os" in TEXT and not "s do " + m.group("Mstdo_3") + "or " + m.group("Mstdo_4") + "os" in TEXT and not " o " + m.group("Mstdo_3") + "or " + m.group("Mstdo_4") + "os" in TEXT and not m.group("Mstdo_3") + "or-" + m.group("Mstdo_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_5>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mstdo_6").lower() in excAdo and not " e " + m.group("Mstdo_5") + "or " + m.group("Mstdo_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Mstdo_5") + "or " + m.group("Mstdo_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Mstdo_5") + "or " + m.group("Mstdo_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Mstdo_5") + "or " + m.group("Mstdo_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Mstdo_5") + "or " + m.group("Mstdo_6") + m.group(3) + "dos" in TEXT and not m.group("Mstdo_5") + "or-" + m.group("Mstdo_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_7>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mstdo_8").lower() in excIsta and not " e " + m.group("Mstdo_7") + "or " + m.group("Mstdo_8") + "s" in TEXT and not " ou " + m.group("Mstdo_7") + "or " + m.group("Mstdo_8") + "s" in TEXT and not "s de " + m.group("Mstdo_7") + "or " + m.group("Mstdo_8") + "s" in TEXT and not "s do " + m.group("Mstdo_7") + "or " + m.group("Mstdo_8") + "s" in TEXT and not " o " + m.group("Mstdo_7") + "or " + m.group("Mstdo_8") + "s" in TEXT and not m.group("Mstdo_7") + "or-" + m.group("Mstdo_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_9>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_10").lower() in plvrInva and not " e " + m.group("Mstdo_9") + "or " + m.group("Mstdo_10") + "s" in TEXT and not " ou " + m.group("Mstdo_9") + "or " + m.group("Mstdo_10") + "s" in TEXT and not "s de " + m.group("Mstdo_9") + "or " + m.group("Mstdo_10") + "s" in TEXT and not "s do " + m.group("Mstdo_9") + "or " + m.group("Mstdo_10") + "s" in TEXT and not " a " + m.group("Mstdo_9") + "or " + m.group("Mstdo_10") + "s" in TEXT and not m.group("Mstdo_9") + "or-" + m.group("Mstdo_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_11>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mstdo_12").lower() in excAdo and not " e " + m.group("Mstdo_11") + "or " + m.group("Mstdo_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Mstdo_11") + "or " + m.group("Mstdo_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Mstdo_11") + "or " + m.group("Mstdo_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Mstdo_11") + "or " + m.group("Mstdo_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Mstdo_11") + "or " + m.group("Mstdo_12") + m.group(3) + "das" in TEXT and not m.group("Mstdo_11") + "or-" + m.group("Mstdo_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_13>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_13") + "or " + m.group("Mstdo_14") + "osos" in TEXT and not " ou " + m.group("Mstdo_13") + "or " + m.group("Mstdo_14") + "osos" in TEXT and not "s de " + m.group("Mstdo_13") + "or " + m.group("Mstdo_14") + "osos" in TEXT and not "s do " + m.group("Mstdo_13") + "or " + m.group("Mstdo_14") + "osos" in TEXT and not " o " + m.group("Mstdo_13") + "or " + m.group("Mstdo_14") + "osos" in TEXT and not m.group("Mstdo_13") + "or-" + m.group("Mstdo_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_15>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_15") + "or " + m.group("Mstdo_16") + "osas" in TEXT and not " ou " + m.group("Mstdo_15") + "or " + m.group("Mstdo_16") + "osas" in TEXT and not "s de " + m.group("Mstdo_15") + "or " + m.group("Mstdo_16") + "osas" in TEXT and not "s do " + m.group("Mstdo_15") + "or " + m.group("Mstdo_16") + "osas" in TEXT and not " o " + m.group("Mstdo_15") + "or " + m.group("Mstdo_16") + "osas" in TEXT and not m.group("Mstdo_15") + "or-" + m.group("Mstdo_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_17>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_17") + "or " + m.group("Mstdo_18") + "ivas" in TEXT and not " ou " + m.group("Mstdo_17") + "or " + m.group("Mstdo_18") + "ivas" in TEXT and not "s de " + m.group("Mstdo_17") + "or " + m.group("Mstdo_18") + "ivas" in TEXT and not "s do " + m.group("Mstdo_17") + "or " + m.group("Mstdo_18") + "ivas" in TEXT and not " o " + m.group("Mstdo_17") + "or " + m.group("Mstdo_18") + "ivas" in TEXT and not m.group("Mstdo_17") + "or-" + m.group("Mstdo_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_19>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_19") + "or " + m.group("Mstdo_20") + "ivas" in TEXT and not " ou " + m.group("Mstdo_19") + "or " + m.group("Mstdo_20") + "ivas" in TEXT and not "s de " + m.group("Mstdo_19") + "or " + m.group("Mstdo_20") + "ivas" in TEXT and not "s do " + m.group("Mstdo_19") + "or " + m.group("Mstdo_20") + "ivas" in TEXT and not " o " + m.group("Mstdo_19") + "or " + m.group("Mstdo_20") + "ivas" in TEXT and not m.group("Mstdo_19") + "or-" + m.group("Mstdo_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_21>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_21") + "or " + m.group("Mstdo_22") + "icos" in TEXT and not " ou " + m.group("Mstdo_21") + "or " + m.group("Mstdo_22") + "icos" in TEXT and not "s de " + m.group("Mstdo_21") + "or " + m.group("Mstdo_22") + "icos" in TEXT and not "s do " + m.group("Mstdo_21") + "or " + m.group("Mstdo_22") + "icos" in TEXT and not " o " + m.group("Mstdo_21") + "or " + m.group("Mstdo_22") + "icos" in TEXT and not m.group("Mstdo_21") + "or-" + m.group("Mstdo_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_23>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_23") + "or " + m.group("Mstdo_24") + "icos" in TEXT and not " ou " + m.group("Mstdo_23") + "or " + m.group("Mstdo_24") + "icos" in TEXT and not "s de " + m.group("Mstdo_23") + "or " + m.group("Mstdo_24") + "icos" in TEXT and not "s do " + m.group("Mstdo_23") + "or " + m.group("Mstdo_24") + "icos" in TEXT and not " o " + m.group("Mstdo_23") + "or " + m.group("Mstdo_24") + "icos" in TEXT and not m.group("Mstdo_23") + "or-" + m.group("Mstdo_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_25>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_25") + "or " + m.group("Mstdo_26") + "icos" in TEXT and not " ou " + m.group("Mstdo_25") + "or " + m.group("Mstdo_26") + "icos" in TEXT and not "s de " + m.group("Mstdo_25") + "or " + m.group("Mstdo_26") + "icos" in TEXT and not "s do " + m.group("Mstdo_25") + "or " + m.group("Mstdo_26") + "icos" in TEXT and not " o " + m.group("Mstdo_25") + "or " + m.group("Mstdo_26") + "icos" in TEXT and not m.group("Mstdo_25") + "or-" + m.group("Mstdo_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_27>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_27") + "or " + m.group("Mstdo_28") + "escos" in TEXT and not " ou " + m.group("Mstdo_27") + "or " + m.group("Mstdo_28") + "escos" in TEXT and not "s de " + m.group("Mstdo_27") + "or " + m.group("Mstdo_28") + "escos" in TEXT and not "s do " + m.group("Mstdo_27") + "or " + m.group("Mstdo_28") + "escos" in TEXT and not " o " + m.group("Mstdo_27") + "or " + m.group("Mstdo_28") + "escos" in TEXT and not m.group("Mstdo_27") + "or-" + m.group("Mstdo_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_29>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_29") + "or " + m.group("Mstdo_30") + "idos" in TEXT and not " ou " + m.group("Mstdo_29") + "s " + m.group("Mstdo_30") + "idos" in TEXT and not "s de " + m.group("Mstdo_29") + "s " + m.group("Mstdo_30") + "idos" in TEXT and not "s do " + m.group("Mstdo_29") + "s " + m.group("Mstdo_30") + "idos" in TEXT and not " o " + m.group("Mstdo_29") + "s " + m.group("Mstdo_30") + "idos" in TEXT and not m.group("Mstdo_29") + "or-" + m.group("Mstdo_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_31>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_31") + "or " + m.group("Mstdo_32") + "logos" in TEXT and not " ou " + m.group("Mstdo_31") + "or " + m.group("Mstdo_32") + "logos" in TEXT and not "s de " + m.group("Mstdo_31") + "or " + m.group("Mstdo_32") + "logos" in TEXT and not "s do " + m.group("Mstdo_31") + "or " + m.group("Mstdo_32") + "logos" in TEXT and not " o " + m.group("Mstdo_31") + "or " + m.group("Mstdo_32") + "logos" in TEXT and not m.group("Mstdo_31") + "or-" + m.group("Mstdo_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_33>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_33") + "or " + m.group("Mstdo_34") + "rios" in TEXT and not " ou " + m.group("Mstdo_33") + "or " + m.group("Mstdo_34") + "rios" in TEXT and not "s de " + m.group("Mstdo_33") + "or " + m.group("Mstdo_34") + "rios" in TEXT and not "s do " + m.group("Mstdo_33") + "or " + m.group("Mstdo_34") + "rios" in TEXT and not " o " + m.group("Mstdo_33") + "or " + m.group("Mstdo_34") + "rios" in TEXT and not m.group("Mstdo_33") + "or-" + m.group("Mstdo_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_35>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_35") + "or " + m.group("Mstdo_36") + "ssimos" in TEXT and not " ou " + m.group("Mstdo_35") + "or " + m.group("Mstdo_36") + "ssimos" in TEXT and not "s de " + m.group("Mstdo_35") + "or " + m.group("Mstdo_36") + "ssimos" in TEXT and not "s do " + m.group("Mstdo_35") + "or " + m.group("Mstdo_36") + "ssimos" in TEXT and not " o " + m.group("Mstdo_35") + "or " + m.group("Mstdo_36") + "ssimos" in TEXT and not m.group("Mstdo_35") + "or-" + m.group("Mstdo_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_37>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_37") + "or " + m.group("Mstdo_38") + "simos" in TEXT and not " ou " + m.group("Mstdo_37") + "or " + m.group("Mstdo_38") + "simos" in TEXT and not "s de " + m.group("Mstdo_37") + "or " + m.group("Mstdo_38") + "simos" in TEXT and not "s do " + m.group("Mstdo_37") + "or " + m.group("Mstdo_38") + "simos" in TEXT and not " o " + m.group("Mstdo_37") + "or " + m.group("Mstdo_38") + "simos" in TEXT and not m.group("Mstdo_37") + "or-" + m.group("Mstdo_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_41>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mstdo_42") in "D-d-" and not " e " + m.group("Mstdo_41") + "or " + m.group("Mstdo_42") + "ores" in TEXT and not " ou " + m.group("Mstdo_41") + "or " + m.group("Mstdo_42") + "ores" in TEXT and not "s de " + m.group("Mstdo_41") + "or " + m.group("Mstdo_42") + "ores" in TEXT and not "s do " + m.group("Mstdo_41") + "or " + m.group("Mstdo_42") + "ores" in TEXT and not " o " + m.group("Mstdo_41") + "or " + m.group("Mstdo_42") + "ores" in TEXT and not m.group("Mstdo_41") + "or-" + m.group("Mstdo_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_43>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_44") in plvrMfr and not " e " + m.group("Mstdo_43") + "or " + m.group("Mstdo_44") + "es" in TEXT and not " ou " + m.group("Mstdo_43") + "or " + m.group("Mstdo_44") + "es" in TEXT and not "s de " + m.group("Mstdo_43") + "or " + m.group("Mstdo_44") + "es" in TEXT and not "s do " + m.group("Mstdo_43") + "or " + m.group("Mstdo_44") + "es" in TEXT and not " o " + m.group("Mstdo_43") + "or " + m.group("Mstdo_44") + "es" in TEXT and not m.group("Mstdo_43") + "or-" + m.group("Mstdo_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_45>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_46") in plvrMascr and not " e " + m.group("Mstdo_45") + "or " + m.group("Mstdo_46") + "es" in TEXT and not " ou " + m.group("Mstdo_45") + "or " + m.group("Mstdo_46") + "es" in TEXT and not "s de " + m.group("Mstdo_45") + "or " + m.group("Mstdo_46") + "es" in TEXT and not "s do " + m.group("Mstdo_45") + "or " + m.group("Mstdo_46") + "es" in TEXT and not " o " + m.group("Mstdo_45") + "or " + m.group("Mstdo_46") + "es" in TEXT and not m.group("Mstdo_45") + "or-" + m.group("Mstdo_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_47>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_48") in plvrMfal and not " e " + m.group("Mstdo_47") + "or " + m.group("Mstdo_48") + "is" in TEXT and not " ou " + m.group("Mstdo_47") + "or " + m.group("Mstdo_48") + "is" in TEXT and not "s de " + m.group("Mstdo_47") + "or " + m.group("Mstdo_48") + "is" in TEXT and not "s do " + m.group("Mstdo_47") + "or " + m.group("Mstdo_48") + "is" in TEXT and not " o " + m.group("Mstdo_47") + "or " + m.group("Mstdo_48") + "is" in TEXT and not m.group("Mstdo_47") + "or-" + m.group("Mstdo_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_49>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_50") in plvrMfcao and not " e " + m.group("Mstdo_49") + "or " + m.group("Mstdo_50") + "ões" in TEXT and not + " ou " + m.group("Mstdo_49") + "or " + m.group("Mstdo_50") + "ões" in TEXT and not + "s de " + m.group("Mstdo_49") + "or " + m.group("Mstdo_50") + "ões" in TEXT and not + "s do " + m.group("Mstdo_49") + "or " + m.group("Mstdo_50") + "ões" in TEXT and not + " a " + m.group("Mstdo_49") + "or " + m.group("Mstdo_50") + "ões" in TEXT and not m.group("Mstdo_49") + "or-" + m.group("Mstdo_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_51>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_52") in plvrNfemcao and not " e " + m.group("Mstdo_51") + "or " + m.group("Mstdo_52") + "ões" in TEXT and not " ou " + m.group("Mstdo_51") + "or " + m.group("Mstdo_52") + "ões" in TEXT and not "s de " + m.group("Mstdo_51") + "or " + m.group("Mstdo_52") + "ões" in TEXT and not "s do " + m.group("Mstdo_51") + "or " + m.group("Mstdo_52") + "ões" in TEXT and not " o " + m.group("Mstdo_51") + "or " + m.group("Mstdo_52") + "ões" in TEXT and not m.group("Mstdo_51") + "or-" + m.group("Mstdo_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_55>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_55") + "or " + m.group("Mstdo_56") + "veis" in TEXT and not " ou " + m.group("Mstdo_55") + "or " + m.group("Mstdo_56") + "veis" in TEXT and not "s de " + m.group("Mstdo_55") + "or " + m.group("Mstdo_56") + "veis" in TEXT and not "s do " + m.group("Mstdo_55") + "or " + m.group("Mstdo_56") + "veis" in TEXT and not " o " + m.group("Mstdo_55") + "or " + m.group("Mstdo_56") + "veis" in TEXT and not m.group("Mstdo_55") + "or-" + m.group("Mstdo_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_57>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_58").lower() in plvrMfe and not " e " + m.group("Mstdo_57") + "or " + m.group("Mstdo_58") + "es" in TEXT and not " ou " + m.group("Mstdo_57") + "or " + m.group("Mstdo_58") + "es" in TEXT and not "s de " + m.group("Mstdo_57") + "or " + m.group("Mstdo_58") + "es" in TEXT and not "s do " + m.group("Mstdo_57") + "or " + m.group("Mstdo_58") + "es" in TEXT and not " o " + m.group("Mstdo_57") + "or " + m.group("Mstdo_58") + "es" in TEXT and not m.group("Mstdo_57") + "or-" + m.group("Mstdo_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_59>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_60").lower() in plvrMasce and not " e " + m.group("Mstdo_59") + "or " + m.group("Mstdo_60") + "es" in TEXT and not " ou " + m.group("Mstdo_59") + "or " + m.group("Mstdo_60") + "es" in TEXT and not "s de " + m.group("Mstdo_59") + "or " + m.group("Mstdo_60") + "es" in TEXT and not "s do " + m.group("Mstdo_59") + "or " + m.group("Mstdo_60") + "es" in TEXT and not " o " + m.group("Mstdo_59") + "or " + m.group("Mstdo_60") + "es" in TEXT and not m.group("Mstdo_59") + "or-" + m.group("Mstdo_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_61>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_62") in plvrMfel and not " e " + m.group("Mstdo_61") + "or " + m.group("Mstdo_62") + "éis" in TEXT and not " ou " + m.group("Mstdo_61") + "or " + m.group("Mstdo_62") + "éis" in TEXT and not "s de " + m.group("Mstdo_61") + "or " + m.group("Mstdo_62") + "éis" in TEXT and not "s do " + m.group("Mstdo_61") + "or " + m.group("Mstdo_62") + "éis" in TEXT and not " o " + m.group("Mstdo_61") + "or " + m.group("Mstdo_62") + "éis" in TEXT and not m.group("Mstdo_61") + "or-" + m.group("Mstdo_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_63>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_64") in plvrMascel and not " e " + m.group("Mstdo_63") + "or " + m.group("Mstdo_64") + "éis" in TEXT and not " ou " + m.group("Mstdo_63") + "or " + m.group("Mstdo_64") + "éis" in TEXT and not "s de " + m.group("Mstdo_63") + "or " + m.group("Mstdo_64") + "éis" in TEXT and not "s do " + m.group("Mstdo_63") + "or " + m.group("Mstdo_64") + "éis" in TEXT and not " o " + m.group("Mstdo_63") + "or " + m.group("Mstdo_64") + "éis" in TEXT and not m.group("Mstdo_63") + "or-" + m.group("Mstdo_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_65>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_66") in plvrMfeu and not " e " + m.group("Mstdo_65") + "or " + m.group("Mstdo_66") + "us" in TEXT and not " ou " + m.group("Mstdo_65") + "or " + m.group("Mstdo_66") + "us" in TEXT and not "s de " + m.group("Mstdo_65") + "or " + m.group("Mstdo_66") + "us" in TEXT and not "s do " + m.group("Mstdo_65") + "or " + m.group("Mstdo_66") + "us" in TEXT and not " o " + m.group("Mstdo_65") + "or " + m.group("Mstdo_66") + "us" in TEXT and not m.group("Mstdo_65") + "or-" + m.group("Mstdo_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_67>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_68") in plvrMascu and not " e " + m.group("Mstdo_67") + "or " + m.group("Mstdo_68") + "us" in TEXT and not " ou " + m.group("Mstdo_67") + "or " + m.group("Mstdo_68") + "us" in TEXT and not "s de " + m.group("Mstdo_67") + "or " + m.group("Mstdo_68") + "us" in TEXT and not "s do " + m.group("Mstdo_67") + "or " + m.group("Mstdo_68") + "us" in TEXT and not " o " + m.group("Mstdo_67") + "or " + m.group("Mstdo_68") + "us" in TEXT and not m.group("Mstdo_67") + "or-" + m.group("Mstdo_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_69>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_70") in plvrInvaz and not " e " + m.group("Mstdo_69") + "or " + m.group("Mstdo_70") + "zes" in TEXT and not " ou " + m.group("Mstdo_69") + "or " + m.group("Mstdo_70") + "zes" in TEXT and not "s de " + m.group("Mstdo_69") + "or " + m.group("Mstdo_70") + "zes" in TEXT and not "s do " + m.group("Mstdo_69") + "or " + m.group("Mstdo_70") + "zes" in TEXT and not " o " + m.group("Mstdo_69") + "or " + m.group("Mstdo_70") + "zes" in TEXT and not m.group("Mstdo_69") + "or-" + m.group("Mstdo_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_71>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_72") in plvrMascz and not " e " + m.group("Mstdo_71") + "or " + m.group("Mstdo_72") + "zes" in TEXT and not " ou " + m.group("Mstdo_71") + "or " + m.group("Mstdo_72") + "zes" in TEXT and not "s de " + m.group("Mstdo_71") + "or " + m.group("Mstdo_72") + "zes" in TEXT and not "s do " + m.group("Mstdo_71") + "or " + m.group("Mstdo_72") + "zes" in TEXT and not " o " + m.group("Mstdo_71") + "or " + m.group("Mstdo_72") + "zes" in TEXT and not m.group("Mstdo_71") + "or-" + m.group("Mstdo_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_73>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_74") in pvrMascan and not " e " + m.group("Mstdo_73") + "or " + m.group("Mstdo_74") + "s" in TEXT and not " ou " + m.group("Mstdo_73") + "or " + m.group("Mstdo_74") + "s" in TEXT and not "s de " + m.group("Mstdo_73") + "or " + m.group("Mstdo_74") + "s" in TEXT and not "s do " + m.group("Mstdo_73") + "or " + m.group("Mstdo_74") + "s" in TEXT and not " o " + m.group("Mstdo_73") + "or " + m.group("Mstdo_74") + "s" in TEXT and not m.group("Mstdo_73") + "or-" + m.group("Mstdo_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_75>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_76").lower() in plvrMasco and not " e " + m.group("Mstdo_75") + "or " + m.group("Mstdo_76") +"s" in TEXT and not " ou " + m.group("Mstdo_75") + "or " + m.group("Mstdo_76") + "s" in TEXT and not "s de " + m.group("Mstdo_75") + "or " + m.group("Mstdo_76") + "s" in TEXT and not "s do " + m.group("Mstdo_75") + "or " + m.group("Mstdo_76") + "s" in TEXT and not " o " + m.group("Mstdo_75") + "or " + m.group("Mstdo_76") + "s" in TEXT and not m.group("Mstdo_75") + "or-" + m.group("Mstdo_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_77>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_77") + "or " + m.group("Mstdo_78") + "inhos" in TEXT and not " ou " + m.group("Mstdo_77") + "or " + m.group("Mstdo_78") + "inhos" in TEXT and not "s de " + m.group("Mstdo_77") + "or " + m.group("Mstdo_78") + "inhos" in TEXT and not "s do " + m.group("Mstdo_77") + "or " + m.group("Mstdo_78") + "inhos" in TEXT and not " o " + m.group("Mstdo_77") + "or " + m.group("Mstdo_78") + "inhos" in TEXT and not m.group("Mstdo_77") + "or-" + m.group("Mstdo_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_79>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_79") + "or " + m.group("Mstdo_80") + "icas" in TEXT and not " ou " + m.group("Mstdo_79") + "or " + m.group("Mstdo_80") + "icas" in TEXT and not "s de " + m.group("Mstdo_79") + "or " + m.group("Mstdo_80") + "icas" in TEXT and not "s do " + m.group("Mstdo_79") + "or " + m.group("Mstdo_80") + "icas" in TEXT and not " o " + m.group("Mstdo_79") + "or " + m.group("Mstdo_80") + "icas" in TEXT and not m.group("Mstdo_79") + "or-" + m.group("Mstdo_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_81>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_81") + "or " + m.group("Mstdo_82") + "icas" in TEXT and not " ou " + m.group("Mstdo_81") + "or " + m.group("Mstdo_82") + "icas" in TEXT and not "s de " + m.group("Mstdo_81") + "or " + m.group("Mstdo_82") + "icas" in TEXT and not "s do " + m.group("Mstdo_81") + "or " + m.group("Mstdo_82") + "icas" in TEXT and not " o " + m.group("Mstdo_81") + "or " + m.group("Mstdo_82") + "icas" in TEXT and not m.group("Mstdo_81") + "or-" + m.group("Mstdo_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_83>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_83") + "or " + m.group("Mstdo_84") + "icas" in TEXT and not " ou " + m.group("Mstdo_83") + "or " + m.group("Mstdo_84") + "icas" in TEXT and not "s de " + m.group("Mstdo_83") + "or " + m.group("Mstdo_84") + "icas" in TEXT and not "s do " + m.group("Mstdo_83") + "or " + m.group("Mstdo_84") + "icas" in TEXT and not " o " + m.group("Mstdo_83") + "or " + m.group("Mstdo_84") + "icas" in TEXT and not m.group("Mstdo_83") + "or-" + m.group("Mstdo_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_85>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_85") + "or " + m.group("Mstdo_86") + "escas" in TEXT and not " ou " + m.group("Mstdo_85") + "or " + m.group("Mstdo_86") + "escas" in TEXT and not "s de " + m.group("Mstdo_85") + "or " + m.group("Mstdo_86") + "escas" in TEXT and not "s do " + m.group("Mstdo_85") + "or " + m.group("Mstdo_86") + "escas" in TEXT and not " o " + m.group("Mstdo_85") + "or " + m.group("Mstdo_86") + "escas" in TEXT and not m.group("Mstdo_85") + "or-" + m.group("Mstdo_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_87>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_87") + "or " + m.group("Mstdo_88") + "idas" in TEXT and not " ou " + m.group("Mstdo_87") + "s " + m.group("Mstdo_88") + "idas" in TEXT and not "s de " + m.group("Mstdo_87") + "s " + m.group("Mstdo_88") + "idas" in TEXT and not "s do " + m.group("Mstdo_87") + "s " + m.group("Mstdo_88") + "idas" in TEXT and not " o " + m.group("Mstdo_87") + "s " + m.group("Mstdo_88") + "idas" in TEXT and not m.group("Mstdo_87") + "or-" + m.group("Mstdo_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_89>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_89") + "or " + m.group("Mstdo_90") + "logas" in TEXT and not " ou " + m.group("Mstdo_89") + "or " + m.group("Mstdo_90") + "logas" in TEXT and not "s de " + m.group("Mstdo_89") + "or " + m.group("Mstdo_90") + "logas" in TEXT and not "s do " + m.group("Mstdo_89") + "or " + m.group("Mstdo_90") + "logas" in TEXT and not " o " + m.group("Mstdo_89") + "or " + m.group("Mstdo_90") + "logas" in TEXT and not m.group("Mstdo_89") + "or-" + m.group("Mstdo_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_91>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_91") + "or " + m.group("Mstdo_92") + "rias" in TEXT and not " ou " + m.group("Mstdo_91") + "or " + m.group("Mstdo_92") + "rias" in TEXT and not "s de " + m.group("Mstdo_91") + "or " + m.group("Mstdo_92") + "rias" in TEXT and not "s do " + m.group("Mstdo_91") + "or " + m.group("Mstdo_92") + "rias" in TEXT and not " o " + m.group("Mstdo_91") + "or " + m.group("Mstdo_92") + "rias" in TEXT and not m.group("Mstdo_91") + "or-" + m.group("Mstdo_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_93>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_93") + "or " + m.group("Mstdo_94") + "ssimas" in TEXT and not " ou " + m.group("Mstdo_93") + "or " + m.group("Mstdo_94") + "ssimas" in TEXT and not "s de " + m.group("Mstdo_93") + "or " + m.group("Mstdo_94") + "ssimas" in TEXT and not "s do " + m.group("Mstdo_93") + "or " + m.group("Mstdo_94") + "ssimas" in TEXT and not " o " + m.group("Mstdo_93") + "or " + m.group("Mstdo_94") + "ssimas" in TEXT and not m.group("Mstdo_93") + "or-" + m.group("Mstdo_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_95>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " e " + m.group("Mstdo_95") + "or " + m.group("Mstdo_96") + "simas" in TEXT and not " ou " + m.group("Mstdo_95") + "or " + m.group("Mstdo_96") + "simas" in TEXT and not "s de " + m.group("Mstdo_95") + "or " + m.group("Mstdo_96") + "simas" in TEXT and not "s do " + m.group("Mstdo_95") + "or " + m.group("Mstdo_96") + "simas" in TEXT and not " o " + m.group("Mstdo_95") + "or " + m.group("Mstdo_96") + "simas" in TEXT and not m.group("Mstdo_95") + "or-" + m.group("Mstdo_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_97>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_98").lower() in plvrMfoa and not " e " + m.group("Mstdo_97") + "or " + m.group("Mstdo_98") + "as" in TEXT and not " ou " + m.group("Mstdo_97") + "or " + m.group("Mstdo_98") + "as" in TEXT and not "s de " + m.group("Mstdo_97") + "or " + m.group("Mstdo_98") + "as" in TEXT and not "s do " + m.group("Mstdo_97") + "or " + m.group("Mstdo_98") + "as" in TEXT and not " o " + m.group("Mstdo_97") + "or " + m.group("Mstdo_98") + "as" in TEXT and not m.group("Mstdo_97") + "or-" + m.group("Mstdo_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_99>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_100") in plvrMFm and not " e " + m.group("Mstdo_99") + "or " + m.group("Mstdo_100") + "ns" in TEXT and not " ou " + m.group("Mstdo_99") + "or " + m.group("Mstdo_100") + "ns" in TEXT and not "s de " + m.group("Mstdo_99") + "or " + m.group("Mstdo_100") + "ns" in TEXT and not "s da " + m.group("Mstdo_99") + "or " + m.group("Mstdo_100") + "ns" in TEXT and not " a " + m.group("Mstdo_99") + "or " + m.group("Mstdo_100") + "ns" in TEXT and not m.group("Mstdo_99") + "or-" + m.group("Mstdo_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mstdo_101>[a-zA-Zçáéíóúâêô]+[dst])or (?P<Mstdo_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ores " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mstdo_102") in plvrMascm and not " e " + m.group("Mstdo_101") + "or " + m.group("Mstdo_102") + "ns" in TEXT and not " ou " + m.group("Mstdo_101") + "or " + m.group("Mstdo_102") + "ns" in TEXT and not "s de " + m.group("Mstdo_101") + "or " + m.group("Mstdo_102") + "ns" in TEXT and not "s da " + m.group("Mstdo_101") + "or " + m.group("Mstdo_102") + "ns" in TEXT and not " a " + m.group("Mstdo_101") + "or " + m.group("Mstdo_102") + "ns" in TEXT and not m.group("Mstdo_101") + "or-" + m.group("Mstdo_102") + "ns" in tCompostops'],
# plvrMfr a
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_1>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_1").lower() in plvrMfr and m.group("Msmfra_2").lower() in plvrFema and not " e " + m.group("Msmfra_1") + " " + m.group("Msmfra_2") +"s" in TEXT and not " ou " + m.group("Msmfra_1") + " " + m.group("Msmfra_2") + "s" in TEXT and not "s de " + m.group("Msmfra_1") + " " + m.group("Msmfra_2") + "s" in TEXT and not "s da " + m.group("Msmfra_1") + " " + m.group("Msmfra_2") + "s" in TEXT and not " a " + m.group("Msmfra_1") + " " + m.group("Msmfra_2") + "s" in TEXT and not m.group("Msmfra_1") + "-" + m.group("Msmfra_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_3>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_3").lower() in plvrMfr and m.group("Msmfra_4").lower() in plvrMfoa and not " e " + m.group("Msmfra_3") + " " + m.group("Msmfra_4") + "as" in TEXT and not " ou " + m.group("Msmfra_3") + " " + m.group("Msmfra_4") + "as" in TEXT and not "s de " + m.group("Msmfra_3") + " " + m.group("Msmfra_4") + "as" in TEXT and not "s da " + m.group("Msmfra_3") + " " + m.group("Msmfra_4") + "as" in TEXT and not " a " + m.group("Msmfra_3") + " " + m.group("Msmfra_4") + "as" in TEXT and not m.group("Msmfra_3") + "-" + m.group("Msmfra_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_5>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_5").lower() in plvrMfr and not m.group("Msmfra_6").lower() in excAdo and not " e " + m.group("Msmfra_5") + " " + m.group("Msmfra_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msmfra_5") + " " + m.group("Msmfra_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msmfra_5") + " " + m.group("Msmfra_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Msmfra_5") + " " + m.group("Msmfra_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Msmfra_5") + " " + m.group("Msmfra_6") + m.group(3) + "dos" in TEXT and not m.group("Msmfra_5") + "-" + m.group("Msmfra_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_7>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_7").lower() in plvrMfr and not m.group("Msmfra_8").lower() in XexcIsta and not " e " + m.group("Msmfra_7") + " " + m.group("Msmfra_8") + "s" in TEXT and not " ou " + m.group("Msmfra_7") + " " + m.group("Msmfra_8") + "s" in TEXT and not "s de " + m.group("Msmfra_7") + " " + m.group("Msmfra_8") + "s" in TEXT and not "s da " + m.group("Msmfra_7") + " " + m.group("Msmfra_8") + "s" in TEXT and not " a " + m.group("Msmfra_7") + " " + m.group("Msmfra_8") + "s" in TEXT and not m.group("Msmfra_7") + "-" + m.group("Msmfra_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_9>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_10>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_9").lower() in plvrMfr and m.group("Msmfra_10").lower() in plvrInva and not " e " + m.group("Msmfra_9") + " " + m.group("Msmfra_10") + "s" in TEXT and not " ou " + m.group("Msmfra_9") + " " + m.group("Msmfra_10") + "s" in TEXT and not "s de " + m.group("Msmfra_9") + " " + m.group("Msmfra_10") + "s" in TEXT and not "s da " + m.group("Msmfra_9") + " " + m.group("Msmfra_10") + "s" in TEXT and not " a " + m.group("Msmfra_9") + " " + m.group("Msmfra_10") + "s" in TEXT and not m.group("Msmfra_9") + "-" + m.group("Msmfra_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_11>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_11").lower() in plvrMfr and not m.group("Msmfra_12").lower() in excAdo and not " e " + m.group("Msmfra_11") + " " + m.group("Msmfra_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msmfra_11") + " " + m.group("Msmfra_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msmfra_11") + " " + m.group("Msmfra_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Msmfra_11") + " " + m.group("Msmfra_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Msmfra_11") + " " + m.group("Msmfra_12") + m.group(3) + "das" in TEXT and not m.group("Msmfra_11") + "-" + m.group("Msmfra_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_15>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_15").lower() in plvrMfr and not " e " + m.group("Msmfra_15") + " " + m.group("Msmfra_16") + "osas" in TEXT and not " ou " + m.group("Msmfra_15") + " " + m.group("Msmfra_16") + "osas" in TEXT and not "s de " + m.group("Msmfra_15") + " " + m.group("Msmfra_16") + "osas" in TEXT and not "s da " + m.group("Msmfra_15") + " " + m.group("Msmfra_16") + "osas" in TEXT and not " a " + m.group("Msmfra_15") + " " + m.group("Msmfra_16") + "osas" in TEXT and not m.group("Msmfra_15") + "-" + m.group("Msmfra_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_17>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_17").lower() in plvrMfr and not " e " + m.group("Msmfra_17") + " " + m.group("Msmfra_18") + "ivas" in TEXT and not " ou " + m.group("Msmfra_17") + " " + m.group("Msmfra_18") + "ivas" in TEXT and not "s de " + m.group("Msmfra_17") + " " + m.group("Msmfra_18") + "ivas" in TEXT and not "s da " + m.group("Msmfra_17") + " " + m.group("Msmfra_18") + "ivas" in TEXT and not " a " + m.group("Msmfra_17") + " " + m.group("Msmfra_18") + "ivas" in TEXT and not m.group("Msmfra_17") + "-" + m.group("Msmfra_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_21>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_21").lower() in plvrMfr and not " e " + m.group("Msmfra_21") + " " + m.group("Msmfra_22") + "icas" in TEXT and not " ou " + m.group("Msmfra_21") + " " + m.group("Msmfra_22") + "icas" in TEXT and not "s de " + m.group("Msmfra_21") + " " + m.group("Msmfra_22") + "icas" in TEXT and not "s da " + m.group("Msmfra_21") + " " + m.group("Msmfra_22") + "icas" in TEXT and not " a " + m.group("Msmfra_21") + " " + m.group("Msmfra_22") + "icas" in TEXT and not m.group("Msmfra_21") + "-" + m.group("Msmfra_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_23>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_23").lower() in plvrMfr and not " e " + m.group("Msmfra_23") + " " + m.group("Msmfra_24") + "icas" in TEXT and not " ou " + m.group("Msmfra_23") + " " + m.group("Msmfra_24") + "icas" in TEXT and not "s de " + m.group("Msmfra_23") + " " + m.group("Msmfra_24") + "icas" in TEXT and not "s da " + m.group("Msmfra_23") + " " + m.group("Msmfra_24") + "icas" in TEXT and not " a " + m.group("Msmfra_23") + " " + m.group("Msmfra_24") + "icas" in TEXT and not m.group("Msmfra_23") + "-" + m.group("Msmfra_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_25>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_25").lower() in plvrMfr and not " e " + m.group("Msmfra_25") + " " + m.group("Msmfra_26") + "icas" in TEXT and not " ou " + m.group("Msmfra_25") + " " + m.group("Msmfra_26") + "icas" in TEXT and not "s de " + m.group("Msmfra_25") + " " + m.group("Msmfra_26") + "icas" in TEXT and not "s da " + m.group("Msmfra_25") + " " + m.group("Msmfra_26") + "icas" in TEXT and not " a " + m.group("Msmfra_25") + " " + m.group("Msmfra_26") + "icas" in TEXT and not m.group("Msmfra_25") + "-" + m.group("Msmfra_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_27>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_27").lower() in plvrMfr and not " e " + m.group("Msmfra_27") + " " + m.group("Msmfra_28") + "escas" in TEXT and not " ou " + m.group("Msmfra_27") + " " + m.group("Msmfra_28") + "escas" in TEXT and not "s de " + m.group("Msmfra_27") + " " + m.group("Msmfra_28") + "escas" in TEXT and not "s da " + m.group("Msmfra_27") + " " + m.group("Msmfra_28") + "escas" in TEXT and not " a " + m.group("Msmfra_27") + " " + m.group("Msmfra_28") + "escas" in TEXT and not m.group("Msmfra_27") + "-" + m.group("Msmfra_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_29>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_29").lower() in plvrMfr and not " e " + m.group("Msmfra_29") + " " + m.group("Msmfra_30") + "idas" in TEXT and not " ou " + m.group("Msmfra_29") + "s " + m.group("Msmfra_30") + "idas" in TEXT and not "s de " + m.group("Msmfra_29") + "s " + m.group("Msmfra_30") + "idas" in TEXT and not "s da " + m.group("Msmfra_29") + "s " + m.group("Msmfra_30") + "idas" in TEXT and not " a " + m.group("Msmfra_29") + "s " + m.group("Msmfra_30") + "idas" in TEXT and not m.group("Msmfra_29") + "-" + m.group("Msmfra_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_31>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_31").lower() in plvrMfr and not " e " + m.group("Msmfra_31") + " " + m.group("Msmfra_32") + "logas" in TEXT and not " ou " + m.group("Msmfra_31") + " " + m.group("Msmfra_32") + "logas" in TEXT and not "s de " + m.group("Msmfra_31") + " " + m.group("Msmfra_32") + "logas" in TEXT and not "s da " + m.group("Msmfra_31") + " " + m.group("Msmfra_32") + "logas" in TEXT and not " a " + m.group("Msmfra_31") + " " + m.group("Msmfra_32") + "logas" in TEXT and not m.group("Msmfra_31") + "-" + m.group("Msmfra_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_33>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_33").lower() in plvrMfr and not " e " + m.group("Msmfra_33") + " " + m.group("Msmfra_34") + "rias" in TEXT and not " ou " + m.group("Msmfra_33") + " " + m.group("Msmfra_34") + "rias" in TEXT and not "s de " + m.group("Msmfra_33") + " " + m.group("Msmfra_34") + "rias" in TEXT and not "s da " + m.group("Msmfra_33") + " " + m.group("Msmfra_34") + "rias" in TEXT and not " a " + m.group("Msmfra_33") + " " + m.group("Msmfra_34") + "rias" in TEXT and not m.group("Msmfra_33") + "-" + m.group("Msmfra_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_35>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_35").lower() in plvrMfr and not " e " + m.group("Msmfra_35") + " " + m.group("Msmfra_36") + "ssimas" in TEXT and not " ou " + m.group("Msmfra_35") + " " + m.group("Msmfra_36") + "ssimas" in TEXT and not "s de " + m.group("Msmfra_35") + " " + m.group("Msmfra_36") + "ssimas" in TEXT and not "s da " + m.group("Msmfra_35") + " " + m.group("Msmfra_36") + "ssimas" in TEXT and not " a " + m.group("Msmfra_35") + " " + m.group("Msmfra_36") + "ssimas" in TEXT and not m.group("Msmfra_35") + "-" + m.group("Msmfra_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_37>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_37").lower() in plvrMfr and not " e " + m.group("Msmfra_37") + " " + m.group("Msmfra_38") + "simas" in TEXT and not " ou " + m.group("Msmfra_37") + " " + m.group("Msmfra_38") + "simas" in TEXT and not "s de " + m.group("Msmfra_37") + " " + m.group("Msmfra_38") + "simas" in TEXT and not "s da " + m.group("Msmfra_37") + " " + m.group("Msmfra_38") + "simas" in TEXT and not " a " + m.group("Msmfra_37") + " " + m.group("Msmfra_38") + "simas" in TEXT and not m.group("Msmfra_37") + "-" + m.group("Msmfra_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_41>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_41").lower() in plvrMfr and not m.group("Msmfra_42") in "D-d-" and not " e " + m.group("Msmfra_41") + " " + m.group("Msmfra_42") + "oras" in TEXT and not " ou " + m.group("Msmfra_41") + " " + m.group("Msmfra_42") + "oras" in TEXT and not "s de " + m.group("Msmfra_41") + " " + m.group("Msmfra_42") + "oras" in TEXT and not "s da " + m.group("Msmfra_41") + " " + m.group("Msmfra_42") + "oras" in TEXT and not " a " + m.group("Msmfra_41") + " " + m.group("Msmfra_42") + "oras" in TEXT and not m.group("Msmfra_41") + "-" + m.group("Msmfra_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_43>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_43").lower() in plvrMfr and m.group("Msmfra_44") in plvrMfr and not " e " + m.group("Msmfra_43") + " " + m.group("Msmfra_44") + "es" in TEXT and not " ou " + m.group("Msmfra_43") + " " + m.group("Msmfra_44") + "es" in TEXT and not "s de " + m.group("Msmfra_43") + " " + m.group("Msmfra_44") + "es" in TEXT and not "s da " + m.group("Msmfra_43") + " " + m.group("Msmfra_44") + "es" in TEXT and not " a " + m.group("Msmfra_43") + " " + m.group("Msmfra_44") + "es" in TEXT and not m.group("Msmfra_43") + "-" + m.group("Msmfra_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_45>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_45").lower() in plvrMfr and m.group("Msmfra_46") in plvrFemr and not " e " + m.group("Msmfra_45") + " " + m.group("Msmfra_46") + "es" in TEXT and not " ou " + m.group("Msmfra_45") + " " + m.group("Msmfra_46") + "es" in TEXT and not "s de " + m.group("Msmfra_45") + " " + m.group("Msmfra_46") + "es" in TEXT and not "s da " + m.group("Msmfra_45") + " " + m.group("Msmfra_46") + "es" in TEXT and not " a " + m.group("Msmfra_45") + " " + m.group("Msmfra_46") + "es" in TEXT and not m.group("Msmfra_45") + "-" + m.group("Msmfra_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_47>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_47").lower() in plvrMfr and m.group("Msmfra_48") in plvrMfal and not " e " + m.group("Msmfra_47") + " " + m.group("Msmfra_48") + "is" in TEXT and not " ou " + m.group("Msmfra_47") + " " + m.group("Msmfra_48") + "is" in TEXT and not "s de " + m.group("Msmfra_47") + " " + m.group("Msmfra_48") + "is" in TEXT and not "s da " + m.group("Msmfra_47") + " " + m.group("Msmfra_48") + "is" in TEXT and not " a " + m.group("Msmfra_47") + " " + m.group("Msmfra_48") + "is" in TEXT and not m.group("Msmfra_47") + "-" + m.group("Msmfra_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_49>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_49").lower() in plvrMfr and m.group("Msmfra_50") in plvrMfcao and not " e " + m.group("Msmfra_49") + " " + m.group("Msmfra_50") + "ões" in TEXT and not + " ou " + m.group("Msmfra_49") + " " + m.group("Msmfra_50") + "ões" in TEXT and not + "s de " + m.group("Msmfra_49") + " " + m.group("Msmfra_50") + "ões" in TEXT and not + "s da " + m.group("Msmfra_49") + " " + m.group("Msmfra_50") + "ões" in TEXT and not + " a " + m.group("Msmfra_49") + " " + m.group("Msmfra_50") + "ões" in TEXT and not m.group("Msmfra_49") + "-" + m.group("Msmfra_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_51>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_51").lower() in plvrMfr and not m.group("Msmfra_52") in plvrMascao and not " e " + m.group("Msmfra_51") + " " + m.group("Msmfra_52") + "ões" in TEXT and not " ou " + m.group("Msmfra_51") + " " + m.group("Msmfra_52") + "ões" in TEXT and not "s de " + m.group("Msmfra_51") + " " + m.group("Msmfra_52") + "ões" in TEXT and not "s da " + m.group("Msmfra_51") + " " + m.group("Msmfra_52") + "ões" in TEXT and not " a " + m.group("Msmfra_51") + " " + m.group("Msmfra_52") + "ões" in TEXT and not m.group("Msmfra_51") + "-" + m.group("Msmfra_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_53>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_53").lower() in plvrMfr and m.group("Msmfra_54") in plvrFemao and not " e " + m.group("Msmfra_53") + " " + m.group("Msmfra_54") + "ões" in TEXT and not " ou " + m.group("Msmfra_53") + " " + m.group("Msmfra_54") + "ões" in TEXT and not "s de " + m.group("Msmfra_53") + " " + m.group("Msmfra_54") + "ões" in TEXT and not "s da " + m.group("Msmfra_53") + " " + m.group("Msmfra_54") + "ões" in TEXT and not " a " + m.group("Msmfra_53") + " " + m.group("Msmfra_54") + "ões" in TEXT and not m.group("Msmfra_53") + "-" + m.group("Msmfra_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_55>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_55").lower() in plvrMfr and not " e " + m.group("Msmfra_55") + " " + m.group("Msmfra_56") + "veis" in TEXT and not " ou " + m.group("Msmfra_55") + " " + m.group("Msmfra_56") + "veis" in TEXT and not "s de " + m.group("Msmfra_55") + " " + m.group("Msmfra_56") + "veis" in TEXT and not "s da " + m.group("Msmfra_55") + " " + m.group("Msmfra_56") + "veis" in TEXT and not " a " + m.group("Msmfra_55") + " " + m.group("Msmfra_56") + "veis" in TEXT and not m.group("Msmfra_55") + "-" + m.group("Msmfra_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_57>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_57").lower() in plvrMfr and m.group("Msmfra_58").lower() in plvrMfr and not " e " + m.group("Msmfra_57") + " " + m.group("Msmfra_58") + "es" in TEXT and not " ou " + m.group("Msmfra_57") + " " + m.group("Msmfra_58") + "es" in TEXT and not "s de " + m.group("Msmfra_57") + " " + m.group("Msmfra_58") + "es" in TEXT and not "s da " + m.group("Msmfra_57") + " " + m.group("Msmfra_58") + "es" in TEXT and not " a " + m.group("Msmfra_57") + " " + m.group("Msmfra_58") + "es" in TEXT and not m.group("Msmfra_57") + "-" + m.group("Msmfra_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_59>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_59").lower() in plvrMfr and m.group("Msmfra_60").lower() in plvrMfr and not " e " + m.group("Msmfra_59") + " " + m.group("Msmfra_60") + "es" in TEXT and not " ou " + m.group("Msmfra_59") + " " + m.group("Msmfra_60") + "es" in TEXT and not "s de " + m.group("Msmfra_59") + " " + m.group("Msmfra_60") + "es" in TEXT and not "s da " + m.group("Msmfra_59") + " " + m.group("Msmfra_60") + "es" in TEXT and not " a " + m.group("Msmfra_59") + " " + m.group("Msmfra_60") + "es" in TEXT and not m.group("Msmfra_59") + "-" + m.group("Msmfra_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_61>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_61").lower() in plvrMfr and m.group("Msmfra_62") in plvrMfel and not " e " + m.group("Msmfra_61") + " " + m.group("Msmfra_62") + "éis" in TEXT and not " ou " + m.group("Msmfra_61") + " " + m.group("Msmfra_62") + "éis" in TEXT and not "s de " + m.group("Msmfra_61") + " " + m.group("Msmfra_62") + "éis" in TEXT and not "s da " + m.group("Msmfra_61") + " " + m.group("Msmfra_62") + "éis" in TEXT and not " a " + m.group("Msmfra_61") + " " + m.group("Msmfra_62") + "éis" in TEXT and not m.group("Msmfra_61") + "-" + m.group("Msmfra_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_63>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_63").lower() in plvrMfr and m.group("Msmfra_64") in plvrFemel and not " e " + m.group("Msmfra_63") + " " + m.group("Msmfra_64") + "éis" in TEXT and not " ou " + m.group("Msmfra_63") + " " + m.group("Msmfra_64") + "éis" in TEXT and not "s de " + m.group("Msmfra_63") + " " + m.group("Msmfra_64") + "éis" in TEXT and not "s da " + m.group("Msmfra_63") + " " + m.group("Msmfra_64") + "éis" in TEXT and not " a " + m.group("Msmfra_63") + " " + m.group("Msmfra_64") + "éis" in TEXT and not m.group("Msmfra_63") + "-" + m.group("Msmfra_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_65>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_65").lower() in plvrMfr and m.group("Msmfra_66") in plvrMfeu and not " e " + m.group("Msmfra_65") + " " + m.group("Msmfra_66") + "us" in TEXT and not " ou " + m.group("Msmfra_65") + " " + m.group("Msmfra_66") + "us" in TEXT and not "s de " + m.group("Msmfra_65") + " " + m.group("Msmfra_66") + "us" in TEXT and not "s da " + m.group("Msmfra_65") + " " + m.group("Msmfra_66") + "us" in TEXT and not " a " + m.group("Msmfra_65") + " " + m.group("Msmfra_66") + "us" in TEXT and not m.group("Msmfra_65") + "-" + m.group("Msmfra_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_67>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_67").lower() in plvrMfr and m.group("Msmfra_68") in plvrFemu and not " e " + m.group("Msmfra_67") + " " + m.group("Msmfra_68") + "us" in TEXT and not " ou " + m.group("Msmfra_67") + " " + m.group("Msmfra_68") + "us" in TEXT and not "s de " + m.group("Msmfra_67") + " " + m.group("Msmfra_68") + "us" in TEXT and not "s da " + m.group("Msmfra_67") + " " + m.group("Msmfra_68") + "us" in TEXT and not " a " + m.group("Msmfra_67") + " " + m.group("Msmfra_68") + "us" in TEXT and not m.group("Msmfra_67") + "-" + m.group("Msmfra_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_69>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_69").lower() in plvrMfr and m.group("Msmfra_70") in plvrInvaz and not " e " + m.group("Msmfra_69") + " " + m.group("Msmfra_70") + "zes" in TEXT and not " ou " + m.group("Msmfra_69") + " " + m.group("Msmfra_70") + "zes" in TEXT and not "s de " + m.group("Msmfra_69") + " " + m.group("Msmfra_70") + "zes" in TEXT and not "s da " + m.group("Msmfra_69") + " " + m.group("Msmfra_70") + "zes" in TEXT and not " a " + m.group("Msmfra_69") + " " + m.group("Msmfra_70") + "zes" in TEXT and not m.group("Msmfra_69") + "-" + m.group("Msmfra_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_71>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_71").lower() in plvrMfr and m.group("Msmfra_72") in plvrFemz and not " e " + m.group("Msmfra_71") + " " + m.group("Msmfra_72") + "zes" in TEXT and not " ou " + m.group("Msmfra_71") + " " + m.group("Msmfra_72") + "zes" in TEXT and not "s de " + m.group("Msmfra_71") + " " + m.group("Msmfra_72") + "zes" in TEXT and not "s da " + m.group("Msmfra_71") + " " + m.group("Msmfra_72") + "zes" in TEXT and not " a " + m.group("Msmfra_71") + " " + m.group("Msmfra_72") + "zes" in TEXT and not m.group("Msmfra_71") + "-" + m.group("Msmfra_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_73>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_73").lower() in plvrMfr and m.group("Msmfra_74") in pvrFeman and not " e " + m.group("Msmfra_73") + " " + m.group("Msmfra_74") + "s" in TEXT and not " ou " + m.group("Msmfra_73") + " " + m.group("Msmfra_74") + "s" in TEXT and not "s de " + m.group("Msmfra_73") + " " + m.group("Msmfra_74") + "s" in TEXT and not "s da " + m.group("Msmfra_73") + " " + m.group("Msmfra_74") + "s" in TEXT and not " a " + m.group("Msmfra_73") + " " + m.group("Msmfra_74") + "s" in TEXT and not m.group("Msmfra_73") + "-" + m.group("Msmfra_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_75>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_76>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_75").lower() in plvrMfr and m.group("Msmfra_76") in plvrMFm and not " e " + m.group("Msmfra_75") + " " + m.group("Msmfra_76") + "ns" in TEXT and not " ou " + m.group("Msmfra_75") + " " + m.group("Msmfra_76") + "ns" in TEXT and not "s de " + m.group("Msmfra_75") + " " + m.group("Msmfra_76") + "ns" in TEXT and not "s da " + m.group("Msmfra_75") + " " + m.group("Msmfra_76") + "ns" in TEXT and not " a " + m.group("Msmfra_75") + " " + m.group("Msmfra_76") + "ns" in TEXT and not m.group("Msmfra_75") + "-" + m.group("Msmfra_76") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfra_77>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfra_78>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfra_77").lower() in plvrMfr and m.group("Msmfra_78") in plvrFemm and not " e " + m.group("Msmfra_77") + " " + m.group("Msmfra_78") + "ns" in TEXT and not " ou " + m.group("Msmfra_77") + " " + m.group("Msmfra_78") + "ns" in TEXT and not "s de " + m.group("Msmfra_77") + " " + m.group("Msmfra_78") + "ns" in TEXT and not "s da " + m.group("Msmfra_77") + " " + m.group("Msmfra_78") + "ns" in TEXT and not " a " + m.group("Msmfra_77") + " " + m.group("Msmfra_78") + "ns" in TEXT and not m.group("Msmfra_77") + "-" + m.group("Msmfra_78") + "ns" in tCompostops'],
# plvrMfr o
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_1>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_1").lower() in plvrMfr and m.group("Msmfro_2").lower() in plvrMasca and not " e " + m.group("Msmfro_1") + " " + m.group("Msmfro_2") +"s" in TEXT and not " ou " + m.group("Msmfro_1") + " " + m.group("Msmfro_2") + "s" in TEXT and not "s de " + m.group("Msmfro_1") + " " + m.group("Msmfro_2") + "s" in TEXT and not "s do " + m.group("Msmfro_1") + " " + m.group("Msmfro_2") + "s" in TEXT and not " o " + m.group("Msmfro_1") + " " + m.group("Msmfro_2") + "s" in TEXT and not m.group("Msmfro_1") + "-" + m.group("Msmfro_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_3>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_3").lower() in plvrMfr and m.group("Msmfro_4").lower() in plvrMfoa and not " e " + m.group("Msmfro_3") + " " + m.group("Msmfro_4") + "os" in TEXT and not " ou " + m.group("Msmfro_3") + " " + m.group("Msmfro_4") + "os" in TEXT and not "s de " + m.group("Msmfro_3") + " " + m.group("Msmfro_4") + "os" in TEXT and not "s do " + m.group("Msmfro_3") + " " + m.group("Msmfro_4") + "os" in TEXT and not " o " + m.group("Msmfro_3") + " " + m.group("Msmfro_4") + "os" in TEXT and not m.group("Msmfro_3") + "-" + m.group("Msmfro_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_5>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_5").lower() in plvrMfr and not m.group("Msmfro_6").lower() in excAdo and not " e " + m.group("Msmfro_5") + " " + m.group("Msmfro_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msmfro_5") + " " + m.group("Msmfro_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msmfro_5") + " " + m.group("Msmfro_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msmfro_5") + " " + m.group("Msmfro_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msmfro_5") + " " + m.group("Msmfro_6") + m.group(3) + "dos" in TEXT and not m.group("Msmfro_5") + "-" + m.group("Msmfro_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_13>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_13").lower() in plvrMfr and not " e " + m.group("Msmfro_13") + " " + m.group("Msmfro_14") + "osos" in TEXT and not " ou " + m.group("Msmfro_13") + " " + m.group("Msmfro_14") + "osos" in TEXT and not "s de " + m.group("Msmfro_13") + " " + m.group("Msmfro_14") + "osos" in TEXT and not "s do " + m.group("Msmfro_13") + " " + m.group("Msmfro_14") + "osos" in TEXT and not " o " + m.group("Msmfro_13") + " " + m.group("Msmfro_14") + "osos" in TEXT and not m.group("Msmfro_13") + "-" + m.group("Msmfro_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_19>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_19").lower() in plvrMfr and not " e " + m.group("Msmfro_19") + " " + m.group("Msmfro_20") + "ivas" in TEXT and not " ou " + m.group("Msmfro_19") + " " + m.group("Msmfro_20") + "ivas" in TEXT and not "s de " + m.group("Msmfro_19") + " " + m.group("Msmfro_20") + "ivas" in TEXT and not "s do " + m.group("Msmfro_19") + " " + m.group("Msmfro_20") + "ivas" in TEXT and not " o " + m.group("Msmfro_19") + " " + m.group("Msmfro_20") + "ivas" in TEXT and not m.group("Msmfro_19") + "-" + m.group("Msmfro_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_21>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_21").lower() in plvrMfr and not " e " + m.group("Msmfro_21") + " " + m.group("Msmfro_22") + "icos" in TEXT and not " ou " + m.group("Msmfro_21") + " " + m.group("Msmfro_22") + "icos" in TEXT and not "s de " + m.group("Msmfro_21") + " " + m.group("Msmfro_22") + "icos" in TEXT and not "s do " + m.group("Msmfro_21") + " " + m.group("Msmfro_22") + "icos" in TEXT and not " o " + m.group("Msmfro_21") + " " + m.group("Msmfro_22") + "icos" in TEXT and not m.group("Msmfro_21") + "-" + m.group("Msmfro_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_23>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_23").lower() in plvrMfr and not " e " + m.group("Msmfro_23") + " " + m.group("Msmfro_24") + "icos" in TEXT and not " ou " + m.group("Msmfro_23") + " " + m.group("Msmfro_24") + "icos" in TEXT and not "s de " + m.group("Msmfro_23") + " " + m.group("Msmfro_24") + "icos" in TEXT and not "s do " + m.group("Msmfro_23") + " " + m.group("Msmfro_24") + "icos" in TEXT and not " o " + m.group("Msmfro_23") + " " + m.group("Msmfro_24") + "icos" in TEXT and not m.group("Msmfro_23") + "-" + m.group("Msmfro_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_25>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_25").lower() in plvrMfr and not " e " + m.group("Msmfro_25") + " " + m.group("Msmfro_26") + "icos" in TEXT and not " ou " + m.group("Msmfro_25") + " " + m.group("Msmfro_26") + "icos" in TEXT and not "s de " + m.group("Msmfro_25") + " " + m.group("Msmfro_26") + "icos" in TEXT and not "s do " + m.group("Msmfro_25") + " " + m.group("Msmfro_26") + "icos" in TEXT and not " o " + m.group("Msmfro_25") + " " + m.group("Msmfro_26") + "icos" in TEXT and not m.group("Msmfro_25") + "-" + m.group("Msmfro_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_27>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_27").lower() in plvrMfr and not " e " + m.group("Msmfro_27") + " " + m.group("Msmfro_28") + "escos" in TEXT and not " ou " + m.group("Msmfro_27") + " " + m.group("Msmfro_28") + "escos" in TEXT and not "s de " + m.group("Msmfro_27") + " " + m.group("Msmfro_28") + "escos" in TEXT and not "s do " + m.group("Msmfro_27") + " " + m.group("Msmfro_28") + "escos" in TEXT and not " o " + m.group("Msmfro_27") + " " + m.group("Msmfro_28") + "escos" in TEXT and not m.group("Msmfro_27") + "-" + m.group("Msmfro_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_29>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_29").lower() in plvrMfr and not " e " + m.group("Msmfro_29") + " " + m.group("Msmfro_30") + "idos" in TEXT and not " ou " + m.group("Msmfro_29") + "s " + m.group("Msmfro_30") + "idos" in TEXT and not "s de " + m.group("Msmfro_29") + "s " + m.group("Msmfro_30") + "idos" in TEXT and not "s do " + m.group("Msmfro_29") + "s " + m.group("Msmfro_30") + "idos" in TEXT and not " o " + m.group("Msmfro_29") + "s " + m.group("Msmfro_30") + "idos" in TEXT and not m.group("Msmfro_29") + "-" + m.group("Msmfro_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_31>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_31").lower() in plvrMfr and not " e " + m.group("Msmfro_31") + " " + m.group("Msmfro_32") + "logos" in TEXT and not " ou " + m.group("Msmfro_31") + " " + m.group("Msmfro_32") + "logos" in TEXT and not "s de " + m.group("Msmfro_31") + " " + m.group("Msmfro_32") + "logos" in TEXT and not "s do " + m.group("Msmfro_31") + " " + m.group("Msmfro_32") + "logos" in TEXT and not " o " + m.group("Msmfro_31") + " " + m.group("Msmfro_32") + "logos" in TEXT and not m.group("Msmfro_31") + "-" + m.group("Msmfro_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_33>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_33").lower() in plvrMfr and not " e " + m.group("Msmfro_33") + " " + m.group("Msmfro_34") + "rios" in TEXT and not " ou " + m.group("Msmfro_33") + " " + m.group("Msmfro_34") + "rios" in TEXT and not "s de " + m.group("Msmfro_33") + " " + m.group("Msmfro_34") + "rios" in TEXT and not "s do " + m.group("Msmfro_33") + " " + m.group("Msmfro_34") + "rios" in TEXT and not " o " + m.group("Msmfro_33") + " " + m.group("Msmfro_34") + "rios" in TEXT and not m.group("Msmfro_33") + "-" + m.group("Msmfro_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_35>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_35").lower() in plvrMfr and not " e " + m.group("Msmfro_35") + " " + m.group("Msmfro_36") + "ssimos" in TEXT and not " ou " + m.group("Msmfro_35") + " " + m.group("Msmfro_36") + "ssimos" in TEXT and not "s de " + m.group("Msmfro_35") + " " + m.group("Msmfro_36") + "ssimos" in TEXT and not "s do " + m.group("Msmfro_35") + " " + m.group("Msmfro_36") + "ssimos" in TEXT and not " o " + m.group("Msmfro_35") + " " + m.group("Msmfro_36") + "ssimos" in TEXT and not m.group("Msmfro_35") + "-" + m.group("Msmfro_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_37>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_37").lower() in plvrMfr and not " e " + m.group("Msmfro_37") + " " + m.group("Msmfro_38") + "simos" in TEXT and not " ou " + m.group("Msmfro_37") + " " + m.group("Msmfro_38") + "simos" in TEXT and not "s de " + m.group("Msmfro_37") + " " + m.group("Msmfro_38") + "simos" in TEXT and not "s do " + m.group("Msmfro_37") + " " + m.group("Msmfro_38") + "simos" in TEXT and not " o " + m.group("Msmfro_37") + " " + m.group("Msmfro_38") + "simos" in TEXT and not m.group("Msmfro_37") + "-" + m.group("Msmfro_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_43>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_43").lower() in plvrMfr and m.group("Msmfro_44") in plvrMfr and not " e " + m.group("Msmfro_43") + " " + m.group("Msmfro_44") + "es" in TEXT and not " ou " + m.group("Msmfro_43") + " " + m.group("Msmfro_44") + "es" in TEXT and not "s de " + m.group("Msmfro_43") + " " + m.group("Msmfro_44") + "es" in TEXT and not "s do " + m.group("Msmfro_43") + " " + m.group("Msmfro_44") + "es" in TEXT and not " o " + m.group("Msmfro_43") + " " + m.group("Msmfro_44") + "es" in TEXT and not m.group("Msmfro_43") + "-" + m.group("Msmfro_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_45>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_45").lower() in plvrMfr and m.group("Msmfro_46") in plvrMascr and not " e " + m.group("Msmfro_45") + " " + m.group("Msmfro_46") + "es" in TEXT and not " ou " + m.group("Msmfro_45") + " " + m.group("Msmfro_46") + "es" in TEXT and not "s de " + m.group("Msmfro_45") + " " + m.group("Msmfro_46") + "es" in TEXT and not "s do " + m.group("Msmfro_45") + " " + m.group("Msmfro_46") + "es" in TEXT and not " o " + m.group("Msmfro_45") + " " + m.group("Msmfro_46") + "es" in TEXT and not m.group("Msmfro_45") + "-" + m.group("Msmfro_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_47>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_47").lower() in plvrMfr and m.group("Msmfro_48") in plvrMfal and not " e " + m.group("Msmfro_47") + " " + m.group("Msmfro_48") + "is" in TEXT and not " ou " + m.group("Msmfro_47") + " " + m.group("Msmfro_48") + "is" in TEXT and not "s de " + m.group("Msmfro_47") + " " + m.group("Msmfro_48") + "is" in TEXT and not "s do " + m.group("Msmfro_47") + " " + m.group("Msmfro_48") + "is" in TEXT and not " o " + m.group("Msmfro_47") + " " + m.group("Msmfro_48") + "is" in TEXT and not m.group("Msmfro_47") + "-" + m.group("Msmfro_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_49>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_49").lower() in plvrMfr and m.group("Msmfro_50") in plvrMfcao and not " e " + m.group("Msmfro_49") + " " + m.group("Msmfro_50") + "ões" in TEXT and not + " ou " + m.group("Msmfro_49") + " " + m.group("Msmfro_50") + "ões" in TEXT and not + "s de " + m.group("Msmfro_49") + " " + m.group("Msmfro_50") + "ões" in TEXT and not + "s do " + m.group("Msmfro_49") + " " + m.group("Msmfro_50") + "ões" in TEXT and not + " a " + m.group("Msmfro_49") + " " + m.group("Msmfro_50") + "ões" in TEXT and not m.group("Msmfro_49") + "-" + m.group("Msmfro_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_51>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_51").lower() in plvrMfr and m.group("Msmfro_52") in plvrNfemcao and not " e " + m.group("Msmfro_51") + " " + m.group("Msmfro_52") + "ões" in TEXT and not " ou " + m.group("Msmfro_51") + " " + m.group("Msmfro_52") + "ões" in TEXT and not "s de " + m.group("Msmfro_51") + " " + m.group("Msmfro_52") + "ões" in TEXT and not "s do " + m.group("Msmfro_51") + " " + m.group("Msmfro_52") + "ões" in TEXT and not " o " + m.group("Msmfro_51") + " " + m.group("Msmfro_52") + "ões" in TEXT and not m.group("Msmfro_51") + "-" + m.group("Msmfro_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_57>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_57").lower() in plvrMfr and m.group("Msmfro_58").lower() in plvrMfr and not " e " + m.group("Msmfro_57") + " " + m.group("Msmfro_58") + "es" in TEXT and not " ou " + m.group("Msmfro_57") + " " + m.group("Msmfro_58") + "es" in TEXT and not "s de " + m.group("Msmfro_57") + " " + m.group("Msmfro_58") + "es" in TEXT and not "s do " + m.group("Msmfro_57") + " " + m.group("Msmfro_58") + "es" in TEXT and not " o " + m.group("Msmfro_57") + " " + m.group("Msmfro_58") + "es" in TEXT and not m.group("Msmfro_57") + "-" + m.group("Msmfro_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_59>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_59").lower() in plvrMfr and m.group("Msmfro_60").lower() in plvrMasce and not " e " + m.group("Msmfro_59") + " " + m.group("Msmfro_60") + "es" in TEXT and not " ou " + m.group("Msmfro_59") + " " + m.group("Msmfro_60") + "es" in TEXT and not "s de " + m.group("Msmfro_59") + " " + m.group("Msmfro_60") + "es" in TEXT and not "s do " + m.group("Msmfro_59") + " " + m.group("Msmfro_60") + "es" in TEXT and not " o " + m.group("Msmfro_59") + " " + m.group("Msmfro_60") + "es" in TEXT and not m.group("Msmfro_59") + "-" + m.group("Msmfro_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_61>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_61").lower() in plvrMfr and m.group("Msmfro_62") in plvrMfel and not " e " + m.group("Msmfro_61") + " " + m.group("Msmfro_62") + "éis" in TEXT and not " ou " + m.group("Msmfro_61") + " " + m.group("Msmfro_62") + "éis" in TEXT and not "s de " + m.group("Msmfro_61") + " " + m.group("Msmfro_62") + "éis" in TEXT and not "s do " + m.group("Msmfro_61") + " " + m.group("Msmfro_62") + "éis" in TEXT and not " o " + m.group("Msmfro_61") + " " + m.group("Msmfro_62") + "éis" in TEXT and not m.group("Msmfro_61") + "-" + m.group("Msmfro_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_63>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_63").lower() in plvrMfr and m.group("Msmfro_64") in plvrMascel and not " e " + m.group("Msmfro_63") + " " + m.group("Msmfro_64") + "éis" in TEXT and not " ou " + m.group("Msmfro_63") + " " + m.group("Msmfro_64") + "éis" in TEXT and not "s de " + m.group("Msmfro_63") + " " + m.group("Msmfro_64") + "éis" in TEXT and not "s do " + m.group("Msmfro_63") + " " + m.group("Msmfro_64") + "éis" in TEXT and not " o " + m.group("Msmfro_63") + " " + m.group("Msmfro_64") + "éis" in TEXT and not m.group("Msmfro_63") + "-" + m.group("Msmfro_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_65>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_65").lower() in plvrMfr and m.group("Msmfro_66") in plvrMfeu and not " e " + m.group("Msmfro_65") + " " + m.group("Msmfro_66") + "us" in TEXT and not " ou " + m.group("Msmfro_65") + " " + m.group("Msmfro_66") + "us" in TEXT and not "s de " + m.group("Msmfro_65") + " " + m.group("Msmfro_66") + "us" in TEXT and not "s do " + m.group("Msmfro_65") + " " + m.group("Msmfro_66") + "us" in TEXT and not " o " + m.group("Msmfro_65") + " " + m.group("Msmfro_66") + "us" in TEXT and not m.group("Msmfro_65") + "-" + m.group("Msmfro_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_67>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_67").lower() in plvrMfr and m.group("Msmfro_68") in plvrMascu and not " e " + m.group("Msmfro_67") + " " + m.group("Msmfro_68") + "us" in TEXT and not " ou " + m.group("Msmfro_67") + " " + m.group("Msmfro_68") + "us" in TEXT and not "s de " + m.group("Msmfro_67") + " " + m.group("Msmfro_68") + "us" in TEXT and not "s do " + m.group("Msmfro_67") + " " + m.group("Msmfro_68") + "us" in TEXT and not " o " + m.group("Msmfro_67") + " " + m.group("Msmfro_68") + "us" in TEXT and not m.group("Msmfro_67") + "-" + m.group("Msmfro_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_71>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_71").lower() in plvrMfr and m.group("Msmfro_72") in plvrMascz and not " e " + m.group("Msmfro_71") + " " + m.group("Msmfro_72") + "zes" in TEXT and not " ou " + m.group("Msmfro_71") + " " + m.group("Msmfro_72") + "zes" in TEXT and not "s de " + m.group("Msmfro_71") + " " + m.group("Msmfro_72") + "zes" in TEXT and not "s do " + m.group("Msmfro_71") + " " + m.group("Msmfro_72") + "zes" in TEXT and not " o " + m.group("Msmfro_71") + " " + m.group("Msmfro_72") + "zes" in TEXT and not m.group("Msmfro_71") + "-" + m.group("Msmfro_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_73>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_73").lower() in plvrMfr and m.group("Msmfro_74") in pvrMascan and not " e " + m.group("Msmfro_73") + " " + m.group("Msmfro_74") + "s" in TEXT and not " ou " + m.group("Msmfro_73") + " " + m.group("Msmfro_74") + "s" in TEXT and not "s de " + m.group("Msmfro_73") + " " + m.group("Msmfro_74") + "s" in TEXT and not "s do " + m.group("Msmfro_73") + " " + m.group("Msmfro_74") + "s" in TEXT and not " o " + m.group("Msmfro_73") + " " + m.group("Msmfro_74") + "s" in TEXT and not m.group("Msmfro_73") + "-" + m.group("Msmfro_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_75>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_75").lower() in plvrMfr and m.group("Msmfro_76").lower() in plvrMasco and not " e " + m.group("Msmfro_75") + " " + m.group("Msmfro_76") +"s" in TEXT and not " ou " + m.group("Msmfro_75") + " " + m.group("Msmfro_76") + "s" in TEXT and not "s de " + m.group("Msmfro_75") + " " + m.group("Msmfro_76") + "s" in TEXT and not "s do " + m.group("Msmfro_75") + " " + m.group("Msmfro_76") + "s" in TEXT and not " o " + m.group("Msmfro_75") + " " + m.group("Msmfro_76") + "s" in TEXT and not m.group("Msmfro_75") + "-" + m.group("Msmfro_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_77>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_77").lower() in plvrMfr and not " e " + m.group("Msmfro_77") + " " + m.group("Msmfro_78") + "inhos" in TEXT and not " ou " + m.group("Msmfro_77") + " " + m.group("Msmfro_78") + "inhos" in TEXT and not "s de " + m.group("Msmfro_77") + " " + m.group("Msmfro_78") + "inhos" in TEXT and not "s do " + m.group("Msmfro_77") + " " + m.group("Msmfro_78") + "inhos" in TEXT and not " o " + m.group("Msmfro_77") + " " + m.group("Msmfro_78") + "inhos" in TEXT and not m.group("Msmfro_77") + "-" + m.group("Msmfro_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_83>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_83").lower() in plvrMfr and not " e " + m.group("Msmfro_83") + " " + m.group("Msmfro_84") + "icas" in TEXT and not " ou " + m.group("Msmfro_83") + " " + m.group("Msmfro_84") + "icas" in TEXT and not "s de " + m.group("Msmfro_83") + " " + m.group("Msmfro_84") + "icas" in TEXT and not "s do " + m.group("Msmfro_83") + " " + m.group("Msmfro_84") + "icas" in TEXT and not " o " + m.group("Msmfro_83") + " " + m.group("Msmfro_84") + "icas" in TEXT and not m.group("Msmfro_83") + "-" + m.group("Msmfro_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_85>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_85").lower() in plvrMfr and not " e " + m.group("Msmfro_85") + " " + m.group("Msmfro_86") + "escas" in TEXT and not " ou " + m.group("Msmfro_85") + " " + m.group("Msmfro_86") + "escas" in TEXT and not "s de " + m.group("Msmfro_85") + " " + m.group("Msmfro_86") + "escas" in TEXT and not "s do " + m.group("Msmfro_85") + " " + m.group("Msmfro_86") + "escas" in TEXT and not " o " + m.group("Msmfro_85") + " " + m.group("Msmfro_86") + "escas" in TEXT and not m.group("Msmfro_85") + "-" + m.group("Msmfro_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfro_87>[a-zA-Zçáéíóúâêô]+r) (?P<Msmfro_88>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfro_87").lower() in plvrMfr and m.group("Msmfro_88") in plvrMascm and not " e " + m.group("Msmfro_87") + " " + m.group("Msmfro_88") + "ns" in TEXT and not " ou " + m.group("Msmfro_87") + " " + m.group("Msmfro_88") + "ns" in TEXT and not "s de " + m.group("Msmfro_87") + " " + m.group("Msmfro_88") + "ns" in TEXT and not "s da " + m.group("Msmfro_87") + " " + m.group("Msmfro_88") + "ns" in TEXT and not " a " + m.group("Msmfro_87") + " " + m.group("Msmfro_88") + "ns" in TEXT and not m.group("Msmfro_87") + "-" + m.group("Msmfro_88") + "ns" in tCompostops'],
# plvrMascr
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_1>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_1").lower() in plvrMascr and m.group("Msmcr_2").lower() in plvrMasca and not " e " + m.group("Msmcr_1") + " " + m.group("Msmcr_2") +"s" in TEXT and not " ou " + m.group("Msmcr_1") + " " + m.group("Msmcr_2") + "s" in TEXT and not "s de " + m.group("Msmcr_1") + " " + m.group("Msmcr_2") + "s" in TEXT and not "s do " + m.group("Msmcr_1") + " " + m.group("Msmcr_2") + "s" in TEXT and not " o " + m.group("Msmcr_1") + " " + m.group("Msmcr_2") + "s" in TEXT and not m.group("Msmcr_1") + "e-" + m.group("Msmcr_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_3>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_3").lower() in plvrMascr and m.group("Msmcr_4").lower() in plvrMfoa and not " e " + m.group("Msmcr_3") + " " + m.group("Msmcr_4") + "os" in TEXT and not " ou " + m.group("Msmcr_3") + " " + m.group("Msmcr_4") + "os" in TEXT and not "s de " + m.group("Msmcr_3") + " " + m.group("Msmcr_4") + "os" in TEXT and not "s do " + m.group("Msmcr_3") + " " + m.group("Msmcr_4") + "os" in TEXT and not " o " + m.group("Msmcr_3") + " " + m.group("Msmcr_4") + "os" in TEXT and not m.group("Msmcr_3") + "e-" + m.group("Msmcr_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_5>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_5").lower() in plvrMascr and not m.group("Msmcr_6").lower() in excAdo and not " e " + m.group("Msmcr_5") + " " + m.group("Msmcr_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msmcr_5") + " " + m.group("Msmcr_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msmcr_5") + " " + m.group("Msmcr_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msmcr_5") + " " + m.group("Msmcr_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msmcr_5") + " " + m.group("Msmcr_6") + m.group(3) + "dos" in TEXT and not m.group("Msmcr_5") + "e-" + m.group("Msmcr_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_7>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_7").lower() in plvrMascr and not m.group("Msmcr_8").lower() in excIsta and not " e " + m.group("Msmcr_7") + " " + m.group("Msmcr_8") + "s" in TEXT and not " ou " + m.group("Msmcr_7") + " " + m.group("Msmcr_8") + "s" in TEXT and not "s de " + m.group("Msmcr_7") + " " + m.group("Msmcr_8") + "s" in TEXT and not "s do " + m.group("Msmcr_7") + " " + m.group("Msmcr_8") + "s" in TEXT and not " o " + m.group("Msmcr_7") + " " + m.group("Msmcr_8") + "s" in TEXT and not m.group("Msmcr_7") + "e-" + m.group("Msmcr_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_9>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_9").lower() in plvrMascr and m.group("Msmcr_10").lower() in plvrInva and not " e " + m.group("Msmcr_9") + " " + m.group("Msmcr_10") + "s" in TEXT and not " ou " + m.group("Msmcr_9") + " " + m.group("Msmcr_10") + "s" in TEXT and not "s de " + m.group("Msmcr_9") + " " + m.group("Msmcr_10") + "s" in TEXT and not "s do " + m.group("Msmcr_9") + " " + m.group("Msmcr_10") + "s" in TEXT and not " a " + m.group("Msmcr_9") + " " + m.group("Msmcr_10") + "s" in TEXT and not m.group("Msmcr_9") + "e-" + m.group("Msmcr_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_11>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_11").lower() in plvrMascr and not m.group("Msmcr_12").lower() in excAdo and not " e " + m.group("Msmcr_11") + " " + m.group("Msmcr_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msmcr_11") + " " + m.group("Msmcr_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msmcr_11") + " " + m.group("Msmcr_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Msmcr_11") + " " + m.group("Msmcr_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Msmcr_11") + " " + m.group("Msmcr_12") + m.group(3) + "das" in TEXT and not m.group("Msmcr_11") + "e-" + m.group("Msmcr_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_13>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_13").lower() in plvrMascr and not " e " + m.group("Msmcr_13") + " " + m.group("Msmcr_14") + "osos" in TEXT and not " ou " + m.group("Msmcr_13") + " " + m.group("Msmcr_14") + "osos" in TEXT and not "s de " + m.group("Msmcr_13") + " " + m.group("Msmcr_14") + "osos" in TEXT and not "s do " + m.group("Msmcr_13") + " " + m.group("Msmcr_14") + "osos" in TEXT and not " o " + m.group("Msmcr_13") + " " + m.group("Msmcr_14") + "osos" in TEXT and not m.group("Msmcr_13") + "e-" + m.group("Msmcr_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_15>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_15").lower() in plvrMascr and not " e " + m.group("Msmcr_15") + " " + m.group("Msmcr_16") + "osas" in TEXT and not " ou " + m.group("Msmcr_15") + " " + m.group("Msmcr_16") + "osas" in TEXT and not "s de " + m.group("Msmcr_15") + " " + m.group("Msmcr_16") + "osas" in TEXT and not "s do " + m.group("Msmcr_15") + " " + m.group("Msmcr_16") + "osas" in TEXT and not " o " + m.group("Msmcr_15") + " " + m.group("Msmcr_16") + "osas" in TEXT and not m.group("Msmcr_15") + "e-" + m.group("Msmcr_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_17>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_17").lower() in plvrMascr and not " e " + m.group("Msmcr_17") + " " + m.group("Msmcr_18") + "ivas" in TEXT and not " ou " + m.group("Msmcr_17") + " " + m.group("Msmcr_18") + "ivas" in TEXT and not "s de " + m.group("Msmcr_17") + " " + m.group("Msmcr_18") + "ivas" in TEXT and not "s do " + m.group("Msmcr_17") + " " + m.group("Msmcr_18") + "ivas" in TEXT and not " o " + m.group("Msmcr_17") + " " + m.group("Msmcr_18") + "ivas" in TEXT and not m.group("Msmcr_17") + "e-" + m.group("Msmcr_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_19>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_19").lower() in plvrMascr and not " e " + m.group("Msmcr_19") + " " + m.group("Msmcr_20") + "ivas" in TEXT and not " ou " + m.group("Msmcr_19") + " " + m.group("Msmcr_20") + "ivas" in TEXT and not "s de " + m.group("Msmcr_19") + " " + m.group("Msmcr_20") + "ivas" in TEXT and not "s do " + m.group("Msmcr_19") + " " + m.group("Msmcr_20") + "ivas" in TEXT and not " o " + m.group("Msmcr_19") + " " + m.group("Msmcr_20") + "ivas" in TEXT and not m.group("Msmcr_19") + "e-" + m.group("Msmcr_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_21>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_21").lower() in plvrMascr and not " e " + m.group("Msmcr_21") + " " + m.group("Msmcr_22") + "icos" in TEXT and not " ou " + m.group("Msmcr_21") + " " + m.group("Msmcr_22") + "icos" in TEXT and not "s de " + m.group("Msmcr_21") + " " + m.group("Msmcr_22") + "icos" in TEXT and not "s do " + m.group("Msmcr_21") + " " + m.group("Msmcr_22") + "icos" in TEXT and not " o " + m.group("Msmcr_21") + " " + m.group("Msmcr_22") + "icos" in TEXT and not m.group("Msmcr_21") + "e-" + m.group("Msmcr_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_23>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_23").lower() in plvrMascr and not " e " + m.group("Msmcr_23") + " " + m.group("Msmcr_24") + "icos" in TEXT and not " ou " + m.group("Msmcr_23") + " " + m.group("Msmcr_24") + "icos" in TEXT and not "s de " + m.group("Msmcr_23") + " " + m.group("Msmcr_24") + "icos" in TEXT and not "s do " + m.group("Msmcr_23") + " " + m.group("Msmcr_24") + "icos" in TEXT and not " o " + m.group("Msmcr_23") + " " + m.group("Msmcr_24") + "icos" in TEXT and not m.group("Msmcr_23") + "e-" + m.group("Msmcr_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_25>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_25").lower() in plvrMascr and not " e " + m.group("Msmcr_25") + " " + m.group("Msmcr_26") + "icos" in TEXT and not " ou " + m.group("Msmcr_25") + " " + m.group("Msmcr_26") + "icos" in TEXT and not "s de " + m.group("Msmcr_25") + " " + m.group("Msmcr_26") + "icos" in TEXT and not "s do " + m.group("Msmcr_25") + " " + m.group("Msmcr_26") + "icos" in TEXT and not " o " + m.group("Msmcr_25") + " " + m.group("Msmcr_26") + "icos" in TEXT and not m.group("Msmcr_25") + "e-" + m.group("Msmcr_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_27>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_27").lower() in plvrMascr and not " e " + m.group("Msmcr_27") + " " + m.group("Msmcr_28") + "escos" in TEXT and not " ou " + m.group("Msmcr_27") + " " + m.group("Msmcr_28") + "escos" in TEXT and not "s de " + m.group("Msmcr_27") + " " + m.group("Msmcr_28") + "escos" in TEXT and not "s do " + m.group("Msmcr_27") + " " + m.group("Msmcr_28") + "escos" in TEXT and not " o " + m.group("Msmcr_27") + " " + m.group("Msmcr_28") + "escos" in TEXT and not m.group("Msmcr_27") + "e-" + m.group("Msmcr_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_29>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_29").lower() in plvrMascr and not " e " + m.group("Msmcr_29") + " " + m.group("Msmcr_30") + "idos" in TEXT and not " ou " + m.group("Msmcr_29") + "s " + m.group("Msmcr_30") + "idos" in TEXT and not "s de " + m.group("Msmcr_29") + "s " + m.group("Msmcr_30") + "idos" in TEXT and not "s do " + m.group("Msmcr_29") + "s " + m.group("Msmcr_30") + "idos" in TEXT and not " o " + m.group("Msmcr_29") + "s " + m.group("Msmcr_30") + "idos" in TEXT and not m.group("Msmcr_29") + "e-" + m.group("Msmcr_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_31>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_31").lower() in plvrMascr and not " e " + m.group("Msmcr_31") + " " + m.group("Msmcr_32") + "logos" in TEXT and not " ou " + m.group("Msmcr_31") + " " + m.group("Msmcr_32") + "logos" in TEXT and not "s de " + m.group("Msmcr_31") + " " + m.group("Msmcr_32") + "logos" in TEXT and not "s do " + m.group("Msmcr_31") + " " + m.group("Msmcr_32") + "logos" in TEXT and not " o " + m.group("Msmcr_31") + " " + m.group("Msmcr_32") + "logos" in TEXT and not m.group("Msmcr_31") + "e-" + m.group("Msmcr_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_33>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_33").lower() in plvrMascr and not " e " + m.group("Msmcr_33") + " " + m.group("Msmcr_34") + "rios" in TEXT and not " ou " + m.group("Msmcr_33") + " " + m.group("Msmcr_34") + "rios" in TEXT and not "s de " + m.group("Msmcr_33") + " " + m.group("Msmcr_34") + "rios" in TEXT and not "s do " + m.group("Msmcr_33") + " " + m.group("Msmcr_34") + "rios" in TEXT and not " o " + m.group("Msmcr_33") + " " + m.group("Msmcr_34") + "rios" in TEXT and not m.group("Msmcr_33") + "e-" + m.group("Msmcr_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_35>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_35").lower() in plvrMascr and not " e " + m.group("Msmcr_35") + " " + m.group("Msmcr_36") + "ssimos" in TEXT and not " ou " + m.group("Msmcr_35") + " " + m.group("Msmcr_36") + "ssimos" in TEXT and not "s de " + m.group("Msmcr_35") + " " + m.group("Msmcr_36") + "ssimos" in TEXT and not "s do " + m.group("Msmcr_35") + " " + m.group("Msmcr_36") + "ssimos" in TEXT and not " o " + m.group("Msmcr_35") + " " + m.group("Msmcr_36") + "ssimos" in TEXT and not m.group("Msmcr_35") + "e-" + m.group("Msmcr_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_37>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_37").lower() in plvrMascr and not " e " + m.group("Msmcr_37") + " " + m.group("Msmcr_38") + "simos" in TEXT and not " ou " + m.group("Msmcr_37") + " " + m.group("Msmcr_38") + "simos" in TEXT and not "s de " + m.group("Msmcr_37") + " " + m.group("Msmcr_38") + "simos" in TEXT and not "s do " + m.group("Msmcr_37") + " " + m.group("Msmcr_38") + "simos" in TEXT and not " o " + m.group("Msmcr_37") + " " + m.group("Msmcr_38") + "simos" in TEXT and not m.group("Msmcr_37") + "e-" + m.group("Msmcr_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_41>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_41").lower() in plvrMascr and not m.group("Msmcr_42") in "D-d-" and not " e " + m.group("Msmcr_41") + " " + m.group("Msmcr_42") + "ores" in TEXT and not " ou " + m.group("Msmcr_41") + " " + m.group("Msmcr_42") + "ores" in TEXT and not "s de " + m.group("Msmcr_41") + " " + m.group("Msmcr_42") + "ores" in TEXT and not "s do " + m.group("Msmcr_41") + " " + m.group("Msmcr_42") + "ores" in TEXT and not " o " + m.group("Msmcr_41") + " " + m.group("Msmcr_42") + "ores" in TEXT and not m.group("Msmcr_41") + "e-" + m.group("Msmcr_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_43>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_43").lower() in plvrMascr and m.group("Msmcr_44") in plvrMfr and not " e " + m.group("Msmcr_43") + " " + m.group("Msmcr_44") + "es" in TEXT and not " ou " + m.group("Msmcr_43") + " " + m.group("Msmcr_44") + "es" in TEXT and not "s de " + m.group("Msmcr_43") + " " + m.group("Msmcr_44") + "es" in TEXT and not "s do " + m.group("Msmcr_43") + " " + m.group("Msmcr_44") + "es" in TEXT and not " o " + m.group("Msmcr_43") + " " + m.group("Msmcr_44") + "es" in TEXT and not m.group("Msmcr_43") + "e-" + m.group("Msmcr_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_45>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_45").lower() in plvrMascr and m.group("Msmcr_46") in plvrMascr and not " e " + m.group("Msmcr_45") + " " + m.group("Msmcr_46") + "es" in TEXT and not " ou " + m.group("Msmcr_45") + " " + m.group("Msmcr_46") + "es" in TEXT and not "s de " + m.group("Msmcr_45") + " " + m.group("Msmcr_46") + "es" in TEXT and not "s do " + m.group("Msmcr_45") + " " + m.group("Msmcr_46") + "es" in TEXT and not " o " + m.group("Msmcr_45") + " " + m.group("Msmcr_46") + "es" in TEXT and not m.group("Msmcr_45") + "e-" + m.group("Msmcr_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_47>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_47").lower() in plvrMascr and m.group("Msmcr_48") in plvrMfal and not " e " + m.group("Msmcr_47") + " " + m.group("Msmcr_48") + "is" in TEXT and not " ou " + m.group("Msmcr_47") + " " + m.group("Msmcr_48") + "is" in TEXT and not "s de " + m.group("Msmcr_47") + " " + m.group("Msmcr_48") + "is" in TEXT and not "s do " + m.group("Msmcr_47") + " " + m.group("Msmcr_48") + "is" in TEXT and not " o " + m.group("Msmcr_47") + " " + m.group("Msmcr_48") + "is" in TEXT and not m.group("Msmcr_47") + "e-" + m.group("Msmcr_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_49>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_49").lower() in plvrMascr and m.group("Msmcr_50") in plvrMfcao and not " e " + m.group("Msmcr_49") + " " + m.group("Msmcr_50") + "ões" in TEXT and not + " ou " + m.group("Msmcr_49") + " " + m.group("Msmcr_50") + "ões" in TEXT and not + "s de " + m.group("Msmcr_49") + " " + m.group("Msmcr_50") + "ões" in TEXT and not + "s do " + m.group("Msmcr_49") + " " + m.group("Msmcr_50") + "ões" in TEXT and not + " a " + m.group("Msmcr_49") + " " + m.group("Msmcr_50") + "ões" in TEXT and not m.group("Msmcr_49") + "e-" + m.group("Msmcr_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_51>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_51").lower() in plvrMascr and m.group("Msmcr_52") in plvrNfemcao and not " e " + m.group("Msmcr_51") + " " + m.group("Msmcr_52") + "ões" in TEXT and not " ou " + m.group("Msmcr_51") + " " + m.group("Msmcr_52") + "ões" in TEXT and not "s de " + m.group("Msmcr_51") + " " + m.group("Msmcr_52") + "ões" in TEXT and not "s do " + m.group("Msmcr_51") + " " + m.group("Msmcr_52") + "ões" in TEXT and not " o " + m.group("Msmcr_51") + " " + m.group("Msmcr_52") + "ões" in TEXT and not m.group("Msmcr_51") + "e-" + m.group("Msmcr_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_55>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_55").lower() in plvrMascr and not " e " + m.group("Msmcr_55") + " " + m.group("Msmcr_56") + "veis" in TEXT and not " ou " + m.group("Msmcr_55") + " " + m.group("Msmcr_56") + "veis" in TEXT and not "s de " + m.group("Msmcr_55") + " " + m.group("Msmcr_56") + "veis" in TEXT and not "s do " + m.group("Msmcr_55") + " " + m.group("Msmcr_56") + "veis" in TEXT and not " o " + m.group("Msmcr_55") + " " + m.group("Msmcr_56") + "veis" in TEXT and not m.group("Msmcr_55") + "e-" + m.group("Msmcr_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_57>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_57").lower() in plvrMascr and m.group("Msmcr_58").lower() in plvrMfe and not " e " + m.group("Msmcr_57") + " " + m.group("Msmcr_58") + "es" in TEXT and not " ou " + m.group("Msmcr_57") + " " + m.group("Msmcr_58") + "es" in TEXT and not "s de " + m.group("Msmcr_57") + " " + m.group("Msmcr_58") + "es" in TEXT and not "s do " + m.group("Msmcr_57") + " " + m.group("Msmcr_58") + "es" in TEXT and not " o " + m.group("Msmcr_57") + " " + m.group("Msmcr_58") + "es" in TEXT and not m.group("Msmcr_57") + "e-" + m.group("Msmcr_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_59>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_59").lower() in plvrMascr and m.group("Msmcr_60").lower() in plvrMascr and not " e " + m.group("Msmcr_59") + " " + m.group("Msmcr_60") + "es" in TEXT and not " ou " + m.group("Msmcr_59") + " " + m.group("Msmcr_60") + "es" in TEXT and not "s de " + m.group("Msmcr_59") + " " + m.group("Msmcr_60") + "es" in TEXT and not "s do " + m.group("Msmcr_59") + " " + m.group("Msmcr_60") + "es" in TEXT and not " o " + m.group("Msmcr_59") + " " + m.group("Msmcr_60") + "es" in TEXT and not m.group("Msmcr_59") + "e-" + m.group("Msmcr_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_61>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_61").lower() in plvrMascr and m.group("Msmcr_62") in plvrMfel and not " e " + m.group("Msmcr_61") + " " + m.group("Msmcr_62") + "éis" in TEXT and not " ou " + m.group("Msmcr_61") + " " + m.group("Msmcr_62") + "éis" in TEXT and not "s de " + m.group("Msmcr_61") + " " + m.group("Msmcr_62") + "éis" in TEXT and not "s do " + m.group("Msmcr_61") + " " + m.group("Msmcr_62") + "éis" in TEXT and not " o " + m.group("Msmcr_61") + " " + m.group("Msmcr_62") + "éis" in TEXT and not m.group("Msmcr_61") + "e-" + m.group("Msmcr_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_63>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_63").lower() in plvrMascr and m.group("Msmcr_64") in plvrMascel and not " e " + m.group("Msmcr_63") + " " + m.group("Msmcr_64") + "éis" in TEXT and not " ou " + m.group("Msmcr_63") + " " + m.group("Msmcr_64") + "éis" in TEXT and not "s de " + m.group("Msmcr_63") + " " + m.group("Msmcr_64") + "éis" in TEXT and not "s do " + m.group("Msmcr_63") + " " + m.group("Msmcr_64") + "éis" in TEXT and not " o " + m.group("Msmcr_63") + " " + m.group("Msmcr_64") + "éis" in TEXT and not m.group("Msmcr_63") + "e-" + m.group("Msmcr_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_65>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_65").lower() in plvrMascr and m.group("Msmcr_66") in plvrMfeu and not " e " + m.group("Msmcr_65") + " " + m.group("Msmcr_66") + "us" in TEXT and not " ou " + m.group("Msmcr_65") + " " + m.group("Msmcr_66") + "us" in TEXT and not "s de " + m.group("Msmcr_65") + " " + m.group("Msmcr_66") + "us" in TEXT and not "s do " + m.group("Msmcr_65") + " " + m.group("Msmcr_66") + "us" in TEXT and not " o " + m.group("Msmcr_65") + " " + m.group("Msmcr_66") + "us" in TEXT and not m.group("Msmcr_65") + "e-" + m.group("Msmcr_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_67>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_67").lower() in plvrMascr and m.group("Msmcr_68") in plvrMascu and not " e " + m.group("Msmcr_67") + " " + m.group("Msmcr_68") + "us" in TEXT and not " ou " + m.group("Msmcr_67") + " " + m.group("Msmcr_68") + "us" in TEXT and not "s de " + m.group("Msmcr_67") + " " + m.group("Msmcr_68") + "us" in TEXT and not "s do " + m.group("Msmcr_67") + " " + m.group("Msmcr_68") + "us" in TEXT and not " o " + m.group("Msmcr_67") + " " + m.group("Msmcr_68") + "us" in TEXT and not m.group("Msmcr_67") + "e-" + m.group("Msmcr_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_69>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_69").lower() in plvrMascr and m.group("Msmcr_70") in plvrInvaz and not " e " + m.group("Msmcr_69") + " " + m.group("Msmcr_70") + "zes" in TEXT and not " ou " + m.group("Msmcr_69") + " " + m.group("Msmcr_70") + "zes" in TEXT and not "s de " + m.group("Msmcr_69") + " " + m.group("Msmcr_70") + "zes" in TEXT and not "s do " + m.group("Msmcr_69") + " " + m.group("Msmcr_70") + "zes" in TEXT and not " o " + m.group("Msmcr_69") + " " + m.group("Msmcr_70") + "zes" in TEXT and not m.group("Msmcr_69") + "e-" + m.group("Msmcr_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_71>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_71").lower() in plvrMascr and m.group("Msmcr_72") in plvrMascz and not " e " + m.group("Msmcr_71") + " " + m.group("Msmcr_72") + "zes" in TEXT and not " ou " + m.group("Msmcr_71") + " " + m.group("Msmcr_72") + "zes" in TEXT and not "s de " + m.group("Msmcr_71") + " " + m.group("Msmcr_72") + "zes" in TEXT and not "s do " + m.group("Msmcr_71") + " " + m.group("Msmcr_72") + "zes" in TEXT and not " o " + m.group("Msmcr_71") + " " + m.group("Msmcr_72") + "zes" in TEXT and not m.group("Msmcr_71") + "e-" + m.group("Msmcr_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_73>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_73").lower() in plvrMascr and m.group("Msmcr_74") in pvrMascan and not " e " + m.group("Msmcr_73") + " " + m.group("Msmcr_74") + "s" in TEXT and not " ou " + m.group("Msmcr_73") + " " + m.group("Msmcr_74") + "s" in TEXT and not "s de " + m.group("Msmcr_73") + " " + m.group("Msmcr_74") + "s" in TEXT and not "s do " + m.group("Msmcr_73") + " " + m.group("Msmcr_74") + "s" in TEXT and not " o " + m.group("Msmcr_73") + " " + m.group("Msmcr_74") + "s" in TEXT and not m.group("Msmcr_73") + "e-" + m.group("Msmcr_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_75>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_75").lower() in plvrMascr and m.group("Msmcr_76").lower() in plvrMasco and not " e " + m.group("Msmcr_75") + " " + m.group("Msmcr_76") +"s" in TEXT and not " ou " + m.group("Msmcr_75") + " " + m.group("Msmcr_76") + "s" in TEXT and not "s de " + m.group("Msmcr_75") + " " + m.group("Msmcr_76") + "s" in TEXT and not "s do " + m.group("Msmcr_75") + " " + m.group("Msmcr_76") + "s" in TEXT and not " o " + m.group("Msmcr_75") + " " + m.group("Msmcr_76") + "s" in TEXT and not m.group("Msmcr_75") + "e-" + m.group("Msmcr_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_77>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_77").lower() in plvrMascr and not " e " + m.group("Msmcr_77") + " " + m.group("Msmcr_78") + "inhos" in TEXT and not " ou " + m.group("Msmcr_77") + " " + m.group("Msmcr_78") + "inhos" in TEXT and not "s de " + m.group("Msmcr_77") + " " + m.group("Msmcr_78") + "inhos" in TEXT and not "s do " + m.group("Msmcr_77") + " " + m.group("Msmcr_78") + "inhos" in TEXT and not " o " + m.group("Msmcr_77") + " " + m.group("Msmcr_78") + "inhos" in TEXT and not m.group("Msmcr_77") + "e-" + m.group("Msmcr_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_79>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_79").lower() in plvrMascr and not " e " + m.group("Msmcr_79") + " " + m.group("Msmcr_80") + "icas" in TEXT and not " ou " + m.group("Msmcr_79") + " " + m.group("Msmcr_80") + "icas" in TEXT and not "s de " + m.group("Msmcr_79") + " " + m.group("Msmcr_80") + "icas" in TEXT and not "s do " + m.group("Msmcr_79") + " " + m.group("Msmcr_80") + "icas" in TEXT and not " o " + m.group("Msmcr_79") + " " + m.group("Msmcr_80") + "icas" in TEXT and not m.group("Msmcr_79") + "e-" + m.group("Msmcr_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_81>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_81").lower() in plvrMascr and not " e " + m.group("Msmcr_81") + " " + m.group("Msmcr_82") + "icas" in TEXT and not " ou " + m.group("Msmcr_81") + " " + m.group("Msmcr_82") + "icas" in TEXT and not "s de " + m.group("Msmcr_81") + " " + m.group("Msmcr_82") + "icas" in TEXT and not "s do " + m.group("Msmcr_81") + " " + m.group("Msmcr_82") + "icas" in TEXT and not " o " + m.group("Msmcr_81") + " " + m.group("Msmcr_82") + "icas" in TEXT and not m.group("Msmcr_81") + "e-" + m.group("Msmcr_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_83>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_83").lower() in plvrMascr and not " e " + m.group("Msmcr_83") + " " + m.group("Msmcr_84") + "icas" in TEXT and not " ou " + m.group("Msmcr_83") + " " + m.group("Msmcr_84") + "icas" in TEXT and not "s de " + m.group("Msmcr_83") + " " + m.group("Msmcr_84") + "icas" in TEXT and not "s do " + m.group("Msmcr_83") + " " + m.group("Msmcr_84") + "icas" in TEXT and not " o " + m.group("Msmcr_83") + " " + m.group("Msmcr_84") + "icas" in TEXT and not m.group("Msmcr_83") + "e-" + m.group("Msmcr_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_85>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_85").lower() in plvrMascr and not " e " + m.group("Msmcr_85") + " " + m.group("Msmcr_86") + "escas" in TEXT and not " ou " + m.group("Msmcr_85") + " " + m.group("Msmcr_86") + "escas" in TEXT and not "s de " + m.group("Msmcr_85") + " " + m.group("Msmcr_86") + "escas" in TEXT and not "s do " + m.group("Msmcr_85") + " " + m.group("Msmcr_86") + "escas" in TEXT and not " o " + m.group("Msmcr_85") + " " + m.group("Msmcr_86") + "escas" in TEXT and not m.group("Msmcr_85") + "e-" + m.group("Msmcr_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_87>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_87").lower() in plvrMascr and not " e " + m.group("Msmcr_87") + " " + m.group("Msmcr_88") + "idas" in TEXT and not " ou " + m.group("Msmcr_87") + "s " + m.group("Msmcr_88") + "idas" in TEXT and not "s de " + m.group("Msmcr_87") + "s " + m.group("Msmcr_88") + "idas" in TEXT and not "s do " + m.group("Msmcr_87") + "s " + m.group("Msmcr_88") + "idas" in TEXT and not " o " + m.group("Msmcr_87") + "s " + m.group("Msmcr_88") + "idas" in TEXT and not m.group("Msmcr_87") + "e-" + m.group("Msmcr_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_89>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_89").lower() in plvrMascr and not " e " + m.group("Msmcr_89") + " " + m.group("Msmcr_90") + "logas" in TEXT and not " ou " + m.group("Msmcr_89") + " " + m.group("Msmcr_90") + "logas" in TEXT and not "s de " + m.group("Msmcr_89") + " " + m.group("Msmcr_90") + "logas" in TEXT and not "s do " + m.group("Msmcr_89") + " " + m.group("Msmcr_90") + "logas" in TEXT and not " o " + m.group("Msmcr_89") + " " + m.group("Msmcr_90") + "logas" in TEXT and not m.group("Msmcr_89") + "e-" + m.group("Msmcr_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_91>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_91").lower() in plvrMascr and not " e " + m.group("Msmcr_91") + " " + m.group("Msmcr_92") + "rias" in TEXT and not " ou " + m.group("Msmcr_91") + " " + m.group("Msmcr_92") + "rias" in TEXT and not "s de " + m.group("Msmcr_91") + " " + m.group("Msmcr_92") + "rias" in TEXT and not "s do " + m.group("Msmcr_91") + " " + m.group("Msmcr_92") + "rias" in TEXT and not " o " + m.group("Msmcr_91") + " " + m.group("Msmcr_92") + "rias" in TEXT and not m.group("Msmcr_91") + "e-" + m.group("Msmcr_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_93>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_93").lower() in plvrMascr and not " e " + m.group("Msmcr_93") + " " + m.group("Msmcr_94") + "ssimas" in TEXT and not " ou " + m.group("Msmcr_93") + " " + m.group("Msmcr_94") + "ssimas" in TEXT and not "s de " + m.group("Msmcr_93") + " " + m.group("Msmcr_94") + "ssimas" in TEXT and not "s do " + m.group("Msmcr_93") + " " + m.group("Msmcr_94") + "ssimas" in TEXT and not " o " + m.group("Msmcr_93") + " " + m.group("Msmcr_94") + "ssimas" in TEXT and not m.group("Msmcr_93") + "e-" + m.group("Msmcr_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_95>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_95").lower() in plvrMascr and not " e " + m.group("Msmcr_95") + " " + m.group("Msmcr_96") + "simas" in TEXT and not " ou " + m.group("Msmcr_95") + " " + m.group("Msmcr_96") + "simas" in TEXT and not "s de " + m.group("Msmcr_95") + " " + m.group("Msmcr_96") + "simas" in TEXT and not "s do " + m.group("Msmcr_95") + " " + m.group("Msmcr_96") + "simas" in TEXT and not " o " + m.group("Msmcr_95") + " " + m.group("Msmcr_96") + "simas" in TEXT and not m.group("Msmcr_95") + "e-" + m.group("Msmcr_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_97>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_97").lower() in plvrMascr and m.group("Msmcr_98").lower() in plvrMascr and not " e " + m.group("Msmcr_97") + " " + m.group("Msmcr_98") + "as" in TEXT and not " ou " + m.group("Msmcr_97") + " " + m.group("Msmcr_98") + "as" in TEXT and not "s de " + m.group("Msmcr_97") + " " + m.group("Msmcr_98") + "as" in TEXT and not "s do " + m.group("Msmcr_97") + " " + m.group("Msmcr_98") + "as" in TEXT and not " o " + m.group("Msmcr_97") + " " + m.group("Msmcr_98") + "as" in TEXT and not m.group("Msmcr_97") + "e-" + m.group("Msmcr_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_99>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_99").lower() in plvrMascr and m.group("Msmcr_100") in plvrMFm and not " e " + m.group("Msmcr_99") + " " + m.group("Msmcr_100") + "ns" in TEXT and not " ou " + m.group("Msmcr_99") + " " + m.group("Msmcr_100") + "ns" in TEXT and not "s de " + m.group("Msmcr_99") + " " + m.group("Msmcr_100") + "ns" in TEXT and not "s do " + m.group("Msmcr_99") + " " + m.group("Msmcr_100") + "ns" in TEXT and not " o " + m.group("Msmcr_99") + " " + m.group("Msmcr_100") + "ns" in TEXT and not m.group("Msmcr_99") + "e-" + m.group("Msmcr_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcr_101>[a-zA-Zçáéíóúâêô]+r) (?P<Msmcr_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcr_101").lower() in plvrMascr and m.group("Msmcr_102") in plvrMascm and not " e " + m.group("Msmcr_101") + " " + m.group("Msmcr_102") + "ns" in TEXT and not " ou " + m.group("Msmcr_101") + " " + m.group("Msmcr_102") + "ns" in TEXT and not "s de " + m.group("Msmcr_101") + " " + m.group("Msmcr_102") + "ns" in TEXT and not "s do " + m.group("Msmcr_101") + " " + m.group("Msmcr_102") + "ns" in TEXT and not " o " + m.group("Msmcr_101") + " " + m.group("Msmcr_102") + "ns" in TEXT and not m.group("Msmcr_101") + "e-" + m.group("Msmcr_102") + "ns" in tCompostops'],
# plvrFemr
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_1>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_1").lower() in plvrFemr and m.group("Msfmr_2").lower() in plvrFema and not " e " + m.group("Msfmr_1") + " " + m.group("Msfmr_2") +"s" in TEXT and not " ou " + m.group("Msfmr_1") + " " + m.group("Msfmr_2") + "s" in TEXT and not "s de " + m.group("Msfmr_1") + " " + m.group("Msfmr_2") + "s" in TEXT and not "s da " + m.group("Msfmr_1") + " " + m.group("Msfmr_2") + "s" in TEXT and not " a " + m.group("Msfmr_1") + " " + m.group("Msfmr_2") + "s" in TEXT and not m.group("Msfmr_1") + "-" + m.group("Msfmr_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_3>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_3").lower() in plvrFemr and m.group("Msfmr_4").lower() in plvrMfoa and not " e " + m.group("Msfmr_3") + " " + m.group("Msfmr_4") + "as" in TEXT and not " ou " + m.group("Msfmr_3") + " " + m.group("Msfmr_4") + "as" in TEXT and not "s de " + m.group("Msfmr_3") + " " + m.group("Msfmr_4") + "as" in TEXT and not "s da " + m.group("Msfmr_3") + " " + m.group("Msfmr_4") + "as" in TEXT and not " a " + m.group("Msfmr_3") + " " + m.group("Msfmr_4") + "as" in TEXT and not m.group("Msfmr_3") + "-" + m.group("Msfmr_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_5>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_5").lower() in plvrFemr and not m.group("Msfmr_6").lower() in excAdo and not " e " + m.group("Msfmr_5") + " " + m.group("Msfmr_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msfmr_5") + " " + m.group("Msfmr_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msfmr_5") + " " + m.group("Msfmr_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Msfmr_5") + " " + m.group("Msfmr_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Msfmr_5") + " " + m.group("Msfmr_6") + m.group(3) + "dos" in TEXT and not m.group("Msfmr_5") + "-" + m.group("Msfmr_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_7>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_7").lower() in plvrFemr and not m.group("Msfmr_8").lower() in excIsta and not " e " + m.group("Msfmr_7") + " " + m.group("Msfmr_8") + "s" in TEXT and not " ou " + m.group("Msfmr_7") + " " + m.group("Msfmr_8") + "s" in TEXT and not "s de " + m.group("Msfmr_7") + " " + m.group("Msfmr_8") + "s" in TEXT and not "s da " + m.group("Msfmr_7") + " " + m.group("Msfmr_8") + "s" in TEXT and not " a " + m.group("Msfmr_7") + " " + m.group("Msfmr_8") + "s" in TEXT and not m.group("Msfmr_7") + "-" + m.group("Msfmr_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_9>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_9").lower() in plvrFemr and m.group("Msfmr_10").lower() in plvrInva and not " e " + m.group("Msfmr_9") + " " + m.group("Msfmr_10") + "s" in TEXT and not " ou " + m.group("Msfmr_9") + " " + m.group("Msfmr_10") + "s" in TEXT and not "s de " + m.group("Msfmr_9") + " " + m.group("Msfmr_10") + "s" in TEXT and not "s da " + m.group("Msfmr_9") + " " + m.group("Msfmr_10") + "s" in TEXT and not " a " + m.group("Msfmr_9") + " " + m.group("Msfmr_10") + "s" in TEXT and not m.group("Msfmr_9") + "-" + m.group("Msfmr_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_11>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_11").lower() in plvrFemr and not m.group("Msfmr_12").lower() in excAdo and not " e " + m.group("Msfmr_11") + " " + m.group("Msfmr_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msfmr_11") + " " + m.group("Msfmr_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msfmr_11") + " " + m.group("Msfmr_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Msfmr_11") + " " + m.group("Msfmr_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Msfmr_11") + " " + m.group("Msfmr_12") + m.group(3) + "das" in TEXT and not m.group("Msfmr_11") + "-" + m.group("Msfmr_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_15>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_15").lower() in plvrFemr and not " e " + m.group("Msfmr_15") + " " + m.group("Msfmr_16") + "osas" in TEXT and not " ou " + m.group("Msfmr_15") + " " + m.group("Msfmr_16") + "osas" in TEXT and not "s de " + m.group("Msfmr_15") + " " + m.group("Msfmr_16") + "osas" in TEXT and not "s da " + m.group("Msfmr_15") + " " + m.group("Msfmr_16") + "osas" in TEXT and not " a " + m.group("Msfmr_15") + " " + m.group("Msfmr_16") + "osas" in TEXT and not m.group("Msfmr_15") + "-" + m.group("Msfmr_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_17>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_17").lower() in plvrFemr and not " e " + m.group("Msfmr_17") + " " + m.group("Msfmr_18") + "ivas" in TEXT and not " ou " + m.group("Msfmr_17") + " " + m.group("Msfmr_18") + "ivas" in TEXT and not "s de " + m.group("Msfmr_17") + " " + m.group("Msfmr_18") + "ivas" in TEXT and not "s da " + m.group("Msfmr_17") + " " + m.group("Msfmr_18") + "ivas" in TEXT and not " a " + m.group("Msfmr_17") + " " + m.group("Msfmr_18") + "ivas" in TEXT and not m.group("Msfmr_17") + "-" + m.group("Msfmr_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_21>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_21").lower() in plvrFemr and not " e " + m.group("Msfmr_21") + " " + m.group("Msfmr_22") + "icas" in TEXT and not " ou " + m.group("Msfmr_21") + " " + m.group("Msfmr_22") + "icas" in TEXT and not "s de " + m.group("Msfmr_21") + " " + m.group("Msfmr_22") + "icas" in TEXT and not "s da " + m.group("Msfmr_21") + " " + m.group("Msfmr_22") + "icas" in TEXT and not " a " + m.group("Msfmr_21") + " " + m.group("Msfmr_22") + "icas" in TEXT and not m.group("Msfmr_21") + "-" + m.group("Msfmr_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_23>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_23").lower() in plvrFemr and not " e " + m.group("Msfmr_23") + " " + m.group("Msfmr_24") + "icas" in TEXT and not " ou " + m.group("Msfmr_23") + " " + m.group("Msfmr_24") + "icas" in TEXT and not "s de " + m.group("Msfmr_23") + " " + m.group("Msfmr_24") + "icas" in TEXT and not "s da " + m.group("Msfmr_23") + " " + m.group("Msfmr_24") + "icas" in TEXT and not " a " + m.group("Msfmr_23") + " " + m.group("Msfmr_24") + "icas" in TEXT and not m.group("Msfmr_23") + "-" + m.group("Msfmr_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_25>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_25").lower() in plvrFemr and not " e " + m.group("Msfmr_25") + " " + m.group("Msfmr_26") + "icas" in TEXT and not " ou " + m.group("Msfmr_25") + " " + m.group("Msfmr_26") + "icas" in TEXT and not "s de " + m.group("Msfmr_25") + " " + m.group("Msfmr_26") + "icas" in TEXT and not "s da " + m.group("Msfmr_25") + " " + m.group("Msfmr_26") + "icas" in TEXT and not " a " + m.group("Msfmr_25") + " " + m.group("Msfmr_26") + "icas" in TEXT and not m.group("Msfmr_25") + "-" + m.group("Msfmr_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_27>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_27").lower() in plvrFemr and not " e " + m.group("Msfmr_27") + " " + m.group("Msfmr_28") + "escas" in TEXT and not " ou " + m.group("Msfmr_27") + " " + m.group("Msfmr_28") + "escas" in TEXT and not "s de " + m.group("Msfmr_27") + " " + m.group("Msfmr_28") + "escas" in TEXT and not "s da " + m.group("Msfmr_27") + " " + m.group("Msfmr_28") + "escas" in TEXT and not " a " + m.group("Msfmr_27") + " " + m.group("Msfmr_28") + "escas" in TEXT and not m.group("Msfmr_27") + "-" + m.group("Msfmr_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_29>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_29").lower() in plvrFemr and not " e " + m.group("Msfmr_29") + " " + m.group("Msfmr_30") + "idas" in TEXT and not " ou " + m.group("Msfmr_29") + "s " + m.group("Msfmr_30") + "idas" in TEXT and not "s de " + m.group("Msfmr_29") + "s " + m.group("Msfmr_30") + "idas" in TEXT and not "s da " + m.group("Msfmr_29") + "s " + m.group("Msfmr_30") + "idas" in TEXT and not " a " + m.group("Msfmr_29") + "s " + m.group("Msfmr_30") + "idas" in TEXT and not m.group("Msfmr_29") + "-" + m.group("Msfmr_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_31>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_31").lower() in plvrFemr and not " e " + m.group("Msfmr_31") + " " + m.group("Msfmr_32") + "logas" in TEXT and not " ou " + m.group("Msfmr_31") + " " + m.group("Msfmr_32") + "logas" in TEXT and not "s de " + m.group("Msfmr_31") + " " + m.group("Msfmr_32") + "logas" in TEXT and not "s da " + m.group("Msfmr_31") + " " + m.group("Msfmr_32") + "logas" in TEXT and not " a " + m.group("Msfmr_31") + " " + m.group("Msfmr_32") + "logas" in TEXT and not m.group("Msfmr_31") + "-" + m.group("Msfmr_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_33>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_33").lower() in plvrFemr and not " e " + m.group("Msfmr_33") + " " + m.group("Msfmr_34") + "rias" in TEXT and not " ou " + m.group("Msfmr_33") + " " + m.group("Msfmr_34") + "rias" in TEXT and not "s de " + m.group("Msfmr_33") + " " + m.group("Msfmr_34") + "rias" in TEXT and not "s da " + m.group("Msfmr_33") + " " + m.group("Msfmr_34") + "rias" in TEXT and not " a " + m.group("Msfmr_33") + " " + m.group("Msfmr_34") + "rias" in TEXT and not m.group("Msfmr_33") + "-" + m.group("Msfmr_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_35>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_35").lower() in plvrFemr and not " e " + m.group("Msfmr_35") + " " + m.group("Msfmr_36") + "ssimas" in TEXT and not " ou " + m.group("Msfmr_35") + " " + m.group("Msfmr_36") + "ssimas" in TEXT and not "s de " + m.group("Msfmr_35") + " " + m.group("Msfmr_36") + "ssimas" in TEXT and not "s da " + m.group("Msfmr_35") + " " + m.group("Msfmr_36") + "ssimas" in TEXT and not " a " + m.group("Msfmr_35") + " " + m.group("Msfmr_36") + "ssimas" in TEXT and not m.group("Msfmr_35") + "-" + m.group("Msfmr_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_37>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_37").lower() in plvrFemr and not " e " + m.group("Msfmr_37") + " " + m.group("Msfmr_38") + "simas" in TEXT and not " ou " + m.group("Msfmr_37") + " " + m.group("Msfmr_38") + "simas" in TEXT and not "s de " + m.group("Msfmr_37") + " " + m.group("Msfmr_38") + "simas" in TEXT and not "s da " + m.group("Msfmr_37") + " " + m.group("Msfmr_38") + "simas" in TEXT and not " a " + m.group("Msfmr_37") + " " + m.group("Msfmr_38") + "simas" in TEXT and not m.group("Msfmr_37") + "-" + m.group("Msfmr_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_41>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_41").lower() in plvrFemr and not m.group("Msfmr_42") in "D-d-" and not " e " + m.group("Msfmr_41") + " " + m.group("Msfmr_42") + "oras" in TEXT and not " ou " + m.group("Msfmr_41") + " " + m.group("Msfmr_42") + "oras" in TEXT and not "s de " + m.group("Msfmr_41") + " " + m.group("Msfmr_42") + "oras" in TEXT and not "s da " + m.group("Msfmr_41") + " " + m.group("Msfmr_42") + "oras" in TEXT and not " a " + m.group("Msfmr_41") + " " + m.group("Msfmr_42") + "oras" in TEXT and not m.group("Msfmr_41") + "-" + m.group("Msfmr_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_43>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_43").lower() in plvrFemr and m.group("Msfmr_44") in plvrMfr and not " e " + m.group("Msfmr_43") + " " + m.group("Msfmr_44") + "es" in TEXT and not " ou " + m.group("Msfmr_43") + " " + m.group("Msfmr_44") + "es" in TEXT and not "s de " + m.group("Msfmr_43") + " " + m.group("Msfmr_44") + "es" in TEXT and not "s da " + m.group("Msfmr_43") + " " + m.group("Msfmr_44") + "es" in TEXT and not " a " + m.group("Msfmr_43") + " " + m.group("Msfmr_44") + "es" in TEXT and not m.group("Msfmr_43") + "-" + m.group("Msfmr_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_45>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_45").lower() in plvrFemr and m.group("Msfmr_46") in plvrFemr and not " e " + m.group("Msfmr_45") + " " + m.group("Msfmr_46") + "es" in TEXT and not " ou " + m.group("Msfmr_45") + " " + m.group("Msfmr_46") + "es" in TEXT and not "s de " + m.group("Msfmr_45") + " " + m.group("Msfmr_46") + "es" in TEXT and not "s da " + m.group("Msfmr_45") + " " + m.group("Msfmr_46") + "es" in TEXT and not " a " + m.group("Msfmr_45") + " " + m.group("Msfmr_46") + "es" in TEXT and not m.group("Msfmr_45") + "-" + m.group("Msfmr_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_47>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_47").lower() in plvrFemr and m.group("Msfmr_48") in plvrMfal and not " e " + m.group("Msfmr_47") + " " + m.group("Msfmr_48") + "is" in TEXT and not " ou " + m.group("Msfmr_47") + " " + m.group("Msfmr_48") + "is" in TEXT and not "s de " + m.group("Msfmr_47") + " " + m.group("Msfmr_48") + "is" in TEXT and not "s da " + m.group("Msfmr_47") + " " + m.group("Msfmr_48") + "is" in TEXT and not " a " + m.group("Msfmr_47") + " " + m.group("Msfmr_48") + "is" in TEXT and not m.group("Msfmr_47") + "-" + m.group("Msfmr_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_49>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_49").lower() in plvrFemr and m.group("Msfmr_50") in plvrMfcao and not " e " + m.group("Msfmr_49") + " " + m.group("Msfmr_50") + "ões" in TEXT and not + " ou " + m.group("Msfmr_49") + " " + m.group("Msfmr_50") + "ões" in TEXT and not + "s de " + m.group("Msfmr_49") + " " + m.group("Msfmr_50") + "ões" in TEXT and not + "s da " + m.group("Msfmr_49") + " " + m.group("Msfmr_50") + "ões" in TEXT and not + " a " + m.group("Msfmr_49") + " " + m.group("Msfmr_50") + "ões" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_51>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_51").lower() in plvrFemr and not m.group("Msfmr_52") in plvrMascao and not " e " + m.group("Msfmr_51") + " " + m.group("Msfmr_52") + "ões" in TEXT and not " ou " + m.group("Msfmr_51") + " " + m.group("Msfmr_52") + "ões" in TEXT and not "s de " + m.group("Msfmr_51") + " " + m.group("Msfmr_52") + "ões" in TEXT and not "s da " + m.group("Msfmr_51") + " " + m.group("Msfmr_52") + "ões" in TEXT and not " a " + m.group("Msfmr_51") + " " + m.group("Msfmr_52") + "ões" in TEXT and not m.group("Msfmr_51") + "-" + m.group("Msfmr_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_53>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_53").lower() in plvrFemr and m.group("Msfmr_54") in plvrFemao and not " e " + m.group("Msfmr_53") + " " + m.group("Msfmr_54") + "ões" in TEXT and not " ou " + m.group("Msfmr_53") + " " + m.group("Msfmr_54") + "ões" in TEXT and not "s de " + m.group("Msfmr_53") + " " + m.group("Msfmr_54") + "ões" in TEXT and not "s da " + m.group("Msfmr_53") + " " + m.group("Msfmr_54") + "ões" in TEXT and not " a " + m.group("Msfmr_53") + " " + m.group("Msfmr_54") + "ões" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_55>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_55").lower() in plvrFemr and not " e " + m.group("Msfmr_55") + " " + m.group("Msfmr_56") + "veis" in TEXT and not " ou " + m.group("Msfmr_55") + " " + m.group("Msfmr_56") + "veis" in TEXT and not "s de " + m.group("Msfmr_55") + " " + m.group("Msfmr_56") + "veis" in TEXT and not "s da " + m.group("Msfmr_55") + " " + m.group("Msfmr_56") + "veis" in TEXT and not " a " + m.group("Msfmr_55") + " " + m.group("Msfmr_56") + "veis" in TEXT and not m.group("Msfmr_55") + "-" + m.group("Msfmr_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_57>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_57").lower() in plvrFemr and m.group("Msfmr_58").lower() in plvrMfe and not " e " + m.group("Msfmr_57") + " " + m.group("Msfmr_58") + "es" in TEXT and not " ou " + m.group("Msfmr_57") + " " + m.group("Msfmr_58") + "es" in TEXT and not "s de " + m.group("Msfmr_57") + " " + m.group("Msfmr_58") + "es" in TEXT and not "s da " + m.group("Msfmr_57") + " " + m.group("Msfmr_58") + "es" in TEXT and not " a " + m.group("Msfmr_57") + " " + m.group("Msfmr_58") + "es" in TEXT and not m.group("Msfmr_57") + "-" + m.group("Msfmr_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_59>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_59").lower() in plvrFemr and m.group("Msfmr_60").lower() in plvrFeme and not " e " + m.group("Msfmr_59") + " " + m.group("Msfmr_60") + "es" in TEXT and not " ou " + m.group("Msfmr_59") + " " + m.group("Msfmr_60") + "es" in TEXT and not "s de " + m.group("Msfmr_59") + " " + m.group("Msfmr_60") + "es" in TEXT and not "s da " + m.group("Msfmr_59") + " " + m.group("Msfmr_60") + "es" in TEXT and not " a " + m.group("Msfmr_59") + " " + m.group("Msfmr_60") + "es" in TEXT and not m.group("Msfmr_59") + "-" + m.group("Msfmr_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_61>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_61").lower() in plvrFemr and m.group("Msfmr_62") in plvrMfel and not " e " + m.group("Msfmr_61") + " " + m.group("Msfmr_62") + "éis" in TEXT and not " ou " + m.group("Msfmr_61") + " " + m.group("Msfmr_62") + "éis" in TEXT and not "s de " + m.group("Msfmr_61") + " " + m.group("Msfmr_62") + "éis" in TEXT and not "s da " + m.group("Msfmr_61") + " " + m.group("Msfmr_62") + "éis" in TEXT and not " a " + m.group("Msfmr_61") + " " + m.group("Msfmr_62") + "éis" in TEXT and not m.group("Msfmr_61") + "-" + m.group("Msfmr_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_63>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_63").lower() in plvrFemr and m.group("Msfmr_64") in plvrFemel and not " e " + m.group("Msfmr_63") + " " + m.group("Msfmr_64") + "éis" in TEXT and not " ou " + m.group("Msfmr_63") + " " + m.group("Msfmr_64") + "éis" in TEXT and not "s de " + m.group("Msfmr_63") + " " + m.group("Msfmr_64") + "éis" in TEXT and not "s da " + m.group("Msfmr_63") + " " + m.group("Msfmr_64") + "éis" in TEXT and not " a " + m.group("Msfmr_63") + " " + m.group("Msfmr_64") + "éis" in TEXT and not m.group("Msfmr_63") + "-" + m.group("Msfmr_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_65>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_65").lower() in plvrFemr and m.group("Msfmr_66") in plvrMfeu and not " e " + m.group("Msfmr_65") + " " + m.group("Msfmr_66") + "us" in TEXT and not " ou " + m.group("Msfmr_65") + " " + m.group("Msfmr_66") + "us" in TEXT and not "s de " + m.group("Msfmr_65") + " " + m.group("Msfmr_66") + "us" in TEXT and not "s da " + m.group("Msfmr_65") + " " + m.group("Msfmr_66") + "us" in TEXT and not " a " + m.group("Msfmr_65") + " " + m.group("Msfmr_66") + "us" in TEXT and not m.group("Msfmr_65") + "-" + m.group("Msfmr_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_67>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_67").lower() in plvrFemr and m.group("Msfmr_68") in plvrFemu and not " e " + m.group("Msfmr_67") + " " + m.group("Msfmr_68") + "us" in TEXT and not " ou " + m.group("Msfmr_67") + " " + m.group("Msfmr_68") + "us" in TEXT and not "s de " + m.group("Msfmr_67") + " " + m.group("Msfmr_68") + "us" in TEXT and not "s da " + m.group("Msfmr_67") + " " + m.group("Msfmr_68") + "us" in TEXT and not " a " + m.group("Msfmr_67") + " " + m.group("Msfmr_68") + "us" in TEXT and not m.group("Msfmr_67") + "-" + m.group("Msfmr_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_69>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_69").lower() in plvrFemr and m.group("Msfmr_70") in plvrInvaz and not " e " + m.group("Msfmr_69") + " " + m.group("Msfmr_70") + "zes" in TEXT and not " ou " + m.group("Msfmr_69") + " " + m.group("Msfmr_70") + "zes" in TEXT and not "s de " + m.group("Msfmr_69") + " " + m.group("Msfmr_70") + "zes" in TEXT and not "s da " + m.group("Msfmr_69") + " " + m.group("Msfmr_70") + "zes" in TEXT and not " a " + m.group("Msfmr_69") + " " + m.group("Msfmr_70") + "zes" in TEXT and not m.group("Msfmr_69") + "-" + m.group("Msfmr_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_71>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_71").lower() in plvrFemr and m.group("Msfmr_72") in plvrFemz and not " e " + m.group("Msfmr_71") + " " + m.group("Msfmr_72") + "zes" in TEXT and not " ou " + m.group("Msfmr_71") + " " + m.group("Msfmr_72") + "zes" in TEXT and not "s de " + m.group("Msfmr_71") + " " + m.group("Msfmr_72") + "zes" in TEXT and not "s da " + m.group("Msfmr_71") + " " + m.group("Msfmr_72") + "zes" in TEXT and not " a " + m.group("Msfmr_71") + " " + m.group("Msfmr_72") + "zes" in TEXT and not m.group("Msfmr_71") + "-" + m.group("Msfmr_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_73>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_73").lower() in plvrFemr and m.group("Msfmr_74") in pvrFeman and not " e " + m.group("Msfmr_73") + " " + m.group("Msfmr_74") + "s" in TEXT and not " ou " + m.group("Msfmr_73") + " " + m.group("Msfmr_74") + "s" in TEXT and not "s de " + m.group("Msfmr_73") + " " + m.group("Msfmr_74") + "s" in TEXT and not "s da " + m.group("Msfmr_73") + " " + m.group("Msfmr_74") + "s" in TEXT and not " a " + m.group("Msfmr_73") + " " + m.group("Msfmr_74") + "s" in TEXT and not m.group("Msfmr_73") + "-" + m.group("Msfmr_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_75>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_76>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_75").lower() in plvrFemr and m.group("Msfmr_76") in plvrMFm and not " e " + m.group("Msfmr_75") + " " + m.group("Msfmr_76") + "ns" in TEXT and not " ou " + m.group("Msfmr_75") + " " + m.group("Msfmr_76") + "ns" in TEXT and not "s de " + m.group("Msfmr_75") + " " + m.group("Msfmr_76") + "ns" in TEXT and not "s da " + m.group("Msfmr_75") + " " + m.group("Msfmr_76") + "ns" in TEXT and not " a " + m.group("Msfmr_75") + " " + m.group("Msfmr_76") + "ns" in TEXT and not m.group("Msfmr_75") + "-" + m.group("Msfmr_76") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfmr_77>[a-zA-Zçáéíóúâêô]+r) (?P<Msfmr_78>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfmr_77").lower() in plvrFemr and m.group("Msfmr_78") in plvrFemm and not " e " + m.group("Msfmr_77") + " " + m.group("Msfmr_78") + "ns" in TEXT and not " ou " + m.group("Msfmr_77") + " " + m.group("Msfmr_78") + "ns" in TEXT and not "s de " + m.group("Msfmr_77") + " " + m.group("Msfmr_78") + "ns" in TEXT and not "s da " + m.group("Msfmr_77") + " " + m.group("Msfmr_78") + "ns" in TEXT and not " a " + m.group("Msfmr_77") + " " + m.group("Msfmr_78") + "ns" in TEXT and not m.group("Msfmr_77") + "-" + m.group("Msfmr_78") + "ns" in tCompostops'],
# plvrMfal a
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_1>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_1").lower() in plvrMfal and m.group("Msmfla_2").lower() in plvrFema and not " e " + m.group("Msmfla_1") + "l " + m.group("Msmfla_2") +"s" in TEXT and not " ou " + m.group("Msmfla_1") + "l " + m.group("Msmfla_2") + "s" in TEXT and not "s de " + m.group("Msmfla_1") + "l " + m.group("Msmfla_2") + "s" in TEXT and not "s da " + m.group("Msmfla_1") + "l " + m.group("Msmfla_2") + "s" in TEXT and not " a " + m.group("Msmfla_1") + "l " + m.group("Msmfla_2") + "s" in TEXT and not m.group("Msmfla_1") + "l-" + m.group("Msmfla_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_3>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_3").lower() in plvrMfal and m.group("Msmfla_4").lower() in plvrMfoa and not " e " + m.group("Msmfla_3") + "l " + m.group("Msmfla_4") + "as" in TEXT and not " ou " + m.group("Msmfla_3") + "l " + m.group("Msmfla_4") + "as" in TEXT and not "s de " + m.group("Msmfla_3") + "l " + m.group("Msmfla_4") + "as" in TEXT and not "s da " + m.group("Msmfla_3") + "l " + m.group("Msmfla_4") + "as" in TEXT and not " a " + m.group("Msmfla_3") + "l " + m.group("Msmfla_4") + "as" in TEXT and not m.group("Msmfla_3") + "l-" + m.group("Msmfla_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_5>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_5").lower() in plvrMfal and not m.group("Msmfla_6").lower() in excAdo and not " e " + m.group("Msmfla_5") + "l " + m.group("Msmfla_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msmfla_5") + "l " + m.group("Msmfla_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msmfla_5") + "l " + m.group("Msmfla_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Msmfla_5") + "l " + m.group("Msmfla_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Msmfla_5") + "l " + m.group("Msmfla_6") + m.group(3) + "dos" in TEXT and not m.group("Msmfla_5") + "l-" + m.group("Msmfla_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_7>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_7").lower() in plvrMfal and not m.group("Msmfla_8").lower() in XexcIsta and not " e " + m.group("Msmfla_7") + "l " + m.group("Msmfla_8") + "s" in TEXT and not " ou " + m.group("Msmfla_7") + "l " + m.group("Msmfla_8") + "s" in TEXT and not "s de " + m.group("Msmfla_7") + "l " + m.group("Msmfla_8") + "s" in TEXT and not "s da " + m.group("Msmfla_7") + "l " + m.group("Msmfla_8") + "s" in TEXT and not " a " + m.group("Msmfla_7") + "l " + m.group("Msmfla_8") + "s" in TEXT and not m.group("Msmfla_7") + "l-" + m.group("Msmfla_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_9>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_10>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_9").lower() in plvrMfal and m.group("Msmfla_10").lower() in plvrInva and not " e " + m.group("Msmfla_9") + "l " + m.group("Msmfla_10") + "s" in TEXT and not " ou " + m.group("Msmfla_9") + "l " + m.group("Msmfla_10") + "s" in TEXT and not "s de " + m.group("Msmfla_9") + "l " + m.group("Msmfla_10") + "s" in TEXT and not "s da " + m.group("Msmfla_9") + "l " + m.group("Msmfla_10") + "s" in TEXT and not " a " + m.group("Msmfla_9") + "l " + m.group("Msmfla_10") + "s" in TEXT and not m.group("Msmfla_9") + "l-" + m.group("Msmfla_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_11>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_11").lower() in plvrMfal and not m.group("Msmfla_12").lower() in excAdo and not " e " + m.group("Msmfla_11") + "l " + m.group("Msmfla_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msmfla_11") + "l " + m.group("Msmfla_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msmfla_11") + "l " + m.group("Msmfla_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Msmfla_11") + "l " + m.group("Msmfla_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Msmfla_11") + "l " + m.group("Msmfla_12") + m.group(3) + "das" in TEXT and not m.group("Msmfla_11") + "l-" + m.group("Msmfla_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_15>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_15").lower() in plvrMfal and not " e " + m.group("Msmfla_15") + "l " + m.group("Msmfla_16") + "osas" in TEXT and not " ou " + m.group("Msmfla_15") + "l " + m.group("Msmfla_16") + "osas" in TEXT and not "s de " + m.group("Msmfla_15") + "l " + m.group("Msmfla_16") + "osas" in TEXT and not "s da " + m.group("Msmfla_15") + "l " + m.group("Msmfla_16") + "osas" in TEXT and not " a " + m.group("Msmfla_15") + "l " + m.group("Msmfla_16") + "osas" in TEXT and not m.group("Msmfla_15") + "l-" + m.group("Msmfla_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_17>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_17").lower() in plvrMfal and not " e " + m.group("Msmfla_17") + "l " + m.group("Msmfla_18") + "ivas" in TEXT and not " ou " + m.group("Msmfla_17") + "l " + m.group("Msmfla_18") + "ivas" in TEXT and not "s de " + m.group("Msmfla_17") + "l " + m.group("Msmfla_18") + "ivas" in TEXT and not "s da " + m.group("Msmfla_17") + "l " + m.group("Msmfla_18") + "ivas" in TEXT and not " a " + m.group("Msmfla_17") + "l " + m.group("Msmfla_18") + "ivas" in TEXT and not m.group("Msmfla_17") + "l-" + m.group("Msmfla_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_21>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_21").lower() in plvrMfal and not " e " + m.group("Msmfla_21") + "l " + m.group("Msmfla_22") + "icas" in TEXT and not " ou " + m.group("Msmfla_21") + "l " + m.group("Msmfla_22") + "icas" in TEXT and not "s de " + m.group("Msmfla_21") + "l " + m.group("Msmfla_22") + "icas" in TEXT and not "s da " + m.group("Msmfla_21") + "l " + m.group("Msmfla_22") + "icas" in TEXT and not " a " + m.group("Msmfla_21") + "l " + m.group("Msmfla_22") + "icas" in TEXT and not m.group("Msmfla_21") + "l-" + m.group("Msmfla_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_23>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_23").lower() in plvrMfal and not " e " + m.group("Msmfla_23") + "l " + m.group("Msmfla_24") + "icas" in TEXT and not " ou " + m.group("Msmfla_23") + "l " + m.group("Msmfla_24") + "icas" in TEXT and not "s de " + m.group("Msmfla_23") + "l " + m.group("Msmfla_24") + "icas" in TEXT and not "s da " + m.group("Msmfla_23") + "l " + m.group("Msmfla_24") + "icas" in TEXT and not " a " + m.group("Msmfla_23") + "l " + m.group("Msmfla_24") + "icas" in TEXT and not m.group("Msmfla_23") + "l-" + m.group("Msmfla_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_25>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_25").lower() in plvrMfal and not " e " + m.group("Msmfla_25") + "l " + m.group("Msmfla_26") + "icas" in TEXT and not " ou " + m.group("Msmfla_25") + "l " + m.group("Msmfla_26") + "icas" in TEXT and not "s de " + m.group("Msmfla_25") + "l " + m.group("Msmfla_26") + "icas" in TEXT and not "s da " + m.group("Msmfla_25") + "l " + m.group("Msmfla_26") + "icas" in TEXT and not " a " + m.group("Msmfla_25") + "l " + m.group("Msmfla_26") + "icas" in TEXT and not m.group("Msmfla_25") + "l-" + m.group("Msmfla_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_27>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_27").lower() in plvrMfal and not " e " + m.group("Msmfla_27") + "l " + m.group("Msmfla_28") + "escas" in TEXT and not " ou " + m.group("Msmfla_27") + "l " + m.group("Msmfla_28") + "escas" in TEXT and not "s de " + m.group("Msmfla_27") + "l " + m.group("Msmfla_28") + "escas" in TEXT and not "s da " + m.group("Msmfla_27") + "l " + m.group("Msmfla_28") + "escas" in TEXT and not " a " + m.group("Msmfla_27") + "l " + m.group("Msmfla_28") + "escas" in TEXT and not m.group("Msmfla_27") + "l-" + m.group("Msmfla_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_29>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_29").lower() in plvrMfal and not " e " + m.group("Msmfla_29") + "l " + m.group("Msmfla_30") + "idas" in TEXT and not " ou " + m.group("Msmfla_29") + "s " + m.group("Msmfla_30") + "idas" in TEXT and not "s de " + m.group("Msmfla_29") + "s " + m.group("Msmfla_30") + "idas" in TEXT and not "s da " + m.group("Msmfla_29") + "s " + m.group("Msmfla_30") + "idas" in TEXT and not " a " + m.group("Msmfla_29") + "s " + m.group("Msmfla_30") + "idas" in TEXT and not m.group("Msmfla_29") + "l-" + m.group("Msmfla_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_31>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_31").lower() in plvrMfal and not " e " + m.group("Msmfla_31") + "l " + m.group("Msmfla_32") + "logas" in TEXT and not " ou " + m.group("Msmfla_31") + "l " + m.group("Msmfla_32") + "logas" in TEXT and not "s de " + m.group("Msmfla_31") + "l " + m.group("Msmfla_32") + "logas" in TEXT and not "s da " + m.group("Msmfla_31") + "l " + m.group("Msmfla_32") + "logas" in TEXT and not " a " + m.group("Msmfla_31") + "l " + m.group("Msmfla_32") + "logas" in TEXT and not m.group("Msmfla_31") + "l-" + m.group("Msmfla_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_33>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_33").lower() in plvrMfal and not " e " + m.group("Msmfla_33") + "l " + m.group("Msmfla_34") + "rias" in TEXT and not " ou " + m.group("Msmfla_33") + "l " + m.group("Msmfla_34") + "rias" in TEXT and not "s de " + m.group("Msmfla_33") + "l " + m.group("Msmfla_34") + "rias" in TEXT and not "s da " + m.group("Msmfla_33") + "l " + m.group("Msmfla_34") + "rias" in TEXT and not " a " + m.group("Msmfla_33") + "l " + m.group("Msmfla_34") + "rias" in TEXT and not m.group("Msmfla_33") + "l-" + m.group("Msmfla_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_35>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_35").lower() in plvrMfal and not " e " + m.group("Msmfla_35") + "l " + m.group("Msmfla_36") + "ssimas" in TEXT and not " ou " + m.group("Msmfla_35") + "l " + m.group("Msmfla_36") + "ssimas" in TEXT and not "s de " + m.group("Msmfla_35") + "l " + m.group("Msmfla_36") + "ssimas" in TEXT and not "s da " + m.group("Msmfla_35") + "l " + m.group("Msmfla_36") + "ssimas" in TEXT and not " a " + m.group("Msmfla_35") + "l " + m.group("Msmfla_36") + "ssimas" in TEXT and not m.group("Msmfla_35") + "l-" + m.group("Msmfla_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_37>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_37").lower() in plvrMfal and not " e " + m.group("Msmfla_37") + "l " + m.group("Msmfla_38") + "simas" in TEXT and not " ou " + m.group("Msmfla_37") + "l " + m.group("Msmfla_38") + "simas" in TEXT and not "s de " + m.group("Msmfla_37") + "l " + m.group("Msmfla_38") + "simas" in TEXT and not "s da " + m.group("Msmfla_37") + "l " + m.group("Msmfla_38") + "simas" in TEXT and not " a " + m.group("Msmfla_37") + "l " + m.group("Msmfla_38") + "simas" in TEXT and not m.group("Msmfla_37") + "l-" + m.group("Msmfla_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_41>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_41").lower() in plvrMfal and not m.group("Msmfla_42") in "D-d-" and not " e " + m.group("Msmfla_41") + "l " + m.group("Msmfla_42") + "oras" in TEXT and not " ou " + m.group("Msmfla_41") + "l " + m.group("Msmfla_42") + "oras" in TEXT and not "s de " + m.group("Msmfla_41") + "l " + m.group("Msmfla_42") + "oras" in TEXT and not "s da " + m.group("Msmfla_41") + "l " + m.group("Msmfla_42") + "oras" in TEXT and not " a " + m.group("Msmfla_41") + "l " + m.group("Msmfla_42") + "oras" in TEXT and not m.group("Msmfla_41") + "l-" + m.group("Msmfla_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_43>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_43").lower() in plvrMfal and m.group("Msmfla_44") in plvrMfr and not " e " + m.group("Msmfla_43") + "l " + m.group("Msmfla_44") + "es" in TEXT and not " ou " + m.group("Msmfla_43") + "l " + m.group("Msmfla_44") + "es" in TEXT and not "s de " + m.group("Msmfla_43") + "l " + m.group("Msmfla_44") + "es" in TEXT and not "s da " + m.group("Msmfla_43") + "l " + m.group("Msmfla_44") + "es" in TEXT and not " a " + m.group("Msmfla_43") + "l " + m.group("Msmfla_44") + "es" in TEXT and not m.group("Msmfla_43") + "l-" + m.group("Msmfla_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_45>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_45").lower() in plvrMfal and m.group("Msmfla_46") in plvrFemr and not " e " + m.group("Msmfla_45") + "l " + m.group("Msmfla_46") + "es" in TEXT and not " ou " + m.group("Msmfla_45") + "l " + m.group("Msmfla_46") + "es" in TEXT and not "s de " + m.group("Msmfla_45") + "l " + m.group("Msmfla_46") + "es" in TEXT and not "s da " + m.group("Msmfla_45") + "l " + m.group("Msmfla_46") + "es" in TEXT and not " a " + m.group("Msmfla_45") + "l " + m.group("Msmfla_46") + "es" in TEXT and not m.group("Msmfla_45") + "l-" + m.group("Msmfla_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_47>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_47").lower() in plvrMfal and m.group("Msmfla_48") in plvrMfal and not " e " + m.group("Msmfla_47") + "l " + m.group("Msmfla_48") + "is" in TEXT and not " ou " + m.group("Msmfla_47") + "l " + m.group("Msmfla_48") + "is" in TEXT and not "s de " + m.group("Msmfla_47") + "l " + m.group("Msmfla_48") + "is" in TEXT and not "s da " + m.group("Msmfla_47") + "l " + m.group("Msmfla_48") + "is" in TEXT and not " a " + m.group("Msmfla_47") + "l " + m.group("Msmfla_48") + "is" in TEXT and not m.group("Msmfla_47") + "l-" + m.group("Msmfla_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_49>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_49").lower() in plvrMfal and m.group("Msmfla_50") in plvrMfcao and not " e " + m.group("Msmfla_49") + "l " + m.group("Msmfla_50") + "ões" in TEXT and not + " ou " + m.group("Msmfla_49") + "l " + m.group("Msmfla_50") + "ões" in TEXT and not + "s de " + m.group("Msmfla_49") + "l " + m.group("Msmfla_50") + "ões" in TEXT and not + "s da " + m.group("Msmfla_49") + "l " + m.group("Msmfla_50") + "ões" in TEXT and not + " a " + m.group("Msmfla_49") + "l " + m.group("Msmfla_50") + "ões" in TEXT and not m.group("Msmfla_49") + "l-" + m.group("Msmfla_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_51>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_51").lower() in plvrMfal and not m.group("Msmfla_52") in plvrMascao and not " e " + m.group("Msmfla_51") + "l " + m.group("Msmfla_52") + "ões" in TEXT and not " ou " + m.group("Msmfla_51") + "l " + m.group("Msmfla_52") + "ões" in TEXT and not "s de " + m.group("Msmfla_51") + "l " + m.group("Msmfla_52") + "ões" in TEXT and not "s da " + m.group("Msmfla_51") + "l " + m.group("Msmfla_52") + "ões" in TEXT and not " a " + m.group("Msmfla_51") + "l " + m.group("Msmfla_52") + "ões" in TEXT and not m.group("Msmfla_51") + "l-" + m.group("Msmfla_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_53>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_53").lower() in plvrMfal and m.group("Msmfla_54") in plvrFemao and not " e " + m.group("Msmfla_53") + "l " + m.group("Msmfla_54") + "ões" in TEXT and not " ou " + m.group("Msmfla_53") + "l " + m.group("Msmfla_54") + "ões" in TEXT and not "s de " + m.group("Msmfla_53") + "l " + m.group("Msmfla_54") + "ões" in TEXT and not "s da " + m.group("Msmfla_53") + "l " + m.group("Msmfla_54") + "ões" in TEXT and not " a " + m.group("Msmfla_53") + "l " + m.group("Msmfla_54") + "ões" in TEXT and not m.group("Msmfla_53") + "l-" + m.group("Msmfla_54") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_55>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_55").lower() in plvrMfal and not " e " + m.group("Msmfla_55") + "l " + m.group("Msmfla_56") + "veis" in TEXT and not " ou " + m.group("Msmfla_55") + "l " + m.group("Msmfla_56") + "veis" in TEXT and not "s de " + m.group("Msmfla_55") + "l " + m.group("Msmfla_56") + "veis" in TEXT and not "s da " + m.group("Msmfla_55") + "l " + m.group("Msmfla_56") + "veis" in TEXT and not " a " + m.group("Msmfla_55") + "l " + m.group("Msmfla_56") + "veis" in TEXT and not m.group("Msmfla_55") + "l-" + m.group("Msmfla_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_57>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_57").lower() in plvrMfal and m.group("Msmfla_58").lower() in plvrMfal and not " e " + m.group("Msmfla_57") + "l " + m.group("Msmfla_58") + "es" in TEXT and not " ou " + m.group("Msmfla_57") + "l " + m.group("Msmfla_58") + "es" in TEXT and not "s de " + m.group("Msmfla_57") + "l " + m.group("Msmfla_58") + "es" in TEXT and not "s da " + m.group("Msmfla_57") + "l " + m.group("Msmfla_58") + "es" in TEXT and not " a " + m.group("Msmfla_57") + "l " + m.group("Msmfla_58") + "es" in TEXT and not m.group("Msmfla_57") + "l-" + m.group("Msmfla_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_59>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_59").lower() in plvrMfal and m.group("Msmfla_60").lower() in plvrMfal and not " e " + m.group("Msmfla_59") + "l " + m.group("Msmfla_60") + "es" in TEXT and not " ou " + m.group("Msmfla_59") + "l " + m.group("Msmfla_60") + "es" in TEXT and not "s de " + m.group("Msmfla_59") + "l " + m.group("Msmfla_60") + "es" in TEXT and not "s da " + m.group("Msmfla_59") + "l " + m.group("Msmfla_60") + "es" in TEXT and not " a " + m.group("Msmfla_59") + "l " + m.group("Msmfla_60") + "es" in TEXT and not m.group("Msmfla_59") + "l-" + m.group("Msmfla_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_61>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_61").lower() in plvrMfal and m.group("Msmfla_62") in plvrMfel and not " e " + m.group("Msmfla_61") + "l " + m.group("Msmfla_62") + "éis" in TEXT and not " ou " + m.group("Msmfla_61") + "l " + m.group("Msmfla_62") + "éis" in TEXT and not "s de " + m.group("Msmfla_61") + "l " + m.group("Msmfla_62") + "éis" in TEXT and not "s da " + m.group("Msmfla_61") + "l " + m.group("Msmfla_62") + "éis" in TEXT and not " a " + m.group("Msmfla_61") + "l " + m.group("Msmfla_62") + "éis" in TEXT and not m.group("Msmfla_61") + "l-" + m.group("Msmfla_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_63>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_63").lower() in plvrMfal and m.group("Msmfla_64") in plvrFemel and not " e " + m.group("Msmfla_63") + "l " + m.group("Msmfla_64") + "éis" in TEXT and not " ou " + m.group("Msmfla_63") + "l " + m.group("Msmfla_64") + "éis" in TEXT and not "s de " + m.group("Msmfla_63") + "l " + m.group("Msmfla_64") + "éis" in TEXT and not "s da " + m.group("Msmfla_63") + "l " + m.group("Msmfla_64") + "éis" in TEXT and not " a " + m.group("Msmfla_63") + "l " + m.group("Msmfla_64") + "éis" in TEXT and not m.group("Msmfla_63") + "l-" + m.group("Msmfla_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_65>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_65").lower() in plvrMfal and m.group("Msmfla_66") in plvrMfeu and not " e " + m.group("Msmfla_65") + "l " + m.group("Msmfla_66") + "us" in TEXT and not " ou " + m.group("Msmfla_65") + "l " + m.group("Msmfla_66") + "us" in TEXT and not "s de " + m.group("Msmfla_65") + "l " + m.group("Msmfla_66") + "us" in TEXT and not "s da " + m.group("Msmfla_65") + "l " + m.group("Msmfla_66") + "us" in TEXT and not " a " + m.group("Msmfla_65") + "l " + m.group("Msmfla_66") + "us" in TEXT and not m.group("Msmfla_65") + "l-" + m.group("Msmfla_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_67>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_67").lower() in plvrMfal and m.group("Msmfla_68") in plvrFemu and not " e " + m.group("Msmfla_67") + "l " + m.group("Msmfla_68") + "us" in TEXT and not " ou " + m.group("Msmfla_67") + "l " + m.group("Msmfla_68") + "us" in TEXT and not "s de " + m.group("Msmfla_67") + "l " + m.group("Msmfla_68") + "us" in TEXT and not "s da " + m.group("Msmfla_67") + "l " + m.group("Msmfla_68") + "us" in TEXT and not " a " + m.group("Msmfla_67") + "l " + m.group("Msmfla_68") + "us" in TEXT and not m.group("Msmfla_67") + "l-" + m.group("Msmfla_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_69>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_69").lower() in plvrMfal and m.group("Msmfla_70") in plvrInvaz and not " e " + m.group("Msmfla_69") + "l " + m.group("Msmfla_70") + "zes" in TEXT and not " ou " + m.group("Msmfla_69") + "l " + m.group("Msmfla_70") + "zes" in TEXT and not "s de " + m.group("Msmfla_69") + "l " + m.group("Msmfla_70") + "zes" in TEXT and not "s da " + m.group("Msmfla_69") + "l " + m.group("Msmfla_70") + "zes" in TEXT and not " a " + m.group("Msmfla_69") + "l " + m.group("Msmfla_70") + "zes" in TEXT and not m.group("Msmfla_69") + "l-" + m.group("Msmfla_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_71>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_71").lower() in plvrMfal and m.group("Msmfla_72") in plvrFemz and not " e " + m.group("Msmfla_71") + "l " + m.group("Msmfla_72") + "zes" in TEXT and not " ou " + m.group("Msmfla_71") + "l " + m.group("Msmfla_72") + "zes" in TEXT and not "s de " + m.group("Msmfla_71") + "l " + m.group("Msmfla_72") + "zes" in TEXT and not "s da " + m.group("Msmfla_71") + "l " + m.group("Msmfla_72") + "zes" in TEXT and not " a " + m.group("Msmfla_71") + "l " + m.group("Msmfla_72") + "zes" in TEXT and not m.group("Msmfla_71") + "l-" + m.group("Msmfla_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_73>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_73").lower() in plvrMfal and m.group("Msmfla_74") in pvrFeman and not " e " + m.group("Msmfla_73") + "l " + m.group("Msmfla_74") + "s" in TEXT and not " ou " + m.group("Msmfla_73") + "l " + m.group("Msmfla_74") + "s" in TEXT and not "s de " + m.group("Msmfla_73") + "l " + m.group("Msmfla_74") + "s" in TEXT and not "s da " + m.group("Msmfla_73") + "l " + m.group("Msmfla_74") + "s" in TEXT and not " a " + m.group("Msmfla_73") + "l " + m.group("Msmfla_74") + "s" in TEXT and not m.group("Msmfla_73") + "l-" + m.group("Msmfla_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_75>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_76>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_75").lower() in plvrMfal and m.group("Msmfla_76") in plvrMFm and not " e " + m.group("Msmfla_75") + "l " + m.group("Msmfla_76") + "ns" in TEXT and not " ou " + m.group("Msmfla_75") + "l " + m.group("Msmfla_76") + "ns" in TEXT and not "s de " + m.group("Msmfla_75") + "l " + m.group("Msmfla_76") + "ns" in TEXT and not "s da " + m.group("Msmfla_75") + "l " + m.group("Msmfla_76") + "ns" in TEXT and not " a " + m.group("Msmfla_75") + "l " + m.group("Msmfla_76") + "ns" in TEXT and not m.group("Msmfla_75") + "l-" + m.group("Msmfla_76") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmfla_77>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmfla_78>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmfla_77").lower() in plvrMfal and m.group("Msmfla_78") in plvrFemm and not " e " + m.group("Msmfla_77") + "l " + m.group("Msmfla_78") + "ns" in TEXT and not " ou " + m.group("Msmfla_77") + "l " + m.group("Msmfla_78") + "ns" in TEXT and not "s de " + m.group("Msmfla_77") + "l " + m.group("Msmfla_78") + "ns" in TEXT and not "s da " + m.group("Msmfla_77") + "l " + m.group("Msmfla_78") + "ns" in TEXT and not " a " + m.group("Msmfla_77") + "l " + m.group("Msmfla_78") + "ns" in TEXT and not m.group("Msmfla_77") + "l-" + m.group("Msmfla_78") + "ns" in tCompostops'],
# plvrMfal o
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_1>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_1").lower() in plvrMfal and m.group("Msmflo_2").lower() in plvrMasca and not " e " + m.group("Msmflo_1") + "l " + m.group("Msmflo_2") +"s" in TEXT and not " ou " + m.group("Msmflo_1") + "l " + m.group("Msmflo_2") + "s" in TEXT and not "s de " + m.group("Msmflo_1") + "l " + m.group("Msmflo_2") + "s" in TEXT and not "s do " + m.group("Msmflo_1") + "l " + m.group("Msmflo_2") + "s" in TEXT and not " o " + m.group("Msmflo_1") + "l " + m.group("Msmflo_2") + "s" in TEXT and not m.group("Msmflo_1") + "l-" + m.group("Msmflo_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_3>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_3").lower() in plvrMfal and m.group("Msmflo_4").lower() in plvrMfoa and not " e " + m.group("Msmflo_3") + "l " + m.group("Msmflo_4") + "os" in TEXT and not " ou " + m.group("Msmflo_3") + "l " + m.group("Msmflo_4") + "os" in TEXT and not "s de " + m.group("Msmflo_3") + "l " + m.group("Msmflo_4") + "os" in TEXT and not "s do " + m.group("Msmflo_3") + "l " + m.group("Msmflo_4") + "os" in TEXT and not " o " + m.group("Msmflo_3") + "l " + m.group("Msmflo_4") + "os" in TEXT and not m.group("Msmflo_3") + "l-" + m.group("Msmflo_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_5>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_5").lower() in plvrMfal and not m.group("Msmflo_6").lower() in excAdo and not " e " + m.group("Msmflo_5") + "l " + m.group("Msmflo_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msmflo_5") + "l " + m.group("Msmflo_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msmflo_5") + "l " + m.group("Msmflo_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msmflo_5") + "l " + m.group("Msmflo_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msmflo_5") + "l " + m.group("Msmflo_6") + m.group(3) + "dos" in TEXT and not m.group("Msmflo_5") + "l-" + m.group("Msmflo_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_13>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_13").lower() in plvrMfal and not " e " + m.group("Msmflo_13") + "l " + m.group("Msmflo_14") + "osos" in TEXT and not " ou " + m.group("Msmflo_13") + "l " + m.group("Msmflo_14") + "osos" in TEXT and not "s de " + m.group("Msmflo_13") + "l " + m.group("Msmflo_14") + "osos" in TEXT and not "s do " + m.group("Msmflo_13") + "l " + m.group("Msmflo_14") + "osos" in TEXT and not " o " + m.group("Msmflo_13") + "l " + m.group("Msmflo_14") + "osos" in TEXT and not m.group("Msmflo_13") + "l-" + m.group("Msmflo_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_19>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_19").lower() in plvrMfal and not " e " + m.group("Msmflo_19") + "l " + m.group("Msmflo_20") + "ivas" in TEXT and not " ou " + m.group("Msmflo_19") + "l " + m.group("Msmflo_20") + "ivas" in TEXT and not "s de " + m.group("Msmflo_19") + "l " + m.group("Msmflo_20") + "ivas" in TEXT and not "s do " + m.group("Msmflo_19") + "l " + m.group("Msmflo_20") + "ivas" in TEXT and not " o " + m.group("Msmflo_19") + "l " + m.group("Msmflo_20") + "ivas" in TEXT and not m.group("Msmflo_19") + "l-" + m.group("Msmflo_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_21>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_21").lower() in plvrMfal and not " e " + m.group("Msmflo_21") + "l " + m.group("Msmflo_22") + "icos" in TEXT and not " ou " + m.group("Msmflo_21") + "l " + m.group("Msmflo_22") + "icos" in TEXT and not "s de " + m.group("Msmflo_21") + "l " + m.group("Msmflo_22") + "icos" in TEXT and not "s do " + m.group("Msmflo_21") + "l " + m.group("Msmflo_22") + "icos" in TEXT and not " o " + m.group("Msmflo_21") + "l " + m.group("Msmflo_22") + "icos" in TEXT and not m.group("Msmflo_21") + "l-" + m.group("Msmflo_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_23>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_23").lower() in plvrMfal and not " e " + m.group("Msmflo_23") + "l " + m.group("Msmflo_24") + "icos" in TEXT and not " ou " + m.group("Msmflo_23") + "l " + m.group("Msmflo_24") + "icos" in TEXT and not "s de " + m.group("Msmflo_23") + "l " + m.group("Msmflo_24") + "icos" in TEXT and not "s do " + m.group("Msmflo_23") + "l " + m.group("Msmflo_24") + "icos" in TEXT and not " o " + m.group("Msmflo_23") + "l " + m.group("Msmflo_24") + "icos" in TEXT and not m.group("Msmflo_23") + "l-" + m.group("Msmflo_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_25>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_25").lower() in plvrMfal and not " e " + m.group("Msmflo_25") + "l " + m.group("Msmflo_26") + "icos" in TEXT and not " ou " + m.group("Msmflo_25") + "l " + m.group("Msmflo_26") + "icos" in TEXT and not "s de " + m.group("Msmflo_25") + "l " + m.group("Msmflo_26") + "icos" in TEXT and not "s do " + m.group("Msmflo_25") + "l " + m.group("Msmflo_26") + "icos" in TEXT and not " o " + m.group("Msmflo_25") + "l " + m.group("Msmflo_26") + "icos" in TEXT and not m.group("Msmflo_25") + "l-" + m.group("Msmflo_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_27>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_27").lower() in plvrMfal and not " e " + m.group("Msmflo_27") + "l " + m.group("Msmflo_28") + "escos" in TEXT and not " ou " + m.group("Msmflo_27") + "l " + m.group("Msmflo_28") + "escos" in TEXT and not "s de " + m.group("Msmflo_27") + "l " + m.group("Msmflo_28") + "escos" in TEXT and not "s do " + m.group("Msmflo_27") + "l " + m.group("Msmflo_28") + "escos" in TEXT and not " o " + m.group("Msmflo_27") + "l " + m.group("Msmflo_28") + "escos" in TEXT and not m.group("Msmflo_27") + "l-" + m.group("Msmflo_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_29>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_29").lower() in plvrMfal and not " e " + m.group("Msmflo_29") + "l " + m.group("Msmflo_30") + "idos" in TEXT and not " ou " + m.group("Msmflo_29") + "s " + m.group("Msmflo_30") + "idos" in TEXT and not "s de " + m.group("Msmflo_29") + "s " + m.group("Msmflo_30") + "idos" in TEXT and not "s do " + m.group("Msmflo_29") + "s " + m.group("Msmflo_30") + "idos" in TEXT and not " o " + m.group("Msmflo_29") + "s " + m.group("Msmflo_30") + "idos" in TEXT and not m.group("Msmflo_29") + "l-" + m.group("Msmflo_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_31>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_31").lower() in plvrMfal and not " e " + m.group("Msmflo_31") + "l " + m.group("Msmflo_32") + "logos" in TEXT and not " ou " + m.group("Msmflo_31") + "l " + m.group("Msmflo_32") + "logos" in TEXT and not "s de " + m.group("Msmflo_31") + "l " + m.group("Msmflo_32") + "logos" in TEXT and not "s do " + m.group("Msmflo_31") + "l " + m.group("Msmflo_32") + "logos" in TEXT and not " o " + m.group("Msmflo_31") + "l " + m.group("Msmflo_32") + "logos" in TEXT and not m.group("Msmflo_31") + "l-" + m.group("Msmflo_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_33>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_33").lower() in plvrMfal and not " e " + m.group("Msmflo_33") + "l " + m.group("Msmflo_34") + "rios" in TEXT and not " ou " + m.group("Msmflo_33") + "l " + m.group("Msmflo_34") + "rios" in TEXT and not "s de " + m.group("Msmflo_33") + "l " + m.group("Msmflo_34") + "rios" in TEXT and not "s do " + m.group("Msmflo_33") + "l " + m.group("Msmflo_34") + "rios" in TEXT and not " o " + m.group("Msmflo_33") + "l " + m.group("Msmflo_34") + "rios" in TEXT and not m.group("Msmflo_33") + "l-" + m.group("Msmflo_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_35>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_35").lower() in plvrMfal and not " e " + m.group("Msmflo_35") + "l " + m.group("Msmflo_36") + "ssimos" in TEXT and not " ou " + m.group("Msmflo_35") + "l " + m.group("Msmflo_36") + "ssimos" in TEXT and not "s de " + m.group("Msmflo_35") + "l " + m.group("Msmflo_36") + "ssimos" in TEXT and not "s do " + m.group("Msmflo_35") + "l " + m.group("Msmflo_36") + "ssimos" in TEXT and not " o " + m.group("Msmflo_35") + "l " + m.group("Msmflo_36") + "ssimos" in TEXT and not m.group("Msmflo_35") + "l-" + m.group("Msmflo_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_37>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_37").lower() in plvrMfal and not " e " + m.group("Msmflo_37") + "l " + m.group("Msmflo_38") + "simos" in TEXT and not " ou " + m.group("Msmflo_37") + "l " + m.group("Msmflo_38") + "simos" in TEXT and not "s de " + m.group("Msmflo_37") + "l " + m.group("Msmflo_38") + "simos" in TEXT and not "s do " + m.group("Msmflo_37") + "l " + m.group("Msmflo_38") + "simos" in TEXT and not " o " + m.group("Msmflo_37") + "l " + m.group("Msmflo_38") + "simos" in TEXT and not m.group("Msmflo_37") + "l-" + m.group("Msmflo_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_45>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_45").lower() in plvrMfal and m.group("Msmflo_46") in plvrMascr and not " e " + m.group("Msmflo_45") + "l " + m.group("Msmflo_46") + "es" in TEXT and not " ou " + m.group("Msmflo_45") + "l " + m.group("Msmflo_46") + "es" in TEXT and not "s de " + m.group("Msmflo_45") + "l " + m.group("Msmflo_46") + "es" in TEXT and not "s do " + m.group("Msmflo_45") + "l " + m.group("Msmflo_46") + "es" in TEXT and not " o " + m.group("Msmflo_45") + "l " + m.group("Msmflo_46") + "es" in TEXT and not m.group("Msmflo_45") + "l-" + m.group("Msmflo_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_47>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_47").lower() in plvrMfal and m.group("Msmflo_48") in plvrMfal and not " e " + m.group("Msmflo_47") + "l " + m.group("Msmflo_48") + "is" in TEXT and not " ou " + m.group("Msmflo_47") + "l " + m.group("Msmflo_48") + "is" in TEXT and not "s de " + m.group("Msmflo_47") + "l " + m.group("Msmflo_48") + "is" in TEXT and not "s do " + m.group("Msmflo_47") + "l " + m.group("Msmflo_48") + "is" in TEXT and not " o " + m.group("Msmflo_47") + "l " + m.group("Msmflo_48") + "is" in TEXT and not m.group("Msmflo_47") + "l-" + m.group("Msmflo_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_49>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_49").lower() in plvrMfal and m.group("Msmflo_50") in plvrMfcao and not " e " + m.group("Msmflo_49") + "l " + m.group("Msmflo_50") + "ões" in TEXT and not + " ou " + m.group("Msmflo_49") + "l " + m.group("Msmflo_50") + "ões" in TEXT and not + "s de " + m.group("Msmflo_49") + "l " + m.group("Msmflo_50") + "ões" in TEXT and not + "s do " + m.group("Msmflo_49") + "l " + m.group("Msmflo_50") + "ões" in TEXT and not + " a " + m.group("Msmflo_49") + "l " + m.group("Msmflo_50") + "ões" in TEXT and not m.group("Msmflo_49") + "l-" + m.group("Msmflo_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_51>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_51").lower() in plvrMfal and m.group("Msmflo_52") in plvrNfemcao and not " e " + m.group("Msmflo_51") + "l " + m.group("Msmflo_52") + "ões" in TEXT and not " ou " + m.group("Msmflo_51") + "l " + m.group("Msmflo_52") + "ões" in TEXT and not "s de " + m.group("Msmflo_51") + "l " + m.group("Msmflo_52") + "ões" in TEXT and not "s do " + m.group("Msmflo_51") + "l " + m.group("Msmflo_52") + "ões" in TEXT and not " o " + m.group("Msmflo_51") + "l " + m.group("Msmflo_52") + "ões" in TEXT and not m.group("Msmflo_51") + "l-" + m.group("Msmflo_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_57>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_57").lower() in plvrMfal and m.group("Msmflo_58").lower() in plvrMfal and not " e " + m.group("Msmflo_57") + "l " + m.group("Msmflo_58") + "es" in TEXT and not " ou " + m.group("Msmflo_57") + "l " + m.group("Msmflo_58") + "es" in TEXT and not "s de " + m.group("Msmflo_57") + "l " + m.group("Msmflo_58") + "es" in TEXT and not "s do " + m.group("Msmflo_57") + "l " + m.group("Msmflo_58") + "es" in TEXT and not " o " + m.group("Msmflo_57") + "l " + m.group("Msmflo_58") + "es" in TEXT and not m.group("Msmflo_57") + "l-" + m.group("Msmflo_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_59>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_59").lower() in plvrMfal and m.group("Msmflo_60").lower() in plvrMasce and not " e " + m.group("Msmflo_59") + "l " + m.group("Msmflo_60") + "es" in TEXT and not " ou " + m.group("Msmflo_59") + "l " + m.group("Msmflo_60") + "es" in TEXT and not "s de " + m.group("Msmflo_59") + "l " + m.group("Msmflo_60") + "es" in TEXT and not "s do " + m.group("Msmflo_59") + "l " + m.group("Msmflo_60") + "es" in TEXT and not " o " + m.group("Msmflo_59") + "l " + m.group("Msmflo_60") + "es" in TEXT and not m.group("Msmflo_59") + "l-" + m.group("Msmflo_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_61>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_61").lower() in plvrMfal and m.group("Msmflo_62") in plvrMfel and not " e " + m.group("Msmflo_61") + "l " + m.group("Msmflo_62") + "éis" in TEXT and not " ou " + m.group("Msmflo_61") + "l " + m.group("Msmflo_62") + "éis" in TEXT and not "s de " + m.group("Msmflo_61") + "l " + m.group("Msmflo_62") + "éis" in TEXT and not "s do " + m.group("Msmflo_61") + "l " + m.group("Msmflo_62") + "éis" in TEXT and not " o " + m.group("Msmflo_61") + "l " + m.group("Msmflo_62") + "éis" in TEXT and not m.group("Msmflo_61") + "l-" + m.group("Msmflo_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_63>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_63").lower() in plvrMfal and m.group("Msmflo_64") in plvrMascel and not " e " + m.group("Msmflo_63") + "l " + m.group("Msmflo_64") + "éis" in TEXT and not " ou " + m.group("Msmflo_63") + "l " + m.group("Msmflo_64") + "éis" in TEXT and not "s de " + m.group("Msmflo_63") + "l " + m.group("Msmflo_64") + "éis" in TEXT and not "s do " + m.group("Msmflo_63") + "l " + m.group("Msmflo_64") + "éis" in TEXT and not " o " + m.group("Msmflo_63") + "l " + m.group("Msmflo_64") + "éis" in TEXT and not m.group("Msmflo_63") + "l-" + m.group("Msmflo_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_65>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_65").lower() in plvrMfal and m.group("Msmflo_66") in plvrMfeu and not " e " + m.group("Msmflo_65") + "l " + m.group("Msmflo_66") + "us" in TEXT and not " ou " + m.group("Msmflo_65") + "l " + m.group("Msmflo_66") + "us" in TEXT and not "s de " + m.group("Msmflo_65") + "l " + m.group("Msmflo_66") + "us" in TEXT and not "s do " + m.group("Msmflo_65") + "l " + m.group("Msmflo_66") + "us" in TEXT and not " o " + m.group("Msmflo_65") + "l " + m.group("Msmflo_66") + "us" in TEXT and not m.group("Msmflo_65") + "l-" + m.group("Msmflo_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_67>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_67").lower() in plvrMfal and m.group("Msmflo_68") in plvrMascu and not " e " + m.group("Msmflo_67") + "l " + m.group("Msmflo_68") + "us" in TEXT and not " ou " + m.group("Msmflo_67") + "l " + m.group("Msmflo_68") + "us" in TEXT and not "s de " + m.group("Msmflo_67") + "l " + m.group("Msmflo_68") + "us" in TEXT and not "s do " + m.group("Msmflo_67") + "l " + m.group("Msmflo_68") + "us" in TEXT and not " o " + m.group("Msmflo_67") + "l " + m.group("Msmflo_68") + "us" in TEXT and not m.group("Msmflo_67") + "l-" + m.group("Msmflo_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_71>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_71").lower() in plvrMfal and m.group("Msmflo_72") in plvrMascz and not " e " + m.group("Msmflo_71") + "l " + m.group("Msmflo_72") + "zes" in TEXT and not " ou " + m.group("Msmflo_71") + "l " + m.group("Msmflo_72") + "zes" in TEXT and not "s de " + m.group("Msmflo_71") + "l " + m.group("Msmflo_72") + "zes" in TEXT and not "s do " + m.group("Msmflo_71") + "l " + m.group("Msmflo_72") + "zes" in TEXT and not " o " + m.group("Msmflo_71") + "l " + m.group("Msmflo_72") + "zes" in TEXT and not m.group("Msmflo_71") + "l-" + m.group("Msmflo_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_73>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_73").lower() in plvrMfal and m.group("Msmflo_74") in pvrMascan and not " e " + m.group("Msmflo_73") + "l " + m.group("Msmflo_74") + "s" in TEXT and not " ou " + m.group("Msmflo_73") + "l " + m.group("Msmflo_74") + "s" in TEXT and not "s de " + m.group("Msmflo_73") + "l " + m.group("Msmflo_74") + "s" in TEXT and not "s do " + m.group("Msmflo_73") + "l " + m.group("Msmflo_74") + "s" in TEXT and not " o " + m.group("Msmflo_73") + "l " + m.group("Msmflo_74") + "s" in TEXT and not m.group("Msmflo_73") + "l-" + m.group("Msmflo_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_75>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_75").lower() in plvrMfal and m.group("Msmflo_76").lower() in plvrMasco and not " e " + m.group("Msmflo_75") + "l " + m.group("Msmflo_76") +"s" in TEXT and not " ou " + m.group("Msmflo_75") + "l " + m.group("Msmflo_76") + "s" in TEXT and not "s de " + m.group("Msmflo_75") + "l " + m.group("Msmflo_76") + "s" in TEXT and not "s do " + m.group("Msmflo_75") + "l " + m.group("Msmflo_76") + "s" in TEXT and not " o " + m.group("Msmflo_75") + "l " + m.group("Msmflo_76") + "s" in TEXT and not m.group("Msmflo_75") + "l-" + m.group("Msmflo_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_77>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_77").lower() in plvrMfal and not " e " + m.group("Msmflo_77") + "l " + m.group("Msmflo_78") + "inhos" in TEXT and not " ou " + m.group("Msmflo_77") + "l " + m.group("Msmflo_78") + "inhos" in TEXT and not "s de " + m.group("Msmflo_77") + "l " + m.group("Msmflo_78") + "inhos" in TEXT and not "s do " + m.group("Msmflo_77") + "l " + m.group("Msmflo_78") + "inhos" in TEXT and not " o " + m.group("Msmflo_77") + "l " + m.group("Msmflo_78") + "inhos" in TEXT and not m.group("Msmflo_77") + "l-" + m.group("Msmflo_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_83>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_83").lower() in plvrMfal and not " e " + m.group("Msmflo_83") + "l " + m.group("Msmflo_84") + "icas" in TEXT and not " ou " + m.group("Msmflo_83") + "l " + m.group("Msmflo_84") + "icas" in TEXT and not "s de " + m.group("Msmflo_83") + "l " + m.group("Msmflo_84") + "icas" in TEXT and not "s do " + m.group("Msmflo_83") + "l " + m.group("Msmflo_84") + "icas" in TEXT and not " o " + m.group("Msmflo_83") + "l " + m.group("Msmflo_84") + "icas" in TEXT and not m.group("Msmflo_83") + "l-" + m.group("Msmflo_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_85>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_85").lower() in plvrMfal and not " e " + m.group("Msmflo_85") + "l " + m.group("Msmflo_86") + "escas" in TEXT and not " ou " + m.group("Msmflo_85") + "l " + m.group("Msmflo_86") + "escas" in TEXT and not "s de " + m.group("Msmflo_85") + "l " + m.group("Msmflo_86") + "escas" in TEXT and not "s do " + m.group("Msmflo_85") + "l " + m.group("Msmflo_86") + "escas" in TEXT and not " o " + m.group("Msmflo_85") + "l " + m.group("Msmflo_86") + "escas" in TEXT and not m.group("Msmflo_85") + "l-" + m.group("Msmflo_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmflo_87>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmflo_88>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmflo_87").lower() in plvrMfal and m.group("Msmflo_88") in plvrMascm and not " e " + m.group("Msmflo_87") + "l " + m.group("Msmflo_88") + "ns" in TEXT and not " ou " + m.group("Msmflo_87") + "l " + m.group("Msmflo_88") + "ns" in TEXT and not "s de " + m.group("Msmflo_87") + "l " + m.group("Msmflo_88") + "ns" in TEXT and not "s da " + m.group("Msmflo_87") + "l " + m.group("Msmflo_88") + "ns" in TEXT and not " a " + m.group("Msmflo_87") + "l " + m.group("Msmflo_88") + "ns" in TEXT and not m.group("Msmflo_87") + "l-" + m.group("Msmflo_88") + "ns" in tCompostops'],
# plvrMascal
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_1>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_1").lower() in plvrMascal and m.group("Msmcl_2").lower() in plvrMasca and not " e " + m.group("Msmcl_1") + "l " + m.group("Msmcl_2") +"s" in TEXT and not " ou " + m.group("Msmcl_1") + "l " + m.group("Msmcl_2") + "s" in TEXT and not "s de " + m.group("Msmcl_1") + "l " + m.group("Msmcl_2") + "s" in TEXT and not "s do " + m.group("Msmcl_1") + "l " + m.group("Msmcl_2") + "s" in TEXT and not " o " + m.group("Msmcl_1") + "l " + m.group("Msmcl_2") + "s" in TEXT and not m.group("Msmcl_1") + "l-" + m.group("Msmcl_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_3>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_3").lower() in plvrMascal and m.group("Msmcl_4").lower() in plvrMfoa and not " e " + m.group("Msmcl_3") + "l " + m.group("Msmcl_4") + "os" in TEXT and not " ou " + m.group("Msmcl_3") + "l " + m.group("Msmcl_4") + "os" in TEXT and not "s de " + m.group("Msmcl_3") + "l " + m.group("Msmcl_4") + "os" in TEXT and not "s do " + m.group("Msmcl_3") + "l " + m.group("Msmcl_4") + "os" in TEXT and not " o " + m.group("Msmcl_3") + "l " + m.group("Msmcl_4") + "os" in TEXT and not m.group("Msmcl_3") + "l-" + m.group("Msmcl_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_5>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_5").lower() in plvrMascal and not m.group("Msmcl_6").lower() in excAdo and not " e " + m.group("Msmcl_5") + "l " + m.group("Msmcl_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msmcl_5") + "l " + m.group("Msmcl_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msmcl_5") + "l " + m.group("Msmcl_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Msmcl_5") + "l " + m.group("Msmcl_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Msmcl_5") + "l " + m.group("Msmcl_6") + m.group(3) + "dos" in TEXT and not m.group("Msmcl_5") + "l-" + m.group("Msmcl_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_7>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_7").lower() in plvrMascal and not m.group("Msmcl_8").lower() in excIsta and not " e " + m.group("Msmcl_7") + "l " + m.group("Msmcl_8") + "s" in TEXT and not " ou " + m.group("Msmcl_7") + "l " + m.group("Msmcl_8") + "s" in TEXT and not "s de " + m.group("Msmcl_7") + "l " + m.group("Msmcl_8") + "s" in TEXT and not "s do " + m.group("Msmcl_7") + "l " + m.group("Msmcl_8") + "s" in TEXT and not " o " + m.group("Msmcl_7") + "l " + m.group("Msmcl_8") + "s" in TEXT and not m.group("Msmcl_7") + "l-" + m.group("Msmcl_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_9>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_9").lower() in plvrMascal and m.group("Msmcl_10").lower() in plvrInva and not " e " + m.group("Msmcl_9") + "l " + m.group("Msmcl_10") + "s" in TEXT and not " ou " + m.group("Msmcl_9") + "l " + m.group("Msmcl_10") + "s" in TEXT and not "s de " + m.group("Msmcl_9") + "l " + m.group("Msmcl_10") + "s" in TEXT and not "s do " + m.group("Msmcl_9") + "l " + m.group("Msmcl_10") + "s" in TEXT and not " a " + m.group("Msmcl_9") + "l " + m.group("Msmcl_10") + "s" in TEXT and not m.group("Msmcl_9") + "l-" + m.group("Msmcl_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_11>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_11").lower() in plvrMascal and not m.group("Msmcl_12").lower() in excAdo and not " e " + m.group("Msmcl_11") + "l " + m.group("Msmcl_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msmcl_11") + "l " + m.group("Msmcl_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msmcl_11") + "l " + m.group("Msmcl_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Msmcl_11") + "l " + m.group("Msmcl_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Msmcl_11") + "l " + m.group("Msmcl_12") + m.group(3) + "das" in TEXT and not m.group("Msmcl_11") + "l-" + m.group("Msmcl_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_13>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_13").lower() in plvrMascal and not " e " + m.group("Msmcl_13") + "l " + m.group("Msmcl_14") + "osos" in TEXT and not " ou " + m.group("Msmcl_13") + "l " + m.group("Msmcl_14") + "osos" in TEXT and not "s de " + m.group("Msmcl_13") + "l " + m.group("Msmcl_14") + "osos" in TEXT and not "s do " + m.group("Msmcl_13") + "l " + m.group("Msmcl_14") + "osos" in TEXT and not " o " + m.group("Msmcl_13") + "l " + m.group("Msmcl_14") + "osos" in TEXT and not m.group("Msmcl_13") + "l-" + m.group("Msmcl_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_15>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_15").lower() in plvrMascal and not " e " + m.group("Msmcl_15") + "l " + m.group("Msmcl_16") + "osas" in TEXT and not " ou " + m.group("Msmcl_15") + "l " + m.group("Msmcl_16") + "osas" in TEXT and not "s de " + m.group("Msmcl_15") + "l " + m.group("Msmcl_16") + "osas" in TEXT and not "s do " + m.group("Msmcl_15") + "l " + m.group("Msmcl_16") + "osas" in TEXT and not " o " + m.group("Msmcl_15") + "l " + m.group("Msmcl_16") + "osas" in TEXT and not m.group("Msmcl_15") + "l-" + m.group("Msmcl_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_17>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_17").lower() in plvrMascal and not " e " + m.group("Msmcl_17") + "l " + m.group("Msmcl_18") + "ivas" in TEXT and not " ou " + m.group("Msmcl_17") + "l " + m.group("Msmcl_18") + "ivas" in TEXT and not "s de " + m.group("Msmcl_17") + "l " + m.group("Msmcl_18") + "ivas" in TEXT and not "s do " + m.group("Msmcl_17") + "l " + m.group("Msmcl_18") + "ivas" in TEXT and not " o " + m.group("Msmcl_17") + "l " + m.group("Msmcl_18") + "ivas" in TEXT and not m.group("Msmcl_17") + "l-" + m.group("Msmcl_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_19>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_19").lower() in plvrMascal and not " e " + m.group("Msmcl_19") + "l " + m.group("Msmcl_20") + "ivas" in TEXT and not " ou " + m.group("Msmcl_19") + "l " + m.group("Msmcl_20") + "ivas" in TEXT and not "s de " + m.group("Msmcl_19") + "l " + m.group("Msmcl_20") + "ivas" in TEXT and not "s do " + m.group("Msmcl_19") + "l " + m.group("Msmcl_20") + "ivas" in TEXT and not " o " + m.group("Msmcl_19") + "l " + m.group("Msmcl_20") + "ivas" in TEXT and not m.group("Msmcl_19") + "l-" + m.group("Msmcl_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_21>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_21").lower() in plvrMascal and not " e " + m.group("Msmcl_21") + "l " + m.group("Msmcl_22") + "icos" in TEXT and not " ou " + m.group("Msmcl_21") + "l " + m.group("Msmcl_22") + "icos" in TEXT and not "s de " + m.group("Msmcl_21") + "l " + m.group("Msmcl_22") + "icos" in TEXT and not "s do " + m.group("Msmcl_21") + "l " + m.group("Msmcl_22") + "icos" in TEXT and not " o " + m.group("Msmcl_21") + "l " + m.group("Msmcl_22") + "icos" in TEXT and not m.group("Msmcl_21") + "l-" + m.group("Msmcl_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_23>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_23").lower() in plvrMascal and not " e " + m.group("Msmcl_23") + "l " + m.group("Msmcl_24") + "icos" in TEXT and not " ou " + m.group("Msmcl_23") + "l " + m.group("Msmcl_24") + "icos" in TEXT and not "s de " + m.group("Msmcl_23") + "l " + m.group("Msmcl_24") + "icos" in TEXT and not "s do " + m.group("Msmcl_23") + "l " + m.group("Msmcl_24") + "icos" in TEXT and not " o " + m.group("Msmcl_23") + "l " + m.group("Msmcl_24") + "icos" in TEXT and not m.group("Msmcl_23") + "l-" + m.group("Msmcl_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_25>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_25").lower() in plvrMascal and not " e " + m.group("Msmcl_25") + "l " + m.group("Msmcl_26") + "icos" in TEXT and not " ou " + m.group("Msmcl_25") + "l " + m.group("Msmcl_26") + "icos" in TEXT and not "s de " + m.group("Msmcl_25") + "l " + m.group("Msmcl_26") + "icos" in TEXT and not "s do " + m.group("Msmcl_25") + "l " + m.group("Msmcl_26") + "icos" in TEXT and not " o " + m.group("Msmcl_25") + "l " + m.group("Msmcl_26") + "icos" in TEXT and not m.group("Msmcl_25") + "l-" + m.group("Msmcl_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_27>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_27").lower() in plvrMascal and not " e " + m.group("Msmcl_27") + "l " + m.group("Msmcl_28") + "escos" in TEXT and not " ou " + m.group("Msmcl_27") + "l " + m.group("Msmcl_28") + "escos" in TEXT and not "s de " + m.group("Msmcl_27") + "l " + m.group("Msmcl_28") + "escos" in TEXT and not "s do " + m.group("Msmcl_27") + "l " + m.group("Msmcl_28") + "escos" in TEXT and not " o " + m.group("Msmcl_27") + "l " + m.group("Msmcl_28") + "escos" in TEXT and not m.group("Msmcl_27") + "l-" + m.group("Msmcl_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_29>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_29").lower() in plvrMascal and not " e " + m.group("Msmcl_29") + "l " + m.group("Msmcl_30") + "idos" in TEXT and not " ou " + m.group("Msmcl_29") + "s " + m.group("Msmcl_30") + "idos" in TEXT and not "s de " + m.group("Msmcl_29") + "s " + m.group("Msmcl_30") + "idos" in TEXT and not "s do " + m.group("Msmcl_29") + "s " + m.group("Msmcl_30") + "idos" in TEXT and not " o " + m.group("Msmcl_29") + "s " + m.group("Msmcl_30") + "idos" in TEXT and not m.group("Msmcl_29") + "l-" + m.group("Msmcl_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_31>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_31").lower() in plvrMascal and not " e " + m.group("Msmcl_31") + "l " + m.group("Msmcl_32") + "logos" in TEXT and not " ou " + m.group("Msmcl_31") + "l " + m.group("Msmcl_32") + "logos" in TEXT and not "s de " + m.group("Msmcl_31") + "l " + m.group("Msmcl_32") + "logos" in TEXT and not "s do " + m.group("Msmcl_31") + "l " + m.group("Msmcl_32") + "logos" in TEXT and not " o " + m.group("Msmcl_31") + "l " + m.group("Msmcl_32") + "logos" in TEXT and not m.group("Msmcl_31") + "l-" + m.group("Msmcl_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_33>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_33").lower() in plvrMascal and not " e " + m.group("Msmcl_33") + "l " + m.group("Msmcl_34") + "rios" in TEXT and not " ou " + m.group("Msmcl_33") + "l " + m.group("Msmcl_34") + "rios" in TEXT and not "s de " + m.group("Msmcl_33") + "l " + m.group("Msmcl_34") + "rios" in TEXT and not "s do " + m.group("Msmcl_33") + "l " + m.group("Msmcl_34") + "rios" in TEXT and not " o " + m.group("Msmcl_33") + "l " + m.group("Msmcl_34") + "rios" in TEXT and not m.group("Msmcl_33") + "l-" + m.group("Msmcl_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_35>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_35").lower() in plvrMascal and not " e " + m.group("Msmcl_35") + "l " + m.group("Msmcl_36") + "ssimos" in TEXT and not " ou " + m.group("Msmcl_35") + "l " + m.group("Msmcl_36") + "ssimos" in TEXT and not "s de " + m.group("Msmcl_35") + "l " + m.group("Msmcl_36") + "ssimos" in TEXT and not "s do " + m.group("Msmcl_35") + "l " + m.group("Msmcl_36") + "ssimos" in TEXT and not " o " + m.group("Msmcl_35") + "l " + m.group("Msmcl_36") + "ssimos" in TEXT and not m.group("Msmcl_35") + "l-" + m.group("Msmcl_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_37>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_37").lower() in plvrMascal and not " e " + m.group("Msmcl_37") + "l " + m.group("Msmcl_38") + "simos" in TEXT and not " ou " + m.group("Msmcl_37") + "l " + m.group("Msmcl_38") + "simos" in TEXT and not "s de " + m.group("Msmcl_37") + "l " + m.group("Msmcl_38") + "simos" in TEXT and not "s do " + m.group("Msmcl_37") + "l " + m.group("Msmcl_38") + "simos" in TEXT and not " o " + m.group("Msmcl_37") + "l " + m.group("Msmcl_38") + "simos" in TEXT and not m.group("Msmcl_37") + "l-" + m.group("Msmcl_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_41>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_41").lower() in plvrMascal and not m.group("Msmcl_42") in "D-d-" and not " e " + m.group("Msmcl_41") + "l " + m.group("Msmcl_42") + "ores" in TEXT and not " ou " + m.group("Msmcl_41") + "l " + m.group("Msmcl_42") + "ores" in TEXT and not "s de " + m.group("Msmcl_41") + "l " + m.group("Msmcl_42") + "ores" in TEXT and not "s do " + m.group("Msmcl_41") + "l " + m.group("Msmcl_42") + "ores" in TEXT and not " o " + m.group("Msmcl_41") + "l " + m.group("Msmcl_42") + "ores" in TEXT and not m.group("Msmcl_41") + "l-" + m.group("Msmcl_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_43>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_43").lower() in plvrMascal and m.group("Msmcl_44") in plvrMfr and not " e " + m.group("Msmcl_43") + "l " + m.group("Msmcl_44") + "es" in TEXT and not " ou " + m.group("Msmcl_43") + "l " + m.group("Msmcl_44") + "es" in TEXT and not "s de " + m.group("Msmcl_43") + "l " + m.group("Msmcl_44") + "es" in TEXT and not "s do " + m.group("Msmcl_43") + "l " + m.group("Msmcl_44") + "es" in TEXT and not " o " + m.group("Msmcl_43") + "l " + m.group("Msmcl_44") + "es" in TEXT and not m.group("Msmcl_43") + "l-" + m.group("Msmcl_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_45>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_45").lower() in plvrMascal and m.group("Msmcl_46") in plvrMascr and not " e " + m.group("Msmcl_45") + "l " + m.group("Msmcl_46") + "es" in TEXT and not " ou " + m.group("Msmcl_45") + "l " + m.group("Msmcl_46") + "es" in TEXT and not "s de " + m.group("Msmcl_45") + "l " + m.group("Msmcl_46") + "es" in TEXT and not "s do " + m.group("Msmcl_45") + "l " + m.group("Msmcl_46") + "es" in TEXT and not " o " + m.group("Msmcl_45") + "l " + m.group("Msmcl_46") + "es" in TEXT and not m.group("Msmcl_45") + "l-" + m.group("Msmcl_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_47>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_47").lower() in plvrMascal and m.group("Msmcl_48") in plvrMfal and not " e " + m.group("Msmcl_47") + "l " + m.group("Msmcl_48") + "is" in TEXT and not " ou " + m.group("Msmcl_47") + "l " + m.group("Msmcl_48") + "is" in TEXT and not "s de " + m.group("Msmcl_47") + "l " + m.group("Msmcl_48") + "is" in TEXT and not "s do " + m.group("Msmcl_47") + "l " + m.group("Msmcl_48") + "is" in TEXT and not " o " + m.group("Msmcl_47") + "l " + m.group("Msmcl_48") + "is" in TEXT and not m.group("Msmcl_47") + "l-" + m.group("Msmcl_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_49>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_49").lower() in plvrMascal and m.group("Msmcl_50") in plvrMfcao and not " e " + m.group("Msmcl_49") + "l " + m.group("Msmcl_50") + "ões" in TEXT and not + " ou " + m.group("Msmcl_49") + "l " + m.group("Msmcl_50") + "ões" in TEXT and not + "s de " + m.group("Msmcl_49") + "l " + m.group("Msmcl_50") + "ões" in TEXT and not + "s do " + m.group("Msmcl_49") + "l " + m.group("Msmcl_50") + "ões" in TEXT and not + " a " + m.group("Msmcl_49") + "l " + m.group("Msmcl_50") + "ões" in TEXT and not m.group("Msmcl_49") + "l-" + m.group("Msmcl_50") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_51>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_51").lower() in plvrMascal and m.group("Msmcl_52") in plvrNfemcao and not " e " + m.group("Msmcl_51") + "l " + m.group("Msmcl_52") + "ões" in TEXT and not " ou " + m.group("Msmcl_51") + "l " + m.group("Msmcl_52") + "ões" in TEXT and not "s de " + m.group("Msmcl_51") + "l " + m.group("Msmcl_52") + "ões" in TEXT and not "s do " + m.group("Msmcl_51") + "l " + m.group("Msmcl_52") + "ões" in TEXT and not " o " + m.group("Msmcl_51") + "l " + m.group("Msmcl_52") + "ões" in TEXT and not m.group("Msmcl_51") + "l-" + m.group("Msmcl_52") + "ões" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_55>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_55").lower() in plvrMascal and not " e " + m.group("Msmcl_55") + "l " + m.group("Msmcl_56") + "veis" in TEXT and not " ou " + m.group("Msmcl_55") + "l " + m.group("Msmcl_56") + "veis" in TEXT and not "s de " + m.group("Msmcl_55") + "l " + m.group("Msmcl_56") + "veis" in TEXT and not "s do " + m.group("Msmcl_55") + "l " + m.group("Msmcl_56") + "veis" in TEXT and not " o " + m.group("Msmcl_55") + "l " + m.group("Msmcl_56") + "veis" in TEXT and not m.group("Msmcl_55") + "l-" + m.group("Msmcl_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_57>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_57").lower() in plvrMascal and m.group("Msmcl_58").lower() in plvrMfe and not " e " + m.group("Msmcl_57") + "l " + m.group("Msmcl_58") + "es" in TEXT and not " ou " + m.group("Msmcl_57") + "l " + m.group("Msmcl_58") + "es" in TEXT and not "s de " + m.group("Msmcl_57") + "l " + m.group("Msmcl_58") + "es" in TEXT and not "s do " + m.group("Msmcl_57") + "l " + m.group("Msmcl_58") + "es" in TEXT and not " o " + m.group("Msmcl_57") + "l " + m.group("Msmcl_58") + "es" in TEXT and not m.group("Msmcl_57") + "l-" + m.group("Msmcl_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_59>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_59").lower() in plvrMascal and m.group("Msmcl_60").lower() in plvrMascal and not " e " + m.group("Msmcl_59") + "l " + m.group("Msmcl_60") + "es" in TEXT and not " ou " + m.group("Msmcl_59") + "l " + m.group("Msmcl_60") + "es" in TEXT and not "s de " + m.group("Msmcl_59") + "l " + m.group("Msmcl_60") + "es" in TEXT and not "s do " + m.group("Msmcl_59") + "l " + m.group("Msmcl_60") + "es" in TEXT and not " o " + m.group("Msmcl_59") + "l " + m.group("Msmcl_60") + "es" in TEXT and not m.group("Msmcl_59") + "l-" + m.group("Msmcl_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_61>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_61").lower() in plvrMascal and m.group("Msmcl_62") in plvrMfel and not " e " + m.group("Msmcl_61") + "l " + m.group("Msmcl_62") + "éis" in TEXT and not " ou " + m.group("Msmcl_61") + "l " + m.group("Msmcl_62") + "éis" in TEXT and not "s de " + m.group("Msmcl_61") + "l " + m.group("Msmcl_62") + "éis" in TEXT and not "s do " + m.group("Msmcl_61") + "l " + m.group("Msmcl_62") + "éis" in TEXT and not " o " + m.group("Msmcl_61") + "l " + m.group("Msmcl_62") + "éis" in TEXT and not m.group("Msmcl_61") + "l-" + m.group("Msmcl_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_63>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_63").lower() in plvrMascal and m.group("Msmcl_64") in plvrMascel and not " e " + m.group("Msmcl_63") + "l " + m.group("Msmcl_64") + "éis" in TEXT and not " ou " + m.group("Msmcl_63") + "l " + m.group("Msmcl_64") + "éis" in TEXT and not "s de " + m.group("Msmcl_63") + "l " + m.group("Msmcl_64") + "éis" in TEXT and not "s do " + m.group("Msmcl_63") + "l " + m.group("Msmcl_64") + "éis" in TEXT and not " o " + m.group("Msmcl_63") + "l " + m.group("Msmcl_64") + "éis" in TEXT and not m.group("Msmcl_63") + "l-" + m.group("Msmcl_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_65>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_65").lower() in plvrMascal and m.group("Msmcl_66") in plvrMfeu and not " e " + m.group("Msmcl_65") + "l " + m.group("Msmcl_66") + "us" in TEXT and not " ou " + m.group("Msmcl_65") + "l " + m.group("Msmcl_66") + "us" in TEXT and not "s de " + m.group("Msmcl_65") + "l " + m.group("Msmcl_66") + "us" in TEXT and not "s do " + m.group("Msmcl_65") + "l " + m.group("Msmcl_66") + "us" in TEXT and not " o " + m.group("Msmcl_65") + "l " + m.group("Msmcl_66") + "us" in TEXT and not m.group("Msmcl_65") + "l-" + m.group("Msmcl_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_67>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_67").lower() in plvrMascal and m.group("Msmcl_68") in plvrMascu and not " e " + m.group("Msmcl_67") + "l " + m.group("Msmcl_68") + "us" in TEXT and not " ou " + m.group("Msmcl_67") + "l " + m.group("Msmcl_68") + "us" in TEXT and not "s de " + m.group("Msmcl_67") + "l " + m.group("Msmcl_68") + "us" in TEXT and not "s do " + m.group("Msmcl_67") + "l " + m.group("Msmcl_68") + "us" in TEXT and not " o " + m.group("Msmcl_67") + "l " + m.group("Msmcl_68") + "us" in TEXT and not m.group("Msmcl_67") + "l-" + m.group("Msmcl_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_69>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_69").lower() in plvrMascal and m.group("Msmcl_70") in plvrInvaz and not " e " + m.group("Msmcl_69") + "l " + m.group("Msmcl_70") + "zes" in TEXT and not " ou " + m.group("Msmcl_69") + "l " + m.group("Msmcl_70") + "zes" in TEXT and not "s de " + m.group("Msmcl_69") + "l " + m.group("Msmcl_70") + "zes" in TEXT and not "s do " + m.group("Msmcl_69") + "l " + m.group("Msmcl_70") + "zes" in TEXT and not " o " + m.group("Msmcl_69") + "l " + m.group("Msmcl_70") + "zes" in TEXT and not m.group("Msmcl_69") + "l-" + m.group("Msmcl_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_71>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_71").lower() in plvrMascal and m.group("Msmcl_72") in plvrMascz and not " e " + m.group("Msmcl_71") + "l " + m.group("Msmcl_72") + "zes" in TEXT and not " ou " + m.group("Msmcl_71") + "l " + m.group("Msmcl_72") + "zes" in TEXT and not "s de " + m.group("Msmcl_71") + "l " + m.group("Msmcl_72") + "zes" in TEXT and not "s do " + m.group("Msmcl_71") + "l " + m.group("Msmcl_72") + "zes" in TEXT and not " o " + m.group("Msmcl_71") + "l " + m.group("Msmcl_72") + "zes" in TEXT and not m.group("Msmcl_71") + "l-" + m.group("Msmcl_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_73>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_73").lower() in plvrMascal and m.group("Msmcl_74") in pvrMascan and not " e " + m.group("Msmcl_73") + "l " + m.group("Msmcl_74") + "s" in TEXT and not " ou " + m.group("Msmcl_73") + "l " + m.group("Msmcl_74") + "s" in TEXT and not "s de " + m.group("Msmcl_73") + "l " + m.group("Msmcl_74") + "s" in TEXT and not "s do " + m.group("Msmcl_73") + "l " + m.group("Msmcl_74") + "s" in TEXT and not " o " + m.group("Msmcl_73") + "l " + m.group("Msmcl_74") + "s" in TEXT and not m.group("Msmcl_73") + "l-" + m.group("Msmcl_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_75>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_75").lower() in plvrMascal and m.group("Msmcl_76").lower() in plvrMasco and not " e " + m.group("Msmcl_75") + "l " + m.group("Msmcl_76") +"s" in TEXT and not " ou " + m.group("Msmcl_75") + "l " + m.group("Msmcl_76") + "s" in TEXT and not "s de " + m.group("Msmcl_75") + "l " + m.group("Msmcl_76") + "s" in TEXT and not "s do " + m.group("Msmcl_75") + "l " + m.group("Msmcl_76") + "s" in TEXT and not " o " + m.group("Msmcl_75") + "l " + m.group("Msmcl_76") + "s" in TEXT and not m.group("Msmcl_75") + "l-" + m.group("Msmcl_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_77>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_77").lower() in plvrMascal and not " e " + m.group("Msmcl_77") + "l " + m.group("Msmcl_78") + "inhos" in TEXT and not " ou " + m.group("Msmcl_77") + "l " + m.group("Msmcl_78") + "inhos" in TEXT and not "s de " + m.group("Msmcl_77") + "l " + m.group("Msmcl_78") + "inhos" in TEXT and not "s do " + m.group("Msmcl_77") + "l " + m.group("Msmcl_78") + "inhos" in TEXT and not " o " + m.group("Msmcl_77") + "l " + m.group("Msmcl_78") + "inhos" in TEXT and not m.group("Msmcl_77") + "l-" + m.group("Msmcl_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_79>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_79").lower() in plvrMascal and not " e " + m.group("Msmcl_79") + "l " + m.group("Msmcl_80") + "icas" in TEXT and not " ou " + m.group("Msmcl_79") + "l " + m.group("Msmcl_80") + "icas" in TEXT and not "s de " + m.group("Msmcl_79") + "l " + m.group("Msmcl_80") + "icas" in TEXT and not "s do " + m.group("Msmcl_79") + "l " + m.group("Msmcl_80") + "icas" in TEXT and not " o " + m.group("Msmcl_79") + "l " + m.group("Msmcl_80") + "icas" in TEXT and not m.group("Msmcl_79") + "l-" + m.group("Msmcl_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_81>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_81").lower() in plvrMascal and not " e " + m.group("Msmcl_81") + "l " + m.group("Msmcl_82") + "icas" in TEXT and not " ou " + m.group("Msmcl_81") + "l " + m.group("Msmcl_82") + "icas" in TEXT and not "s de " + m.group("Msmcl_81") + "l " + m.group("Msmcl_82") + "icas" in TEXT and not "s do " + m.group("Msmcl_81") + "l " + m.group("Msmcl_82") + "icas" in TEXT and not " o " + m.group("Msmcl_81") + "l " + m.group("Msmcl_82") + "icas" in TEXT and not m.group("Msmcl_81") + "l-" + m.group("Msmcl_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_83>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_83").lower() in plvrMascal and not " e " + m.group("Msmcl_83") + "l " + m.group("Msmcl_84") + "icas" in TEXT and not " ou " + m.group("Msmcl_83") + "l " + m.group("Msmcl_84") + "icas" in TEXT and not "s de " + m.group("Msmcl_83") + "l " + m.group("Msmcl_84") + "icas" in TEXT and not "s do " + m.group("Msmcl_83") + "l " + m.group("Msmcl_84") + "icas" in TEXT and not " o " + m.group("Msmcl_83") + "l " + m.group("Msmcl_84") + "icas" in TEXT and not m.group("Msmcl_83") + "l-" + m.group("Msmcl_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_85>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_85").lower() in plvrMascal and not " e " + m.group("Msmcl_85") + "l " + m.group("Msmcl_86") + "escas" in TEXT and not " ou " + m.group("Msmcl_85") + "l " + m.group("Msmcl_86") + "escas" in TEXT and not "s de " + m.group("Msmcl_85") + "l " + m.group("Msmcl_86") + "escas" in TEXT and not "s do " + m.group("Msmcl_85") + "l " + m.group("Msmcl_86") + "escas" in TEXT and not " o " + m.group("Msmcl_85") + "l " + m.group("Msmcl_86") + "escas" in TEXT and not m.group("Msmcl_85") + "l-" + m.group("Msmcl_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_87>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_87").lower() in plvrMascal and not " e " + m.group("Msmcl_87") + "l " + m.group("Msmcl_88") + "idas" in TEXT and not " ou " + m.group("Msmcl_87") + "s " + m.group("Msmcl_88") + "idas" in TEXT and not "s de " + m.group("Msmcl_87") + "s " + m.group("Msmcl_88") + "idas" in TEXT and not "s do " + m.group("Msmcl_87") + "s " + m.group("Msmcl_88") + "idas" in TEXT and not " o " + m.group("Msmcl_87") + "s " + m.group("Msmcl_88") + "idas" in TEXT and not m.group("Msmcl_87") + "l-" + m.group("Msmcl_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_89>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_89").lower() in plvrMascal and not " e " + m.group("Msmcl_89") + "l " + m.group("Msmcl_90") + "logas" in TEXT and not " ou " + m.group("Msmcl_89") + "l " + m.group("Msmcl_90") + "logas" in TEXT and not "s de " + m.group("Msmcl_89") + "l " + m.group("Msmcl_90") + "logas" in TEXT and not "s do " + m.group("Msmcl_89") + "l " + m.group("Msmcl_90") + "logas" in TEXT and not " o " + m.group("Msmcl_89") + "l " + m.group("Msmcl_90") + "logas" in TEXT and not m.group("Msmcl_89") + "l-" + m.group("Msmcl_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_91>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_91").lower() in plvrMascal and not " e " + m.group("Msmcl_91") + "l " + m.group("Msmcl_92") + "rias" in TEXT and not " ou " + m.group("Msmcl_91") + "l " + m.group("Msmcl_92") + "rias" in TEXT and not "s de " + m.group("Msmcl_91") + "l " + m.group("Msmcl_92") + "rias" in TEXT and not "s do " + m.group("Msmcl_91") + "l " + m.group("Msmcl_92") + "rias" in TEXT and not " o " + m.group("Msmcl_91") + "l " + m.group("Msmcl_92") + "rias" in TEXT and not m.group("Msmcl_91") + "l-" + m.group("Msmcl_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_93>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_93").lower() in plvrMascal and not " e " + m.group("Msmcl_93") + "l " + m.group("Msmcl_94") + "ssimas" in TEXT and not " ou " + m.group("Msmcl_93") + "l " + m.group("Msmcl_94") + "ssimas" in TEXT and not "s de " + m.group("Msmcl_93") + "l " + m.group("Msmcl_94") + "ssimas" in TEXT and not "s do " + m.group("Msmcl_93") + "l " + m.group("Msmcl_94") + "ssimas" in TEXT and not " o " + m.group("Msmcl_93") + "l " + m.group("Msmcl_94") + "ssimas" in TEXT and not m.group("Msmcl_93") + "l-" + m.group("Msmcl_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_95>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_95").lower() in plvrMascal and not " e " + m.group("Msmcl_95") + "l " + m.group("Msmcl_96") + "simas" in TEXT and not " ou " + m.group("Msmcl_95") + "l " + m.group("Msmcl_96") + "simas" in TEXT and not "s de " + m.group("Msmcl_95") + "l " + m.group("Msmcl_96") + "simas" in TEXT and not "s do " + m.group("Msmcl_95") + "l " + m.group("Msmcl_96") + "simas" in TEXT and not " o " + m.group("Msmcl_95") + "l " + m.group("Msmcl_96") + "simas" in TEXT and not m.group("Msmcl_95") + "l-" + m.group("Msmcl_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_97>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_97").lower() in plvrMascal and m.group("Msmcl_98").lower() in plvrMascal and not " e " + m.group("Msmcl_97") + "l " + m.group("Msmcl_98") + "as" in TEXT and not " ou " + m.group("Msmcl_97") + "l " + m.group("Msmcl_98") + "as" in TEXT and not "s de " + m.group("Msmcl_97") + "l " + m.group("Msmcl_98") + "as" in TEXT and not "s do " + m.group("Msmcl_97") + "l " + m.group("Msmcl_98") + "as" in TEXT and not " o " + m.group("Msmcl_97") + "l " + m.group("Msmcl_98") + "as" in TEXT and not m.group("Msmcl_97") + "l-" + m.group("Msmcl_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_99>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_99").lower() in plvrMascal and m.group("Msmcl_100") in plvrMFm and not " e " + m.group("Msmcl_99") + "l " + m.group("Msmcl_100") + "ns" in TEXT and not " ou " + m.group("Msmcl_99") + "l " + m.group("Msmcl_100") + "ns" in TEXT and not "s de " + m.group("Msmcl_99") + "l " + m.group("Msmcl_100") + "ns" in TEXT and not "s do " + m.group("Msmcl_99") + "l " + m.group("Msmcl_100") + "ns" in TEXT and not " o " + m.group("Msmcl_99") + "l " + m.group("Msmcl_100") + "ns" in TEXT and not m.group("Msmcl_99") + "l-" + m.group("Msmcl_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msmcl_101>[a-zA-Zçáéíóúâêô]+[a])l (?P<Msmcl_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msmcl_101").lower() in plvrMascal and m.group("Msmcl_102") in plvrMascm and not " e " + m.group("Msmcl_101") + "l " + m.group("Msmcl_102") + "ns" in TEXT and not " ou " + m.group("Msmcl_101") + "l " + m.group("Msmcl_102") + "ns" in TEXT and not "s de " + m.group("Msmcl_101") + "l " + m.group("Msmcl_102") + "ns" in TEXT and not "s do " + m.group("Msmcl_101") + "l " + m.group("Msmcl_102") + "ns" in TEXT and not " o " + m.group("Msmcl_101") + "l " + m.group("Msmcl_102") + "ns" in TEXT and not m.group("Msmcl_101") + "l-" + m.group("Msmcl_102") + "ns" in tCompostops'],
# not plvrMascao a - palavras femininas terminadas em cao
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_1>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_1").lower() in plvrMascao and m.group("Mscaa_2").lower() in plvrFema and not " e " + m.group("Mscaa_1") + "ão " + m.group("Mscaa_2") +"s" in TEXT and not " ou " + m.group("Mscaa_1") + "ão " + m.group("Mscaa_2") + "s" in TEXT and not "s de " + m.group("Mscaa_1") + "ão " + m.group("Mscaa_2") + "s" in TEXT and not "s da " + m.group("Mscaa_1") + "ão " + m.group("Mscaa_2") + "s" in TEXT and not " a " + m.group("Mscaa_1") + "ão " + m.group("Mscaa_2") + "s" in TEXT and not m.group("Mscaa_1") + "ãa-" + m.group("Mscaa_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_3>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_3").lower() in plvrMascao and m.group("Mscaa_4").lower() in plvrMfoa and not " e " + m.group("Mscaa_3") + "ão " + m.group("Mscaa_4") + "as" in TEXT and not " ou " + m.group("Mscaa_3") + "ão " + m.group("Mscaa_4") + "as" in TEXT and not "s de " + m.group("Mscaa_3") + "ão " + m.group("Mscaa_4") + "as" in TEXT and not "s da " + m.group("Mscaa_3") + "ão " + m.group("Mscaa_4") + "as" in TEXT and not " a " + m.group("Mscaa_3") + "ão " + m.group("Mscaa_4") + "as" in TEXT and not m.group("Mscaa_3") + "ãa-" + m.group("Mscaa_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_5>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_5").lower() in plvrMascao and not m.group("Mscaa_6").lower() in excAdo and not " e " + m.group("Mscaa_5") + "ão " + m.group("Mscaa_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Mscaa_5") + "ão " + m.group("Mscaa_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Mscaa_5") + "ão " + m.group("Mscaa_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Mscaa_5") + "ão " + m.group("Mscaa_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Mscaa_5") + "ão " + m.group("Mscaa_6") + m.group(3) + "dos" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_7>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_7").lower() in plvrMascao and not m.group("Mscaa_8").lower() in excIsta and not " e " + m.group("Mscaa_7") + "ão " + m.group("Mscaa_8") + "s" in TEXT and not " ou " + m.group("Mscaa_7") + "ão " + m.group("Mscaa_8") + "s" in TEXT and not "s de " + m.group("Mscaa_7") + "ão " + m.group("Mscaa_8") + "s" in TEXT and not "s da " + m.group("Mscaa_7") + "ão " + m.group("Mscaa_8") + "s" in TEXT and not " a " + m.group("Mscaa_7") + "ão " + m.group("Mscaa_8") + "s" in TEXT and not m.group("Mscaa_7") + "ãa-" + m.group("Mscaa_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_9>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_9").lower() in plvrMascao and m.group("Mscaa_10").lower() in plvrInva and not " e " + m.group("Mscaa_9") + "ão " + m.group("Mscaa_10") + "s" in TEXT and not " ou " + m.group("Mscaa_9") + "ão " + m.group("Mscaa_10") + "s" in TEXT and not "s de " + m.group("Mscaa_9") + "ão " + m.group("Mscaa_10") + "s" in TEXT and not "s da " + m.group("Mscaa_9") + "ão " + m.group("Mscaa_10") + "s" in TEXT and not " a " + m.group("Mscaa_9") + "ão " + m.group("Mscaa_10") + "s" in TEXT and not m.group("Mscaa_9") + "ãa-" + m.group("Mscaa_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_11>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_11").lower() in plvrMascao and not m.group("Mscaa_12").lower() in excAdo and not " e " + m.group("Mscaa_11") + "ão " + m.group("Mscaa_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Mscaa_11") + "ão " + m.group("Mscaa_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Mscaa_11") + "ão " + m.group("Mscaa_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Mscaa_11") + "ão " + m.group("Mscaa_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Mscaa_11") + "ão " + m.group("Mscaa_12") + m.group(3) + "das" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_13>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_13").lower() in plvrMascao and not " e " + m.group("Mscaa_13") + "ão " + m.group("Mscaa_14") + "osos" in TEXT and not " ou " + m.group("Mscaa_13") + "ão " + m.group("Mscaa_14") + "osos" in TEXT and not "s de " + m.group("Mscaa_13") + "ão " + m.group("Mscaa_14") + "osos" in TEXT and not "s da " + m.group("Mscaa_13") + "ão " + m.group("Mscaa_14") + "osos" in TEXT and not " a " + m.group("Mscaa_13") + "ão " + m.group("Mscaa_14") + "osos" in TEXT and not m.group("Mscaa_13") + "ãa-" + m.group("Mscaa_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_15>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_15").lower() in plvrMascao and not " e " + m.group("Mscaa_15") + "ão " + m.group("Mscaa_16") + "osas" in TEXT and not " ou " + m.group("Mscaa_15") + "ão " + m.group("Mscaa_16") + "osas" in TEXT and not "s de " + m.group("Mscaa_15") + "ão " + m.group("Mscaa_16") + "osas" in TEXT and not "s da " + m.group("Mscaa_15") + "ão " + m.group("Mscaa_16") + "osas" in TEXT and not " a " + m.group("Mscaa_15") + "ão " + m.group("Mscaa_16") + "osas" in TEXT and not m.group("Mscaa_15") + "ãa-" + m.group("Mscaa_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_17>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_17").lower() in plvrMascao and not " e " + m.group("Mscaa_17") + "ão " + m.group("Mscaa_18") + "ivas" in TEXT and not " ou " + m.group("Mscaa_17") + "ão " + m.group("Mscaa_18") + "ivas" in TEXT and not "s de " + m.group("Mscaa_17") + "ão " + m.group("Mscaa_18") + "ivas" in TEXT and not "s da " + m.group("Mscaa_17") + "ão " + m.group("Mscaa_18") + "ivas" in TEXT and not " a " + m.group("Mscaa_17") + "ão " + m.group("Mscaa_18") + "ivas" in TEXT and not m.group("Mscaa_17") + "ãa-" + m.group("Mscaa_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_19>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_19").lower() in plvrMascao and not " e " + m.group("Mscaa_19") + "ão " + m.group("Mscaa_20") + "ivas" in TEXT and not " ou " + m.group("Mscaa_19") + "ão " + m.group("Mscaa_20") + "ivas" in TEXT and not "s de " + m.group("Mscaa_19") + "ão " + m.group("Mscaa_20") + "ivas" in TEXT and not "s da " + m.group("Mscaa_19") + "ão " + m.group("Mscaa_20") + "ivas" in TEXT and not " a " + m.group("Mscaa_19") + "ão " + m.group("Mscaa_20") + "ivas" in TEXT and not m.group("Mscaa_19") + "ãa-" + m.group("Mscaa_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_21>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_21").lower() in plvrMascao and not " e " + m.group("Mscaa_21") + "ão " + m.group("Mscaa_22") + "icas" in TEXT and not " ou " + m.group("Mscaa_21") + "ão " + m.group("Mscaa_22") + "icas" in TEXT and not "s de " + m.group("Mscaa_21") + "ão " + m.group("Mscaa_22") + "icas" in TEXT and not "s da " + m.group("Mscaa_21") + "ão " + m.group("Mscaa_22") + "icas" in TEXT and not " a " + m.group("Mscaa_21") + "ão " + m.group("Mscaa_22") + "icas" in TEXT and not m.group("Mscaa_21") + "ãa-" + m.group("Mscaa_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_23>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_23").lower() in plvrMascao and not " e " + m.group("Mscaa_23") + "ão " + m.group("Mscaa_24") + "icas" in TEXT and not " ou " + m.group("Mscaa_23") + "ão " + m.group("Mscaa_24") + "icas" in TEXT and not "s de " + m.group("Mscaa_23") + "ão " + m.group("Mscaa_24") + "icas" in TEXT and not "s da " + m.group("Mscaa_23") + "ão " + m.group("Mscaa_24") + "icas" in TEXT and not " a " + m.group("Mscaa_23") + "ão " + m.group("Mscaa_24") + "icas" in TEXT and not m.group("Mscaa_23") + "ãa-" + m.group("Mscaa_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_25>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_25").lower() in plvrMascao and not " e " + m.group("Mscaa_25") + "ão " + m.group("Mscaa_26") + "icas" in TEXT and not " ou " + m.group("Mscaa_25") + "ão " + m.group("Mscaa_26") + "icas" in TEXT and not "s de " + m.group("Mscaa_25") + "ão " + m.group("Mscaa_26") + "icas" in TEXT and not "s da " + m.group("Mscaa_25") + "ão " + m.group("Mscaa_26") + "icas" in TEXT and not " a " + m.group("Mscaa_25") + "ão " + m.group("Mscaa_26") + "icas" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_27>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_27").lower() in plvrMascao and not " e " + m.group("Mscaa_27") + "ão " + m.group("Mscaa_28") + "escas" in TEXT and not " ou " + m.group("Mscaa_27") + "ão " + m.group("Mscaa_28") + "escas" in TEXT and not "s de " + m.group("Mscaa_27") + "ão " + m.group("Mscaa_28") + "escas" in TEXT and not "s da " + m.group("Mscaa_27") + "ão " + m.group("Mscaa_28") + "escas" in TEXT and not " a " + m.group("Mscaa_27") + "ão " + m.group("Mscaa_28") + "escas" in TEXT and not m.group("Mscaa_27") + "ãa-" + m.group("Mscaa_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_29>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_29").lower() in plvrMascao and not " e " + m.group("Mscaa_29") + "ão " + m.group("Mscaa_30") + "idas" in TEXT and not " ou " + m.group("Mscaa_29") + "s " + m.group("Mscaa_30") + "idas" in TEXT and not "s de " + m.group("Mscaa_29") + "s " + m.group("Mscaa_30") + "idas" in TEXT and not "s da " + m.group("Mscaa_29") + "s " + m.group("Mscaa_30") + "idas" in TEXT and not " a " + m.group("Mscaa_29") + "s " + m.group("Mscaa_30") + "idas" in TEXT and not m.group("Mscaa_29") + "ãa-" + m.group("Mscaa_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_31>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_31").lower() in plvrMascao and not " e " + m.group("Mscaa_31") + "ão " + m.group("Mscaa_32") + "logas" in TEXT and not " ou " + m.group("Mscaa_31") + "ão " + m.group("Mscaa_32") + "logas" in TEXT and not "s de " + m.group("Mscaa_31") + "ão " + m.group("Mscaa_32") + "logas" in TEXT and not "s da " + m.group("Mscaa_31") + "ão " + m.group("Mscaa_32") + "logas" in TEXT and not " a " + m.group("Mscaa_31") + "ão " + m.group("Mscaa_32") + "logas" in TEXT and not m.group("Mscaa_31") + "ãa-" + m.group("Mscaa_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_33>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_33").lower() in plvrMascao and not " e " + m.group("Mscaa_33") + "ão " + m.group("Mscaa_34") + "rias" in TEXT and not " ou " + m.group("Mscaa_33") + "ão " + m.group("Mscaa_34") + "rias" in TEXT and not "s de " + m.group("Mscaa_33") + "ão " + m.group("Mscaa_34") + "rias" in TEXT and not "s da " + m.group("Mscaa_33") + "ão " + m.group("Mscaa_34") + "rias" in TEXT and not " a " + m.group("Mscaa_33") + "ão " + m.group("Mscaa_34") + "rias" in TEXT and not m.group("Mscaa_33") + "ãa-" + m.group("Mscaa_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_35>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_35").lower() in plvrMascao and not " e " + m.group("Mscaa_35") + "ão " + m.group("Mscaa_36") + "ssimas" in TEXT and not " ou " + m.group("Mscaa_35") + "ão " + m.group("Mscaa_36") + "ssimas" in TEXT and not "s de " + m.group("Mscaa_35") + "ão " + m.group("Mscaa_36") + "ssimas" in TEXT and not "s da " + m.group("Mscaa_35") + "ão " + m.group("Mscaa_36") + "ssimas" in TEXT and not " a " + m.group("Mscaa_35") + "ão " + m.group("Mscaa_36") + "ssimas" in TEXT and not m.group("Mscaa_35") + "ãa-" + m.group("Mscaa_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_37>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_37").lower() in plvrMascao and not " e " + m.group("Mscaa_37") + "ão " + m.group("Mscaa_38") + "simas" in TEXT and not " ou " + m.group("Mscaa_37") + "ão " + m.group("Mscaa_38") + "simas" in TEXT and not "s de " + m.group("Mscaa_37") + "ão " + m.group("Mscaa_38") + "simas" in TEXT and not "s da " + m.group("Mscaa_37") + "ão " + m.group("Mscaa_38") + "simas" in TEXT and not " a " + m.group("Mscaa_37") + "ão " + m.group("Mscaa_38") + "simas" in TEXT and not m.group("Mscaa_37") + "ãa-" + m.group("Mscaa_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_41>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_41").lower() in plvrMascao and not m.group("Mscaa_42") in "D-d-" and not " e " + m.group("Mscaa_41") + "ão " + m.group("Mscaa_42") + "oras" in TEXT and not " ou " + m.group("Mscaa_41") + "ão " + m.group("Mscaa_42") + "oras" in TEXT and not "s de " + m.group("Mscaa_41") + "ão " + m.group("Mscaa_42") + "oras" in TEXT and not "s da " + m.group("Mscaa_41") + "ão " + m.group("Mscaa_42") + "oras" in TEXT and not " a " + m.group("Mscaa_41") + "ão " + m.group("Mscaa_42") + "oras" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_43>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_43").lower() in plvrMascao and m.group("Mscaa_44") in plvrMfr and not " e " + m.group("Mscaa_43") + "ão " + m.group("Mscaa_44") + "es" in TEXT and not " ou " + m.group("Mscaa_43") + "ão " + m.group("Mscaa_44") + "es" in TEXT and not "s de " + m.group("Mscaa_43") + "ão " + m.group("Mscaa_44") + "es" in TEXT and not "s da " + m.group("Mscaa_43") + "ão " + m.group("Mscaa_44") + "es" in TEXT and not " a " + m.group("Mscaa_43") + "ão " + m.group("Mscaa_44") + "es" in TEXT and not m.group("Mscaa_43") + "ãa-" + m.group("Mscaa_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_45>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_45").lower() in plvrMascao and m.group("Mscaa_46") in plvrFemr and not " e " + m.group("Mscaa_45") + "ão " + m.group("Mscaa_46") + "es" in TEXT and not " ou " + m.group("Mscaa_45") + "ão " + m.group("Mscaa_46") + "es" in TEXT and not "s de " + m.group("Mscaa_45") + "ão " + m.group("Mscaa_46") + "es" in TEXT and not "s da " + m.group("Mscaa_45") + "ão " + m.group("Mscaa_46") + "es" in TEXT and not " a " + m.group("Mscaa_45") + "ão " + m.group("Mscaa_46") + "es" in TEXT and not m.group("Mscaa_45") + "ãa-" + m.group("Mscaa_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_47>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_47").lower() in plvrMascao and m.group("Mscaa_48") in plvrMfal and not " e " + m.group("Mscaa_47") + "ão " + m.group("Mscaa_48") + "is" in TEXT and not " ou " + m.group("Mscaa_47") + "ão " + m.group("Mscaa_48") + "is" in TEXT and not "s de " + m.group("Mscaa_47") + "ão " + m.group("Mscaa_48") + "is" in TEXT and not "s da " + m.group("Mscaa_47") + "ão " + m.group("Mscaa_48") + "is" in TEXT and not " a " + m.group("Mscaa_47") + "ão " + m.group("Mscaa_48") + "is" in TEXT and not m.group("Mscaa_47") + "ãa-" + m.group("Mscaa_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_49>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_49").lower() in plvrMascao and m.group("Mscaa_50") in plvrMfcao and not " e " + m.group("Mscaa_49") + "ão " + m.group("Mscaa_50") + "ões" in TEXT and not + " ou " + m.group("Mscaa_49") + "ão " + m.group("Mscaa_50") + "ões" in TEXT and not + "s de " + m.group("Mscaa_49") + "ão " + m.group("Mscaa_50") + "ões" in TEXT and not + "s da " + m.group("Mscaa_49") + "ão " + m.group("Mscaa_50") + "ões" in TEXT and not + " a " + m.group("Mscaa_49") + "ão " + m.group("Mscaa_50") + "ões" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_51>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_51").lower() in plvrMascao and not m.group("Mscaa_52") in plvrMascao and not " e " + m.group("Mscaa_51") + "ão " + m.group("Mscaa_52") + "ões" in TEXT and not " ou " + m.group("Mscaa_51") + "ão " + m.group("Mscaa_52") + "ões" in TEXT and not "s de " + m.group("Mscaa_51") + "ão " + m.group("Mscaa_52") + "ões" in TEXT and not "s da " + m.group("Mscaa_51") + "ão " + m.group("Mscaa_52") + "ões" in TEXT and not " a " + m.group("Mscaa_51") + "ão " + m.group("Mscaa_52") + "ões" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_53>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_53").lower() in plvrMascao and m.group("Mscaa_54") in plvrFemao and not " e " + m.group("Mscaa_53") + "ão " + m.group("Mscaa_54") + "ões" in TEXT and not " ou " + m.group("Mscaa_53") + "ão " + m.group("Mscaa_54") + "ões" in TEXT and not "s de " + m.group("Mscaa_53") + "ão " + m.group("Mscaa_54") + "ões" in TEXT and not "s da " + m.group("Mscaa_53") + "ão " + m.group("Mscaa_54") + "ões" in TEXT and not " a " + m.group("Mscaa_53") + "ão " + m.group("Mscaa_54")+"õ"+"es" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_55>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_55").lower() in plvrMascao and not " e " + m.group("Mscaa_55") + "ão " + m.group("Mscaa_56") + "veis" in TEXT and not " ou " + m.group("Mscaa_55") + "ão " + m.group("Mscaa_56") + "veis" in TEXT and not "s de " + m.group("Mscaa_55") + "ão " + m.group("Mscaa_56") + "veis" in TEXT and not "s da " + m.group("Mscaa_55") + "ão " + m.group("Mscaa_56") + "veis" in TEXT and not " a " + m.group("Mscaa_55") + "ão " + m.group("Mscaa_56") + "veis" in TEXT and not m.group("Mscaa_55") + "ãa-" + m.group("Mscaa_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_57>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_57").lower() in plvrMascao and m.group("Mscaa_58").lower() in plvrMfe and not " e " + m.group("Mscaa_57") + "ão " + m.group("Mscaa_58") + "es" in TEXT and not " ou " + m.group("Mscaa_57") + "ão " + m.group("Mscaa_58") + "es" in TEXT and not "s de " + m.group("Mscaa_57") + "ão " + m.group("Mscaa_58") + "es" in TEXT and not "s da " + m.group("Mscaa_57") + "ão " + m.group("Mscaa_58") + "es" in TEXT and not " a " + m.group("Mscaa_57") + "ão " + m.group("Mscaa_58") + "es" in TEXT and not m.group("Mscaa_57") + "ãa-" + m.group("Mscaa_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_59>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_59").lower() in plvrMascao and m.group("Mscaa_60").lower() in plvrFeme and not " e " + m.group("Mscaa_59") + "ão " + m.group("Mscaa_60") + "es" in TEXT and not " ou " + m.group("Mscaa_59") + "ão " + m.group("Mscaa_60") + "es" in TEXT and not "s de " + m.group("Mscaa_59") + "ão " + m.group("Mscaa_60") + "es" in TEXT and not "s da " + m.group("Mscaa_59") + "ão " + m.group("Mscaa_60") + "es" in TEXT and not " a " + m.group("Mscaa_59") + "ão " + m.group("Mscaa_60") + "es" in TEXT and not m.group("Mscaa_59") + "ãa-" + m.group("Mscaa_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_61>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_61").lower() in plvrMascao and m.group("Mscaa_62") in plvrMfel and not " e " + m.group("Mscaa_61") + "ão " + m.group("Mscaa_62") + "éis" in TEXT and not " ou " + m.group("Mscaa_61") + "ão " + m.group("Mscaa_62") + "éis" in TEXT and not "s de " + m.group("Mscaa_61") + "ão " + m.group("Mscaa_62") + "éis" in TEXT and not "s da " + m.group("Mscaa_61") + "ão " + m.group("Mscaa_62") + "éis" in TEXT and not " a " + m.group("Mscaa_61") + "ão " + m.group("Mscaa_62") + "éis" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_63>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_63").lower() in plvrMascao and m.group("Mscaa_64") in plvrFemel and not " e " + m.group("Mscaa_63") + "ão " + m.group("Mscaa_64") + "éis" in TEXT and not " ou " + m.group("Mscaa_63") + "ão " + m.group("Mscaa_64") + "éis" in TEXT and not "s de " + m.group("Mscaa_63") + "ão " + m.group("Mscaa_64") + "éis" in TEXT and not "s da " + m.group("Mscaa_63") + "ão " + m.group("Mscaa_64") + "éis" in TEXT and not " a " + m.group("Mscaa_63") + "ão " + m.group("Mscaa_64") + "éis" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_65>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_65").lower() in plvrMascao and m.group("Mscaa_66") in plvrMfeu and not " e " + m.group("Mscaa_65") + "ão " + m.group("Mscaa_66") + "us" in TEXT and not " ou " + m.group("Mscaa_65") + "ão " + m.group("Mscaa_66") + "us" in TEXT and not "s de " + m.group("Mscaa_65") + "ão " + m.group("Mscaa_66") + "us" in TEXT and not "s da " + m.group("Mscaa_65") + "ão " + m.group("Mscaa_66") + "us" in TEXT and not " a " + m.group("Mscaa_65") + "ão " + m.group("Mscaa_66") + "us" in TEXT and not m.group("Mscaa_65") + "ãa-" + m.group("Mscaa_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_67>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_67").lower() in plvrMascao and m.group("Mscaa_68") in plvrFemu and not " e " + m.group("Mscaa_67") + "ão " + m.group("Mscaa_68") + "us" in TEXT and not " ou " + m.group("Mscaa_67") + "ão " + m.group("Mscaa_68") + "us" in TEXT and not "s de " + m.group("Mscaa_67") + "ão " + m.group("Mscaa_68") + "us" in TEXT and not "s da " + m.group("Mscaa_67") + "ão " + m.group("Mscaa_68") + "us" in TEXT and not " a " + m.group("Mscaa_67") + "ão " + m.group("Mscaa_68") + "us" in TEXT and not m.group("Mscaa_67") + "ãa-" + m.group("Mscaa_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_69>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_69").lower() in plvrMascao and m.group("Mscaa_70") in plvrInvaz and not " e " + m.group("Mscaa_69") + "ão " + m.group("Mscaa_70") + "zes" in TEXT and not " ou " + m.group("Mscaa_69") + "ão " + m.group("Mscaa_70") + "zes" in TEXT and not "s de " + m.group("Mscaa_69") + "ão " + m.group("Mscaa_70") + "zes" in TEXT and not "s da " + m.group("Mscaa_69") + "ão " + m.group("Mscaa_70") + "zes" in TEXT and not " a " + m.group("Mscaa_69") + "ão " + m.group("Mscaa_70") + "zes" in TEXT and not m.group("Mscaa_69") + "ãa-" + m.group("Mscaa_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_71>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_71").lower() in plvrMascao and m.group("Mscaa_72") in plvrFemz and not " e " + m.group("Mscaa_71") + "ão " + m.group("Mscaa_72") + "zes" in TEXT and not " ou " + m.group("Mscaa_71") + "ão " + m.group("Mscaa_72") + "zes" in TEXT and not "s de " + m.group("Mscaa_71") + "ão " + m.group("Mscaa_72") + "zes" in TEXT and not "s da " + m.group("Mscaa_71") + "ão " + m.group("Mscaa_72") + "zes" in TEXT and not " a " + m.group("Mscaa_71") + "ão " + m.group("Mscaa_72") + "zes" in TEXT and not m.group("Mscaa_71") + "ãa-" + m.group("Mscaa_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_73>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_73").lower() in plvrMascao and m.group("Mscaa_74") in pvrFeman and not " e " + m.group("Mscaa_73") + "ão " + m.group("Mscaa_74") + "s" in TEXT and not " ou " + m.group("Mscaa_73") + "ão " + m.group("Mscaa_74") + "s" in TEXT and not "s de " + m.group("Mscaa_73") + "ão " + m.group("Mscaa_74") + "s" in TEXT and not "s da " + m.group("Mscaa_73") + "ão " + m.group("Mscaa_74") + "s" in TEXT and not " a " + m.group("Mscaa_73") + "ão " + m.group("Mscaa_74") + "s" in TEXT and not m.group("Mscaa_73") + "ãa-" + m.group("Mscaa_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_99>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_99").lower() in plvrMascao and m.group("Mscaa_100") in plvrMFm and not " e " + m.group("Mscaa_99") + "ão " + m.group("Mscaa_100") + "ns" in TEXT and not " ou " + m.group("Mscaa_99") + "ão " + m.group("Mscaa_100") + "ns" in TEXT and not "s de " + m.group("Mscaa_99") + "ão " + m.group("Mscaa_100") + "ns" in TEXT and not "s da " + m.group("Mscaa_99") + "ão " + m.group("Mscaa_100") + "ns" in TEXT and not " a " + m.group("Mscaa_99") + "ão " + m.group("Mscaa_100") + "ns" in TEXT and not m.group("Mscaa_99") + "ãa-"+m.group("Mscaa_100")+"ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_101>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Mscaa_101").lower() in plvrMascao and m.group("Mscaa_102") in plvrFemm and not " e " + m.group("Mscaa_101") + "ão " + m.group("Mscaa_102") + "ns" in TEXT and not " ou " + m.group("Mscaa_101") + "ão " + m.group("Mscaa_102") + "ns" in TEXT and not "s de " + m.group("Mscaa_101") + "ão " + m.group("Mscaa_102") + "ns" in TEXT and not "s da " + m.group("Mscaa_101") + "ão " + m.group("Mscaa_102") + "ns" in TEXT and not " a " + m.group("Mscaa_101") + "ão " + m.group("Mscaa_102") + "ns" in TEXT'],
# plvrMascao o - palavras masculinas
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_1>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_1").lower() in plvrMascao and m.group("Mscao_2").lower() in plvrMasca and not " e " + m.group("Mscao_1") + "ão " + m.group("Mscao_2") +"s" in TEXT and not " ou " + m.group("Mscao_1") + "ão " + m.group("Mscao_2") + "s" in TEXT and not "s de " + m.group("Mscao_1") + "ão " + m.group("Mscao_2") + "s" in TEXT and not "s do " + m.group("Mscao_1") + "ão " + m.group("Mscao_2") + "s" in TEXT and not " o " + m.group("Mscao_1") + "ão " + m.group("Mscao_2") + "s" in TEXT and not m.group("Mscao_1") + "ão-" + m.group("Mscao_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_3>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_4>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_3").lower() in plvrMascao and m.group("Mscao_4").lower() in plvrMfoa and not " e " + m.group("Mscao_3") + "ão " + m.group("Mscao_4") + "os" in TEXT and not " ou " + m.group("Mscao_3") + "ão " + m.group("Mscao_4") + "os" in TEXT and not "s de " + m.group("Mscao_3") + "ão " + m.group("Mscao_4") + "os" in TEXT and not "s do " + m.group("Mscao_3") + "ão " + m.group("Mscao_4") + "os" in TEXT and not " o " + m.group("Mscao_3") + "ão " + m.group("Mscao_4") + "os" in TEXT and not m.group("Mscao_3") + "ão-" + m.group("Mscao_4") + "os" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_5>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_5").lower() in plvrMascao and not m.group("Mscao_6").lower() in excAdo and not " e " + m.group("Mscao_5") + "ão " + m.group("Mscao_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Mscao_5") + "ão " + m.group("Mscao_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Mscao_5") + "ão " + m.group("Mscao_6") + m.group(3) + "dos" in TEXT and not "s do " + m.group("Mscao_5") + "ão " + m.group("Mscao_6") + m.group(3) + "dos" in TEXT and not " o " + m.group("Mscao_5") + "ão " + m.group("Mscao_6") + m.group(3) + "dos" in TEXT and not m.group("Mscao_5") + "ão-" + m.group("Mscao_6") + m.group(3) + "dos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_7>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_7").lower() in plvrMascao and not m.group("Mscao_8").lower() in excIsta and not " e " + m.group("Mscao_7") + "ão " + m.group("Mscao_8") + "s" in TEXT and not " ou " + m.group("Mscao_7") + "ão " + m.group("Mscao_8") + "s" in TEXT and not "s de " + m.group("Mscao_7") + "ão " + m.group("Mscao_8") + "s" in TEXT and not "s do " + m.group("Mscao_7") + "ão " + m.group("Mscao_8") + "s" in TEXT and not " o " + m.group("Mscao_7") + "ão " + m.group("Mscao_8") + "s" in TEXT and not m.group("Mscao_7") + "ão-" + m.group("Mscao_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_9>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_9").lower() in plvrMascao and m.group("Mscao_10").lower() in plvrInva and not " e " + m.group("Mscao_9") + "ão " + m.group("Mscao_10") + "s" in TEXT and not " ou " + m.group("Mscao_9") + "ão " + m.group("Mscao_10") + "s" in TEXT and not "s de " + m.group("Mscao_9") + "ão " + m.group("Mscao_10") + "s" in TEXT and not "s do " + m.group("Mscao_9") + "ão " + m.group("Mscao_10") + "s" in TEXT and not " a " + m.group("Mscao_9") + "ão " + m.group("Mscao_10") + "s" in TEXT and not m.group("Mscao_9") + "ão-" + m.group("Mscao_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_11>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_11").lower() in plvrMascao and not m.group("Mscao_12").lower() in excAdo and not " e " + m.group("Mscao_11") + "ão " + m.group("Mscao_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Mscao_11") + "ão " + m.group("Mscao_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Mscao_11") + "ão " + m.group("Mscao_12") + m.group(3) + "das" in TEXT and not "s do " + m.group("Mscao_11") + "ão " + m.group("Mscao_12") + m.group(3) + "das" in TEXT and not " o " + m.group("Mscao_11") + "ão " + m.group("Mscao_12") + m.group(3) + "das" in TEXT and not m.group("Mscao_11") + "ão-" + m.group("Mscao_12") + m.group(3) + "das" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_13>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_14>[a-zç]+)osos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_13").lower() in plvrMascao and not " e " + m.group("Mscao_13") + "ão " + m.group("Mscao_14") + "osos" in TEXT and not " ou " + m.group("Mscao_13") + "ão " + m.group("Mscao_14") + "osos" in TEXT and not "s de " + m.group("Mscao_13") + "ão " + m.group("Mscao_14") + "osos" in TEXT and not "s do " + m.group("Mscao_13") + "ão " + m.group("Mscao_14") + "osos" in TEXT and not " o " + m.group("Mscao_13") + "ão " + m.group("Mscao_14") + "osos" in TEXT and not m.group("Mscao_13") + "ão-" + m.group("Mscao_14") + "osos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_15>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_15").lower() in plvrMascao and not " e " + m.group("Mscao_15") + "ão " + m.group("Mscao_16") + "osas" in TEXT and not " ou " + m.group("Mscao_15") + "ão " + m.group("Mscao_16") + "osas" in TEXT and not "s de " + m.group("Mscao_15") + "ão " + m.group("Mscao_16") + "osas" in TEXT and not "s do " + m.group("Mscao_15") + "ão " + m.group("Mscao_16") + "osas" in TEXT and not " o " + m.group("Mscao_15") + "ão " + m.group("Mscao_16") + "osas" in TEXT and not m.group("Mscao_15") + "ão-" + m.group("Mscao_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_17>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_17").lower() in plvrMascao and not " e " + m.group("Mscao_17") + "ão " + m.group("Mscao_18") + "ivas" in TEXT and not " ou " + m.group("Mscao_17") + "ão " + m.group("Mscao_18") + "ivas" in TEXT and not "s de " + m.group("Mscao_17") + "ão " + m.group("Mscao_18") + "ivas" in TEXT and not "s do " + m.group("Mscao_17") + "ão " + m.group("Mscao_18") + "ivas" in TEXT and not " o " + m.group("Mscao_17") + "ão " + m.group("Mscao_18") + "ivas" in TEXT and not m.group("Mscao_17") + "ão-" + m.group("Mscao_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_19>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_20>[a-zç]+)ivos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_19").lower() in plvrMascao and not " e " + m.group("Mscao_19") + "ão " + m.group("Mscao_20") + "ivas" in TEXT and not " ou " + m.group("Mscao_19") + "ão " + m.group("Mscao_20") + "ivas" in TEXT and not "s de " + m.group("Mscao_19") + "ão " + m.group("Mscao_20") + "ivas" in TEXT and not "s do " + m.group("Mscao_19") + "ão " + m.group("Mscao_20") + "ivas" in TEXT and not " o " + m.group("Mscao_19") + "ão " + m.group("Mscao_20") + "ivas" in TEXT and not m.group("Mscao_19") + "ão-" + m.group("Mscao_20") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_21>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_22>[a-zç]+[âêô][mn])icos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_21").lower() in plvrMascao and not " e " + m.group("Mscao_21") + "ão " + m.group("Mscao_22") + "icos" in TEXT and not " ou " + m.group("Mscao_21") + "ão " + m.group("Mscao_22") + "icos" in TEXT and not "s de " + m.group("Mscao_21") + "ão " + m.group("Mscao_22") + "icos" in TEXT and not "s do " + m.group("Mscao_21") + "ão " + m.group("Mscao_22") + "icos" in TEXT and not " o " + m.group("Mscao_21") + "ão " + m.group("Mscao_22") + "icos" in TEXT and not m.group("Mscao_21") + "ão-" + m.group("Mscao_22") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_23>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_23").lower() in plvrMascao and not " e " + m.group("Mscao_23") + "ão " + m.group("Mscao_24") + "icos" in TEXT and not " ou " + m.group("Mscao_23") + "ão " + m.group("Mscao_24") + "icos" in TEXT and not "s de " + m.group("Mscao_23") + "ão " + m.group("Mscao_24") + "icos" in TEXT and not "s do " + m.group("Mscao_23") + "ão " + m.group("Mscao_24") + "icos" in TEXT and not " o " + m.group("Mscao_23") + "ão " + m.group("Mscao_24") + "icos" in TEXT and not m.group("Mscao_23") + "ão-" + m.group("Mscao_24") + "icos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_25>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_25").lower() in plvrMascao and not " e " + m.group("Mscao_25") + "ão " + m.group("Mscao_26") + "icos" in TEXT and not " ou " + m.group("Mscao_25") + "ão " + m.group("Mscao_26") + "icos" in TEXT and not "s de " + m.group("Mscao_25") + "ão " + m.group("Mscao_26") + "icos" in TEXT and not "s do " + m.group("Mscao_25") + "ão " + m.group("Mscao_26") + "icos" in TEXT and not " o " + m.group("Mscao_25") + "ão " + m.group("Mscao_26") + "icos" in TEXT and not m.group("Mscao_25") + "ão-" + m.group("Mscao_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_27>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_28>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_27").lower() in plvrMascao and not " e " + m.group("Mscao_27") + "ão " + m.group("Mscao_28") + "escos" in TEXT and not " ou " + m.group("Mscao_27") + "ão " + m.group("Mscao_28") + "escos" in TEXT and not "s de " + m.group("Mscao_27") + "ão " + m.group("Mscao_28") + "escos" in TEXT and not "s do " + m.group("Mscao_27") + "ão " + m.group("Mscao_28") + "escos" in TEXT and not " o " + m.group("Mscao_27") + "ão " + m.group("Mscao_28") + "escos" in TEXT and not m.group("Mscao_27") + "ão-" + m.group("Mscao_28") + "escos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_29>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_29").lower() in plvrMascao and not " e " + m.group("Mscao_29") + "ão " + m.group("Mscao_30") + "idos" in TEXT and not " ou " + m.group("Mscao_29") + "s " + m.group("Mscao_30") + "idos" in TEXT and not "s de " + m.group("Mscao_29") + "s " + m.group("Mscao_30") + "idos" in TEXT and not "s do " + m.group("Mscao_29") + "s " + m.group("Mscao_30") + "idos" in TEXT and not " o " + m.group("Mscao_29") + "s " + m.group("Mscao_30") + "idos" in TEXT and not m.group("Mscao_29") + "ão-" + m.group("Mscao_30") + "idos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_31>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_32>[a-zç]+[ó])logos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_31").lower() in plvrMascao and not " e " + m.group("Mscao_31") + "ão " + m.group("Mscao_32") + "logos" in TEXT and not " ou " + m.group("Mscao_31") + "ão " + m.group("Mscao_32") + "logos" in TEXT and not "s de " + m.group("Mscao_31") + "ão " + m.group("Mscao_32") + "logos" in TEXT and not "s do " + m.group("Mscao_31") + "ão " + m.group("Mscao_32") + "logos" in TEXT and not " o " + m.group("Mscao_31") + "ão " + m.group("Mscao_32") + "logos" in TEXT and not m.group("Mscao_31") + "ão-" + m.group("Mscao_32") + "logos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_33>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_34>[a-zç]+[áéíóúâêô])rios(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_33").lower() in plvrMascao and not " e " + m.group("Mscao_33") + "ão " + m.group("Mscao_34") + "rios" in TEXT and not " ou " + m.group("Mscao_33") + "ão " + m.group("Mscao_34") + "rios" in TEXT and not "s de " + m.group("Mscao_33") + "ão " + m.group("Mscao_34") + "rios" in TEXT and not "s do " + m.group("Mscao_33") + "ão " + m.group("Mscao_34") + "rios" in TEXT and not " o " + m.group("Mscao_33") + "ão " + m.group("Mscao_34") + "rios" in TEXT and not m.group("Mscao_33") + "ão-" + m.group("Mscao_34") + "rios" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_35>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_36>[a-zç]+[í])ssimos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_35").lower() in plvrMascao and not " e " + m.group("Mscao_35") + "ão " + m.group("Mscao_36") + "ssimos" in TEXT and not " ou " + m.group("Mscao_35") + "ão " + m.group("Mscao_36") + "ssimos" in TEXT and not "s de " + m.group("Mscao_35") + "ão " + m.group("Mscao_36") + "ssimos" in TEXT and not "s do " + m.group("Mscao_35") + "ão " + m.group("Mscao_36") + "ssimos" in TEXT and not " o " + m.group("Mscao_35") + "ão " + m.group("Mscao_36") + "ssimos" in TEXT and not m.group("Mscao_35") + "ão-" + m.group("Mscao_36") + "ssimos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_37>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_38>[a-zç]+[é])simos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_37").lower() in plvrMascao and not " e " + m.group("Mscao_37") + "ão " + m.group("Mscao_38") + "simos" in TEXT and not " ou " + m.group("Mscao_37") + "ão " + m.group("Mscao_38") + "simos" in TEXT and not "s de " + m.group("Mscao_37") + "ão " + m.group("Mscao_38") + "simos" in TEXT and not "s do " + m.group("Mscao_37") + "ão " + m.group("Mscao_38") + "simos" in TEXT and not " o " + m.group("Mscao_37") + "ão " + m.group("Mscao_38") + "simos" in TEXT and not m.group("Mscao_37") + "ão-" + m.group("Mscao_38") + "simos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_41>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_42>[a-zçáéíóúâêô]+[dst])ores(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_41").lower() in plvrMascao and not m.group("Mscao_42") in "D-d-" and not " e " + m.group("Mscao_41") + "ão " + m.group("Mscao_42") + "ores" in TEXT and not " ou " + m.group("Mscao_41") + "ão " + m.group("Mscao_42") + "ores" in TEXT and not "s de " + m.group("Mscao_41") + "ão " + m.group("Mscao_42") + "ores" in TEXT and not "s do " + m.group("Mscao_41") + "ão " + m.group("Mscao_42") + "ores" in TEXT and not " o " + m.group("Mscao_41") + "ão " + m.group("Mscao_42") + "ores" in TEXT and not m.group("Mscao_41") + "ão-" + m.group("Mscao_42") + "ores" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_43>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_43").lower() in plvrMascao and m.group("Mscao_44") in plvrMfr and not " e " + m.group("Mscao_43") + "ão " + m.group("Mscao_44") + "es" in TEXT and not " ou " + m.group("Mscao_43") + "ão " + m.group("Mscao_44") + "es" in TEXT and not "s de " + m.group("Mscao_43") + "ão " + m.group("Mscao_44") + "es" in TEXT and not "s do " + m.group("Mscao_43") + "ão " + m.group("Mscao_44") + "es" in TEXT and not " o " + m.group("Mscao_43") + "ão " + m.group("Mscao_44") + "es" in TEXT and not m.group("Mscao_43") + "ão-" + m.group("Mscao_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_45>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_45").lower() in plvrMascao and m.group("Mscao_46") in plvrMascr and not " e " + m.group("Mscao_45") + "ão " + m.group("Mscao_46") + "es" in TEXT and not " ou " + m.group("Mscao_45") + "ão " + m.group("Mscao_46") + "es" in TEXT and not "s de " + m.group("Mscao_45") + "ão " + m.group("Mscao_46") + "es" in TEXT and not "s do " + m.group("Mscao_45") + "ão " + m.group("Mscao_46") + "es" in TEXT and not " o " + m.group("Mscao_45") + "ão " + m.group("Mscao_46") + "es" in TEXT and not m.group("Mscao_45") + "ão-" + m.group("Mscao_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_47>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_47").lower() in plvrMascao and m.group("Mscao_48") in plvrMfal and not " e " + m.group("Mscao_47") + "ão " + m.group("Mscao_48") + "is" in TEXT and not " ou " + m.group("Mscao_47") + "ão " + m.group("Mscao_48") + "is" in TEXT and not "s de " + m.group("Mscao_47") + "ão " + m.group("Mscao_48") + "is" in TEXT and not "s do " + m.group("Mscao_47") + "ão " + m.group("Mscao_48") + "is" in TEXT and not " o " + m.group("Mscao_47") + "ão " + m.group("Mscao_48") + "is" in TEXT and not m.group("Mscao_47") + "ão-" + m.group("Mscao_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_49>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_49").lower() in plvrMascao and m.group("Mscao_50") in plvrMfcao and not " e " + m.group("Mscao_49") + "ão " + m.group("Mscao_50") + "ões" in TEXT and not + " ou " + m.group("Mscao_49") + "ão " + m.group("Mscao_50") + "ões" in TEXT and not + "s de " + m.group("Mscao_49") + "ão " + m.group("Mscao_50") + "ões" in TEXT and not + "s do " + m.group("Mscao_49") + "ão " + m.group("Mscao_50") + "ões" in TEXT and not + " a " + m.group("Mscao_49") + "ão " + m.group("Mscao_50") + "ões" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_51>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_51").lower() in plvrMascao and m.group("Mscao_52") in plvrNfemcao and not " e " + m.group("Mscao_51") + "ão " + m.group("Mscao_52") + "ões" in TEXT and not " ou " + m.group("Mscao_51") + "ão " + m.group("Mscao_52") + "ões" in TEXT and not "s de " + m.group("Mscao_51") + "ão " + m.group("Mscao_52") + "ões" in TEXT and not "s do " + m.group("Mscao_51") + "ão " + m.group("Mscao_52") + "ões" in TEXT and not " o " + m.group("Mscao_51") + "ão " + m.group("Mscao_52") + "ões" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_55>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_55").lower() in plvrMascao and not " e " + m.group("Mscao_55") + "ão " + m.group("Mscao_56") + "veis" in TEXT and not " ou " + m.group("Mscao_55") + "ão " + m.group("Mscao_56") + "veis" in TEXT and not "s de " + m.group("Mscao_55") + "ão " + m.group("Mscao_56") + "veis" in TEXT and not "s do " + m.group("Mscao_55") + "ão " + m.group("Mscao_56") + "veis" in TEXT and not " o " + m.group("Mscao_55") + "ão " + m.group("Mscao_56") + "veis" in TEXT and not m.group("Mscao_55") + "ão-" + m.group("Mscao_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_57>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_57").lower() in plvrMascao and m.group("Mscao_58").lower() in plvrMfe and not " e " + m.group("Mscao_57") + "ão " + m.group("Mscao_58") + "es" in TEXT and not " ou " + m.group("Mscao_57") + "ão " + m.group("Mscao_58") + "es" in TEXT and not "s de " + m.group("Mscao_57") + "ão " + m.group("Mscao_58") + "es" in TEXT and not "s do " + m.group("Mscao_57") + "ão " + m.group("Mscao_58") + "es" in TEXT and not " o " + m.group("Mscao_57") + "ão " + m.group("Mscao_58") + "es" in TEXT and not m.group("Mscao_57") + "ão-" + m.group("Mscao_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_59>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_59").lower() in plvrMascao and m.group("Mscao_60").lower() in plvrMasce and not " e " + m.group("Mscao_59") + "ão " + m.group("Mscao_60") + "es" in TEXT and not " ou " + m.group("Mscao_59") + "ão " + m.group("Mscao_60") + "es" in TEXT and not "s de " + m.group("Mscao_59") + "ão " + m.group("Mscao_60") + "es" in TEXT and not "s do " + m.group("Mscao_59") + "ão " + m.group("Mscao_60") + "es" in TEXT and not " o " + m.group("Mscao_59") + "ão " + m.group("Mscao_60") + "es" in TEXT and not m.group("Mscao_59") + "ão-" + m.group("Mscao_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_61>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_61").lower() in plvrMascao and m.group("Mscao_62") in plvrMfel and not " e " + m.group("Mscao_61") + "ão " + m.group("Mscao_62") + "éis" in TEXT and not " ou " + m.group("Mscao_61") + "ão " + m.group("Mscao_62") + "éis" in TEXT and not "s de " + m.group("Mscao_61") + "ão " + m.group("Mscao_62") + "éis" in TEXT and not "s do " + m.group("Mscao_61") + "ão " + m.group("Mscao_62") + "éis" in TEXT and not " o " + m.group("Mscao_61") + "ão " + m.group("Mscao_62") + "éis" in TEXT and not m.group("Mscao_61") + "ão-" + m.group("Mscao_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_63>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_63").lower() in plvrMascao and m.group("Mscao_64") in plvrMascel and not " e " + m.group("Mscao_63") + "ão " + m.group("Mscao_64") + "éis" in TEXT and not " ou " + m.group("Mscao_63") + "ão " + m.group("Mscao_64") + "éis" in TEXT and not "s de " + m.group("Mscao_63") + "ão " + m.group("Mscao_64") + "éis" in TEXT and not "s do " + m.group("Mscao_63") + "ão " + m.group("Mscao_64") + "éis" in TEXT and not " o " + m.group("Mscao_63") + "ão " + m.group("Mscao_64") + "éis" in TEXT and not m.group("Mscao_63") + "ão-" + m.group("Mscao_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_65>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_65").lower() in plvrMascao and m.group("Mscao_66") in plvrMfeu and not " e " + m.group("Mscao_65") + "ão " + m.group("Mscao_66") + "us" in TEXT and not " ou " + m.group("Mscao_65") + "ão " + m.group("Mscao_66") + "us" in TEXT and not "s de " + m.group("Mscao_65") + "ão " + m.group("Mscao_66") + "us" in TEXT and not "s do " + m.group("Mscao_65") + "ão " + m.group("Mscao_66") + "us" in TEXT and not " o " + m.group("Mscao_65") + "ão " + m.group("Mscao_66") + "us" in TEXT and not m.group("Mscao_65") + "ão-" + m.group("Mscao_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_67>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_67").lower() in plvrMascao and m.group("Mscao_68") in plvrMascu and not " e " + m.group("Mscao_67") + "ão " + m.group("Mscao_68") + "us" in TEXT and not " ou " + m.group("Mscao_67") + "ão " + m.group("Mscao_68") + "us" in TEXT and not "s de " + m.group("Mscao_67") + "ão " + m.group("Mscao_68") + "us" in TEXT and not "s do " + m.group("Mscao_67") + "ão " + m.group("Mscao_68") + "us" in TEXT and not " o " + m.group("Mscao_67") + "ão " + m.group("Mscao_68") + "us" in TEXT and not m.group("Mscao_67") + "ão-" + m.group("Mscao_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_69>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_69").lower() in plvrMascao and m.group("Mscao_70") in plvrInvaz and not " e " + m.group("Mscao_69") + "ão " + m.group("Mscao_70") + "zes" in TEXT and not " ou " + m.group("Mscao_69") + "ão " + m.group("Mscao_70") + "zes" in TEXT and not "s de " + m.group("Mscao_69") + "ão " + m.group("Mscao_70") + "zes" in TEXT and not "s do " + m.group("Mscao_69") + "ão " + m.group("Mscao_70") + "zes" in TEXT and not " o " + m.group("Mscao_69") + "ão " + m.group("Mscao_70") + "zes" in TEXT and not m.group("Mscao_69") + "ão-" + m.group("Mscao_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_71>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_71").lower() in plvrMascao and m.group("Mscao_72") in plvrMascz and not " e " + m.group("Mscao_71") + "ão " + m.group("Mscao_72") + "zes" in TEXT and not " ou " + m.group("Mscao_71") + "ão " + m.group("Mscao_72") + "zes" in TEXT and not "s de " + m.group("Mscao_71") + "ão " + m.group("Mscao_72") + "zes" in TEXT and not "s do " + m.group("Mscao_71") + "ão " + m.group("Mscao_72") + "zes" in TEXT and not " o " + m.group("Mscao_71") + "ão " + m.group("Mscao_72") + "zes" in TEXT and not m.group("Mscao_71") + "ão-" + m.group("Mscao_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_73>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_73").lower() in plvrMascao and m.group("Mscao_74") in pvrMascan and not " e " + m.group("Mscao_73") + "ão " + m.group("Mscao_74") + "s" in TEXT and not " ou " + m.group("Mscao_73") + "ão " + m.group("Mscao_74") + "s" in TEXT and not "s de " + m.group("Mscao_73") + "ão " + m.group("Mscao_74") + "s" in TEXT and not "s do " + m.group("Mscao_73") + "ão " + m.group("Mscao_74") + "s" in TEXT and not " o " + m.group("Mscao_73") + "ão " + m.group("Mscao_74") + "s" in TEXT and not m.group("Mscao_73") + "ão-" + m.group("Mscao_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_75>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_76>[a-záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_75").lower() in plvrMascao and m.group("Mscao_76").lower() in plvrMasco and not " e " + m.group("Mscao_75") + "ão " + m.group("Mscao_76") +"s" in TEXT and not " ou " + m.group("Mscao_75") + "ão " + m.group("Mscao_76") + "s" in TEXT and not "s de " + m.group("Mscao_75") + "ão " + m.group("Mscao_76") + "s" in TEXT and not "s do " + m.group("Mscao_75") + "ão " + m.group("Mscao_76") + "s" in TEXT and not " o " + m.group("Mscao_75") + "ão " + m.group("Mscao_76") + "s" in TEXT and not m.group("Mscao_75") + "ão-" + m.group("Mscao_76") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_77>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_78>[a-zç]+)inhos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "inhos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_77").lower() in plvrMascao and not " e " + m.group("Mscao_77") + "ão " + m.group("Mscao_78") + "inhos" in TEXT and not " ou " + m.group("Mscao_77") + "ão " + m.group("Mscao_78") + "inhos" in TEXT and not "s de " + m.group("Mscao_77") + "ão " + m.group("Mscao_78") + "inhos" in TEXT and not "s do " + m.group("Mscao_77") + "ão " + m.group("Mscao_78") + "inhos" in TEXT and not " o " + m.group("Mscao_77") + "ão " + m.group("Mscao_78") + "inhos" in TEXT and not m.group("Mscao_77") + "ão-" + m.group("Mscao_78") + "inhos" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_79>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_80>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_79").lower() in plvrMascao and not " e " + m.group("Mscao_79") + "ão " + m.group("Mscao_80") + "icas" in TEXT and not " ou " + m.group("Mscao_79") + "ão " + m.group("Mscao_80") + "icas" in TEXT and not "s de " + m.group("Mscao_79") + "ão " + m.group("Mscao_80") + "icas" in TEXT and not "s do " + m.group("Mscao_79") + "ão " + m.group("Mscao_80") + "icas" in TEXT and not " o " + m.group("Mscao_79") + "ão " + m.group("Mscao_80") + "icas" in TEXT and not m.group("Mscao_79") + "ão-" + m.group("Mscao_80") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_81>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_82>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_81").lower() in plvrMascao and not " e " + m.group("Mscao_81") + "ão " + m.group("Mscao_82") + "icas" in TEXT and not " ou " + m.group("Mscao_81") + "ão " + m.group("Mscao_82") + "icas" in TEXT and not "s de " + m.group("Mscao_81") + "ão " + m.group("Mscao_82") + "icas" in TEXT and not "s do " + m.group("Mscao_81") + "ão " + m.group("Mscao_82") + "icas" in TEXT and not " o " + m.group("Mscao_81") + "ão " + m.group("Mscao_82") + "icas" in TEXT and not m.group("Mscao_81") + "ão-" + m.group("Mscao_82") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_83>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_84>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_83").lower() in plvrMascao and not " e " + m.group("Mscao_83") + "ão " + m.group("Mscao_84") + "icas" in TEXT and not " ou " + m.group("Mscao_83") + "ão " + m.group("Mscao_84") + "icas" in TEXT and not "s de " + m.group("Mscao_83") + "ão " + m.group("Mscao_84") + "icas" in TEXT and not "s do " + m.group("Mscao_83") + "ão " + m.group("Mscao_84") + "icas" in TEXT and not " o " + m.group("Mscao_83") + "ão " + m.group("Mscao_84") + "icas" in TEXT and not m.group("Mscao_83") + "ão-" + m.group("Mscao_84") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_85>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_86>[a-zç]+)escos(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_85").lower() in plvrMascao and not " e " + m.group("Mscao_85") + "ão " + m.group("Mscao_86") + "escas" in TEXT and not " ou " + m.group("Mscao_85") + "ão " + m.group("Mscao_86") + "escas" in TEXT and not "s de " + m.group("Mscao_85") + "ão " + m.group("Mscao_86") + "escas" in TEXT and not "s do " + m.group("Mscao_85") + "ão " + m.group("Mscao_86") + "escas" in TEXT and not " o " + m.group("Mscao_85") + "ão " + m.group("Mscao_86") + "escas" in TEXT and not m.group("Mscao_85") + "ão-" + m.group("Mscao_86") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_87>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_88>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_87").lower() in plvrMascao and not " e " + m.group("Mscao_87") + "ão " + m.group("Mscao_88") + "idas" in TEXT and not " ou " + m.group("Mscao_87") + "s " + m.group("Mscao_88") + "idas" in TEXT and not "s de " + m.group("Mscao_87") + "s " + m.group("Mscao_88") + "idas" in TEXT and not "s do " + m.group("Mscao_87") + "s " + m.group("Mscao_88") + "idas" in TEXT and not " o " + m.group("Mscao_87") + "s " + m.group("Mscao_88") + "idas" in TEXT and not m.group("Mscao_87") + "ão-" + m.group("Mscao_88") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_89>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_90>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_89").lower() in plvrMascao and not " e " + m.group("Mscao_89") + "ão " + m.group("Mscao_90") + "logas" in TEXT and not " ou " + m.group("Mscao_89") + "ão " + m.group("Mscao_90") + "logas" in TEXT and not "s de " + m.group("Mscao_89") + "ão " + m.group("Mscao_90") + "logas" in TEXT and not "s do " + m.group("Mscao_89") + "ão " + m.group("Mscao_90") + "logas" in TEXT and not " o " + m.group("Mscao_89") + "ão " + m.group("Mscao_90") + "logas" in TEXT and not m.group("Mscao_89") + "ão-" + m.group("Mscao_90") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_91>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_92>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_91").lower() in plvrMascao and not " e " + m.group("Mscao_91") + "ão " + m.group("Mscao_92") + "rias" in TEXT and not " ou " + m.group("Mscao_91") + "ão " + m.group("Mscao_92") + "rias" in TEXT and not "s de " + m.group("Mscao_91") + "ão " + m.group("Mscao_92") + "rias" in TEXT and not "s do " + m.group("Mscao_91") + "ão " + m.group("Mscao_92") + "rias" in TEXT and not " o " + m.group("Mscao_91") + "ão " + m.group("Mscao_92") + "rias" in TEXT and not m.group("Mscao_91") + "ão-" + m.group("Mscao_92") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_93>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_94>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_93").lower() in plvrMascao and not " e " + m.group("Mscao_93") + "ão " + m.group("Mscao_94") + "ssimas" in TEXT and not " ou " + m.group("Mscao_93") + "ão " + m.group("Mscao_94") + "ssimas" in TEXT and not "s de " + m.group("Mscao_93") + "ão " + m.group("Mscao_94") + "ssimas" in TEXT and not "s do " + m.group("Mscao_93") + "ão " + m.group("Mscao_94") + "ssimas" in TEXT and not " o " + m.group("Mscao_93") + "ão " + m.group("Mscao_94") + "ssimas" in TEXT and not m.group("Mscao_93") + "ão-" + m.group("Mscao_94") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_95>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_96>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_95").lower() in plvrMascao and not " e " + m.group("Mscao_95") + "ão " + m.group("Mscao_96") + "simas" in TEXT and not " ou " + m.group("Mscao_95") + "ão " + m.group("Mscao_96") + "simas" in TEXT and not "s de " + m.group("Mscao_95") + "ão " + m.group("Mscao_96") + "simas" in TEXT and not "s do " + m.group("Mscao_95") + "ão " + m.group("Mscao_96") + "simas" in TEXT and not " o " + m.group("Mscao_95") + "ão " + m.group("Mscao_96") + "simas" in TEXT and not m.group("Mscao_95") + "ão-" + m.group("Mscao_96") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscao_97>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscao_98>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscao_97").lower() in plvrMascao and m.group("Mscao_98").lower() in plvrMascao and not " e " + m.group("Mscao_97") + "ão " + m.group("Mscao_98") + "as" in TEXT and not " ou " + m.group("Mscao_97") + "ão " + m.group("Mscao_98") + "as" in TEXT and not "s de " + m.group("Mscao_97") + "ão " + m.group("Mscao_98") + "as" in TEXT and not "s do " + m.group("Mscao_97") + "ão " + m.group("Mscao_98") + "as" in TEXT and not " o " + m.group("Mscao_97") + "ão " + m.group("Mscao_98") + "as" in TEXT and not m.group("Mscao_97") + "ão-" + m.group("Mscao_98") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_99>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_100>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscaa_99").lower() in plvrMascao and m.group("Mscaa_100") in plvrMFm and not " e " + m.group("Mscaa_99") + "ão " + m.group("Mscaa_100") + "ns" in TEXT and not " ou " + m.group("Mscaa_99") + "ão " + m.group("Mscaa_100") + "ns" in TEXT and not "s de " + m.group("Mscaa_99") + "ão " + m.group("Mscaa_100") + "ns" in TEXT and not "s da " + m.group("Mscaa_99") + "ão " + m.group("Mscaa_100") + "ns" in TEXT and not " a " + m.group("Mscaa_99") + "ão " + m.group("Mscaa_100") + "ns" in TEXT and not m.group("Mscaa_99") + "ão-" + m.group("Mscaa_100") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mscaa_101>[a-zA-Zçáéíóúâêô]+[ç])ão (?P<Mscaa_102>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mscaa_101").lower() in plvrMascao and m.group("Mscaa_102") in plvrMascm and not " e " + m.group("Mscaa_101") + "ão " + m.group("Mscaa_102") + "ns" in TEXT and not " ou " + m.group("Mscaa_101") + "ão " + m.group("Mscaa_102") + "ns" in TEXT and not "s de " + m.group("Mscaa_101") + "ão " + m.group("Mscaa_102") + "ns" in TEXT and not "s da " + m.group("Mscaa_101") + "ão " + m.group("Mscaa_102") + "ns" in TEXT and not " a " + m.group("Mscaa_101") + "ão " + m.group("Mscaa_102") + "ns" in TEXT and not m.group("Mscaa_101") + "ão-" + m.group("Mscaa_102") + "ns" in tCompostops'],
# plvrFemao
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_1>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_2>[a-záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_1").lower() in plvrFemao and m.group("Msfao_2").lower() in plvrFema and not " e " + m.group("Msfao_1") + "ão " + m.group("Msfao_2") +"s" in TEXT and not " ou " + m.group("Msfao_1") + "ão " + m.group("Msfao_2") + "s" in TEXT and not "s de " + m.group("Msfao_1") + "ão " + m.group("Msfao_2") + "s" in TEXT and not "s da " + m.group("Msfao_1") + "ão " + m.group("Msfao_2") + "s" in TEXT and not " a " + m.group("Msfao_1") + "ão " + m.group("Msfao_2") + "s" in TEXT and not m.group("Msfao_1") + "ão-" + m.group("Msfao_2") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_3>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_4>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_3").lower() in plvrFemao and m.group("Msfao_4").lower() in plvrMfoa and not " e " + m.group("Msfao_3") + "ão " + m.group("Msfao_4") + "as" in TEXT and not " ou " + m.group("Msfao_3") + "ão " + m.group("Msfao_4") + "as" in TEXT and not "s de " + m.group("Msfao_3") + "ão " + m.group("Msfao_4") + "as" in TEXT and not "s da " + m.group("Msfao_3") + "ão " + m.group("Msfao_4") + "as" in TEXT and not " a " + m.group("Msfao_3") + "ão " + m.group("Msfao_4") + "as" in TEXT and not m.group("Msfao_3") + "ão-" + m.group("Msfao_4") + "as" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_5>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_6>[a-z]+)([aí])dos(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_5").lower() in plvrFemao and not m.group("Msfao_6").lower() in excAdo and not " e " + m.group("Msfao_5") + "ão " + m.group("Msfao_6") + m.group(3) + "dos" in TEXT and not " ou " + m.group("Msfao_5") + "ão " + m.group("Msfao_6") + m.group(3) + "dos" in TEXT and not "s de " + m.group("Msfao_5") + "ão " + m.group("Msfao_6") + m.group(3) + "dos" in TEXT and not "s da " + m.group("Msfao_5") + "ão " + m.group("Msfao_6") + m.group(3) + "dos" in TEXT and not " a " + m.group("Msfao_5") + "ão " + m.group("Msfao_6") + m.group(3) + "dos" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_7>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_8>[a-z]+ista)s(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_7").lower() in plvrFemao and not m.group("Msfao_8").lower() in excIsta and not " e " + m.group("Msfao_7") + "ão " + m.group("Msfao_8") + "s" in TEXT and not " ou " + m.group("Msfao_7") + "ão " + m.group("Msfao_8") + "s" in TEXT and not "s de " + m.group("Msfao_7") + "ão " + m.group("Msfao_8") + "s" in TEXT and not "s da " + m.group("Msfao_7") + "ão " + m.group("Msfao_8") + "s" in TEXT and not " a " + m.group("Msfao_7") + "ão " + m.group("Msfao_8") + "s" in TEXT and not m.group("Msfao_7") + "ão-" + m.group("Msfao_8") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_9>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_10>[a-z]+a)s(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_9").lower() in plvrFemao and m.group("Msfao_10").lower() in plvrInva and not " e " + m.group("Msfao_9") + "ão " + m.group("Msfao_10") + "s" in TEXT and not " ou " + m.group("Msfao_9") + "ão " + m.group("Msfao_10") + "s" in TEXT and not "s de " + m.group("Msfao_9") + "ão " + m.group("Msfao_10") + "s" in TEXT and not "s da " + m.group("Msfao_9") + "ão " + m.group("Msfao_10") + "s" in TEXT and not " a " + m.group("Msfao_9") + "ão " + m.group("Msfao_10") + "s" in TEXT and not m.group("Msfao_9") + "ão-" + m.group("Msfao_10") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_11>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_12>[a-z]+)([aí])das(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_11").lower() in plvrFemao and not m.group("Msfao_12").lower() in excAdo and not " e " + m.group("Msfao_11") + "ão " + m.group("Msfao_12") + m.group(3) + "das" in TEXT and not " ou " + m.group("Msfao_11") + "ão " + m.group("Msfao_12") + m.group(3) + "das" in TEXT and not "s de " + m.group("Msfao_11") + "ão " + m.group("Msfao_12") + m.group(3) + "das" in TEXT and not "s da " + m.group("Msfao_11") + "ão " + m.group("Msfao_12") + m.group(3) + "das" in TEXT and not " a " + m.group("Msfao_11") + "ão " + m.group("Msfao_12") + m.group(3) + "das" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_15>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_16>[a-zç]+)osas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_15").lower() in plvrFemao and not " e " + m.group("Msfao_15") + "ão " + m.group("Msfao_16") + "osas" in TEXT and not " ou " + m.group("Msfao_15") + "ão " + m.group("Msfao_16") + "osas" in TEXT and not "s de " + m.group("Msfao_15") + "ão " + m.group("Msfao_16") + "osas" in TEXT and not "s da " + m.group("Msfao_15") + "ão " + m.group("Msfao_16") + "osas" in TEXT and not " a " + m.group("Msfao_15") + "ão " + m.group("Msfao_16") + "osas" in TEXT and not m.group("Msfao_15") + "ão-" + m.group("Msfao_16") + "osas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_17>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_18>[a-zç]+)ivas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_17").lower() in plvrFemao and not " e " + m.group("Msfao_17") + "ão " + m.group("Msfao_18") + "ivas" in TEXT and not " ou " + m.group("Msfao_17") + "ão " + m.group("Msfao_18") + "ivas" in TEXT and not "s de " + m.group("Msfao_17") + "ão " + m.group("Msfao_18") + "ivas" in TEXT and not "s da " + m.group("Msfao_17") + "ão " + m.group("Msfao_18") + "ivas" in TEXT and not " a " + m.group("Msfao_17") + "ão " + m.group("Msfao_18") + "ivas" in TEXT and not m.group("Msfao_17") + "ão-" + m.group("Msfao_18") + "ivas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_21>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_22>[a-zç]+[âêô][mn])icas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_21").lower() in plvrFemao and not " e " + m.group("Msfao_21") + "ão " + m.group("Msfao_22") + "icas" in TEXT and not " ou " + m.group("Msfao_21") + "ão " + m.group("Msfao_22") + "icas" in TEXT and not "s de " + m.group("Msfao_21") + "ão " + m.group("Msfao_22") + "icas" in TEXT and not "s da " + m.group("Msfao_21") + "ão " + m.group("Msfao_22") + "icas" in TEXT and not " a " + m.group("Msfao_21") + "ão " + m.group("Msfao_22") + "icas" in TEXT and not m.group("Msfao_21") + "ão-" + m.group("Msfao_22") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_23>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_23").lower() in plvrFemao and not " e " + m.group("Msfao_23") + "ão " + m.group("Msfao_24") + "icas" in TEXT and not " ou " + m.group("Msfao_23") + "ão " + m.group("Msfao_24") + "icas" in TEXT and not "s de " + m.group("Msfao_23") + "ão " + m.group("Msfao_24") + "icas" in TEXT and not "s da " + m.group("Msfao_23") + "ão " + m.group("Msfao_24") + "icas" in TEXT and not " a " + m.group("Msfao_23") + "ão " + m.group("Msfao_24") + "icas" in TEXT and not m.group("Msfao_23") + "ão-" + m.group("Msfao_24") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_25>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])icas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_25").lower() in plvrFemao and not " e " + m.group("Msfao_25") + "ão " + m.group("Msfao_26") + "icas" in TEXT and not " ou " + m.group("Msfao_25") + "ão " + m.group("Msfao_26") + "icas" in TEXT and not "s de " + m.group("Msfao_25") + "ão " + m.group("Msfao_26") + "icas" in TEXT and not "s da " + m.group("Msfao_25") + "ão " + m.group("Msfao_26") + "icas" in TEXT and not " a " + m.group("Msfao_25") + "ão " + m.group("Msfao_26") + "icas" in TEXT and not m.group("Msfao_25") + "ão-" + m.group("Msfao_26") + "icas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_27>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_28>[a-zç]+)escas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_27").lower() in plvrFemao and not " e " + m.group("Msfao_27") + "ão " + m.group("Msfao_28") + "escas" in TEXT and not " ou " + m.group("Msfao_27") + "ão " + m.group("Msfao_28") + "escas" in TEXT and not "s de " + m.group("Msfao_27") + "ão " + m.group("Msfao_28") + "escas" in TEXT and not "s da " + m.group("Msfao_27") + "ão " + m.group("Msfao_28") + "escas" in TEXT and not " a " + m.group("Msfao_27") + "ão " + m.group("Msfao_28") + "escas" in TEXT and not m.group("Msfao_27") + "ão-" + m.group("Msfao_28") + "escas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_29>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])idas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_29").lower() in plvrFemao and not " e " + m.group("Msfao_29") + "ão " + m.group("Msfao_30") + "idas" in TEXT and not " ou " + m.group("Msfao_29") + "s " + m.group("Msfao_30") + "idas" in TEXT and not "s de " + m.group("Msfao_29") + "s " + m.group("Msfao_30") + "idas" in TEXT and not "s da " + m.group("Msfao_29") + "s " + m.group("Msfao_30") + "idas" in TEXT and not " a " + m.group("Msfao_29") + "s " + m.group("Msfao_30") + "idas" in TEXT and not m.group("Msfao_29") + "ão-" + m.group("Msfao_30") + "idas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_31>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_32>[a-zç]+[ó])logas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_31").lower() in plvrFemao and not " e " + m.group("Msfao_31") + "ão " + m.group("Msfao_32") + "logas" in TEXT and not " ou " + m.group("Msfao_31") + "ão " + m.group("Msfao_32") + "logas" in TEXT and not "s de " + m.group("Msfao_31") + "ão " + m.group("Msfao_32") + "logas" in TEXT and not "s da " + m.group("Msfao_31") + "ão " + m.group("Msfao_32") + "logas" in TEXT and not " a " + m.group("Msfao_31") + "ão " + m.group("Msfao_32") + "logas" in TEXT and not m.group("Msfao_31") + "ão-" + m.group("Msfao_32") + "logas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_33>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_34>[a-zç]+[áéíóúâêô])rias(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_33").lower() in plvrFemao and not " e " + m.group("Msfao_33") + "ão " + m.group("Msfao_34") + "rias" in TEXT and not " ou " + m.group("Msfao_33") + "ão " + m.group("Msfao_34") + "rias" in TEXT and not "s de " + m.group("Msfao_33") + "ão " + m.group("Msfao_34") + "rias" in TEXT and not "s da " + m.group("Msfao_33") + "ão " + m.group("Msfao_34") + "rias" in TEXT and not " a " + m.group("Msfao_33") + "ão " + m.group("Msfao_34") + "rias" in TEXT and not m.group("Msfao_33") + "ão-" + m.group("Msfao_34") + "rias" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_35>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_36>[a-zç]+[í])ssimas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_35").lower() in plvrFemao and not " e " + m.group("Msfao_35") + "ão " + m.group("Msfao_36") + "ssimas" in TEXT and not " ou " + m.group("Msfao_35") + "ão " + m.group("Msfao_36") + "ssimas" in TEXT and not "s de " + m.group("Msfao_35") + "ão " + m.group("Msfao_36") + "ssimas" in TEXT and not "s da " + m.group("Msfao_35") + "ão " + m.group("Msfao_36") + "ssimas" in TEXT and not " a " + m.group("Msfao_35") + "ão " + m.group("Msfao_36") + "ssimas" in TEXT and not m.group("Msfao_35") + "ão-" + m.group("Msfao_36") + "ssimas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_37>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_38>[a-zç]+[é])simas(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_37").lower() in plvrFemao and not " e " + m.group("Msfao_37") + "ão " + m.group("Msfao_38") + "simas" in TEXT and not " ou " + m.group("Msfao_37") + "ão " + m.group("Msfao_38") + "simas" in TEXT and not "s de " + m.group("Msfao_37") + "ão " + m.group("Msfao_38") + "simas" in TEXT and not "s da " + m.group("Msfao_37") + "ão " + m.group("Msfao_38") + "simas" in TEXT and not " a " + m.group("Msfao_37") + "ão " + m.group("Msfao_38") + "simas" in TEXT and not m.group("Msfao_37") + "ão-" + m.group("Msfao_38") + "simas" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_41>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_42>[a-zçáéíóúâêô]+[dst])oras(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_41").lower() in plvrFemao and not m.group("Msfao_42") in "D-d-" and not " e " + m.group("Msfao_41") + "ão " + m.group("Msfao_42") + "oras" in TEXT and not " ou " + m.group("Msfao_41") + "ão " + m.group("Msfao_42") + "oras" in TEXT and not "s de " + m.group("Msfao_41") + "ão " + m.group("Msfao_42") + "oras" in TEXT and not "s da " + m.group("Msfao_41") + "ão " + m.group("Msfao_42") + "oras" in TEXT and not " a " + m.group("Msfao_41") + "ão " + m.group("Msfao_42") + "oras" in TEXT and not m.group("Msfao_41") + "ão-" + m.group("Msfao_42") + "oras" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_43>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_44>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_43").lower() in plvrFemao and m.group("Msfao_44") in plvrMfr and not " e " + m.group("Msfao_43") + "ão " + m.group("Msfao_44") + "es" in TEXT and not " ou " + m.group("Msfao_43") + "ão " + m.group("Msfao_44") + "es" in TEXT and not "s de " + m.group("Msfao_43") + "ão " + m.group("Msfao_44") + "es" in TEXT and not "s da " + m.group("Msfao_43") + "ão " + m.group("Msfao_44") + "es" in TEXT and not " a " + m.group("Msfao_43") + "ão " + m.group("Msfao_44") + "es" in TEXT and not m.group("Msfao_43") + "ão-" + m.group("Msfao_44") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_45>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_46>[a-zçáéíóúâêô]+r)es(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_45").lower() in plvrFemao and m.group("Msfao_46") in plvrFemr and not " e " + m.group("Msfao_45") + "ão " + m.group("Msfao_46") + "es" in TEXT and not " ou " + m.group("Msfao_45") + "ão " + m.group("Msfao_46") + "es" in TEXT and not "s de " + m.group("Msfao_45") + "ão " + m.group("Msfao_46") + "es" in TEXT and not "s da " + m.group("Msfao_45") + "ão " + m.group("Msfao_46") + "es" in TEXT and not " a " + m.group("Msfao_45") + "ão " + m.group("Msfao_46") + "es" in TEXT and not m.group("Msfao_45") + "ão-" + m.group("Msfao_46") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_47>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_48>[a-zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_47").lower() in plvrFemao and m.group("Msfao_48") in plvrMfal and not " e " + m.group("Msfao_47") + "ão " + m.group("Msfao_48") + "is" in TEXT and not " ou " + m.group("Msfao_47") + "ão " + m.group("Msfao_48") + "is" in TEXT and not "s de " + m.group("Msfao_47") + "ão " + m.group("Msfao_48") + "is" in TEXT and not "s da " + m.group("Msfao_47") + "ão " + m.group("Msfao_48") + "is" in TEXT and not " a " + m.group("Msfao_47") + "ão " + m.group("Msfao_48") + "is" in TEXT and not m.group("Msfao_47") + "ão-" + m.group("Msfao_48") + "is" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_49>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_50>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_49").lower() in plvrFemao and m.group("Msfao_50") in plvrMfcao and not " e " + m.group("Msfao_49") + "ão " + m.group("Msfao_50") + "ões" in TEXT and not + " ou " + m.group("Msfao_49") + "ão " + m.group("Msfao_50") + "ões" in TEXT and not + "s de " + m.group("Msfao_49") + "ão " + m.group("Msfao_50") + "ões" in TEXT and not + "s da " + m.group("Msfao_49") + "ão " + m.group("Msfao_50") + "ões" in TEXT and not + " a " + m.group("Msfao_49") + "ão " + m.group("Msfao_50") + "ões" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_51>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_52>[a-zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_51").lower() in plvrFemao and not m.group("Msfao_52") in plvrMascao and not " e " + m.group("Msfao_51") + "ão " + m.group("Msfao_52") + "ões" in TEXT and not " ou " + m.group("Msfao_51") + "ão " + m.group("Msfao_52") + "ões" in TEXT and not "s de " + m.group("Msfao_51") + "ão " + m.group("Msfao_52") + "ões" in TEXT and not "s da " + m.group("Msfao_51") + "ão " + m.group("Msfao_52") + "ões" in TEXT and not " a " + m.group("Msfao_51") + "ão " + m.group("Msfao_52") + "ões" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_53>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_53").lower() in plvrFemao and m.group("Msfao_54") in plvrFemao and not " e " + m.group("Msfao_53") + "ão " + m.group("Msfao_54") + "ões" in TEXT and not " ou " + m.group("Msfao_53") + "ão " + m.group("Msfao_54") + "ões" in TEXT and not "s de " + m.group("Msfao_53") + "ão " + m.group("Msfao_54") + "ões" in TEXT and not "s da " + m.group("Msfao_53") + "ão " + m.group("Msfao_54") + "ões" in TEXT and not " a " + m.group("Msfao_53") + "ão " + m.group("Msfao_54") + "ões" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_55>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_56>[a-zç]+[áéíóú])veis(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_55").lower() in plvrFemao and not " e " + m.group("Msfao_55") + "ão " + m.group("Msfao_56") + "veis" in TEXT and not " ou " + m.group("Msfao_55") + "ão " + m.group("Msfao_56") + "veis" in TEXT and not "s de " + m.group("Msfao_55") + "ão " + m.group("Msfao_56") + "veis" in TEXT and not "s da " + m.group("Msfao_55") + "ão " + m.group("Msfao_56") + "veis" in TEXT and not " a " + m.group("Msfao_55") + "ão " + m.group("Msfao_56") + "veis" in TEXT and not m.group("Msfao_55") + "ão-" + m.group("Msfao_56") + "veis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_57>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_58>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_57").lower() in plvrFemao and m.group("Msfao_58").lower() in plvrMfe and not " e " + m.group("Msfao_57") + "ão " + m.group("Msfao_58") + "es" in TEXT and not " ou " + m.group("Msfao_57") + "ão " + m.group("Msfao_58") + "es" in TEXT and not "s de " + m.group("Msfao_57") + "ão " + m.group("Msfao_58") + "es" in TEXT and not "s da " + m.group("Msfao_57") + "ão " + m.group("Msfao_58") + "es" in TEXT and not " a " + m.group("Msfao_57") + "ão " + m.group("Msfao_58") + "es" in TEXT and not m.group("Msfao_57") + "ão-" + m.group("Msfao_58") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_59>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_60>[a-zçáéíóúâêô]+)es(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_59").lower() in plvrFemao and m.group("Msfao_60").lower() in plvrFeme and not " e " + m.group("Msfao_59") + "ão " + m.group("Msfao_60") + "es" in TEXT and not " ou " + m.group("Msfao_59") + "ão " + m.group("Msfao_60") + "es" in TEXT and not "s de " + m.group("Msfao_59") + "ão " + m.group("Msfao_60") + "es" in TEXT and not "s da " + m.group("Msfao_59") + "ão " + m.group("Msfao_60") + "es" in TEXT and not " a " + m.group("Msfao_59") + "ão " + m.group("Msfao_60") + "es" in TEXT and not m.group("Msfao_59") + "ão-" + m.group("Msfao_60") + "es" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_61>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_62>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_61").lower() in plvrFemao and m.group("Msfao_62") in plvrMfel and not " e " + m.group("Msfao_61") + "ão " + m.group("Msfao_62") + "éis" in TEXT and not " ou " + m.group("Msfao_61") + "ão " + m.group("Msfao_62") + "éis" in TEXT and not "s de " + m.group("Msfao_61") + "ão " + m.group("Msfao_62") + "éis" in TEXT and not "s da " + m.group("Msfao_61") + "ão " + m.group("Msfao_62") + "éis" in TEXT and not " a " + m.group("Msfao_61") + "ão " + m.group("Msfao_62") + "éis" in TEXT and not m.group("Msfao_61") + "ão-" + m.group("Msfao_62") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_63>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_64>[a-z]+)éis(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_63").lower() in plvrFemao and m.group("Msfao_64") in plvrFemel and not " e " + m.group("Msfao_63") + "ão " + m.group("Msfao_64") + "éis" in TEXT and not " ou " + m.group("Msfao_63") + "ão " + m.group("Msfao_64") + "éis" in TEXT and not "s de " + m.group("Msfao_63") + "ão " + m.group("Msfao_64") + "éis" in TEXT and not "s da " + m.group("Msfao_63") + "ão " + m.group("Msfao_64") + "éis" in TEXT and not " a " + m.group("Msfao_63") + "ão " + m.group("Msfao_64") + "éis" in TEXT and not m.group("Msfao_63") + "ão-" + m.group("Msfao_64") + "éis" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_65>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_66>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_65").lower() in plvrFemao and m.group("Msfao_66") in plvrMfeu and not " e " + m.group("Msfao_65") + "ão " + m.group("Msfao_66") + "us" in TEXT and not " ou " + m.group("Msfao_65") + "ão " + m.group("Msfao_66") + "us" in TEXT and not "s de " + m.group("Msfao_65") + "ão " + m.group("Msfao_66") + "us" in TEXT and not "s da " + m.group("Msfao_65") + "ão " + m.group("Msfao_66") + "us" in TEXT and not " a " + m.group("Msfao_65") + "ão " + m.group("Msfao_66") + "us" in TEXT and not m.group("Msfao_65") + "ão-" + m.group("Msfao_66") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_67>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_68>[a-zçáéíóúâêô]+)us(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_67").lower() in plvrFemao and m.group("Msfao_68") in plvrFemu and not " e " + m.group("Msfao_67") + "ão " + m.group("Msfao_68") + "us" in TEXT and not " ou " + m.group("Msfao_67") + "ão " + m.group("Msfao_68") + "us" in TEXT and not "s de " + m.group("Msfao_67") + "ão " + m.group("Msfao_68") + "us" in TEXT and not "s da " + m.group("Msfao_67") + "ão " + m.group("Msfao_68") + "us" in TEXT and not " a " + m.group("Msfao_67") + "ão " + m.group("Msfao_68") + "us" in TEXT and not m.group("Msfao_67") + "ão-" + m.group("Msfao_68") + "us" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_69>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_70>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_69").lower() in plvrFemao and m.group("Msfao_70") in plvrInvaz and not " e " + m.group("Msfao_69") + "ão " + m.group("Msfao_70") + "zes" in TEXT and not " ou " + m.group("Msfao_69") + "ão " + m.group("Msfao_70") + "zes" in TEXT and not "s de " + m.group("Msfao_69") + "ão " + m.group("Msfao_70") + "zes" in TEXT and not "s da " + m.group("Msfao_69") + "ão " + m.group("Msfao_70") + "zes" in TEXT and not " a " + m.group("Msfao_69") + "ão " + m.group("Msfao_70") + "zes" in TEXT and not m.group("Msfao_69") + "ão-" + m.group("Msfao_70") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_71>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_72>[a-z]+)zes(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_71").lower() in plvrFemao and m.group("Msfao_72") in plvrFemz and not " e " + m.group("Msfao_71") + "ão " + m.group("Msfao_72") + "zes" in TEXT and not " ou " + m.group("Msfao_71") + "ão " + m.group("Msfao_72") + "zes" in TEXT and not "s de " + m.group("Msfao_71") + "ão " + m.group("Msfao_72") + "zes" in TEXT and not "s da " + m.group("Msfao_71") + "ão " + m.group("Msfao_72") + "zes" in TEXT and not " a " + m.group("Msfao_71") + "ão " + m.group("Msfao_72") + "zes" in TEXT and not m.group("Msfao_71") + "ão-" + m.group("Msfao_72") + "zes" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_73>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_74>[a-záâãçéêíóôú]+[ã])s(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_73").lower() in plvrFemao and m.group("Msfao_74") in pvrFeman and not " e " + m.group("Msfao_73") + "ão " + m.group("Msfao_74") + "s" in TEXT and not " ou " + m.group("Msfao_73") + "ão " + m.group("Msfao_74") + "s" in TEXT and not "s de " + m.group("Msfao_73") + "ão " + m.group("Msfao_74") + "s" in TEXT and not "s da " + m.group("Msfao_73") + "ão " + m.group("Msfao_74") + "s" in TEXT and not " a " + m.group("Msfao_73") + "ão " + m.group("Msfao_74") + "s" in TEXT and not m.group("Msfao_73") + "ão-" + m.group("Msfao_74") + "s" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_75>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_76>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_75").lower() in plvrFemao and m.group("Msfao_76") in plvrMFm and not " e " + m.group("Msfao_75") + "ão " + m.group("Msfao_76") + "ns" in TEXT and not " ou " + m.group("Msfao_75") + "ão " + m.group("Msfao_76") + "ns" in TEXT and not "s de " + m.group("Msfao_75") + "ão " + m.group("Msfao_76") + "ns" in TEXT and not "s da " + m.group("Msfao_75") + "ão " + m.group("Msfao_76") + "ns" in TEXT and not " a " + m.group("Msfao_75") + "ão " + m.group("Msfao_76") + "ns" in TEXT and not m.group("Msfao_75") + "ão-" + m.group("Msfao_76") + "ns" in tCompostops'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfao_77>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão (?P<Msfao_78>[a-zA-Záâãçéêíóôú]+)ns(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ns"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msfao_77").lower() in plvrFemao and m.group("Msfao_78") in plvrFemm and not " e " + m.group("Msfao_77") + "ão " + m.group("Msfao_78") + "ns" in TEXT and not " ou " + m.group("Msfao_77") + "ão " + m.group("Msfao_78") + "ns" in TEXT and not "s de " + m.group("Msfao_77") + "ão " + m.group("Msfao_78") + "ns" in TEXT and not "s da " + m.group("Msfao_77") + "ão " + m.group("Msfao_78") + "ns" in TEXT and not " a " + m.group("Msfao_77") + "ão " + m.group("Msfao_78") + "ns" in TEXT and not m.group("Msfao_77") + "ão-" + m.group("Msfao_78") + "ns" in tCompostops'],
# Fim
# CONCORDANCIA NOMINAL PLURAL - SINGULAR
# plvrFema
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_1>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_2>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_1").lower() in plvrFema and m.group("Misf_2").lower() in plvrFema and not m.group("Misf_1") + "s " + m.group("Misf_2") + " e " in TEXT and not " de " + m.group("Misf_1") + "s " + m.group("Misf_2") in TEXT and not m.group("Misf_1") + "s " + m.group("Misf_2") + " ou " in TEXT and not m.group("Misf_1") + "s-" + m.group("Misf_2") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_3>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_4>[a-zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_3").lower() in plvrFema and m.group("Misf_4").lower() in plvrMfoa and not m.group("Misf_3") + "s " + m.group("Misf_4") + "a e " in TEXT and not " de " + m.group("Misf_3") + "s " + m.group("Misf_4") + "a" in TEXT and not m.group("Misf_3") + "s " + m.group("Misf_4") + "a ou " in TEXT and not m.group("Misf_3") + "s-" + m.group("Misf_4") + "a" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_5>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_6>[a-z]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_5").lower() in plvrFema and not m.group("Misf_6").lower() in excAdo and not m.group("Misf_5") + "s " + m.group("Misf_6") + m.group(3) + "do e " in TEXT and not m.group("Misf_5") + "s " + m.group("Misf_6") + "ado ou " in TEXT and not " de " + m.group("Misf_5") + "s " + m.group("Misf_6") in TEXT and not " das " + m.group("Misf_5") + "s " + m.group("Misf_6") + m.group(3) +"do " in TEXT and not m.group("Misf_5") in "-hora-Hora-semana-Semana-" and not m.group("Misf_5") + "s-" + m.group("Misf_6") + m.group(3) + "do" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_7>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_8>[a-z]+ista)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_7").lower() in plvrFema and not m.group("Misf_8").lower() in excIsta and not m.group("Misf_7") + "s " + m.group("Misf_8") + " e " in TEXT and not m.group("Misf_7") + "s " + m.group("Misf_8") + " ou " in TEXT and not " de " + m.group("Misf_7") + "s " + m.group("Misf_8") in TEXT and not m.group("Misf_7") + "s-" + m.group("Misf_8") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_9>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_10>[a-z]+a)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_9").lower() in plvrFema and m.group("Misf_10").lower() in plvrInva and not m.group("Misf_9") + "s " + m.group("Misf_10") + " e " in TEXT and not m.group("Misf_9") + "s " + m.group("Misf_10") + " ou " in TEXT and not " de " + m.group("Misf_9") + "s " + m.group("Misf_10") in TEXT and not m.group("Misf_9") + "s-" + m.group("Misf_10") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_11>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_12>[a-z]+)([aí])da(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_11").lower() in plvrFema and not m.group("Misf_12").lower() in excAdo and not m.group("Misf_11") + "s " + m.group("Misf_12") + "da e " in TEXT and not m.group("Misf_11") + "s " + m.group("Misf_12") + "da ou " in TEXT and not " de " + m.group("Misf_11") + "s " + m.group("Misf_12") in TEXT and not m.group("Misf_11") + "s-" + m.group("Misf_12") + "da" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_13>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_14>[a-zç]+)oso(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_13").lower() in plvrFema and not m.group("Misf_13") + "s " + m.group("Misf_14") + "oso e " in TEXT and not m.group("Misf_13") + "s " + m.group("Misf_14") + "oso ou " in TEXT and not " de " + m.group("Misf_13") + "s " + m.group("Misf_14") in TEXT and not m.group("Misf_13") + "s-" + m.group("Misf_14") + "oso" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_15>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_16>[a-zç]+)osa(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_15").lower() in plvrFema and not m.group("Misf_15") + "s " + m.group("Misf_16") + "osa e " in TEXT and not m.group("Misf_15") + "s " + m.group("Misf_16") + "osa ou " in TEXT and not " de " + m.group("Misf_15") + "s " + m.group("Misf_16") in TEXT and not m.group("Misf_15") + "s-" + m.group("Misf_16") + "osa" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_17>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_18>[a-zç]+)iva(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_17").lower() in plvrFema and not m.group("Misf_17") + "s " + m.group("Misf_18") + "iva e " in TEXT and not m.group("Misf_17") + "s " + m.group("Misf_18") + "iva ou " in TEXT and not " de " + m.group("Misf_17") + "s " + m.group("Misf_18") in TEXT and not m.group("Misf_17") + "s-" + m.group("Misf_18") + "iva" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_19>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_20>[a-zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_19").lower() in plvrFema and not m.group("Misf_19") + "s " + m.group("Misf_20") + "iva e " in TEXT and not m.group("Misf_19") + "s " + m.group("Misf_20") + "iva ou " in TEXT and not " de " + m.group("Misf_19") + "s " + m.group("Misf_20") in TEXT and not m.group("Misf_19") + "s-" + m.group("Misf_20") + "iva" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_21>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_22>[a-zç]+[âêô][mn])ica(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_21").lower() in plvrFema and not m.group("Misf_21") + "s " + m.group("Misf_22") + "ica e " in TEXT and not m.group("Misf_21") + "s " + m.group("Misf_22") + "ica ou " in TEXT and not " de " + m.group("Misf_21") + "s " + m.group("Misf_22") in TEXT and not m.group("Misf_21") + "s-" + m.group("Misf_22") + "ica" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_23>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_23").lower() in plvrFema and not m.group("Misf_23") + "s " + m.group("Misf_24") + "ica e " in TEXT and not m.group("Misf_23") + "s " + m.group("Misf_24") + "ica ou " in TEXT and not " de " + m.group("Misf_23") + "s " + m.group("Misf_24") in TEXT and not m.group("Misf_23") + "s-" + m.group("Misf_24") + "ica" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_25>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_25").lower() in plvrFema and not m.group("Misf_25") + "s " + m.group("Misf_26") + "ica e " in TEXT and not m.group("Misf_25") + "s " + m.group("Misf_26") + "ica ou " in TEXT and not " de " + m.group("Misf_25") + "s " + m.group("Misf_26") in TEXT and not m.group("Misf_25") + "s-" + m.group("Misf_26") + "ica" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_27>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_28>[a-zç]+)esca(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_27").lower() in plvrFema and not m.group("Misf_27") + "s " + m.group("Misf_28") + "esca e " in TEXT and not m.group("Misf_27") + "s " + m.group("Misf_28") + "esca ou " in TEXT and not " de " + m.group("Misf_27") + "s " + m.group("Misf_28") in TEXT and not m.group("Misf_27") + "s-" + m.group("Misf_28") + "esca" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_29>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ida(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_29").lower() in plvrFema and not m.group("Misf_29") + "s " + m.group("Misf_30") + "ida e " in TEXT and not m.group("Misf_29") + "s " + m.group("Misf_30") + "ida ou " in TEXT and not " de " + m.group("Misf_29") + "s " + m.group("Misf_30") in TEXT and not m.group("Misf_29") + "s-" + m.group("Misf_30") + "ida" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_31>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_32>[a-zç]+[ó])loga(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_31").lower() in plvrFema and not m.group("Misf_31") + "s " + m.group("Misf_32") + "loga e " in TEXT and not m.group("Misf_31") + "s " + m.group("Misf_32") + "loga ou " in TEXT and not " de " + m.group("Misf_31") + "s " + m.group("Misf_32") in TEXT and not m.group("Misf_31") + "s-" + m.group("Misf_32") + "loga" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_33>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_34>[a-zç]+[áéíóúâêô])ria(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_33").lower() in plvrFema and not m.group("Misf_33") + "s " + m.group("Misf_34") + "ria e " in TEXT and not m.group("Misf_33") + "s " + m.group("Misf_34") + "ria ou " in TEXT and not " de " + m.group("Misf_33") + "s " + m.group("Misf_34") in TEXT and not m.group("Misf_33") + "s-" + m.group("Misf_34") + "ria" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_35>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_36>[a-zç]+[í])ssima(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_35").lower() in plvrFema and not m.group("Misf_35") + "s " + m.group("Misf_36") + "ssima e " in TEXT and not m.group("Misf_35") + "s " + m.group("Misf_36") + "ssima ou " in TEXT and not " de " + m.group("Misf_35") + "s " + m.group("Misf_36") in TEXT and not m.group("Misf_35") + "s-" + m.group("Misf_36") + "ssima" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_37>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_38>[a-zç]+[é])sima(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_37").lower() in plvrFema and not m.group("Misf_37") + "s " + m.group("Misf_38") + "sima e " in TEXT and not m.group("Misf_37") + "s " + m.group("Misf_38") + "sima ou " in TEXT and not " de " + m.group("Misf_37") + "s " + m.group("Misf_38") in TEXT and not m.group("Misf_37") + "s-" + m.group("Misf_38") + "sima" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_41>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_42>[a-zçáéíóúâêô]+[dst])ora(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_41").lower() in plvrFema and not m.group("Misf_42") in "D-d-" and not m.group("Misf_41") + "s " + m.group("Misf_42") + "ora e " in TEXT and not m.group("Misf_41") + "s " + m.group("Misf_42") + "ora ou " in TEXT and not " de " + m.group("Misf_41") + "s " + m.group("Misf_42") + "ora" in TEXT and not m.group("Misf_41") + "s-" + m.group("Misf_42") + "ora" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_43>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_44>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_43").lower() in plvrFema and m.group("Misf_44") in plvrMfr and not m.group("Misf_43") + "s " + m.group("Misf_44") + " e " in TEXT and not m.group("Misf_43") + "s " + m.group("Misf_44") + " ou " in TEXT and not " de " + m.group("Misf_43") + "s " + m.group("Misf_44") in TEXT and not m.group("Misf_43") + "s-" + m.group("Misf_44") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_45>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_46>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_45").lower() in plvrFema and m.group("Misf_46") in plvrFemr and not m.group("Misf_45") + "s " + m.group("Misf_46") + " e " in TEXT and not m.group("Misf_45") + "s " + m.group("Misf_46") + " ou " in TEXT and not " de " + m.group("Misf_45") + "s " + m.group("Misf_46") in TEXT and not m.group("Misf_45") + "s-" + m.group("Misf_46") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_47>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_48>[a-zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_47").lower() in plvrFema and m.group("Misf_48") in plvrMfal and not m.group("Misf_47") + "s " + m.group("Misf_48") + "l e " in TEXT and not m.group("Misf_47") + "s " + m.group("Misf_48") + "l ou " in TEXT and not " de " + m.group("Misf_47") + "s " + m.group("Misf_48") in TEXT and not m.group("Misf_47") + "s-" + m.group("Misf_48") + "l" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_49>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_50>[a-zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_49").lower() in plvrFema and m.group("Misf_50") in plvrMfcao and not m.group("Misf_49") + "s " + m.group("Misf_50") + "ão e " in TEXT and not m.group("Misf_49") + "s " + m.group("Misf_50") + "ão ou " in TEXT and not " de " + m.group("Misf_49") + "s " + m.group("Misf_50") in TEXT and not m.group("Misf_49") + "s-" + m.group("Misf_50") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_51>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_52>[a-zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_51").lower() in plvrFema and not m.group("Misf_52") in plvrMascao and not m.group("Misf_51") + "s " + m.group("Misf_52") + "ão e " in TEXT and not m.group("Misf_51") + "s " + m.group("Misf_52") + "ão ou " in TEXT and not " de " + m.group("Misf_51") + "s " + m.group("Misf_52") in TEXT and not m.group("Misf_51") + "s-" + m.group("Misf_52") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_53>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_53").lower() in plvrFema and m.group("Misf_54") in plvrFemao and not m.group("Misf_53") + "s " + m.group("Misf_54") + "ão e " in TEXT and not " de " + m.group("Misf_53") + "s " + m.group("Misf_54") in TEXT and not m.group("Misf_53") + "s " + m.group("Misf_54") + "ão ou " in TEXT and not m.group("Misf_53") + "s-" + m.group("Misf_54") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_55>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_56>[a-zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_55").lower() in plvrFema and not m.group("Misf_55") + "s " + m.group("Misf_56") + "vel e " in TEXT and not m.group("Misf_55") + "s " + m.group("Misf_56") + "vel ou " in TEXT and not " de " + m.group("Misf_55") + "s " + m.group("Misf_56") in TEXT and not m.group("Misf_55") + "s-" + m.group("Misf_56") + "vel" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_57>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_58>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_57").lower() in plvrFema and m.group("Misf_58").lower() in plvrMfe and not m.group("Misf_57") + "s " + m.group("Misf_58") + "e e " in TEXT and not m.group("Misf_57") + "s " + m.group("Misf_58") + "e ou " in TEXT and not " de " + m.group("Misf_57") + "s " + m.group("Misf_58") in TEXT and not m.group("Misf_57") + "s-" + m.group("Misf_58") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_59>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_60>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_59").lower() in plvrFema and m.group("Misf_60").lower() in plvrFeme and not m.group("Misf_59") + "s " + m.group("Misf_60") + "e e " in TEXT and not m.group("Misf_59") + "s " + m.group("Misf_60") + "e ou " in TEXT and not " de " + m.group("Misf_59") + "s " + m.group("Misf_60") in TEXT and not m.group("Misf_59") + "s-" + m.group("Misf_60") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_61>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_62>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_61").lower() in plvrFema and m.group("Misf_62") in plvrMfel and not m.group("Misf_61") + "s " + m.group("Misf_62") + "el e " in TEXT and not m.group("Misf_61") + "s " + m.group("Misf_62") + "el ou " in TEXT and not " de " + m.group("Misf_61") + "s " + m.group("Misf_62") in TEXT and not m.group("Misf_61") + "s-" + m.group("Misf_62") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_63>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_64>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_63").lower() in plvrFema and m.group("Misf_64") in plvrFemel and not m.group("Misf_63") + "s " + m.group("Misf_64") + "el e " in TEXT and not m.group("Misf_63") + "s " + m.group("Misf_64") + "el ou " in TEXT and not " de " + m.group("Misf_63") + "s " + m.group("Misf_64") in TEXT and not m.group("Misf_63") + "s-" + m.group("Misf_64") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_65>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_66>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_65").lower() in plvrFema and m.group("Misf_66") in plvrMfeu and not m.group("Misf_65") + "s " + m.group("Misf_66") + "u e " in TEXT and not m.group("Misf_65") + "s " + m.group("Misf_66") + "u ou " in TEXT and not " de " + m.group("Misf_65") + "s " + m.group("Misf_66") in TEXT and not m.group("Misf_65") + "s-" + m.group("Misf_66") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_67>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_68>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_67").lower() in plvrFema and m.group("Misf_68") in plvrFemu and not m.group("Misf_67") + "s " + m.group("Misf_68") + "u e " in TEXT and not m.group("Misf_67") + "s " + m.group("Misf_68") + "u ou " in TEXT and not " de " + m.group("Misf_67") + "s " + m.group("Misf_68") in TEXT and not m.group("Misf_67") + "s-" + m.group("Misf_68") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_69>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_70>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_69").lower() in plvrFema and m.group("Misf_70") in plvrInvaz and not m.group("Misf_69") + "s " + m.group("Misf_70") + "z e " in TEXT and not m.group("Misf_69") + "s " + m.group("Misf_70") + "z ou " in TEXT and not " de " + m.group("Misf_69") + "s " + m.group("Misf_70") in TEXT and not m.group("Misf_69") + "s-" + m.group("Misf_70") + "z" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_71>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_72>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_71").lower() in plvrFema and m.group("Misf_72") in plvrFemz and not m.group("Misf_71") + "s " + m.group("Misf_72") + "z e " in TEXT and not m.group("Misf_71") + "s " + m.group("Misf_72") + "z ou " in TEXT and not " de " + m.group("Misf_71") + "s " + m.group("Misf_72") in TEXT and not m.group("Misf_71") + "s-" + m.group("Misf_72") + "z" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Misf_73>[a-zA-Záâãçéêíóôú]+[a])s (?P<Misf_74>[a-záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Misf_73").lower() in plvrFema and m.group("Misf_74") in pvrFeman and not m.group("Misf_73") + "s " + m.group("Misf_74") + " e " in TEXT and not m.group("Misf_73") + "s " + m.group("Misf_74") + " ou " in TEXT and not " de " + m.group("Misf_73") + "s " + m.group("Misf_74") in TEXT and not m.group("Misf_73") + "s-" + m.group("Misf_74") in tCompostops and not excplSin.search(TEXT)'],
# plvrFeme combinada
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_1>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_2>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_1").lower() in plvrFeme and m.group("Mife_2").lower() in plvrFema and not m.group("Mife_1") + "es " + m.group("Mife_2") + " e " in TEXT and not " de " + m.group("Mife_1") + "es " + m.group("Mife_2") in TEXT and not m.group("Mife_1") + "es " + m.group("Mife_2") + " ou " in TEXT and not m.group("Mife_1") + "es-" + m.group("Mife_2") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_3>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_4>[a-zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_3").lower() in plvrFeme and m.group("Mife_4").lower() in plvrMfoa and not m.group("Mife_3") + "es " + m.group("Mife_4") + "a e " in TEXT and not m.group("Mife_3") + "es " + m.group("Mife_4") + "a ou " in TEXT and not " de " + m.group("Mife_3") + "es " + m.group("Mife_4") in TEXT and not m.group("Mife_3") + "es-" + m.group("Mife_4") + "a" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_5>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_6>[a-z]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_5").lower() in plvrFeme and not m.group("Mife_6").lower() in excAdo and not m.group("Mife_5") + "es " + m.group("Mife_6") + "do e " in TEXT and not m.group("Mife_5") + "es " + m.group("Mife_6") + "do ou " in TEXT and not " de " + m.group("Mife_5") + "es " + m.group("Mife_6") in TEXT and not m.group("Mife_5") + "es-" + m.group("Mife_6") + "do" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_7>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_8>[a-z]+ista)(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_7").lower() in plvrFeme and not m.group("Mife_8").lower() in excIsta and not m.group("Mife_7") + "es " + m.group("Mife_8") + " e " in TEXT and not m.group("Mife_7") + "es " + m.group("Mife_8") + " ou " in TEXT and not " de " + m.group("Mife_7") + "es " + m.group("Mife_8") in TEXT and not m.group("Mife_7") + "es-" + m.group("Mife_8") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_9>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_10>[a-z]+a)(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_9").lower() in plvrFeme and m.group("Mife_10").lower() in plvrInva and not m.group("Mife_9") + "es " + m.group("Mife_10") + " e " in TEXT and not m.group("Mife_9") + "es " + m.group("Mife_10") + " ou " in TEXT and not " de " + m.group("Mife_9") + "es " + m.group("Mife_10") in TEXT and not m.group("Mife_9") + "es-" + m.group("Mife_10") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_11>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_12>[a-z]+)([aí])da(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_11").lower() in plvrFeme and not m.group("Mife_12").lower() in excAdo and not m.group("Mife_11") + "es " + m.group("Mife_12") + "da e " in TEXT and not m.group("Mife_11") + "es " + m.group("Mife_12") + "da ou " in TEXT and not " de " + m.group("Mife_11") + "es " + m.group("Mife_12") in TEXT and not m.group("Mife_11") + "es-" + m.group("Mife_12") + "da" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_13>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_14>[a-zç]+)oso(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_13").lower() in plvrFeme and not m.group("Mife_13") + "es " + m.group("Mife_14") + "oso e " in TEXT and not m.group("Mife_13") + "es " + m.group("Mife_14") + "oso ou " in TEXT and not " de " + m.group("Mife_13") + "es " + m.group("Mife_14") in TEXT and not m.group("Mife_13") + "es-" + m.group("Mife_14") + "oso" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_15>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_16>[a-zç]+)osa(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_15").lower() in plvrFeme and not m.group("Mife_15") + "es " + m.group("Mife_16") + "osa e " in TEXT and not m.group("Mife_15") + "es " + m.group("Mife_16") + "osa ou " in TEXT and not " de " + m.group("Mife_15") + "es " + m.group("Mife_16") in TEXT and not m.group("Mife_15") + "es-" + m.group("Mife_16") + "osa" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_17>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_18>[a-zç]+)iva(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_17").lower() in plvrFeme and not m.group("Mife_17") + "es " + m.group("Mife_18") + "iva e " in TEXT and not m.group("Mife_17") + "es " + m.group("Mife_18") + "iva ou " in TEXT and not " de " + m.group("Mife_17") + "es " + m.group("Mife_18") in TEXT and not m.group("Mife_17") + "es-" + m.group("Mife_18") + "iva" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_19>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_20>[a-zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_19").lower() in plvrFeme and not m.group("Mife_19") + "es " + m.group("Mife_20") + "iva e " in TEXT and not m.group("Mife_19") + "es " + m.group("Mife_20") + "iva ou " in TEXT and not " de " + m.group("Mife_19") + "es " + m.group("Mife_20") in TEXT and not m.group("Mife_19") + "es-" + m.group("Mife_20") + "iva" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_21>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_22>[a-zç]+[âêô][mn])ica(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_21").lower() in plvrFeme and not m.group("Mife_21") + "es " + m.group("Mife_22") + "ica e " in TEXT and not m.group("Mife_21") + "es " + m.group("Mife_22") + "ica ou " in TEXT and not " de " + m.group("Mife_21") + "es " + m.group("Mife_22") in TEXT and not m.group("Mife_21") + "es-" + m.group("Mife_22") + "ica" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_23>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_23").lower() in plvrFeme and not m.group("Mife_23") + "es " + m.group("Mife_24") + "ica e " in TEXT and not m.group("Mife_23") + "es " + m.group("Mife_24") + "ica ou " in TEXT and not " de " + m.group("Mife_23") + "es " + m.group("Mife_24") in TEXT and not m.group("Mife_23") + "es-" + m.group("Mife_24") + "ica" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_25>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_25").lower() in plvrFeme and not m.group("Mife_25") + "es " + m.group("Mife_26") + "ica e " in TEXT and not m.group("Mife_25") + "es " + m.group("Mife_26") + "ica ou " in TEXT and not " de " + m.group("Mife_25") + "es " + m.group("Mife_26") in TEXT and not m.group("Mife_25") + "es-" + m.group("Mife_26") + "ica" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_27>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_28>[a-zç]+)esca(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_27").lower() in plvrFeme and not m.group("Mife_27") + "es " + m.group("Mife_28") + "esca e " in TEXT and not m.group("Mife_27") + "es " + m.group("Mife_28") + "esca ou " in TEXT and not " de " + m.group("Mife_27") + "es " + m.group("Mife_28") in TEXT and not m.group("Mife_27") + "es-" + m.group("Mife_28") + "esca" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_29>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ida(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_29").lower() in plvrFeme and not m.group("Mife_29") + "es " + m.group("Mife_30") + "ida e " in TEXT and not m.group("Mife_29") + "es " + m.group("Mife_30") + "ida ou " in TEXT and not " de " + m.group("Mife_29") + "es " + m.group("Mife_30") in TEXT and not m.group("Mife_29") + "es-" + m.group("Mife_30") + "ida" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_31>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_32>[a-zç]+[ó])loga(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_31").lower() in plvrFeme and not m.group("Mife_31") + "es " + m.group("Mife_32") + "loga e " in TEXT and not m.group("Mife_31") + "es " + m.group("Mife_32") + "loga ou " in TEXT and not " de " + m.group("Mife_31") + "es " + m.group("Mife_32") in TEXT and not m.group("Mife_31") + "es-" + m.group("Mife_32") + "loga" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_33>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_34>[a-zç]+[áéíóúâêô])ria(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_33").lower() in plvrFeme and not m.group("Mife_33") + "es " + m.group("Mife_34") + "ria e " in TEXT and not m.group("Mife_33") + "es " + m.group("Mife_34") + "ria ou " in TEXT and not " de " + m.group("Mife_33") + "es " + m.group("Mife_34") in TEXT and not m.group("Mife_33") + "es-" + m.group("Mife_34") + "ria" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_35>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_36>[a-zç]+[í])ssima(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_35").lower() in plvrFeme and not m.group("Mife_35") + "es " + m.group("Mife_36") + "essima e " in TEXT and not m.group("Mife_35") + "es " + m.group("Mife_36") + "essima ou " in TEXT and not " de " + m.group("Mife_35") + "es " + m.group("Mife_36") in TEXT and not m.group("Mife_35") + "es-" + m.group("Mife_36") + "essima" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_37>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_38>[a-zç]+[é])sima(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_37").lower() in plvrFeme and not m.group("Mife_37") + "es " + m.group("Mife_38") + "esima e " in TEXT and not m.group("Mife_37") + "es " + m.group("Mife_38") + "esima ou " in TEXT and not " de " + m.group("Mife_37") + "es " + m.group("Mife_38") in TEXT and not m.group("Mife_37") + "es-" + m.group("Mife_38") + "esima" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_41>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_42>[a-zçáéíóúâêô]+[dst])ora(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_41").lower() in plvrFeme and not m.group("Mife_42") in "D-d-" and not m.group("Mife_41") + "es " + m.group("Mife_42") + "ora e " in TEXT and not m.group("Mife_41") + "es " + m.group("Mife_42") + "ora ou " in TEXT and not " de " + m.group("Mife_41") + "es " + m.group("Mife_42") in TEXT and not m.group("Mife_41") + "es-" + m.group("Mife_42") + "ora" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_43>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_44>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_43").lower() in plvrFeme and m.group("Mife_44") in plvrMfr and not m.group("Mife_43") + "es " + m.group("Mife_44") + " e " in TEXT and not m.group("Mife_43") + "es " + m.group("Mife_44") + " ou " in TEXT and not " de " + m.group("Mife_43") + "es " + m.group("Mife_44") in TEXT and not m.group("Mife_43") + "es-" + m.group("Mife_44") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_45>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_46>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_45").lower() in plvrFeme and m.group("Mife_46") in plvrFemr and not m.group("Mife_45") + "es " + m.group("Mife_46") + " e " in TEXT and not m.group("Mife_45") + "es " + m.group("Mife_46") + " ou " in TEXT and not " de " + m.group("Mife_45") + "es " + m.group("Mife_46") in TEXT and not m.group("Mife_45") + "es-" + m.group("Mife_46") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_47>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_48>[a-zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_47").lower() in plvrFeme and m.group("Mife_48") in plvrMfal and not m.group("Mife_47") + "es " + m.group("Mife_48") + "l e " in TEXT and not m.group("Mife_47") + "es " + m.group("Mife_48") + "l ou " in TEXT and not " de " + m.group("Mife_47") + "es " + m.group("Mife_48") in TEXT and not m.group("Mife_47") + "es-" + m.group("Mife_48") + "l" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_49>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_50>[a-zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_49").lower() in plvrFeme and m.group("Mife_50") in plvrMfcao and not m.group("Mife_49") + "es " + m.group("Mife_50") + "ão e " in TEXT and not m.group("Mife_49") + "es " + m.group("Mife_50") + "ão ou " in TEXT and not " de " + m.group("Mife_49") + "es " + m.group("Mife_50") in TEXT and not m.group("Mife_49") + "es-" + m.group("Mife_50") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_51>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_52>[a-zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_51").lower() in plvrFeme and not m.group("Mife_52") in plvrMascao and not m.group("Mife_51") + "es " + m.group("Mife_52") + "ão e " in TEXT and not m.group("Mife_51") + "es " + m.group("Mife_52") + "ão ou " in TEXT and not " de " + m.group("Mife_51") + "es " + m.group("Mife_52") in TEXT and not m.group("Mife_51") + "es-" + m.group("Mife_52") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_53>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_53").lower() in plvrFeme and m.group("Mife_54") in plvrFemao and not m.group("Mife_53") + "es " + m.group("Mife_54") + "ão e " in TEXT and not " de " + m.group("Mife_53") + "es " + m.group("Mife_54") in TEXT and not m.group("Mife_53") + "es " + m.group("Mife_54") + "ão ou " in TEXT and not m.group("Mife_53") + "es-" + m.group("Mife_54") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_55>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_56>[a-zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_55").lower() in plvrFeme and not m.group("Mife_55") + "es " + m.group("Mife_56") + "vel e " in TEXT and not m.group("Mife_55") + "es " + m.group("Mife_56") + "vel ou " in TEXT and not " de " + m.group("Mife_55") + "es " + m.group("Mife_56") in TEXT and not m.group("Mife_55") + "es-" + m.group("Mife_56") + "vel" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_57>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_58>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_57").lower() in plvrFeme and m.group("Mife_58").lower() in plvrMfe and not m.group("Mife_57") + "es " + m.group("Mife_58") + "e e " in TEXT and not m.group("Mife_57") + "es " + m.group("Mife_58") + "e ou " in TEXT and not " de " + m.group("Mife_57") + "es " + m.group("Mife_58") in TEXT and not m.group("Mife_57") + "es-" + m.group("Mife_58") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_59>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_60>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_59").lower() in plvrFeme and m.group("Mife_60").lower() in plvrFeme and not m.group("Mife_59") + "es " + m.group("Mife_60") + "e e " in TEXT and not m.group("Mife_59") + "es " + m.group("Mife_60") + "e ou " in TEXT and not " de " + m.group("Mife_59") + "es " + m.group("Mife_60") in TEXT and not m.group("Mife_59") + "es-" + m.group("Mife_60") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_61>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_62>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_61").lower() in plvrFeme and m.group("Mife_62") in plvrMfel and not m.group("Mife_61") + "es " + m.group("Mife_62") + "el e " in TEXT and not m.group("Mife_61") + "es " + m.group("Mife_62") + "el ou " in TEXT and not " de " + m.group("Mife_61") + "es " + m.group("Mife_62") in TEXT and not m.group("Mife_61") + "es-" + m.group("Mife_62") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_63>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_64>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_63").lower() in plvrFeme and m.group("Mife_64") in plvrFemel and not m.group("Mife_63") + "es " + m.group("Mife_64") + "el e " in TEXT and not m.group("Mife_63") + "es " + m.group("Mife_64") + "el ou " in TEXT and not " de " + m.group("Mife_63") + "es " + m.group("Mife_64") in TEXT and not m.group("Mife_63") + "es-" + m.group("Mife_64") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_65>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_66>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_65").lower() in plvrFeme and m.group("Mife_66") in plvrMfeu and not m.group("Mife_65") + "es " + m.group("Mife_66") + "u e " in TEXT and not m.group("Mife_65") + "es " + m.group("Mife_66") + "u ou " in TEXT and not " de " + m.group("Mife_65") + "es " + m.group("Mife_66") in TEXT and not m.group("Mife_65") + "es-" + m.group("Mife_66") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_67>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_68>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_67").lower() in plvrFeme and m.group("Mife_68") in plvrFemu and not m.group("Mife_67") + "es " + m.group("Mife_68") + "u e " in TEXT and not m.group("Mife_67") + "es " + m.group("Mife_68") + "u ou " in TEXT and not " de " + m.group("Mife_67") + "es " + m.group("Mife_68") in TEXT and not m.group("Mife_67") + "es-" + m.group("Mife_68") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_69>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_70>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_69").lower() in plvrFeme and m.group("Mife_70") in plvrInvaz and not m.group("Mife_69") + "es " + m.group("Mife_70") + "z e " in TEXT and not m.group("Mife_69") + "es " + m.group("Mife_70") + "z ou " in TEXT and not " de " + m.group("Mife_69") + "es " + m.group("Mife_70") in TEXT and not m.group("Mife_69") + "es-" + m.group("Mife_70") + "z" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_71>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_72>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_71").lower() in plvrFeme and m.group("Mife_72") in plvrFemz and not m.group("Mife_71") + "es " + m.group("Mife_72") + "z e " in TEXT and not m.group("Mife_71") + "es " + m.group("Mife_72") + "z ou " in TEXT and not " de " + m.group("Mife_71") + "es " + m.group("Mife_72") in TEXT and not m.group("Mife_71") + "es-" + m.group("Mife_72") + "z" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mife_73>[a-zA-Záâãçéêíóôú]+)es (?P<Mife_74>[a-záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mife_73").lower() in plvrFeme and m.group("Mife_74") in pvrFeman and not m.group("Mife_73") + "es " + m.group("Mife_74") + " e " in TEXT and not m.group("Mife_73") + "es " + m.group("Mife_74") + " ou " in TEXT and not " de " + m.group("Mife_73") + "es " + m.group("Mife_74") in TEXT and not m.group("Mife_73") + "es-" + m.group("Mife_74") in tCompostops and not excplSin.search(TEXT)'],
# plvrMfe combinada
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_1>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_2>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_1").lower() in plvrMfe and m.group("Mxfe_2").lower() in plvrFema and not m.group("Mxfe_1") + "es " + m.group("Mxfe_2") + " e " in TEXT and not " de " + m.group("Mxfe_1") + "es " + m.group("Mxfe_2") in TEXT and not m.group("Mxfe_1") + "es " + m.group("Mxfe_2") + " ou " in TEXT and not m.group("Mxfe_1") + "es-" + m.group("Mxfe_2") in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_3>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_4>[a-zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_3").lower() in plvrMfe and m.group("Mxfe_4").lower() in plvrMfoa and not m.group("Mxfe_3") + "es " + m.group("Mxfe_4") + "a e " in TEXT and not m.group("Mxfe_3") + "es " + m.group("Mxfe_4") + "a ou " in TEXT and not " de " + m.group("Mxfe_3") + "es " + m.group("Mxfe_4") in TEXT and not m.group("Mxfe_3") + "es-" + m.group("Mxfe_4") + "a" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_5>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_6>[a-z]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_5").lower() in plvrMfe and not m.group("Mxfe_6").lower() in excAdo and not m.group("Mxfe_5") + "es " + m.group("Mxfe_6") + "do e " in TEXT and not m.group("Mxfe_5") + "es " + m.group("Mxfe_6") + "do ou " in TEXT and not " de " + m.group("Mxfe_5") + "es " + m.group("Mxfe_6") in TEXT and not m.group("Mxfe_5") + "es-" + m.group("Mxfe_6") + "do" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_7>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_8>[a-z]+ista)(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_7").lower() in plvrMfe and not m.group("Mxfe_8").lower() in excIsta and not m.group("Mxfe_7") + "es " + m.group("Mxfe_8") + " e " in TEXT and not m.group("Mxfe_7") + "es " + m.group("Mxfe_8") + " ou " in TEXT and not " de " + m.group("Mxfe_7") + "es " + m.group("Mxfe_8") in TEXT and not m.group("Mxfe_7") + "es-" + m.group("Mxfe_8") in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_9>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_10>[a-z]+a)(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_9").lower() in plvrMfe and m.group("Mxfe_10").lower() in plvrInva and not m.group("Mxfe_9") + "es " + m.group("Mxfe_10") + " e " in TEXT and not m.group("Mxfe_9") + "es " + m.group("Mxfe_10") + " ou " in TEXT and not " de " + m.group("Mxfe_9") + "es " + m.group("Mxfe_10") in TEXT and not m.group("Mxfe_9") + "es-" + m.group("Mxfe_10") in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_11>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_12>[a-z]+)([aí])da(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_11").lower() in plvrMfe and not m.group("Mxfe_12").lower() in excAdo and not m.group("Mxfe_11") + "es " + m.group("Mxfe_12") + "da e " in TEXT and not m.group("Mxfe_11") + "es " + m.group("Mxfe_12") + "da ou " in TEXT and not " de " + m.group("Mxfe_11") + "es " + m.group("Mxfe_12") in TEXT and not m.group("Mxfe_11") + "es-" + m.group("Mxfe_12") + "da" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_13>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_14>[a-zç]+)oso(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_13").lower() in plvrMfe and not m.group("Mxfe_13") + "es " + m.group("Mxfe_14") + "oso e " in TEXT and not m.group("Mxfe_13") + "es " + m.group("Mxfe_14") + "oso ou " in TEXT and not " de " + m.group("Mxfe_13") + "es " + m.group("Mxfe_14") in TEXT and not m.group("Mxfe_13") + "es-" + m.group("Mxfe_14") + "oso" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_15>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_16>[a-zç]+)osa(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_15").lower() in plvrMfe and not m.group("Mxfe_15") + "es " + m.group("Mxfe_16") + "osa e " in TEXT and not m.group("Mxfe_15") + "es " + m.group("Mxfe_16") + "osa ou " in TEXT and not " de " + m.group("Mxfe_15") + "es " + m.group("Mxfe_16") in TEXT and not m.group("Mxfe_15") + "es-" + m.group("Mxfe_16") + "osa" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_17>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_18>[a-zç]+)iva(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_17").lower() in plvrMfe and not m.group("Mxfe_17") + "es " + m.group("Mxfe_18") + "iva e " in TEXT and not m.group("Mxfe_17") + "es " + m.group("Mxfe_18") + "iva ou " in TEXT and not " de " + m.group("Mxfe_17") + "es " + m.group("Mxfe_18") in TEXT and not m.group("Mxfe_17") + "es-" + m.group("Mxfe_18") + "iva" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_19>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_20>[a-zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_19").lower() in plvrMfe and not m.group("Mxfe_19") + "es " + m.group("Mxfe_20") + "iva e " in TEXT and not m.group("Mxfe_19") + "es " + m.group("Mxfe_20") + "iva ou " in TEXT and not " de " + m.group("Mxfe_19") + "es " + m.group("Mxfe_20") in TEXT and not m.group("Mxfe_19") + "es-" + m.group("Mxfe_20") + "iva" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_21>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_22>[a-zç]+[âêô][mn])ica(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_21").lower() in plvrMfe and not m.group("Mxfe_21") + "es " + m.group("Mxfe_22") + "ica e " in TEXT and not m.group("Mxfe_21") + "es " + m.group("Mxfe_22") + "ica ou " in TEXT and not " de " + m.group("Mxfe_21") + "es " + m.group("Mxfe_22") in TEXT and not m.group("Mxfe_21") + "es-" + m.group("Mxfe_22") + "ica" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_23>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_23").lower() in plvrMfe and not m.group("Mxfe_23") + "es " + m.group("Mxfe_24") + "ica e " in TEXT and not m.group("Mxfe_23") + "es " + m.group("Mxfe_24") + "ica ou " in TEXT and not " de " + m.group("Mxfe_23") + "es " + m.group("Mxfe_24") in TEXT and not m.group("Mxfe_23") + "es-" + m.group("Mxfe_24") + "ica" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_25>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_25").lower() in plvrMfe and not m.group("Mxfe_25") + "es " + m.group("Mxfe_26") + "ica e " in TEXT and not m.group("Mxfe_25") + "es " + m.group("Mxfe_26") + "ica ou " in TEXT and not " de " + m.group("Mxfe_25") + "es " + m.group("Mxfe_26") in TEXT and not m.group("Mxfe_25") + "es-" + m.group("Mxfe_26") + "ica" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_27>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_28>[a-zç]+)esca(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_27").lower() in plvrMfe and not m.group("Mxfe_27") + "es " + m.group("Mxfe_28") + "esca e " in TEXT and not m.group("Mxfe_27") + "es " + m.group("Mxfe_28") + "esca ou " in TEXT and not " de " + m.group("Mxfe_27") + "es " + m.group("Mxfe_28") in TEXT and not m.group("Mxfe_27") + "es-" + m.group("Mxfe_28") + "esca" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_29>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ida(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_29").lower() in plvrMfe and not m.group("Mxfe_29") + "es " + m.group("Mxfe_30") + "ida e " in TEXT and not m.group("Mxfe_29") + "es " + m.group("Mxfe_30") + "ida ou " in TEXT and not " de " + m.group("Mxfe_29") + "es " + m.group("Mxfe_30") in TEXT and not m.group("Mxfe_29") + "es-" + m.group("Mxfe_30") + "ida" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_31>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_32>[a-zç]+[ó])loga(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_31").lower() in plvrMfe and not m.group("Mxfe_31") + "es " + m.group("Mxfe_32") + "loga e " in TEXT and not m.group("Mxfe_31") + "es " + m.group("Mxfe_32") + "loga ou " in TEXT and not " de " + m.group("Mxfe_31") + "es " + m.group("Mxfe_32") in TEXT and not m.group("Mxfe_31") + "es-" + m.group("Mxfe_32") + "loga" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_33>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_34>[a-zç]+[áéíóúâêô])ria(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_33").lower() in plvrMfe and not m.group("Mxfe_33") + "es " + m.group("Mxfe_34") + "ria e " in TEXT and not m.group("Mxfe_33") + "es " + m.group("Mxfe_34") + "ria ou " in TEXT and not " de " + m.group("Mxfe_33") + "es " + m.group("Mxfe_34") in TEXT and not m.group("Mxfe_33") + "es-" + m.group("Mxfe_34") + "ria" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_35>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_36>[a-zç]+[í])ssima(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_35").lower() in plvrMfe and not m.group("Mxfe_35") + "es " + m.group("Mxfe_36") + "essima e " in TEXT and not m.group("Mxfe_35") + "es " + m.group("Mxfe_36") + "essima ou " in TEXT and not " de " + m.group("Mxfe_35") + "es " + m.group("Mxfe_36") in TEXT and not m.group("Mxfe_35") + "es-" + m.group("Mxfe_36") + "essima" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_37>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_38>[a-zç]+[é])sima(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_37").lower() in plvrMfe and not m.group("Mxfe_37") + "es " + m.group("Mxfe_38") + "esima e " in TEXT and not m.group("Mxfe_37") + "es " + m.group("Mxfe_38") + "esima ou " in TEXT and not " de " + m.group("Mxfe_37") + "es " + m.group("Mxfe_38") in TEXT and not m.group("Mxfe_37") + "es-" + m.group("Mxfe_38") + "esima" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_41>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_42>[a-zçáéíóúâêô]+[dst])ora(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_41").lower() in plvrMfe and not m.group("Mxfe_42") in "D-d-" and not m.group("Mxfe_41") + "es " + m.group("Mxfe_42") + "ora e " in TEXT and not m.group("Mxfe_41") + "es " + m.group("Mxfe_42") + "ora ou " in TEXT and not " de " + m.group("Mxfe_41") + "es " + m.group("Mxfe_42") in TEXT and not m.group("Mxfe_41") + "es-" + m.group("Mxfe_42") + "ora" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_43>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_44>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_43").lower() in plvrMfe and m.group("Mxfe_44") in plvrMfr and not m.group("Mxfe_43") + "es " + m.group("Mxfe_44") + " e " in TEXT and not m.group("Mxfe_43") + "es " + m.group("Mxfe_44") + " ou " in TEXT and not " de " + m.group("Mxfe_43") + "es " + m.group("Mxfe_44") in TEXT and not m.group("Mxfe_43") + "es-" + m.group("Mxfe_44") in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_45>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_46>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_45").lower() in plvrMfe and m.group("Mxfe_46") in plvrFemr and not m.group("Mxfe_45") + "es " + m.group("Mxfe_46") + " e " in TEXT and not m.group("Mxfe_45") + "es " + m.group("Mxfe_46") + " ou " in TEXT and not " de " + m.group("Mxfe_45") + "es " + m.group("Mxfe_46") in TEXT and not m.group("Mxfe_45") + "es-" + m.group("Mxfe_46") in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_47>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_48>[a-zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_47").lower() in plvrMfe and m.group("Mxfe_48") in plvrMfal and not m.group("Mxfe_47") + "es " + m.group("Mxfe_48") + "l e " in TEXT and not m.group("Mxfe_47") + "es " + m.group("Mxfe_48") + "l ou " in TEXT and not " de " + m.group("Mxfe_47") + "es " + m.group("Mxfe_48") in TEXT and not m.group("Mxfe_47") + "es-" + m.group("Mxfe_48") + "l" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_49>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_50>[a-zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_49").lower() in plvrMfe and m.group("Mxfe_50") in plvrMfcao and not m.group("Mxfe_49") + "es " + m.group("Mxfe_50") + "ão e " in TEXT and not m.group("Mxfe_49") + "es " + m.group("Mxfe_50") + "ão ou " in TEXT and not " de " + m.group("Mxfe_49") + "es " + m.group("Mxfe_50") in TEXT and not m.group("Mxfe_49") + "es-" + m.group("Mxfe_50") + "ão" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_51>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_52>[a-zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_51").lower() in plvrMfe and not m.group("Mxfe_52") in plvrMascao and not m.group("Mxfe_51") + "es " + m.group("Mxfe_52") + "ão e " in TEXT and not m.group("Mxfe_51") + "es " + m.group("Mxfe_52") + "ão ou " in TEXT and not " de " + m.group("Mxfe_51") + "es " + m.group("Mxfe_52") in TEXT and not m.group("Mxfe_51") + "es-" + m.group("Mxfe_52") + "ão" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_53>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_53").lower() in plvrMfe and m.group("Mxfe_54") in plvrFemao and not m.group("Mxfe_53") + "es " + m.group("Mxfe_54") + "ão e " in TEXT and not " de " + m.group("Mxfe_53") + "es " + m.group("Mxfe_54") in TEXT and not m.group("Mxfe_53") + "es " + m.group("Mxfe_54") + "ão ou " in TEXT and not m.group("Mxfe_53") + "es-" + m.group("Mxfe_54") + "ão" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_55>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_56>[a-zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_55").lower() in plvrMfe and not m.group("Mxfe_55") + "es " + m.group("Mxfe_56") + "vel e " in TEXT and not m.group("Mxfe_55") + "es " + m.group("Mxfe_56") + "vel ou " in TEXT and not " de " + m.group("Mxfe_55") + "es " + m.group("Mxfe_56") in TEXT and not m.group("Mxfe_55") + "es-" + m.group("Mxfe_56") + "vel" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_57>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_58>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_57").lower() in plvrMfe and m.group("Mxfe_58").lower() in plvrMfe and not m.group("Mxfe_57") + "es " + m.group("Mxfe_58") + "e e " in TEXT and not m.group("Mxfe_57") + "es " + m.group("Mxfe_58") + "e ou " in TEXT and not " de " + m.group("Mxfe_57") + "es " + m.group("Mxfe_58") in TEXT and not m.group("Mxfe_57") + "es-" + m.group("Mxfe_58") + "e" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_59>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_60>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_59").lower() in plvrMfe and m.group("Mxfe_60").lower() in plvrMfe and not m.group("Mxfe_59") + "es " + m.group("Mxfe_60") + "e e " in TEXT and not m.group("Mxfe_59") + "es " + m.group("Mxfe_60") + "e ou " in TEXT and not " de " + m.group("Mxfe_59") + "es " + m.group("Mxfe_60") in TEXT and not m.group("Mxfe_59") + "es-" + m.group("Mxfe_60") + "e" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_61>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_62>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_61").lower() in plvrMfe and m.group("Mxfe_62") in plvrMfel and not m.group("Mxfe_61") + "es " + m.group("Mxfe_62") + "el e " in TEXT and not m.group("Mxfe_61") + "es " + m.group("Mxfe_62") + "el ou " in TEXT and not " de " + m.group("Mxfe_61") + "es " + m.group("Mxfe_62") in TEXT and not m.group("Mxfe_61") + "es-" + m.group("Mxfe_62") + "el" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_63>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_64>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_63").lower() in plvrMfe and m.group("Mxfe_64") in plvrMfel and not m.group("Mxfe_63") + "es " + m.group("Mxfe_64") + "el e " in TEXT and not m.group("Mxfe_63") + "es " + m.group("Mxfe_64") + "el ou " in TEXT and not " de " + m.group("Mxfe_63") + "es " + m.group("Mxfe_64") in TEXT and not m.group("Mxfe_63") + "es-" + m.group("Mxfe_64") + "el" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_65>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_66>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_65").lower() in plvrMfe and m.group("Mxfe_66") in plvrMfeu and not m.group("Mxfe_65") + "es " + m.group("Mxfe_66") + "u e " in TEXT and not m.group("Mxfe_65") + "es " + m.group("Mxfe_66") + "u ou " in TEXT and not " de " + m.group("Mxfe_65") + "es " + m.group("Mxfe_66") in TEXT and not m.group("Mxfe_65") + "es-" + m.group("Mxfe_66") + "u" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_67>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_68>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_67").lower() in plvrMfe and m.group("Mxfe_68") in plvrFemu and not m.group("Mxfe_67") + "es " + m.group("Mxfe_68") + "u e " in TEXT and not m.group("Mxfe_67") + "es " + m.group("Mxfe_68") + "u ou " in TEXT and not " de " + m.group("Mxfe_67") + "es " + m.group("Mxfe_68") in TEXT and not m.group("Mxfe_67") + "es-" + m.group("Mxfe_68") + "u" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_69>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_70>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_69").lower() in plvrMfe and m.group("Mxfe_70") in plvrInvaz and not m.group("Mxfe_69") + "es " + m.group("Mxfe_70") + "z e " in TEXT and not m.group("Mxfe_69") + "es " + m.group("Mxfe_70") + "z ou " in TEXT and not " de " + m.group("Mxfe_69") + "es " + m.group("Mxfe_70") in TEXT and not m.group("Mxfe_69") + "es-" + m.group("Mxfe_70") + "z" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_71>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_72>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_71").lower() in plvrMfe and m.group("Mxfe_72") in plvrFemz and not m.group("Mxfe_71") + "es " + m.group("Mxfe_72") + "z e " in TEXT and not m.group("Mxfe_71") + "es " + m.group("Mxfe_72") + "z ou " in TEXT and not " de " + m.group("Mxfe_71") + "es " + m.group("Mxfe_72") in TEXT and not m.group("Mxfe_71") + "es-" + m.group("Mxfe_72") + "z" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_73>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_74>[a-záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_73").lower() in plvrMfe and m.group("Mxfe_74").lower() in plvrMfe and not m.group("Mxfe_73") + "es " + m.group("Mxfe_74") + " e " in TEXT and not " de " + m.group("Mxfe_73") + "es " + m.group("Mxfe_74") in TEXT and not m.group("Mxfe_73") + "es " + m.group("Mxfe_74") + " ou " in TEXT and not m.group("Mxfe_73") + "es-" + m.group("Mxfe_74") in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_75>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_76>[a-záâãçéêíóôú]+)e(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_75").lower() in plvrMfe and m.group("Mxfe_76").lower() in plvrFeme and not m.group("Mxfe_75") + "es " + m.group("Mxfe_76") + " e " in TEXT and not " de " + m.group("Mxfe_75") + "es " + m.group("Mxfe_76") in TEXT and not m.group("Mxfe_75") + "es " + m.group("Mxfe_76") + " ou " in TEXT and not m.group("Mxfe_75") + "es-" + m.group("Mxfe_76") in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_77>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_78>[a-zç]+[âêô][mn])ico(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_77").lower() in plvrMfe and not m.group("Mxfe_77") + "es " + m.group("Mxfe_78") + "ico e " in TEXT and not m.group("Mxfe_77") + "es " + m.group("Mxfe_78") + "ico ou " in TEXT and not " de " + m.group("Mxfe_77") + "es " + m.group("Mxfe_78") in TEXT and not m.group("Mxfe_77") + "es-" + m.group("Mxfe_78") + "ico" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_79>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_80>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_79").lower() in plvrMfe and not m.group("Mxfe_79") + "es " + m.group("Mxfe_80") + "ico e " in TEXT and not m.group("Mxfe_79") + "es " + m.group("Mxfe_80") + "ico ou " in TEXT and not " de " + m.group("Mxfe_79") + "es " + m.group("Mxfe_80") in TEXT and not m.group("Mxfe_79") + "es-" + m.group("Mxfe_80") + "ico" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mxfe_81>[a-zA-Záâãçéêíóôú]+)es (?P<Mxfe_82>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "es " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mxfe_81").lower() in plvrMfe and not m.group("Mxfe_81") + "es " + m.group("Mxfe_82") + "ico e " in TEXT and not m.group("Mxfe_81") + "es " + m.group("Mxfe_82") + "ico ou " in TEXT and not " de " + m.group("Mxfe_81") + "es " + m.group("Mxfe_82") in TEXT and not m.group("Mxfe_81") + "es-" + m.group("Mxfe_82") + "ico" in tCompostops and not excplSin.search(TEXT) and not excFparte.search(TEXT)'],
# NOT plvrMascao - femininas terminadas em cao
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_1>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_2>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_1").lower() in plvrMascao and m.group("Msfcao_2").lower() in plvrFema and not m.group("Msfcao_1") + "ões " + m.group("Msfcao_2") + " e " in TEXT and not " de " + m.group("Msfcao_1") + "ões " + m.group("Msfcao_2") in TEXT and not m.group("Msfcao_1") + "ões " + m.group("Msfcao_2") + " ou " in TEXT and not m.group("Msfcao_1") + "ões-" + m.group("Msfcao_2") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_3>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_4>[a-zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_3").lower() in plvrMascao and m.group("Msfcao_4").lower() in plvrMfoa and not m.group("Msfcao_3") + "ões " + m.group("Msfcao_4") + "a e " in TEXT and not m.group("Msfcao_3") + "ões " + m.group("Msfcao_4") + "a ou " in TEXT and not m.group("Msfcao_3") + "ões-" + m.group("Msfcao_4") + "a" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_5>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_6>[a-z]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_5").lower() in plvrMascao and not m.group("Msfcao_6").lower() in excAdo and not m.group("Msfcao_5") + "ões " + m.group("Msfcao_6") + m.group(3) + "do e " in TEXT and not m.group("Msfcao_5") + "ões " + m.group("Msfcao_6") + "ado ou " in TEXT and not " de " + m.group("Msfcao_5") + "ões " + m.group("Msfcao_6") in TEXT and not " das " + m.group("Msfcao_5") + "ões " + m.group("Msfcao_6") + m.group(3) +"do " in TEXT and not m.group("Msfcao_5") + "ões-" + m.group("Msfcao_6") + m.group(3) + "do" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_7>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_8>[a-z]+ista)(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_7").lower() in plvrMascao and not m.group("Msfcao_8").lower() in excIsta and not m.group("Msfcao_7") + "ões " + m.group("Msfcao_8") + " e " in TEXT and not m.group("Msfcao_7") + "ões " + m.group("Msfcao_8") + " ou " in TEXT and not " de " + m.group("Msfcao_7") + "ões " + m.group("Msfcao_8") in TEXT and not m.group("Msfcao_7") + "ões-" + m.group("Msfcao_8") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_9>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_10>[a-z]+a)(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_9").lower() in plvrMascao and m.group("Msfcao_10").lower() in plvrInva and not m.group("Msfcao_9") + "ões " + m.group("Msfcao_10") + " e " in TEXT and not m.group("Msfcao_9") + "ões " + m.group("Msfcao_10") + " ou " in TEXT and not " de " + m.group("Msfcao_9") + "ões " + m.group("Msfcao_10") in TEXT and not m.group("Msfcao_9") + "ões-" + m.group("Msfcao_10") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_11>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_12>[a-z]+)([aí])da(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_11").lower() in plvrMascao and not m.group("Msfcao_12").lower() in excAdo and not m.group("Msfcao_11") + "ões " + m.group("Msfcao_12") + "da e " in TEXT and not m.group("Msfcao_11") + "ões " + m.group("Msfcao_12") + "da ou " in TEXT and not " de " + m.group("Msfcao_11") + "ões " + m.group("Msfcao_12") in TEXT and not m.group("Msfcao_11") + "ões-" + m.group("Msfcao_12") + "da" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_13>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_14>[a-zç]+)oso(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_13").lower() in plvrMascao and not m.group("Msfcao_13") + "ões " + m.group("Msfcao_14") + "oso e " in TEXT and not m.group("Msfcao_13") + "ões " + m.group("Msfcao_14") + "oso ou " in TEXT and not " de " + m.group("Msfcao_13") + "ões " + m.group("Msfcao_14") in TEXT and not m.group("Msfcao_13") + "ões-" + m.group("Msfcao_14") + "oso" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_15>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_16>[a-zç]+)osa(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_15").lower() in plvrMascao and not m.group("Msfcao_15") + "ões " + m.group("Msfcao_16") + "osa e " in TEXT and not m.group("Msfcao_15") + "ões " + m.group("Msfcao_16") + "osa ou " in TEXT and not " de " + m.group("Msfcao_15") + "ões " + m.group("Msfcao_16") in TEXT and not m.group("Msfcao_15") + "ões-" + m.group("Msfcao_16") + "osa" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_17>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_18>[a-zç]+)iva(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_17").lower() in plvrMascao and not m.group("Msfcao_17") + "ões " + m.group("Msfcao_18") + "iva e " in TEXT and not m.group("Msfcao_17") + "ões " + m.group("Msfcao_18") + "iva ou " in TEXT and not " de " + m.group("Msfcao_17") + "ões " + m.group("Msfcao_18") in TEXT and not m.group("Msfcao_17") + "ões-" + m.group("Msfcao_18") + "iva" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_19>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_20>[a-zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_19").lower() in plvrMascao and not m.group("Msfcao_19") + "ões " + m.group("Msfcao_20") + "iva e " in TEXT and not m.group("Msfcao_19") + "ões " + m.group("Msfcao_20") + "iva ou " in TEXT and not " de " + m.group("Msfcao_19") + "ões " + m.group("Msfcao_20") in TEXT and not m.group("Msfcao_19") + "ões-" + m.group("Msfcao_20") + "iva" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_21>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_22>[a-zç]+[âêô][mn])ica(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_21").lower() in plvrMascao and not m.group("Msfcao_21") + "ões " + m.group("Msfcao_22") + "ica e " in TEXT and not m.group("Msfcao_21") + "ões " + m.group("Msfcao_22") + "ica ou " in TEXT and not " de " + m.group("Msfcao_21") + "ões " + m.group("Msfcao_22") in TEXT and not m.group("Msfcao_21") + "ões-" + m.group("Msfcao_22") + "ica" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_23>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_23").lower() in plvrMascao and not m.group("Msfcao_23") + "ões " + m.group("Msfcao_24") + "ica e " in TEXT and not m.group("Msfcao_23") + "ões " + m.group("Msfcao_24") + "ica ou " in TEXT and not " de " + m.group("Msfcao_23") + "ões " + m.group("Msfcao_24") in TEXT and not m.group("Msfcao_23") + "ões-" + m.group("Msfcao_24") + "ica" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_25>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_25").lower() in plvrMascao and not m.group("Msfcao_25") + "ões " + m.group("Msfcao_26") + "ica e " in TEXT and not m.group("Msfcao_25") + "ões " + m.group("Msfcao_26") + "ica ou " in TEXT and not " de " + m.group("Msfcao_25") + "ões " + m.group("Msfcao_26") in TEXT and not m.group("Msfcao_25") + "ões-" + m.group("Msfcao_26") + "ica" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_27>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_28>[a-zç]+)esca(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_27").lower() in plvrMascao and not m.group("Msfcao_27") + "ões " + m.group("Msfcao_28") + "esca e " in TEXT and not m.group("Msfcao_27") + "ões " + m.group("Msfcao_28") + "esca ou " in TEXT and not " de " + m.group("Msfcao_27") + "ões " + m.group("Msfcao_28") in TEXT and not m.group("Msfcao_27") + "ões-" + m.group("Msfcao_28") + "esca" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_29>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ida(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_29").lower() in plvrMascao and not m.group("Msfcao_29") + "ões " + m.group("Msfcao_30") + "ida e " in TEXT and not m.group("Msfcao_29") + "ões " + m.group("Msfcao_30") + "ida ou " in TEXT and not " de " + m.group("Msfcao_29") + "ões " + m.group("Msfcao_30") in TEXT and not m.group("Msfcao_29") + "ões-" + m.group("Msfcao_30") + "ida" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_31>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_32>[a-zç]+[ó])loga(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_31").lower() in plvrMascao and not m.group("Msfcao_31") + "ões " + m.group("Msfcao_32") + "loga e " in TEXT and not m.group("Msfcao_31") + "ões " + m.group("Msfcao_32") + "loga ou " in TEXT and not " de " + m.group("Msfcao_31") + "ões " + m.group("Msfcao_32") in TEXT and not m.group("Msfcao_31") + "ões-" + m.group("Msfcao_32") + "loga" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_33>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_34>[a-zç]+[áéíóúâêô])ria(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_33").lower() in plvrMascao and not m.group("Msfcao_33") + "ões " + m.group("Msfcao_34") + "ria e " in TEXT and not m.group("Msfcao_33") + "ões " + m.group("Msfcao_34") + "ria ou " in TEXT and not " de " + m.group("Msfcao_33") + "ões " + m.group("Msfcao_34") in TEXT and not m.group("Msfcao_33") + "ões-" + m.group("Msfcao_34") + "ria" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_35>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_36>[a-zç]+[í])ssima(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_35").lower() in plvrMascao and not m.group("Msfcao_35") + "ões " + m.group("Msfcao_36") + "ssima e " in TEXT and not m.group("Msfcao_35") + "ões " + m.group("Msfcao_36") + "ssima ou " in TEXT and not " de " + m.group("Msfcao_35") + "ões " + m.group("Msfcao_36") in TEXT and not m.group("Msfcao_35") + "ões-" + m.group("Msfcao_36") + "ssima" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_37>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_38>[a-zç]+[é])sima(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_37").lower() in plvrMascao and not m.group("Msfcao_37") + "ões " + m.group("Msfcao_38") + "sima e " in TEXT and not m.group("Msfcao_37") + "ões " + m.group("Msfcao_38") + "sima ou " in TEXT and not " de " + m.group("Msfcao_37") + "ões " + m.group("Msfcao_38") in TEXT and not m.group("Msfcao_37") + "ões-" + m.group("Msfcao_38") + "sima" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_41>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_42>[a-zçáéíóúâêô]+[dst])ora(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_41").lower() in plvrMascao and not m.group("Msfcao_42") in "D-d-" and not m.group("Msfcao_41") + "ões " + m.group("Msfcao_42") + "ora e " in TEXT and not m.group("Msfcao_41") + "ões " + m.group("Msfcao_42") + "ora ou " in TEXT and not " de " + m.group("Msfcao_41") + "ões " + m.group("Msfcao_42") + "ora" in TEXT and not m.group("Msfcao_41") + "ões-" + m.group("Msfcao_42") + "ora" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_43>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_44>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_43").lower() in plvrMascao and m.group("Msfcao_44") in plvrMfr and not m.group("Msfcao_43") + "ões " + m.group("Msfcao_44") + " e " in TEXT and not m.group("Msfcao_43") + "ões " + m.group("Msfcao_44") + " ou " in TEXT and not " de " + m.group("Msfcao_43") + "ões " + m.group("Msfcao_44") in TEXT and not m.group("Msfcao_43") + "ões-" + m.group("Msfcao_44") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_45>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_46>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_45").lower() in plvrMascao and m.group("Msfcao_46") in plvrFemr and not m.group("Msfcao_45") + "ões " + m.group("Msfcao_46") + " e " in TEXT and not m.group("Msfcao_45") + "ões " + m.group("Msfcao_46") + " ou " in TEXT and not " de " + m.group("Msfcao_45") + "ões " + m.group("Msfcao_46") in TEXT and not m.group("Msfcao_45") + "ões-" + m.group("Msfcao_46") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_47>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_48>[a-zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_47").lower() in plvrMascao and m.group("Msfcao_48") in plvrMfal and not m.group("Msfcao_47") + "ões " + m.group("Msfcao_48") + "l e " in TEXT and not m.group("Msfcao_47") + "ões " + m.group("Msfcao_48") + "l ou " in TEXT and not " de " + m.group("Msfcao_47") + "ões " + m.group("Msfcao_48") in TEXT and not m.group("Msfcao_47") + "ões-" + m.group("Msfcao_48") + "l" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_49>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_50>[a-zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_49").lower() in plvrMascao and m.group("Msfcao_50") in plvrMfcao and not m.group("Msfcao_49") + "ões " + m.group("Msfcao_50") + "ão e " in TEXT and not m.group("Msfcao_49") + "ões " + m.group("Msfcao_50") + "ão ou " in TEXT and not " de " + m.group("Msfcao_49") + "ões " + m.group("Msfcao_50") in TEXT and not m.group("Msfcao_49") + "ões-" + m.group("Msfcao_50") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_51>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_52>[a-zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_51").lower() in plvrMascao and not m.group("Msfcao_52") in plvrMascao and not m.group("Msfcao_51") + "ões " + m.group("Msfcao_52") + "ão e " in TEXT and not m.group("Msfcao_51") + "ões " + m.group("Msfcao_52") + "ão ou " in TEXT and not " de " + m.group("Msfcao_51") + "ões " + m.group("Msfcao_52") in TEXT and not m.group("Msfcao_51") + "ões-" + m.group("Msfcao_52") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_53>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_53").lower() in plvrMascao and m.group("Msfcao_54") in plvrFemao and not m.group("Msfcao_53") + "ões " + m.group("Msfcao_54") + "ão e " in TEXT and not " de " + m.group("Msfcao_53") + "ões " + m.group("Msfcao_54") in TEXT and not m.group("Msfcao_53") + "ões " + m.group("Msfcao_54") + "ão ou " in TEXT and not m.group("Msfcao_53") + "ões-" + m.group("Msfcao_54") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_55>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_56>[a-zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_55").lower() in plvrMascao and not m.group("Msfcao_55") + "ões " + m.group("Msfcao_56") + "vel e " in TEXT and not m.group("Msfcao_55") + "ões " + m.group("Msfcao_56") + "vel ou " in TEXT and not " de " + m.group("Msfcao_55") + "ões " + m.group("Msfcao_56") in TEXT and not m.group("Msfcao_55") + "ões-" + m.group("Msfcao_56") + "vel" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_57>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_58>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_57").lower() in plvrMascao and m.group("Msfcao_58").lower() in plvrMfe and not m.group("Msfcao_57") + "ões " + m.group("Msfcao_58") + "e e " in TEXT and not m.group("Msfcao_57") + "ões " + m.group("Msfcao_58") + "e ou " in TEXT and not " de " + m.group("Msfcao_57") + "ões " + m.group("Msfcao_58") in TEXT and not m.group("Msfcao_57") + "ões-" + m.group("Msfcao_58") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_59>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_60>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_59").lower() in plvrMascao and m.group("Msfcao_60").lower() in plvrFeme and not m.group("Msfcao_59") + "ões " + m.group("Msfcao_60") + "e e " in TEXT and not m.group("Msfcao_59") + "ões " + m.group("Msfcao_60") + "e ou " in TEXT and not " de " + m.group("Msfcao_59") + "ões " + m.group("Msfcao_60") in TEXT and not m.group("Msfcao_59") + "ões-" + m.group("Msfcao_60") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_61>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_62>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_61").lower() in plvrMascao and m.group("Msfcao_62") in plvrMfel and not m.group("Msfcao_61") + "ões " + m.group("Msfcao_62") + "el e " in TEXT and not m.group("Msfcao_61") + "ões " + m.group("Msfcao_62") + "el ou " in TEXT and not " de " + m.group("Msfcao_61") + "ões " + m.group("Msfcao_62") in TEXT and not m.group("Msfcao_61") + "ões-" + m.group("Msfcao_62") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_63>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_64>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_63").lower() in plvrMascao and m.group("Msfcao_64") in plvrFemel and not m.group("Msfcao_63") + "ões " + m.group("Msfcao_64") + "el e " in TEXT and not m.group("Msfcao_63") + "ões " + m.group("Msfcao_64") + "el ou " in TEXT and not " de " + m.group("Msfcao_63") + "ões " + m.group("Msfcao_64") in TEXT and not m.group("Msfcao_63") + "ões-" + m.group("Msfcao_64") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_65>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_66>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_65").lower() in plvrMascao and m.group("Msfcao_66") in plvrMfeu and not m.group("Msfcao_65") + "ões " + m.group("Msfcao_66") + "u e " in TEXT and not m.group("Msfcao_65") + "ões " + m.group("Msfcao_66") + "u ou " in TEXT and not " de " + m.group("Msfcao_65") + "ões " + m.group("Msfcao_66") in TEXT and not m.group("Msfcao_65") + "ões-" + m.group("Msfcao_66") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_67>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_68>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_67").lower() in plvrMascao and m.group("Msfcao_68") in plvrFemu and not m.group("Msfcao_67") + "ões " + m.group("Msfcao_68") + "u e " in TEXT and not m.group("Msfcao_67") + "ões " + m.group("Msfcao_68") + "u ou " in TEXT and not " de " + m.group("Msfcao_67") + "ões " + m.group("Msfcao_68") in TEXT and not m.group("Msfcao_67") + "ões-" + m.group("Msfcao_68") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_69>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_70>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_69").lower() in plvrMascao and m.group("Msfcao_70") in plvrInvaz and not m.group("Msfcao_69") + "ões " + m.group("Msfcao_70") + "z e " in TEXT and not m.group("Msfcao_69") + "ões " + m.group("Msfcao_70") + "z ou " in TEXT and not " de " + m.group("Msfcao_69") + "ões " + m.group("Msfcao_70") in TEXT and not m.group("Msfcao_69") + "ões-" + m.group("Msfcao_70") + "z" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_71>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_72>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_71").lower() in plvrMascao and m.group("Msfcao_72") in plvrFemz and not m.group("Msfcao_71") + "ões " + m.group("Msfcao_72") + "z e " in TEXT and not m.group("Msfcao_71") + "ões " + m.group("Msfcao_72") + "z ou " in TEXT and not " de " + m.group("Msfcao_71") + "ões " + m.group("Msfcao_72") in TEXT and not m.group("Msfcao_71") + "ões-" + m.group("Msfcao_72") + "z" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msfcao_73>[a-zA-Zçáéíóúâêô]+[ç])ões (?P<Msfcao_74>[a-záâãçéêíóôú]+[ã])(?![-\\w–\xad])', '= m.group(1) + "ões " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msfcao_73").lower() in plvrMascao and m.group("Msfcao_74") in pvrFeman and not m.group("Msfcao_73") + "ões " + m.group("Msfcao_74") + " e " in TEXT and not m.group("Msfcao_73") + "ões " + m.group("Msfcao_74") + " ou " in TEXT and not " de " + m.group("Msfcao_73") + "ões " + m.group("Msfcao_74") in TEXT and not m.group("Msfcao_73") + "ões-" + m.group("Msfcao_74") in tCompostops and not excplSin.search(TEXT)'],
# plvrMasco conbinado
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_1>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_2>[a-záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_1").lower() in plvrMasco and m.group("Mist_2").lower() in plvrMasco and not m.group("Mist_1") + "s " + m.group("Mist_2") + " e " in TEXT and not " de " + m.group("Mist_1") + "s " + m.group("Mist_2") in TEXT and not m.group("Mist_1") + "s " + m.group("Mist_2") + " ou " in TEXT and not m.group("Mist_1") + "s-" + m.group("Mist_2") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_3>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_4>[a-zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_3").lower() in plvrMasco and m.group("Mist_4").lower() in plvrMfoa and not m.group("Mist_4").lower() in excMist and not m.group("Mist_3") + "s " + m.group("Mist_4") + "o e " in TEXT and not m.group("Mist_3") + "s " + m.group("Mist_4") + "o ou " in TEXT and not " de " + m.group("Mist_3") + "s " + m.group("Mist_4") in TEXT and not m.group("Mist_3") + "s-" + m.group("Mist_4") + "o" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_5>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_6>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_5").lower() in plvrMasco and m.group("Mist_6").lower() in plvrMasca and not m.group("Mist_5") + "s " + m.group("Mist_6") + " e " in TEXT and not m.group("Mist_5") + "s " + m.group("Mist_6") + " ou " in TEXT and not " de " + m.group("Mist_5") + "s " + m.group("Mist_6") in TEXT and not m.group("Mist_5") + "s-" + m.group("Mist_6") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_7>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_8>[a-z]+ista)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_7").lower() in plvrMasco and not m.group("Mist_8").lower() in excIsta and not m.group("Mist_7") + "s " + m.group("Mist_8") + " e " in TEXT and not m.group("Mist_7") + "s " + m.group("Mist_8") + " ou " in TEXT and not " de " + m.group("Mist_7") + "s " + m.group("Mist_8") in TEXT and not m.group("Mist_7") + "s-" + m.group("Mist_8") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_9>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_10>[a-z]+a)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_9").lower() in plvrMasco and m.group("Mist_10").lower() in plvrInva and not m.group("Mist_9") + "s " + m.group("Mist_10") + " e " in TEXT and not m.group("Mist_9") + "s " + m.group("Mist_10") + " ou " in TEXT and not " de " + m.group("Mist_9") + "s " + m.group("Mist_10") in TEXT and not m.group("Mist_9") + "s-" + m.group("Mist_10") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_11>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_12>[a-z]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "dos\\n" +m.group(1) + "s, " + m.group(2) + m.group(3) + "do"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_11").lower() in plvrMasco and not m.group("Mist_12").lower() in excAdo and not m.group("Mist_11") + "s " + m.group("Mist_12") + "do e " in TEXT and not m.group("Mist_11") + "s " + m.group("Mist_12") + "do ou " in TEXT and not " de " + m.group("Mist_11") + "s " + m.group("Mist_12") in TEXT and not m.group("Mist_11") + "s-" + m.group("Mist_12") + "do" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_15>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_16>[a-zç]+)oso(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_15").lower() in plvrMasco and not m.group("Mist_15") + "s " + m.group("Mist_16") + "oso e " in TEXT and not m.group("Mist_15") + "s " + m.group("Mist_16") + "oso ou " in TEXT and not " de " + m.group("Mist_15") + "s " + m.group("Mist_16") in TEXT and not m.group("Mist_15") + "s-" + m.group("Mist_16") + "oso" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_17>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_18>[a-zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_17").lower() in plvrMasco and not m.group("Mist_17") + "s " + m.group("Mist_18") + "ivo e " in TEXT and not m.group("Mist_17") + "s " + m.group("Mist_18") + "ivo ou " in TEXT and not " de " + m.group("Mist_17") + "s " + m.group("Mist_18") in TEXT and not m.group("Mist_17") + "s-" + m.group("Mist_18") + "ivo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_19>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_20>[a-zç]+)mento(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_19").lower() in plvrMasco and not m.group("Mist_20") in excMento and not m.group("Mist_19") + "s " + m.group("Mist_20") + "mento e " in TEXT and not m.group("Mist_19") + "s " + m.group("Mist_20") + "mento ou " in TEXT and not " de " + m.group("Mist_19") + "s " + m.group("Mist_20") in TEXT and not m.group("Mist_19") + "s-" + m.group("Mist_20") + "mento" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_21>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_22>[a-zç]+[âêô][mn])ico(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_21").lower() in plvrMasco and not m.group("Mist_21") + "s " + m.group("Mist_22") + "ico e " in TEXT and not m.group("Mist_21") + "s " + m.group("Mist_22") + "ico ou " in TEXT and not " de " + m.group("Mist_21") + "s " + m.group("Mist_22") in TEXT and not m.group("Mist_21") + "s-" + m.group("Mist_22") + "ico" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_23>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_23").lower() in plvrMasco and not m.group("Mist_23") + "s " + m.group("Mist_24") + "ico e " in TEXT and not m.group("Mist_23") + "s " + m.group("Mist_24") + "ico ou " in TEXT and not " de " + m.group("Mist_23") + "s " + m.group("Mist_24") in TEXT and not m.group("Mist_23") + "s-" + m.group("Mist_24") + "ico" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_25>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_25").lower() in plvrMasco and not m.group("Mist_25") + "s " + m.group("Mist_26") + "ico e " in TEXT and not m.group("Mist_25") + "s " + m.group("Mist_26") + "ico ou " in TEXT and not " de " + m.group("Mist_25") + "s " + m.group("Mist_26") in TEXT and not m.group("Mist_25") + "s-" + m.group("Mist_26") + "ico" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_27>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_28>[a-zç]+)esco(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_27").lower() in plvrMasco and not m.group("Mist_27") + "s " + m.group("Mist_28") + "esco e " in TEXT and not m.group("Mist_27") + "s " + m.group("Mist_28") + "esco ou " in TEXT and not " de " + m.group("Mist_27") + "s " + m.group("Mist_28") in TEXT and not m.group("Mist_27") + "s-" + m.group("Mist_28") + "esco" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_29>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ido(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_29").lower() in plvrMasco and not m.group("Mist_29") + "s " + m.group("Mist_30") + "ido e " in TEXT and not m.group("Mist_29") + "s " + m.group("Mist_30") + "ido ou " in TEXT and not " de " + m.group("Mist_29") + "s " + m.group("Mist_30") in TEXT and not m.group("Mist_29") + "s-" + m.group("Mist_30") + "ido" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_31>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_32>[a-zç]+[ó])logo(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_31").lower() in plvrMasco and not m.group("Mist_31") + "s " + m.group("Mist_32") + "logo e " in TEXT and not m.group("Mist_31") + "s " + m.group("Mist_32") + "logo ou " in TEXT and not " de " + m.group("Mist_31") + "s " + m.group("Mist_32") in TEXT and not m.group("Mist_31") + "s-" + m.group("Mist_32") + "logo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_33>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_34>[a-zç]+[áéíóúâêô])rio(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_33").lower() in plvrMasco and not m.group("Mist_33") + "s " + m.group("Mist_34") + "rio e " in TEXT and not m.group("Mist_33") + "s " + m.group("Mist_34") + "rio ou " in TEXT and not " de " + m.group("Mist_33") + "s " + m.group("Mist_34") in TEXT and not m.group("Mist_33") + "s-" + m.group("Mist_34") + "rio" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_35>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_36>[a-zç]+[í])ssimo(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_35").lower() in plvrMasco and not m.group("Mist_35") + "s " + m.group("Mist_36") + "ssimo e " in TEXT and not m.group("Mist_35") + "s " + m.group("Mist_36") + "ssimo ou " in TEXT and not " de " + m.group("Mist_35") + "s " + m.group("Mist_36") in TEXT and not m.group("Mist_35") + "s-" + m.group("Mist_36") + "ssimo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_37>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_38>[a-zç]+[é])simo(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_37").lower() in plvrMasco and not m.group("Mist_37") + "s " + m.group("Mist_38") + "simo e " in TEXT and not m.group("Mist_37") + "s " + m.group("Mist_38") + "simo ou " in TEXT and not " de " + m.group("Mist_37") + "s " + m.group("Mist_38") in TEXT and not m.group("Mist_37") + "s-" + m.group("Mist_38") + "simo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_41>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_42>[a-zçáéíóúâêô]+[dst])or(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_41").lower() in plvrMasco and not m.group("Mist_42") in "D-d-" and not m.group("Mist_41") + "s " + m.group("Mist_42") + "or e " in TEXT and not m.group("Mist_41") + "s " + m.group("Mist_42") + "or ou " in TEXT and not " de " + m.group("Mist_41") + "s " + m.group("Mist_42") in TEXT and not m.group("Mist_41") + "s-" + m.group("Mist_42") + "or" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_43>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_44>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_43").lower() in plvrMasco and m.group("Mist_44") in plvrMfr and not m.group("Mist_43") + "s " + m.group("Mist_44") + " e " in TEXT and not m.group("Mist_43") + "s " + m.group("Mist_44") + " ou " in TEXT and not " de " + m.group("Mist_43") + "s " + m.group("Mist_44") in TEXT and not m.group("Mist_43") + "s-" + m.group("Mist_44") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_45>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_46>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_45").lower() in plvrMasco and m.group("Mist_46") in plvrMascr and not m.group("Mist_45") + "s " + m.group("Mist_46") + " e " in TEXT and not m.group("Mist_45") + "s " + m.group("Mist_46") + " ou " in TEXT and not " de " + m.group("Mist_45") + "s " + m.group("Mist_46") in TEXT and not m.group("Mist_45") + "s-" + m.group("Mist_46") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_47>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_48>[a-zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_47").lower() in plvrMasco and m.group("Mist_48") in plvrMfal and not m.group("Mist_47") + "s " + m.group("Mist_48") + "l e " in TEXT and not m.group("Mist_47") + "s " + m.group("Mist_48") + "l ou " in TEXT and not " de " + m.group("Mist_47") + "s " + m.group("Mist_48") in TEXT and not m.group("Mist_47") + "s-" + m.group("Mist_48") + "l" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_49>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_50>[a-zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_49").lower() in plvrMasco and m.group("Mist_50") in plvrMascal and not m.group("Mist_49") + "s " + m.group("Mist_50") + "l e " in TEXT and not m.group("Mist_49") + "s " + m.group("Mist_50") + "l ou " in TEXT and not " de " + m.group("Mist_49") + "s " + m.group("Mist_50") in TEXT and not m.group("Mist_49") + "s-" + m.group("Mist_50") + "l" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_51>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_52>[a-zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_51").lower() in plvrMasco and m.group("Mist_52") in plvrMfcao and not m.group("Mist_51") + "s " + m.group("Mist_52") + "ão e " in TEXT and not m.group("Mist_51") + "s " + m.group("Mist_52") + "ão ou " in TEXT and not " de " + m.group("Mist_51") + "s " + m.group("Mist_52") in TEXT and not m.group("Mist_51") + "s-" + m.group("Mist_52") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_53>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_53").lower() in plvrMasco and not m.group("Mist_54") in plvrFemao and not m.group("Mist_54") in excPlvrao and m.group("Mist_54") in plvrMfcao and not m.group("Mist_53") + "s " + m.group("Mist_54") + "ão e " in TEXT and not " de " + m.group("Mist_53") + "s " + m.group("Mist_54") in TEXT and not m.group("Mist_53") + "s " + m.group("Mist_54") + "ão ou " in TEXT and not m.group("Mist_53") + "s-" + m.group("Mist_54") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_55>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_56>[a-zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_55").lower() in plvrMasco and not m.group("Mist_55") + "s " + m.group("Mist_56") + "vel e " in TEXT and not m.group("Mist_55") + "s " + m.group("Mist_56") + "vel ou " in TEXT and not " de " + m.group("Mist_55") + "s " + m.group("Mist_56") in TEXT and not m.group("Mist_55") + "s-" + m.group("Mist_56") + "vel" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_57>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_58>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_57").lower() in plvrMasco and m.group("Mist_58").lower() in plvrMfe and not m.group("Mist_57") + "s " + m.group("Mist_58") + "e e " in TEXT and not m.group("Mist_57") + "s " + m.group("Mist_58") + "e ou " in TEXT and not " de " + m.group("Mist_57") + "s " + m.group("Mist_58") in TEXT and not m.group("Mist_57") + "s-" + m.group("Mist_58") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_59>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_60>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_59").lower() in plvrMasco and m.group("Mist_60").lower() in plvrMasce and not m.group("Mist_59") + "s " + m.group("Mist_60") + "e e " in TEXT and not m.group("Mist_59") + "s " + m.group("Mist_60") + "e ou " in TEXT and not " de " + m.group("Mist_59") + "s " + m.group("Mist_60") in TEXT and not m.group("Mist_59") + "s-" + m.group("Mist_60") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_61>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_62>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_61").lower() in plvrMasco and m.group("Mist_62") in plvrMfel and not m.group("Mist_61") + "s " + m.group("Mist_62") + "el e " in TEXT and not m.group("Mist_61") + "s " + m.group("Mist_62") + "el ou " in TEXT and not " de " + m.group("Mist_61") + "s " + m.group("Mist_62") in TEXT and not m.group("Mist_61") + "s-" + m.group("Mist_62") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_63>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_64>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_63").lower() in plvrMasco and m.group("Mist_64") in plvrMascel and not m.group("Mist_63") + "s " + m.group("Mist_64") + "el e " in TEXT and not m.group("Mist_63") + "s " + m.group("Mist_64") + "el ou " in TEXT and not " de " + m.group("Mist_63") + "s " + m.group("Mist_64") in TEXT and not m.group("Mist_63") + "s-" + m.group("Mist_64") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_65>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_66>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_65").lower() in plvrMasco and m.group("Mist_66") in plvrMfeu and not m.group("Mist_65") + "s " + m.group("Mist_66") + "u e " in TEXT and not m.group("Mist_65") + "s " + m.group("Mist_66") + "u ou " in TEXT and not " de " + m.group("Mist_65") + "s " + m.group("Mist_66") in TEXT and not m.group("Mist_65") + "s-" + m.group("Mist_66") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_67>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_68>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_67").lower() in plvrMasco and m.group("Mist_68") in plvrMascu and not m.group("Mist_67") + "s " + m.group("Mist_68") + "u e " in TEXT and not m.group("Mist_67") + "s " + m.group("Mist_68") + "u ou " in TEXT and not " de " + m.group("Mist_67") + "s " + m.group("Mist_68") in TEXT and not m.group("Mist_67") + "s-" + m.group("Mist_68") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_69>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_70>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_69").lower() in plvrMasco and m.group("Mist_70") in plvrInvaz and not m.group("Mist_69") + "s " + m.group("Mist_70") + "z e " in TEXT and not m.group("Mist_69") + "s " + m.group("Mist_70") + "z ou " in TEXT and not " de " + m.group("Mist_69") + "s " + m.group("Mist_70") in TEXT and not m.group("Mist_69") + "s-" + m.group("Mist_70") + "z" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mist_71>[a-zA-Záâãçéêíóôú]+[o])s (?P<Mist_72>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mist_71").lower() in plvrMasco and m.group("Mist_72") in plvrMascz and not m.group("Mist_71") + "s " + m.group("Mist_72") + "z e " in TEXT and not m.group("Mist_71") + "s " + m.group("Mist_72") + "z ou " in TEXT and not " de " + m.group("Mist_71") + "s " + m.group("Mist_72") in TEXT and not m.group("Mist_71") + "s-" + m.group("Mist_72") + "z" in tCompostops and not excplSin.search(TEXT)'],
# plvrMasca conbinado
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_1>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_2>[a-záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_1").lower() in plvrMasca and m.group("Mixt_2").lower() in plvrMasco and not m.group("Mixt_1") + "s " + m.group("Mixt_2") + " e " in TEXT and not " de " + m.group("Mixt_1") + "s " + m.group("Mixt_2") in TEXT and not m.group("Mixt_1") + "s " + m.group("Mixt_2") + " ou " in TEXT and not m.group("Mixt_1") + "s-" + m.group("Mixt_2") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_3>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_4>[a-zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_3").lower() in plvrMasca and m.group("Mixt_4").lower() in plvrMfoa and not m.group("Mixt_4").lower() in excMist and not m.group("Mixt_3") + "s " + m.group("Mixt_4") + "o e " in TEXT and not m.group("Mixt_3") + "s " + m.group("Mixt_4") + "o ou " in TEXT and not " de " + m.group("Mixt_3") + "s " + m.group("Mixt_4") in TEXT and not m.group("Mixt_3") + "s-" + m.group("Mixt_4") + "o" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_5>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_6>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_5").lower() in plvrMasca and m.group("Mixt_6").lower() in plvrMasca and not m.group("Mixt_5") + "s " + m.group("Mixt_6") + " e " in TEXT and not m.group("Mixt_5") + "s " + m.group("Mixt_6") + " ou " in TEXT and not " de " + m.group("Mixt_5") + "s " + m.group("Mixt_6") in TEXT and not m.group("Mixt_5") + "s-" + m.group("Mixt_6") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_7>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_8>[a-z]+ista)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_7").lower() in plvrMasca and not m.group("Mixt_8").lower() in excIsta and not m.group("Mixt_7") + "s " + m.group("Mixt_8") + " e " in TEXT and not m.group("Mixt_7") + "s " + m.group("Mixt_8") + " ou " in TEXT and not " de " + m.group("Mixt_7") + "s " + m.group("Mixt_8") in TEXT and not m.group("Mixt_7") + "s-" + m.group("Mixt_8") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_9>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_10>[a-z]+a)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_9").lower() in plvrMasca and m.group("Mixt_10").lower() in plvrInva and not m.group("Mixt_9") + "s " + m.group("Mixt_10") + " e " in TEXT and not m.group("Mixt_9") + "s " + m.group("Mixt_10") + " ou " in TEXT and not " de " + m.group("Mixt_9") + "s " + m.group("Mixt_10") in TEXT and not m.group("Mixt_9") + "s-" + m.group("Mixt_10") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_11>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_12>[a-z]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + m.group(3) + "dos\\n" +m.group(1) + "s, " + m.group(2) + m.group(3) + "do"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_11").lower() in plvrMasca and not m.group("Mixt_12").lower() in excAdo and not m.group("Mixt_11") + "s " + m.group("Mixt_12") + "do e " in TEXT and not m.group("Mixt_11") + "s " + m.group("Mixt_12") + "do ou " in TEXT and not " de " + m.group("Mixt_11") + "s " + m.group("Mixt_12") in TEXT and not m.group("Mixt_11") + "s-" + m.group("Mixt_12") + "do" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_15>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_16>[a-zç]+)oso(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_15").lower() in plvrMasca and not m.group("Mixt_15") + "s " + m.group("Mixt_16") + "oso e " in TEXT and not m.group("Mixt_15") + "s " + m.group("Mixt_16") + "oso ou " in TEXT and not " de " + m.group("Mixt_15") + "s " + m.group("Mixt_16") in TEXT and not m.group("Mixt_15") + "s-" + m.group("Mixt_16") + "oso" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_17>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_18>[a-zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_17").lower() in plvrMasca and not m.group("Mixt_17") + "s " + m.group("Mixt_18") + "ivo e " in TEXT and not m.group("Mixt_17") + "s " + m.group("Mixt_18") + "ivo ou " in TEXT and not " de " + m.group("Mixt_17") + "s " + m.group("Mixt_18") in TEXT and not m.group("Mixt_17") + "s-" + m.group("Mixt_18") + "ivo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_19>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_20>[a-zç]+)mento(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_19").lower() in plvrMasca and not m.group("Mixt_20") in excMento and not m.group("Mixt_19") + "s " + m.group("Mixt_20") + "mento e " in TEXT and not m.group("Mixt_19") + "s " + m.group("Mixt_20") + "mento ou " in TEXT and not " de " + m.group("Mixt_19") + "s " + m.group("Mixt_20") in TEXT and not m.group("Mixt_19") + "s-" + m.group("Mixt_20") + "mento" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_21>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_22>[a-zç]+[âêô][mn])ico(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_21").lower() in plvrMasca and not m.group("Mixt_21") + "s " + m.group("Mixt_22") + "ico e " in TEXT and not m.group("Mixt_21") + "s " + m.group("Mixt_22") + "ico ou " in TEXT and not " de " + m.group("Mixt_21") + "s " + m.group("Mixt_22") in TEXT and not m.group("Mixt_21") + "s-" + m.group("Mixt_22") + "ico" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_23>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_23").lower() in plvrMasca and not m.group("Mixt_23") + "s " + m.group("Mixt_24") + "ico e " in TEXT and not m.group("Mixt_23") + "s " + m.group("Mixt_24") + "ico ou " in TEXT and not " de " + m.group("Mixt_23") + "s " + m.group("Mixt_24") in TEXT and not m.group("Mixt_23") + "s-" + m.group("Mixt_24") + "ico" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_25>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_25").lower() in plvrMasca and not m.group("Mixt_25") + "s " + m.group("Mixt_26") + "ico e " in TEXT and not m.group("Mixt_25") + "s " + m.group("Mixt_26") + "ico ou " in TEXT and not " de " + m.group("Mixt_25") + "s " + m.group("Mixt_26") in TEXT and not m.group("Mixt_25") + "s-" + m.group("Mixt_26") + "ico" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_27>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_28>[a-zç]+)esco(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_27").lower() in plvrMasca and not m.group("Mixt_27") + "s " + m.group("Mixt_28") + "esco e " in TEXT and not m.group("Mixt_27") + "s " + m.group("Mixt_28") + "esco ou " in TEXT and not " de " + m.group("Mixt_27") + "s " + m.group("Mixt_28") in TEXT and not m.group("Mixt_27") + "s-" + m.group("Mixt_28") + "esco" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_29>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ido(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_29").lower() in plvrMasca and not m.group("Mixt_29") + "s " + m.group("Mixt_30") + "ido e " in TEXT and not m.group("Mixt_29") + "s " + m.group("Mixt_30") + "ido ou " in TEXT and not " de " + m.group("Mixt_29") + "s " + m.group("Mixt_30") in TEXT and not m.group("Mixt_29") + "s-" + m.group("Mixt_30") + "ido" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_31>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_32>[a-zç]+[ó])logo(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_31").lower() in plvrMasca and not m.group("Mixt_31") + "s " + m.group("Mixt_32") + "logo e " in TEXT and not m.group("Mixt_31") + "s " + m.group("Mixt_32") + "logo ou " in TEXT and not " de " + m.group("Mixt_31") + "s " + m.group("Mixt_32") in TEXT and not m.group("Mixt_31") + "s-" + m.group("Mixt_32") + "logo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_33>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_34>[a-zç]+[áéíóúâêô])rio(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_33").lower() in plvrMasca and not m.group("Mixt_33") + "s " + m.group("Mixt_34") + "rio e " in TEXT and not m.group("Mixt_33") + "s " + m.group("Mixt_34") + "rio ou " in TEXT and not " de " + m.group("Mixt_33") + "s " + m.group("Mixt_34") in TEXT and not m.group("Mixt_33") + "s-" + m.group("Mixt_34") + "rio" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_35>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_36>[a-zç]+[í])ssimo(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_35").lower() in plvrMasca and not m.group("Mixt_35") + "s " + m.group("Mixt_36") + "ssimo e " in TEXT and not m.group("Mixt_35") + "s " + m.group("Mixt_36") + "ssimo ou " in TEXT and not " de " + m.group("Mixt_35") + "s " + m.group("Mixt_36") in TEXT and not m.group("Mixt_35") + "s-" + m.group("Mixt_36") + "ssimo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_37>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_38>[a-zç]+[é])simo(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_37").lower() in plvrMasca and not m.group("Mixt_37") + "s " + m.group("Mixt_38") + "simo e " in TEXT and not m.group("Mixt_37") + "s " + m.group("Mixt_38") + "simo ou " in TEXT and not " de " + m.group("Mixt_37") + "s " + m.group("Mixt_38") in TEXT and not m.group("Mixt_37") + "s-" + m.group("Mixt_38") + "simo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_41>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_42>[a-zçáéíóúâêô]+[dst])or(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_41").lower() in plvrMasca and not m.group("Mixt_42") in "D-d-" and not m.group("Mixt_41") + "s " + m.group("Mixt_42") + "or e " in TEXT and not m.group("Mixt_41") + "s " + m.group("Mixt_42") + "or ou " in TEXT and not " de " + m.group("Mixt_41") + "s " + m.group("Mixt_42") in TEXT and not m.group("Mixt_41") + "s-" + m.group("Mixt_42") + "or" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_43>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_44>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_43").lower() in plvrMasca and m.group("Mixt_44") in plvrMfr and not m.group("Mixt_43") + "s " + m.group("Mixt_44") + " e " in TEXT and not m.group("Mixt_43") + "s " + m.group("Mixt_44") + " ou " in TEXT and not " de " + m.group("Mixt_43") + "s " + m.group("Mixt_44") in TEXT and not m.group("Mixt_43") + "s-" + m.group("Mixt_44") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_45>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_46>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_45").lower() in plvrMasca and m.group("Mixt_46") in plvrMascr and not m.group("Mixt_45") + "s " + m.group("Mixt_46") + " e " in TEXT and not m.group("Mixt_45") + "s " + m.group("Mixt_46") + " ou " in TEXT and not " de " + m.group("Mixt_45") + "s " + m.group("Mixt_46") in TEXT and not m.group("Mixt_45") + "s-" + m.group("Mixt_46") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_47>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_48>[a-zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_47").lower() in plvrMasca and m.group("Mixt_48") in plvrMfal and not m.group("Mixt_47") + "s " + m.group("Mixt_48") + "l e " in TEXT and not m.group("Mixt_47") + "s " + m.group("Mixt_48") + "l ou " in TEXT and not " de " + m.group("Mixt_47") + "s " + m.group("Mixt_48") in TEXT and not m.group("Mixt_47") + "s-" + m.group("Mixt_48") + "l" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_49>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_50>[a-zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_49").lower() in plvrMasca and m.group("Mixt_50") in plvrMascal and not m.group("Mixt_49") + "s " + m.group("Mixt_50") + "l e " in TEXT and not m.group("Mixt_49") + "s " + m.group("Mixt_50") + "l ou " in TEXT and not " de " + m.group("Mixt_49") + "s " + m.group("Mixt_50") in TEXT and not m.group("Mixt_49") + "s-" + m.group("Mixt_50") + "l" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_51>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_52>[a-zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_51").lower() in plvrMasca and m.group("Mixt_52") in plvrMfcao and not m.group("Mixt_51") + "s " + m.group("Mixt_52") + "ão e " in TEXT and not m.group("Mixt_51") + "s " + m.group("Mixt_52") + "ão ou " in TEXT and not " de " + m.group("Mixt_51") + "s " + m.group("Mixt_52") in TEXT and not m.group("Mixt_51") + "s-" + m.group("Mixt_52") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_53>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_53").lower() in plvrMasca and not m.group("Mixt_54") in plvrFemao and not m.group("Mixt_54") in excPlvrao and m.group("Mixt_54") in plvrMfcao and not m.group("Mixt_53") + "s " + m.group("Mixt_54") + "ão e " in TEXT and not " de " + m.group("Mixt_53") + "s " + m.group("Mixt_54") in TEXT and not m.group("Mixt_53") + "s " + m.group("Mixt_54") + "ão ou " in TEXT and not m.group("Mixt_53") + "s-" + m.group("Mixt_54") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_55>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_56>[a-zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_55").lower() in plvrMasca and not m.group("Mixt_55") + "s " + m.group("Mixt_56") + "vel e " in TEXT and not m.group("Mixt_55") + "s " + m.group("Mixt_56") + "vel ou " in TEXT and not " de " + m.group("Mixt_55") + "s " + m.group("Mixt_56") in TEXT and not m.group("Mixt_55") + "s-" + m.group("Mixt_56") + "vel" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_57>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_58>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_57").lower() in plvrMasca and m.group("Mixt_58").lower() in plvrMfe and not m.group("Mixt_57") + "s " + m.group("Mixt_58") + "e e " in TEXT and not m.group("Mixt_57") + "s " + m.group("Mixt_58") + "e ou " in TEXT and not " de " + m.group("Mixt_57") + "s " + m.group("Mixt_58") in TEXT and not m.group("Mixt_57") + "s-" + m.group("Mixt_58") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_59>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_60>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_59").lower() in plvrMasca and m.group("Mixt_60").lower() in plvrMasce and not m.group("Mixt_59") + "s " + m.group("Mixt_60") + "e e " in TEXT and not m.group("Mixt_59") + "s " + m.group("Mixt_60") + "e ou " in TEXT and not " de " + m.group("Mixt_59") + "s " + m.group("Mixt_60") in TEXT and not m.group("Mixt_59") + "s-" + m.group("Mixt_60") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_61>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_62>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_61").lower() in plvrMasca and m.group("Mixt_62") in plvrMfel and not m.group("Mixt_61") + "s " + m.group("Mixt_62") + "el e " in TEXT and not m.group("Mixt_61") + "s " + m.group("Mixt_62") + "el ou " in TEXT and not " de " + m.group("Mixt_61") + "s " + m.group("Mixt_62") in TEXT and not m.group("Mixt_61") + "s-" + m.group("Mixt_62") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_63>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_64>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_63").lower() in plvrMasca and m.group("Mixt_64") in plvrMascel and not m.group("Mixt_63") + "s " + m.group("Mixt_64") + "el e " in TEXT and not m.group("Mixt_63") + "s " + m.group("Mixt_64") + "el ou " in TEXT and not " de " + m.group("Mixt_63") + "s " + m.group("Mixt_64") in TEXT and not m.group("Mixt_63") + "s-" + m.group("Mixt_64") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_65>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_66>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_65").lower() in plvrMasca and m.group("Mixt_66") in plvrMfeu and not m.group("Mixt_65") + "s " + m.group("Mixt_66") + "u e " in TEXT and not m.group("Mixt_65") + "s " + m.group("Mixt_66") + "u ou " in TEXT and not " de " + m.group("Mixt_65") + "s " + m.group("Mixt_66") in TEXT and not m.group("Mixt_65") + "s-" + m.group("Mixt_66") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_67>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_68>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_67").lower() in plvrMasca and m.group("Mixt_68") in plvrMascu and not m.group("Mixt_67") + "s " + m.group("Mixt_68") + "u e " in TEXT and not m.group("Mixt_67") + "s " + m.group("Mixt_68") + "u ou " in TEXT and not " de " + m.group("Mixt_67") + "s " + m.group("Mixt_68") in TEXT and not m.group("Mixt_67") + "s-" + m.group("Mixt_68") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_69>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_70>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_69").lower() in plvrMasca and m.group("Mixt_70") in plvrInvaz and not m.group("Mixt_69") + "s " + m.group("Mixt_70") + "z e " in TEXT and not m.group("Mixt_69") + "s " + m.group("Mixt_70") + "z ou " in TEXT and not " de " + m.group("Mixt_69") + "s " + m.group("Mixt_70") in TEXT and not m.group("Mixt_69") + "s-" + m.group("Mixt_70") + "z" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mixt_71>[a-zA-Záâãçéêíóôú]+[a])s (?P<Mixt_72>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mixt_71").lower() in plvrMasca and m.group("Mixt_72") in plvrMascz and not m.group("Mixt_71") + "s " + m.group("Mixt_72") + "z e " in TEXT and not m.group("Mixt_71") + "s " + m.group("Mixt_72") + "z ou " in TEXT and not " de " + m.group("Mixt_71") + "s " + m.group("Mixt_72") in TEXT and not m.group("Mixt_71") + "s-" + m.group("Mixt_72") + "z" in tCompostops and not excplSin.search(TEXT)'],
# plvrMfal conbinado
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_1>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_2>[a-záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_1").lower() in plvrMfal and m.group("Malx_2").lower() in plvrMasco and not m.group("Malx_1") + "is " + m.group("Malx_2") + " e " in TEXT and not " de " + m.group("Malx_1") + "is " + m.group("Malx_2") in TEXT and not m.group("Malx_1") + "is " + m.group("Malx_2") + " ou " in TEXT and not m.group("Malx_1") + "is-" + m.group("Malx_2") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_3>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_4>[a-zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_3").lower() in plvrMfal and m.group("Malx_4").lower() in plvrMfoa and not m.group("Malx_4").lower() in excMist and not m.group("Malx_3") + "is " + m.group("Malx_4") + "o e " in TEXT and not m.group("Malx_3") + "is " + m.group("Malx_4") + "o ou " in TEXT and not " de " + m.group("Malx_3") + "is " + m.group("Malx_4") in TEXT and not m.group("Malx_3") + "s-" + m.group("Malx_4") + "o" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_5>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_6>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_5").lower() in plvrMfal and m.group("Malx_6").lower() in plvrMasca and not m.group("Malx_5") + "is " + m.group("Malx_6") + " e " in TEXT and not m.group("Malx_5") + "is " + m.group("Malx_6") + " ou " in TEXT and not " de " + m.group("Malx_5") + "is " + m.group("Malx_6") in TEXT and not m.group("Malx_5") + "s-" + m.group("Malx_6") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_7>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_8>[a-z]+ista)(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_7").lower() in plvrMfal and not m.group("Malx_8").lower() in excIsta and not m.group("Malx_7") + "is " + m.group("Malx_8") + " e " in TEXT and not m.group("Malx_7") + "is " + m.group("Malx_8") + " ou " in TEXT and not " de " + m.group("Malx_7") + "is " + m.group("Malx_8") in TEXT and not m.group("Malx_7") + "s-" + m.group("Malx_8") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_9>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_10>[a-z]+a)(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_9").lower() in plvrMfal and m.group("Malx_10").lower() in plvrInva and not m.group("Malx_9") + "is " + m.group("Malx_10") + " e " in TEXT and not m.group("Malx_9") + "is " + m.group("Malx_10") + " ou " in TEXT and not " de " + m.group("Malx_9") + "is " + m.group("Malx_10") in TEXT and not m.group("Malx_9") + "s-" + m.group("Malx_10") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_11>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_12>[a-z]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + m.group(3) + "dos\\n" +m.group(1) + "s, " + m.group(2) + m.group(3) + "do"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_11").lower() in plvrMfal and not m.group("Malx_12").lower() in excAdo and not m.group("Malx_11") + "is " + m.group("Malx_12") + "do e " in TEXT and not m.group("Malx_11") + "is " + m.group("Malx_12") + "do ou " in TEXT and not " de " + m.group("Malx_11") + "is " + m.group("Malx_12") in TEXT and not m.group("Malx_11") + "s-" + m.group("Malx_12") + "do" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_15>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_16>[a-zç]+)oso(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_15").lower() in plvrMfal and not m.group("Malx_15") + "is " + m.group("Malx_16") + "oso e " in TEXT and not m.group("Malx_15") + "is " + m.group("Malx_16") + "oso ou " in TEXT and not " de " + m.group("Malx_15") + "is " + m.group("Malx_16") in TEXT and not m.group("Malx_15") + "s-" + m.group("Malx_16") + "oso" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_17>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_18>[a-zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_17").lower() in plvrMfal and not m.group("Malx_17") + "is " + m.group("Malx_18") + "ivo e " in TEXT and not m.group("Malx_17") + "is " + m.group("Malx_18") + "ivo ou " in TEXT and not " de " + m.group("Malx_17") + "is " + m.group("Malx_18") in TEXT and not m.group("Malx_17") + "s-" + m.group("Malx_18") + "ivo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_19>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_20>[a-zç]+)mento(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_19").lower() in plvrMfal and not m.group("Malx_20") in excMento and not m.group("Malx_19") + "is " + m.group("Malx_20") + "mento e " in TEXT and not m.group("Malx_19") + "is " + m.group("Malx_20") + "mento ou " in TEXT and not " de " + m.group("Malx_19") + "is " + m.group("Malx_20") in TEXT and not m.group("Malx_19") + "s-" + m.group("Malx_20") + "mento" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_21>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_22>[a-zç]+[âêô][mn])ico(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_21").lower() in plvrMfal and not m.group("Malx_21") + "is " + m.group("Malx_22") + "ico e " in TEXT and not m.group("Malx_21") + "is " + m.group("Malx_22") + "ico ou " in TEXT and not " de " + m.group("Malx_21") + "is " + m.group("Malx_22") in TEXT and not m.group("Malx_21") + "s-" + m.group("Malx_22") + "ico" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_23>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_23").lower() in plvrMfal and not m.group("Malx_23") + "is " + m.group("Malx_24") + "ico e " in TEXT and not m.group("Malx_23") + "is " + m.group("Malx_24") + "ico ou " in TEXT and not " de " + m.group("Malx_23") + "is " + m.group("Malx_24") in TEXT and not m.group("Malx_23") + "s-" + m.group("Malx_24") + "ico" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_25>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_25").lower() in plvrMfal and not m.group("Malx_25") + "is " + m.group("Malx_26") + "ico e " in TEXT and not m.group("Malx_25") + "is " + m.group("Malx_26") + "ico ou " in TEXT and not " de " + m.group("Malx_25") + "is " + m.group("Malx_26") in TEXT and not m.group("Malx_25") + "s-" + m.group("Malx_26") + "ico" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_27>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_28>[a-zç]+)esco(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_27").lower() in plvrMfal and not m.group("Malx_27") + "is " + m.group("Malx_28") + "esco e " in TEXT and not m.group("Malx_27") + "is " + m.group("Malx_28") + "esco ou " in TEXT and not " de " + m.group("Malx_27") + "is " + m.group("Malx_28") in TEXT and not m.group("Malx_27") + "s-" + m.group("Malx_28") + "esco" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_29>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ido(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_29").lower() in plvrMfal and not m.group("Malx_29") + "is " + m.group("Malx_30") + "ido e " in TEXT and not m.group("Malx_29") + "is " + m.group("Malx_30") + "ido ou " in TEXT and not " de " + m.group("Malx_29") + "is " + m.group("Malx_30") in TEXT and not m.group("Malx_29") + "s-" + m.group("Malx_30") + "ido" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_31>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_32>[a-zç]+[ó])logo(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_31").lower() in plvrMfal and not m.group("Malx_31") + "is " + m.group("Malx_32") + "logo e " in TEXT and not m.group("Malx_31") + "is " + m.group("Malx_32") + "logo ou " in TEXT and not " de " + m.group("Malx_31") + "is " + m.group("Malx_32") in TEXT and not m.group("Malx_31") + "s-" + m.group("Malx_32") + "logo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_33>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_34>[a-zç]+[áéíóúâêô])rio(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_33").lower() in plvrMfal and not m.group("Malx_33") + "is " + m.group("Malx_34") + "rio e " in TEXT and not m.group("Malx_33") + "is " + m.group("Malx_34") + "rio ou " in TEXT and not " de " + m.group("Malx_33") + "is " + m.group("Malx_34") in TEXT and not m.group("Malx_33") + "s-" + m.group("Malx_34") + "rio" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_35>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_36>[a-zç]+[í])ssimo(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_35").lower() in plvrMfal and not m.group("Malx_35") + "is " + m.group("Malx_36") + "ssimo e " in TEXT and not m.group("Malx_35") + "is " + m.group("Malx_36") + "ssimo ou " in TEXT and not " de " + m.group("Malx_35") + "is " + m.group("Malx_36") in TEXT and not m.group("Malx_35") + "s-" + m.group("Malx_36") + "ssimo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_37>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_38>[a-zç]+[é])simo(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_37").lower() in plvrMfal and not m.group("Malx_37") + "is " + m.group("Malx_38") + "simo e " in TEXT and not m.group("Malx_37") + "is " + m.group("Malx_38") + "simo ou " in TEXT and not " de " + m.group("Malx_37") + "is " + m.group("Malx_38") in TEXT and not m.group("Malx_37") + "s-" + m.group("Malx_38") + "simo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_41>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_42>[a-zçáéíóúâêô]+[dst])or(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_41").lower() in plvrMfal and not m.group("Malx_42") in "D-d-" and not m.group("Malx_41") + "is " + m.group("Malx_42") + "or e " in TEXT and not m.group("Malx_41") + "is " + m.group("Malx_42") + "or ou " in TEXT and not " de " + m.group("Malx_41") + "is " + m.group("Malx_42") in TEXT and not m.group("Malx_41") + "s-" + m.group("Malx_42") + "or" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_43>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_44>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_43").lower() in plvrMfal and m.group("Malx_44") in plvrMfr and not m.group("Malx_43") + "is " + m.group("Malx_44") + " e " in TEXT and not m.group("Malx_43") + "is " + m.group("Malx_44") + " ou " in TEXT and not " de " + m.group("Malx_43") + "is " + m.group("Malx_44") in TEXT and not m.group("Malx_43") + "s-" + m.group("Malx_44") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_45>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_46>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_45").lower() in plvrMfal and m.group("Malx_46") in plvrMascr and not m.group("Malx_45") + "is " + m.group("Malx_46") + " e " in TEXT and not m.group("Malx_45") + "is " + m.group("Malx_46") + " ou " in TEXT and not " de " + m.group("Malx_45") + "is " + m.group("Malx_46") in TEXT and not m.group("Malx_45") + "s-" + m.group("Malx_46") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_47>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_48>[a-zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_47").lower() in plvrMfal and m.group("Malx_48") in plvrMfal and not m.group("Malx_47") + "is " + m.group("Malx_48") + "l e " in TEXT and not m.group("Malx_47") + "is " + m.group("Malx_48") + "l ou " in TEXT and not " de " + m.group("Malx_47") + "is " + m.group("Malx_48") in TEXT and not m.group("Malx_47") + "s-" + m.group("Malx_48") + "l" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_49>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_50>[a-zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_49").lower() in plvrMfal and m.group("Malx_50") in plvrMascal and not m.group("Malx_49") + "is " + m.group("Malx_50") + "l e " in TEXT and not m.group("Malx_49") + "is " + m.group("Malx_50") + "l ou " in TEXT and not " de " + m.group("Malx_49") + "is " + m.group("Malx_50") in TEXT and not m.group("Malx_49") + "s-" + m.group("Malx_50") + "l" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_51>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_52>[a-zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_51").lower() in plvrMfal and m.group("Malx_52") in plvrMfcao and not m.group("Malx_51") + "is " + m.group("Malx_52") + "ão e " in TEXT and not m.group("Malx_51") + "is " + m.group("Malx_52") + "ão ou " in TEXT and not " de " + m.group("Malx_51") + "is " + m.group("Malx_52") in TEXT and not m.group("Malx_51") + "s-" + m.group("Malx_52") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_53>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_53").lower() in plvrMfal and not m.group("Malx_54") in plvrFemao and not m.group("Malx_54") in excPlvrao and m.group("Malx_54") in plvrMfcao and not m.group("Malx_53") + "is " + m.group("Malx_54") + "ão e " in TEXT and not " de " + m.group("Malx_53") + "is " + m.group("Malx_54") in TEXT and not m.group("Malx_53") + "is " + m.group("Malx_54") + "ão ou " in TEXT and not m.group("Malx_53") + "s-" + m.group("Malx_54") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_55>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_56>[a-zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_55").lower() in plvrMfal and not m.group("Malx_55") + "is " + m.group("Malx_56") + "vel e " in TEXT and not m.group("Malx_55") + "is " + m.group("Malx_56") + "vel ou " in TEXT and not " de " + m.group("Malx_55") + "is " + m.group("Malx_56") in TEXT and not m.group("Malx_55") + "s-" + m.group("Malx_56") + "vel" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_57>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_58>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_57").lower() in plvrMfal and m.group("Malx_58").lower() in plvrMfe and not m.group("Malx_57") + "is " + m.group("Malx_58") + "e e " in TEXT and not m.group("Malx_57") + "is " + m.group("Malx_58") + "e ou " in TEXT and not " de " + m.group("Malx_57") + "is " + m.group("Malx_58") in TEXT and not m.group("Malx_57") + "s-" + m.group("Malx_58") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_59>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_60>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_59").lower() in plvrMfal and m.group("Malx_60").lower() in plvrMasce and not m.group("Malx_59") + "is " + m.group("Malx_60") + "e e " in TEXT and not m.group("Malx_59") + "is " + m.group("Malx_60") + "e ou " in TEXT and not " de " + m.group("Malx_59") + "is " + m.group("Malx_60") in TEXT and not m.group("Malx_59") + "s-" + m.group("Malx_60") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_61>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_62>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_61").lower() in plvrMfal and m.group("Malx_62") in plvrMfel and not m.group("Malx_61") + "is " + m.group("Malx_62") + "el e " in TEXT and not m.group("Malx_61") + "is " + m.group("Malx_62") + "el ou " in TEXT and not " de " + m.group("Malx_61") + "is " + m.group("Malx_62") in TEXT and not m.group("Malx_61") + "s-" + m.group("Malx_62") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_63>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_64>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_63").lower() in plvrMfal and m.group("Malx_64") in plvrMascel and not m.group("Malx_63") + "is " + m.group("Malx_64") + "el e " in TEXT and not m.group("Malx_63") + "is " + m.group("Malx_64") + "el ou " in TEXT and not " de " + m.group("Malx_63") + "is " + m.group("Malx_64") in TEXT and not m.group("Malx_63") + "s-" + m.group("Malx_64") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_65>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_66>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_65").lower() in plvrMfal and m.group("Malx_66") in plvrMfeu and not m.group("Malx_65") + "is " + m.group("Malx_66") + "u e " in TEXT and not m.group("Malx_65") + "is " + m.group("Malx_66") + "u ou " in TEXT and not " de " + m.group("Malx_65") + "is " + m.group("Malx_66") in TEXT and not m.group("Malx_65") + "s-" + m.group("Malx_66") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_67>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_68>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_67").lower() in plvrMfal and m.group("Malx_68") in plvrMascu and not m.group("Malx_67") + "is " + m.group("Malx_68") + "u e " in TEXT and not m.group("Malx_67") + "is " + m.group("Malx_68") + "u ou " in TEXT and not " de " + m.group("Malx_67") + "is " + m.group("Malx_68") in TEXT and not m.group("Malx_67") + "s-" + m.group("Malx_68") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_69>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_70>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_69").lower() in plvrMfal and m.group("Malx_70") in plvrInvaz and not m.group("Malx_69") + "is " + m.group("Malx_70") + "z e " in TEXT and not m.group("Malx_69") + "is " + m.group("Malx_70") + "z ou " in TEXT and not " de " + m.group("Malx_69") + "is " + m.group("Malx_70") in TEXT and not m.group("Malx_69") + "s-" + m.group("Malx_70") + "z" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malx_71>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malx_72>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malx_71").lower() in plvrMfal and m.group("Malx_72") in plvrMascz and not m.group("Malx_71") + "is " + m.group("Malx_72") + "z e " in TEXT and not m.group("Malx_71") + "is " + m.group("Malx_72") + "z ou " in TEXT and not " de " + m.group("Malx_71") + "is " + m.group("Malx_72") in TEXT and not m.group("Malx_71") + "s-" + m.group("Malx_72") + "z" in tCompostops and not excplSin.search(TEXT)'],
# plvrMascal conbinado
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_1>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_2>[a-záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_1").lower() in plvrMascal and m.group("Malk_2").lower() in plvrMasco and not m.group("Malk_1") + "is " + m.group("Malk_2") + " e " in TEXT and not " de " + m.group("Malk_1") + "is " + m.group("Malk_2") in TEXT and not m.group("Malk_1") + "is " + m.group("Malk_2") + " ou " in TEXT and not m.group("Malk_1") + "is-" + m.group("Malk_2") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_3>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_4>[a-zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_3").lower() in plvrMascal and m.group("Malk_4").lower() in plvrMfoa and not m.group("Malk_4").lower() in excMist and not m.group("Malk_3") + "is " + m.group("Malk_4") + "o e " in TEXT and not m.group("Malk_3") + "is " + m.group("Malk_4") + "o ou " in TEXT and not " de " + m.group("Malk_3") + "is " + m.group("Malk_4") in TEXT and not m.group("Malk_3") + "s-" + m.group("Malk_4") + "o" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_5>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_6>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_5").lower() in plvrMascal and m.group("Malk_6").lower() in plvrMasca and not m.group("Malk_5") + "is " + m.group("Malk_6") + " e " in TEXT and not m.group("Malk_5") + "is " + m.group("Malk_6") + " ou " in TEXT and not " de " + m.group("Malk_5") + "is " + m.group("Malk_6") in TEXT and not m.group("Malk_5") + "s-" + m.group("Malk_6") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_7>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_8>[a-z]+ista)(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_7").lower() in plvrMascal and not m.group("Malk_8").lower() in excIsta and not m.group("Malk_7") + "is " + m.group("Malk_8") + " e " in TEXT and not m.group("Malk_7") + "is " + m.group("Malk_8") + " ou " in TEXT and not " de " + m.group("Malk_7") + "is " + m.group("Malk_8") in TEXT and not m.group("Malk_7") + "s-" + m.group("Malk_8") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_9>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_10>[a-z]+a)(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_9").lower() in plvrMascal and m.group("Malk_10").lower() in plvrInva and not m.group("Malk_9") + "is " + m.group("Malk_10") + " e " in TEXT and not m.group("Malk_9") + "is " + m.group("Malk_10") + " ou " in TEXT and not " de " + m.group("Malk_9") + "is " + m.group("Malk_10") in TEXT and not m.group("Malk_9") + "s-" + m.group("Malk_10") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_11>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_12>[a-z]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + m.group(3) + "dos\\n" +m.group(1) + "s, " + m.group(2) + m.group(3) + "do"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_11").lower() in plvrMascal and not m.group("Malk_12").lower() in excAdo and not m.group("Malk_11") + "is " + m.group("Malk_12") + "do e " in TEXT and not m.group("Malk_11") + "is " + m.group("Malk_12") + "do ou " in TEXT and not " de " + m.group("Malk_11") + "is " + m.group("Malk_12") in TEXT and not m.group("Malk_11") + "s-" + m.group("Malk_12") + "do" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_15>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_16>[a-zç]+)oso(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_15").lower() in plvrMascal and not m.group("Malk_15") + "is " + m.group("Malk_16") + "oso e " in TEXT and not m.group("Malk_15") + "is " + m.group("Malk_16") + "oso ou " in TEXT and not " de " + m.group("Malk_15") + "is " + m.group("Malk_16") in TEXT and not m.group("Malk_15") + "s-" + m.group("Malk_16") + "oso" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_17>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_18>[a-zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_17").lower() in plvrMascal and not m.group("Malk_17") + "is " + m.group("Malk_18") + "ivo e " in TEXT and not m.group("Malk_17") + "is " + m.group("Malk_18") + "ivo ou " in TEXT and not " de " + m.group("Malk_17") + "is " + m.group("Malk_18") in TEXT and not m.group("Malk_17") + "s-" + m.group("Malk_18") + "ivo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_19>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_20>[a-zç]+)mento(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_19").lower() in plvrMascal and not m.group("Malk_20") in excMento and not m.group("Malk_19") + "is " + m.group("Malk_20") + "mento e " in TEXT and not m.group("Malk_19") + "is " + m.group("Malk_20") + "mento ou " in TEXT and not " de " + m.group("Malk_19") + "is " + m.group("Malk_20") in TEXT and not m.group("Malk_19") + "s-" + m.group("Malk_20") + "mento" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_21>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_22>[a-zç]+[âêô][mn])ico(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_21").lower() in plvrMascal and not m.group("Malk_21") + "is " + m.group("Malk_22") + "ico e " in TEXT and not m.group("Malk_21") + "is " + m.group("Malk_22") + "ico ou " in TEXT and not " de " + m.group("Malk_21") + "is " + m.group("Malk_22") in TEXT and not m.group("Malk_21") + "s-" + m.group("Malk_22") + "ico" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_23>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_23").lower() in plvrMascal and not m.group("Malk_23") + "is " + m.group("Malk_24") + "ico e " in TEXT and not m.group("Malk_23") + "is " + m.group("Malk_24") + "ico ou " in TEXT and not " de " + m.group("Malk_23") + "is " + m.group("Malk_24") in TEXT and not m.group("Malk_23") + "s-" + m.group("Malk_24") + "ico" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_25>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_25").lower() in plvrMascal and not m.group("Malk_25") + "is " + m.group("Malk_26") + "ico e " in TEXT and not m.group("Malk_25") + "is " + m.group("Malk_26") + "ico ou " in TEXT and not " de " + m.group("Malk_25") + "is " + m.group("Malk_26") in TEXT and not m.group("Malk_25") + "s-" + m.group("Malk_26") + "ico" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_27>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_28>[a-zç]+)esco(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_27").lower() in plvrMascal and not m.group("Malk_27") + "is " + m.group("Malk_28") + "esco e " in TEXT and not m.group("Malk_27") + "is " + m.group("Malk_28") + "esco ou " in TEXT and not " de " + m.group("Malk_27") + "is " + m.group("Malk_28") in TEXT and not m.group("Malk_27") + "s-" + m.group("Malk_28") + "esco" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_29>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ido(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_29").lower() in plvrMascal and not m.group("Malk_29") + "is " + m.group("Malk_30") + "ido e " in TEXT and not m.group("Malk_29") + "is " + m.group("Malk_30") + "ido ou " in TEXT and not " de " + m.group("Malk_29") + "is " + m.group("Malk_30") in TEXT and not m.group("Malk_29") + "s-" + m.group("Malk_30") + "ido" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_31>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_32>[a-zç]+[ó])logo(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_31").lower() in plvrMascal and not m.group("Malk_31") + "is " + m.group("Malk_32") + "logo e " in TEXT and not m.group("Malk_31") + "is " + m.group("Malk_32") + "logo ou " in TEXT and not " de " + m.group("Malk_31") + "is " + m.group("Malk_32") in TEXT and not m.group("Malk_31") + "s-" + m.group("Malk_32") + "logo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_33>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_34>[a-zç]+[áéíóúâêô])rio(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_33").lower() in plvrMascal and not m.group("Malk_33") + "is " + m.group("Malk_34") + "rio e " in TEXT and not m.group("Malk_33") + "is " + m.group("Malk_34") + "rio ou " in TEXT and not " de " + m.group("Malk_33") + "is " + m.group("Malk_34") in TEXT and not m.group("Malk_33") + "s-" + m.group("Malk_34") + "rio" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_35>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_36>[a-zç]+[í])ssimo(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_35").lower() in plvrMascal and not m.group("Malk_35") + "is " + m.group("Malk_36") + "ssimo e " in TEXT and not m.group("Malk_35") + "is " + m.group("Malk_36") + "ssimo ou " in TEXT and not " de " + m.group("Malk_35") + "is " + m.group("Malk_36") in TEXT and not m.group("Malk_35") + "s-" + m.group("Malk_36") + "ssimo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_37>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_38>[a-zç]+[é])simo(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_37").lower() in plvrMascal and not m.group("Malk_37") + "is " + m.group("Malk_38") + "simo e " in TEXT and not m.group("Malk_37") + "is " + m.group("Malk_38") + "simo ou " in TEXT and not " de " + m.group("Malk_37") + "is " + m.group("Malk_38") in TEXT and not m.group("Malk_37") + "s-" + m.group("Malk_38") + "simo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_41>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_42>[a-zçáéíóúâêô]+[dst])or(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_41").lower() in plvrMascal and not m.group("Malk_42") in "D-d-" and not m.group("Malk_41") + "is " + m.group("Malk_42") + "or e " in TEXT and not m.group("Malk_41") + "is " + m.group("Malk_42") + "or ou " in TEXT and not " de " + m.group("Malk_41") + "is " + m.group("Malk_42") in TEXT and not m.group("Malk_41") + "s-" + m.group("Malk_42") + "or" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_43>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_44>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_43").lower() in plvrMascal and m.group("Malk_44") in plvrMfr and not m.group("Malk_43") + "is " + m.group("Malk_44") + " e " in TEXT and not m.group("Malk_43") + "is " + m.group("Malk_44") + " ou " in TEXT and not " de " + m.group("Malk_43") + "is " + m.group("Malk_44") in TEXT and not m.group("Malk_43") + "s-" + m.group("Malk_44") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_45>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_46>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_45").lower() in plvrMascal and m.group("Malk_46") in plvrMascr and not m.group("Malk_45") + "is " + m.group("Malk_46") + " e " in TEXT and not m.group("Malk_45") + "is " + m.group("Malk_46") + " ou " in TEXT and not " de " + m.group("Malk_45") + "is " + m.group("Malk_46") in TEXT and not m.group("Malk_45") + "s-" + m.group("Malk_46") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_47>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_48>[a-zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_47").lower() in plvrMascal and m.group("Malk_48") in plvrMfal and not m.group("Malk_47") + "is " + m.group("Malk_48") + "l e " in TEXT and not m.group("Malk_47") + "is " + m.group("Malk_48") + "l ou " in TEXT and not " de " + m.group("Malk_47") + "is " + m.group("Malk_48") in TEXT and not m.group("Malk_47") + "s-" + m.group("Malk_48") + "l" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_49>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_50>[a-zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_49").lower() in plvrMascal and m.group("Malk_50") in plvrMascal and not m.group("Malk_49") + "is " + m.group("Malk_50") + "l e " in TEXT and not m.group("Malk_49") + "is " + m.group("Malk_50") + "l ou " in TEXT and not " de " + m.group("Malk_49") + "is " + m.group("Malk_50") in TEXT and not m.group("Malk_49") + "s-" + m.group("Malk_50") + "l" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_51>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_52>[a-zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_51").lower() in plvrMascal and m.group("Malk_52") in plvrMfcao and not m.group("Malk_51") + "is " + m.group("Malk_52") + "ão e " in TEXT and not m.group("Malk_51") + "is " + m.group("Malk_52") + "ão ou " in TEXT and not " de " + m.group("Malk_51") + "is " + m.group("Malk_52") in TEXT and not m.group("Malk_51") + "s-" + m.group("Malk_52") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_53>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_53").lower() in plvrMascal and not m.group("Malk_54") in plvrFemao and not m.group("Malk_54") in excPlvrao and m.group("Malk_54") in plvrMfcao and not m.group("Malk_53") + "is " + m.group("Malk_54") + "ão e " in TEXT and not " de " + m.group("Malk_53") + "is " + m.group("Malk_54") in TEXT and not m.group("Malk_53") + "is " + m.group("Malk_54") + "ão ou " in TEXT and not m.group("Malk_53") + "s-" + m.group("Malk_54") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_55>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_56>[a-zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_55").lower() in plvrMascal and not m.group("Malk_55") + "is " + m.group("Malk_56") + "vel e " in TEXT and not m.group("Malk_55") + "is " + m.group("Malk_56") + "vel ou " in TEXT and not " de " + m.group("Malk_55") + "is " + m.group("Malk_56") in TEXT and not m.group("Malk_55") + "s-" + m.group("Malk_56") + "vel" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_57>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_58>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_57").lower() in plvrMascal and m.group("Malk_58").lower() in plvrMfe and not m.group("Malk_57") + "is " + m.group("Malk_58") + "e e " in TEXT and not m.group("Malk_57") + "is " + m.group("Malk_58") + "e ou " in TEXT and not " de " + m.group("Malk_57") + "is " + m.group("Malk_58") in TEXT and not m.group("Malk_57") + "s-" + m.group("Malk_58") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_59>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_60>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_59").lower() in plvrMascal and m.group("Malk_60").lower() in plvrMasce and not m.group("Malk_59") + "is " + m.group("Malk_60") + "e e " in TEXT and not m.group("Malk_59") + "is " + m.group("Malk_60") + "e ou " in TEXT and not " de " + m.group("Malk_59") + "is " + m.group("Malk_60") in TEXT and not m.group("Malk_59") + "s-" + m.group("Malk_60") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_61>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_62>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_61").lower() in plvrMascal and m.group("Malk_62") in plvrMfel and not m.group("Malk_61") + "is " + m.group("Malk_62") + "el e " in TEXT and not m.group("Malk_61") + "is " + m.group("Malk_62") + "el ou " in TEXT and not " de " + m.group("Malk_61") + "is " + m.group("Malk_62") in TEXT and not m.group("Malk_61") + "s-" + m.group("Malk_62") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_63>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_64>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_63").lower() in plvrMascal and m.group("Malk_64") in plvrMascel and not m.group("Malk_63") + "is " + m.group("Malk_64") + "el e " in TEXT and not m.group("Malk_63") + "is " + m.group("Malk_64") + "el ou " in TEXT and not " de " + m.group("Malk_63") + "is " + m.group("Malk_64") in TEXT and not m.group("Malk_63") + "s-" + m.group("Malk_64") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_65>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_66>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_65").lower() in plvrMascal and m.group("Malk_66") in plvrMfeu and not m.group("Malk_65") + "is " + m.group("Malk_66") + "u e " in TEXT and not m.group("Malk_65") + "is " + m.group("Malk_66") + "u ou " in TEXT and not " de " + m.group("Malk_65") + "is " + m.group("Malk_66") in TEXT and not m.group("Malk_65") + "s-" + m.group("Malk_66") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_67>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_68>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_67").lower() in plvrMascal and m.group("Malk_68") in plvrMascu and not m.group("Malk_67") + "is " + m.group("Malk_68") + "u e " in TEXT and not m.group("Malk_67") + "is " + m.group("Malk_68") + "u ou " in TEXT and not " de " + m.group("Malk_67") + "is " + m.group("Malk_68") in TEXT and not m.group("Malk_67") + "s-" + m.group("Malk_68") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_69>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_70>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_69").lower() in plvrMascal and m.group("Malk_70") in plvrInvaz and not m.group("Malk_69") + "is " + m.group("Malk_70") + "z e " in TEXT and not m.group("Malk_69") + "is " + m.group("Malk_70") + "z ou " in TEXT and not " de " + m.group("Malk_69") + "is " + m.group("Malk_70") in TEXT and not m.group("Malk_69") + "s-" + m.group("Malk_70") + "z" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Malk_71>[a-zA-Zçáéíóúâêô]+[a])is (?P<Malk_72>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "is " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Malk_71").lower() in plvrMascal and m.group("Malk_72") in plvrMascz and not m.group("Malk_71") + "is " + m.group("Malk_72") + "z e " in TEXT and not m.group("Malk_71") + "is " + m.group("Malk_72") + "z ou " in TEXT and not " de " + m.group("Malk_71") + "is " + m.group("Malk_72") in TEXT and not m.group("Malk_71") + "s-" + m.group("Malk_72") + "z" in tCompostops and not excplSin.search(TEXT)'],
# plvrMfoa combinado
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_1>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_2>[a-záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_1").lower() in plvrMfoa and m.group("Mast_2").lower() in plvrMasco and not m.group("Mast_1") + "os " + m.group("Mast_2") + " e " in TEXT and not m.group("Mast_1") + "os " + m.group("Mast_2") + " ou " in TEXT and not m.group("Mast_1") + "os-" + m.group("Mast_2") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_3>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_4>[a-zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_3").lower() in plvrMfoa and m.group("Mast_4").lower() in plvrMfoa and not m.group("Mast_4").lower() in excMist and not m.group("Mast_3") + "os " + m.group("Mast_4") + "o e " in TEXT and not m.group("Mast_3") + "os " + m.group("Mast_4") + "o ou " in TEXT and not m.group("Mast_3") + "os-" + m.group("Mast_4") + "o" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_5>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_6>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_5").lower() in plvrMfoa and m.group("Mast_6").lower() in plvrMasca and not m.group("Mast_5") + "os " + m.group("Mast_6") + " e " in TEXT and not m.group("Mast_5") + "os " + m.group("Mast_6") + " ou " in TEXT and not m.group("Mast_5") + "os-" + m.group("Mast_6") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_7>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_8>[a-z]+ista)(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_7").lower() in plvrMfoa and not m.group("Mast_8").lower() in excIsta and not m.group("Mast_7") + "os " + m.group("Mast_8") + " e " in TEXT and not m.group("Mast_7") + "os " + m.group("Mast_8") + " ou " in TEXT and not m.group("Mast_7") + "os-" + m.group("Mast_8") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_9>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_10>[a-z]+a)(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_9").lower() in plvrMfoa and m.group("Mast_10").lower() in plvrInva and not m.group("Mast_9") + "os " + m.group("Mast_10") + " e " in TEXT and not m.group("Mast_9") + "os " + m.group("Mast_10") + " ou " in TEXT and not m.group("Mast_9") + "os-" + m.group("Mast_10") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_11>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_12>[a-z]+)([aí])do(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_11").lower() in plvrMfoa and not m.group("Mast_12").lower() in excAdo and not m.group("Mast_11") + "os " + m.group("Mast_12") + "do e " in TEXT and not m.group("Mast_11") + "os " + m.group("Mast_12") + "do ou " in TEXT and not m.group("Mast_11") + "os-" + m.group("Mast_12") + "do" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_15>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_16>[a-zç]+)oso(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "osos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_15").lower() in plvrMfoa and not m.group("Mast_15") + "os " + m.group("Mast_16") + "oso e " in TEXT and not m.group("Mast_15") + "os " + m.group("Mast_16") + "oso ou " in TEXT and not m.group("Mast_15") + "os-" + m.group("Mast_16") + "oso" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_17>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_18>[a-zç]+)ivo(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ivos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_17").lower() in plvrMfoa and not m.group("Mast_17") + "os " + m.group("Mast_18") + "ivo e " in TEXT and not m.group("Mast_17") + "os " + m.group("Mast_18") + "ivo ou " in TEXT and not m.group("Mast_17") + "os-" + m.group("Mast_18") + "ivo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_19>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_20>[a-zç]+)mento(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_19").lower() in plvrMfoa and not m.group("Mast_20") in excMento and not m.group("Mast_19") + "os " + m.group("Mast_20") + "mento e " in TEXT and not m.group("Mast_19") + "os " + m.group("Mast_20") + "mento ou " in TEXT and not m.group("Mast_19") + "os-" + m.group("Mast_20") + "mento" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_21>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_22>[a-zç]+[âêô][mn])ico(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_21").lower() in plvrMfoa and not m.group("Mast_21") + "os " + m.group("Mast_22") + "ico e " in TEXT and not m.group("Mast_21") + "os " + m.group("Mast_22") + "ico ou " in TEXT and not m.group("Mast_21") + "os-" + m.group("Mast_22") + "ico" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_23>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_23").lower() in plvrMfoa and not m.group("Mast_23") + "os " + m.group("Mast_24") + "ico e " in TEXT and not m.group("Mast_23") + "os " + m.group("Mast_24") + "ico ou " in TEXT and not m.group("Mast_23") + "os-" + m.group("Mast_24") + "ico" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_25>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ico(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "icos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_25").lower() in plvrMfoa and not m.group("Mast_25") + "os " + m.group("Mast_26") + "ico e " in TEXT and not m.group("Mast_25") + "os " + m.group("Mast_26") + "ico ou " in TEXT and not m.group("Mast_25") + "os-" + m.group("Mast_26") + "ico" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_27>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_28>[a-zç]+)esco(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "escos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_27").lower() in plvrMfoa and not m.group("Mast_27") + "os " + m.group("Mast_28") + "esco e " in TEXT and not m.group("Mast_27") + "os " + m.group("Mast_28") + "esco ou " in TEXT and not m.group("Mast_27") + "os-" + m.group("Mast_28") + "esco" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_29>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ido(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "idos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_29").lower() in plvrMfoa and not m.group("Mast_29") + "os " + m.group("Mast_30") + "ido e " in TEXT and not m.group("Mast_29") + "os " + m.group("Mast_30") + "ido ou " in TEXT and not m.group("Mast_29") + "os-" + m.group("Mast_30") + "ido" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_31>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_32>[a-zç]+[ó])logo(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "logos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_31").lower() in plvrMfoa and not m.group("Mast_31") + "os " + m.group("Mast_32") + "logo e " in TEXT and not m.group("Mast_31") + "os " + m.group("Mast_32") + "logo ou " in TEXT and not m.group("Mast_31") + "os-" + m.group("Mast_32") + "logo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_33>[a-zçáéíóúâêô]+)os (?P<Mast_34>[a-zç]+[áéíóúâêô])rio(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "rios"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_33").lower() in plvrMfoa and not m.group("Mast_33") + "os " + m.group("Mast_34") + "rio e " in TEXT and not m.group("Mast_33") + "os " + m.group("Mast_34") + "rio ou " in TEXT and not m.group("Mast_33") + "os-" + m.group("Mast_34") + "rio" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_35>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_36>[a-zç]+[í])ssimo(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ssimos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_35").lower() in plvrMfoa and not m.group("Mast_35") + "os " + m.group("Mast_36") + "ssimo e " in TEXT and not m.group("Mast_35") + "os " + m.group("Mast_36") + "ssimo ou " in TEXT and not m.group("Mast_35") + "os-" + m.group("Mast_36") + "ssimo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_37>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_38>[a-zç]+[é])simo(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "simos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_37").lower() in plvrMfoa and not m.group("Mast_37") + "os " + m.group("Mast_38") + "simo e " in TEXT and not m.group("Mast_37") + "os " + m.group("Mast_38") + "simo ou " in TEXT and not m.group("Mast_37") + "os-" + m.group("Mast_38") + "simo" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_41>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_42>[a-zçáéíóúâêô]+[dst])or(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ores"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_41").lower() in plvrMfoa and not m.group("Mast_42") in "D-d-" and not m.group("Mast_41") + "os " + m.group("Mast_42") + "or e " in TEXT and not m.group("Mast_41") + "os " + m.group("Mast_42") + "or ou " in TEXT and not m.group("Mast_41") + "os-" + m.group("Mast_42") + "or" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_43>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_44>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_43").lower() in plvrMfoa and m.group("Mast_44") in plvrMfr and not m.group("Mast_43") + "os " + m.group("Mast_44") + " e " in TEXT and not m.group("Mast_43") + "os " + m.group("Mast_44") + " ou " in TEXT and not m.group("Mast_43") + "os-" + m.group("Mast_44") in tCompostops and not excMelhorq.search(TEXT) and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_45>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_46>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_45").lower() in plvrMfoa and m.group("Mast_46") in plvrMascr and not m.group("Mast_45") + "os " + m.group("Mast_46") + " e " in TEXT and not m.group("Mast_45") + "os " + m.group("Mast_46") + " ou " in TEXT and not m.group("Mast_45") + "os-" + m.group("Mast_46") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_47>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_48>[a-zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_47").lower() in plvrMfoa and m.group("Mast_48") in plvrMfal and not m.group("Mast_47") + "os " + m.group("Mast_48") + "l e " in TEXT and not m.group("Mast_47") + "os " + m.group("Mast_48") + "l ou " in TEXT and not m.group("Mast_47") + "os-" + m.group("Mast_48") + "l" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_49>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_50>[a-zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_49").lower() in plvrMfoa and m.group("Mast_50") in plvrMascal and not m.group("Mast_49") + "os " + m.group("Mast_50") + "l e " in TEXT and not m.group("Mast_49") + "os " + m.group("Mast_50") + "l ou " in TEXT and not m.group("Mast_49") + "os-" + m.group("Mast_50") + "l" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_51>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_52>[a-zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_51").lower() in plvrMfoa and m.group("Mast_52") in plvrMfcao and not m.group("Mast_51") + "os " + m.group("Mast_52") + "ão e " in TEXT and not m.group("Mast_51") + "os " + m.group("Mast_52") + "ão ou " in TEXT and not m.group("Mast_51") + "os-" + m.group("Mast_52") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_53>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_54>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_53").lower() in plvrMfoa and not m.group("Mast_54") in plvrFemao and not m.group("Mast_54") in excPlvrao and m.group("Mast_54") in plvrMfcao and not m.group("Mast_53") + "os " + m.group("Mast_54") + "ão e " in TEXT and not m.group("Mast_53") + "os " + m.group("Mast_54") + "ão ou " in TEXT and not m.group("Mast_53") + "os-" + m.group("Mast_54") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_55>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_56>[a-zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_55").lower() in plvrMfoa and not m.group("Mast_55") + "os " + m.group("Mast_56") + "vel e " in TEXT and not m.group("Mast_55") + "os " + m.group("Mast_56") + "vel ou " in TEXT and not m.group("Mast_55") + "os-" + m.group("Mast_56") + "vel" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_57>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_58>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_57").lower() in plvrMfoa and m.group("Mast_58").lower() in plvrMfe and not m.group("Mast_57") + "os " + m.group("Mast_58") + "e e " in TEXT and not m.group("Mast_57") + "os " + m.group("Mast_58") + "e ou " in TEXT and not m.group("Mast_57") + "os-" + m.group("Mast_58") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_59>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_60>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_59").lower() in plvrMfoa and m.group("Mast_60").lower() in plvrMasce and not m.group("Mast_59") + "os " + m.group("Mast_60") + "e e " in TEXT and not m.group("Mast_59") + "os " + m.group("Mast_60") + "e ou " in TEXT and not m.group("Mast_59") + "os-" + m.group("Mast_60") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_61>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_62>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_61").lower() in plvrMfoa and m.group("Mast_62") in plvrMfel and not m.group("Mast_61") + "os " + m.group("Mast_62") + "el e " in TEXT and not m.group("Mast_61") + "os " + m.group("Mast_62") + "el ou " in TEXT and not m.group("Mast_61") + "os-" + m.group("Mast_62") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_63>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_64>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_63").lower() in plvrMfoa and m.group("Mast_64") in plvrMascel and not m.group("Mast_63") + "os " + m.group("Mast_64") + "el e " in TEXT and not m.group("Mast_63") + "os " + m.group("Mast_64") + "el ou " in TEXT and not m.group("Mast_63") + "os-" + m.group("Mast_64") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_65>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_66>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_65").lower() in plvrMfoa and m.group("Mast_66") in plvrMfeu and not m.group("Mast_65") + "os " + m.group("Mast_66") + "u e " in TEXT and not m.group("Mast_65") + "os " + m.group("Mast_66") + "u ou " in TEXT and not m.group("Mast_65") + "os-" + m.group("Mast_66") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_67>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_68>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_67").lower() in plvrMfoa and m.group("Mast_68") in plvrMascu and not m.group("Mast_67") + "os " + m.group("Mast_68") + "u e " in TEXT and not m.group("Mast_67") + "os " + m.group("Mast_68") + "u ou " in TEXT and not m.group("Mast_67") + "os-" + m.group("Mast_68") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_69>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_70>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_69").lower() in plvrMfoa and m.group("Mast_70") in plvrInvaz and not m.group("Mast_69") + "os " + m.group("Mast_70") + "z e " in TEXT and not m.group("Mast_69") + "os " + m.group("Mast_70") + "z ou " in TEXT and not m.group("Mast_69") + "os-" + m.group("Mast_70") + "z" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_71>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_72>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_71").lower() in plvrMfoa and m.group("Mast_72") in plvrMascz and not m.group("Mast_71") + "os " + m.group("Mast_72") + "z e " in TEXT and not m.group("Mast_71") + "os " + m.group("Mast_72") + "z ou " in TEXT and not m.group("Mast_71") + "os-" + m.group("Mast_72") + "z" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_73>[a-zA-Zçáéíóúâêô]+)os (?P<Mast_74>[a-zçáéíóúâêô]+)as(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_73").lower() in plvrMfoa and m.group("Mast_74").lower() in plvrMfoa and not m.group("Mast_74").lower() in excMist and not m.group("Mast_73") + "os " + m.group("Mast_74") + "as e " in TEXT and not m.group("Mast_73") + "os " + m.group("Mast_74") + "as ou " in TEXT and not m.group("Mast_73") + "os-" + m.group("Mast_74") + "as" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_75>[a-zçáéíóúâêô]+)os (?P<Mast_76>[a-zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "os " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_75").lower() in plvrMfoa and m.group("Mast_76").lower() in plvrMfoa and not m.group("Mast_76").lower() in excMist and not m.group("Mast_75") + "os " + m.group("Mast_76") + "a e " in TEXT and not m.group("Mast_75") + "os " + m.group("Mast_76") + "a ou " in TEXT and not m.group("Mast_75") + "os-" + m.group("Mast_76") + "a" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_77>[a-zA-Zçáéíóúâêô]+)o (?P<Mast_78>[a-zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "o " + m.group(2) + "o"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_77").lower() in plvrMfoa and m.group("Mast_78").lower() in plvrMfoa and not m.group("Mast_77").lower() in excMist and not m.group("Mast_78").lower() in excMist and not m.group("Mast_77") + "o-" + m.group("Mast_78") + "a" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_79>[a-zçáéíóúâêô]+)a (?P<Mast_80>[a-zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "a " + m.group(2) + "a"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_79").lower() in plvrMfoa and m.group("Mast_80").lower() in plvrMfoa and not m.group("Mast_80").lower() in excMist and not m.group("Mast_79") + "a-" + m.group("Mast_80") + "o" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_81>[a-zçáéíóúâêô]+)a (?P<Mast_82>[a-záâãçéêíóôú]+[o])(?![-\\w–\xad])', '= m.group(1) + "o " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_81").lower() in plvrMfoa and m.group("Mast_82").lower() in plvrMasco and not m.group("Mast_82").lower() in excMist and not m.group("Mast_81") + "a-" + m.group("Mast_82") + "o" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mast_83>[a-zçáéíóúâêô]+)o (?P<Mast_84>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "a " + m.group(2)', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mast_83").lower() in plvrMfoa and m.group("Mast_84").lower() in plvrFema and not m.group("Mast_84").lower() in excMista and not "at"+"é"+" mesmo "+m.group("Mast_84") in TEXT and not m.group("Mast_83") + "o-" + m.group("Mast_84") in tCompostops and not excplSin.search(TEXT)'],
#
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_1>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_2>[a-zç]+o)(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_1").lower() in plvrMfoa and m.group("Mbst_2").lower() in plvrFemo and not m.group("Mbst_1") + "as " + m.group("Mbst_2") + " e " in TEXT and not m.group("Mbst_1") + "as " + m.group("Mbst_2") + " ou " in TEXT and not m.group("Mbst_1") + "as-" + m.group("Mbst_2") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_3>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_4>[a-záâãçéêíóôú]+[a])(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_3").lower() in plvrMfoa and m.group("Mbst_4").lower() in plvrFema and not m.group("Mbst_4").lower() in excMist and not m.group("Mbst_3") + "as " + m.group("Mbst_4") + " e " in TEXT and not m.group("Mbst_3") + "as " + m.group("Mbst_4") + " ou " in TEXT and not m.group("Mbst_3") + "as-" + m.group("Mbst_4") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_5>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_6>[a-záâãéêíóôú]+)([aeiou])nça(?![-\\w–\xad])(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "nças"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_5").lower() in plvrMfoa and not m.group("Mbst_6").lower() in excpLvrnca and not m.group("Mbst_5") + "as " + m.group("Mbst_6") + m.group(3) + "nça e " in TEXT and not m.group("Mbst_5") + "as " + m.group("Mbst_6") + m.group(3) + "nça ou " in TEXT and not m.group("Mbst_5") + "as-" + m.group("Mbst_6") + m.group(3) + "nça" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_7>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_8>[a-z]+ista)(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_7").lower() in plvrMfoa and not m.group("Mbst_8").lower() in excIsta and not m.group("Mbst_7") + "as " + m.group("Mbst_8") + " e " in TEXT and not m.group("Mbst_7") + "as " + m.group("Mbst_8") + " ou " in TEXT and not m.group("Mbst_7") + "as-" + m.group("Mbst_8") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_9>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_10>[a-z]+a)(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "s"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_9").lower() in plvrMfoa and m.group("Mbst_10").lower() in plvrInva and not m.group("Mbst_9") + "as " + m.group("Mbst_10") + " e " in TEXT and not m.group("Mbst_9") + "as " + m.group("Mbst_10") + " ou " in TEXT and not m.group("Mbst_9") + "as-" + m.group("Mbst_10") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_11>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_12>[a-z]+)([aí])da(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_11").lower() in plvrMfoa and not m.group("Mbst_12").lower() in excpLvrada and not m.group("Mbst_11") + "as " + m.group("Mbst_12") + "da e " in TEXT and not m.group("Mbst_11") + "as " + m.group("Mbst_12") + "da ou " in TEXT and not m.group("Mbst_11") + "as-" + m.group("Mbst_12") + "da" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_15>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_16>[a-zç]+)osa(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "osas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_15").lower() in plvrMfoa and not m.group("Mbst_15") + "as " + m.group("Mbst_16") + "osa e " in TEXT and not m.group("Mbst_15") + "as " + m.group("Mbst_16") + "osa ou " in TEXT and not m.group("Mbst_15") + "as-" + m.group("Mbst_16") + "osa" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_17>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_18>[a-zç]+)iva(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ivas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_17").lower() in plvrMfoa and not m.group("Mbst_18").lower() in excpLvriva and not m.group("Mbst_17") + "as " + m.group("Mbst_18") + "iva e " in TEXT and not m.group("Mbst_17") + "as " + m.group("Mbst_18") + "iva ou " in TEXT and not m.group("Mbst_17") + "as-" + m.group("Mbst_18") + "iva" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_19>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_20>[a-zç]+)menta(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "mentas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_19").lower() in plvrMfoa and m.group("Mbst_20") in plvrFmenta and not m.group("Mbst_19") + "as " + m.group("Mbst_20") + "menta e " in TEXT and not m.group("Mbst_19") + "as " + m.group("Mbst_20") + "menta ou " in TEXT and not m.group("Mbst_19") + "as-" + m.group("Mbst_20") + "menta" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_21>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_22>[a-zç]+[âêô][mn])ica(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_21").lower() in plvrMfoa and not m.group("Mbst_21") + "as " + m.group("Mbst_22") + "ica e " in TEXT and not m.group("Mbst_21") + "as " + m.group("Mbst_22") + "ica ou " in TEXT and not m.group("Mbst_21") + "as-" + m.group("Mbst_22") + "ica" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_23>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_24>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_23").lower() in plvrMfoa and not m.group("Mbst_23") + "as " + m.group("Mbst_24") + "ica e " in TEXT and not m.group("Mbst_23") + "as " + m.group("Mbst_24") + "ica ou " in TEXT and not m.group("Mbst_23") + "as-" + m.group("Mbst_24") + "ica" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_25>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_26>[a-zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])ica(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "icas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_25").lower() in plvrMfoa and not m.group("Mbst_25") + "as " + m.group("Mbst_26") + "ica e " in TEXT and not m.group("Mbst_25") + "as " + m.group("Mbst_26") + "ica ou " in TEXT and not m.group("Mbst_25") + "as-" + m.group("Mbst_26") + "ica" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_27>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_28>[a-zç]+)esca(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "escas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_27").lower() in plvrMfoa and not m.group("Mbst_27") + "as " + m.group("Mbst_28") + "esca e " in TEXT and not m.group("Mbst_27") + "as " + m.group("Mbst_28") + "esca ou " in TEXT and not m.group("Mbst_27") + "as-" + m.group("Mbst_28") + "esca" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_29>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_30>[a-zç]+[áéíóúâêô][bcdfglmnprstvx])ida(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "idas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_29").lower() in plvrMfoa and not m.group("Mbst_29") + "as " + m.group("Mbst_30") + "ida e " in TEXT and not m.group("Mbst_29") + "as " + m.group("Mbst_30") + "ida ou " in TEXT and not m.group("Mbst_29") + "as-" + m.group("Mbst_30") + "ida" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_31>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_32>[a-zç]+[ó])loga(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "logas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_31").lower() in plvrMfoa and not m.group("Mbst_31") + "as " + m.group("Mbst_32") + "loga e " in TEXT and not m.group("Mbst_31") + "as " + m.group("Mbst_32") + "loga ou " in TEXT and not m.group("Mbst_31") + "as-" + m.group("Mbst_32") + "loga" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_33>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_34>[a-zç]+[áéíóúâêô])ria(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_33").lower() in plvrMfoa and not m.group("Mbst_33") + "as " + m.group("Mbst_34") + "ria e " in TEXT and not m.group("Mbst_33") + "as " + m.group("Mbst_34") + "ria ou " in TEXT and not m.group("Mbst_33") + "as-" + m.group("Mbst_34") + "ria" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_35>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_36>[a-zç]+[í])ssima(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ssimas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_35").lower() in plvrMfoa and not m.group("Mbst_35") + "as " + m.group("Mbst_36") + "ssima e " in TEXT and not m.group("Mbst_35") + "as " + m.group("Mbst_36") + "ssima ou " in TEXT and not m.group("Mbst_35") + "as-" + m.group("Mbst_36") + "ssima" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_37>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_38>[a-zç]+[é])sima(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "simas"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_37").lower() in plvrMfoa and not m.group("Mbst_37") + "as " + m.group("Mbst_38") + "sima e " in TEXT and not m.group("Mbst_37") + "as " + m.group("Mbst_38") + "sima ou " in TEXT and not m.group("Mbst_37") + "as-" + m.group("Mbst_38") + "sima" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_41>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_42>[a-zçáéíóúâêô]+[dst])ora(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "oras"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_41").lower() in plvrMfoa and not m.group("Mbst_42") in "D-d-" and not m.group("Mbst_41") + "as " + m.group("Mbst_42") + "ora e " in TEXT and not m.group("Mbst_41") + "as " + m.group("Mbst_42") + "ora ou " in TEXT and not m.group("Mbst_41") + "as-" + m.group("Mbst_42") + "ora" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_43>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_44>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_43").lower() in plvrMfoa and m.group("Mbst_44") in plvrMfr and not m.group("Mbst_43") + "as " + m.group("Mbst_44") + " e " in TEXT and not m.group("Mbst_43") + "as " + m.group("Mbst_44") + " ou " in TEXT and not m.group("Mbst_43") + "as-" + m.group("Mbst_44") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_45>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_46>[a-zçáéíóúâêô]+r)(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_45").lower() in plvrMfoa and m.group("Mbst_46") in plvrFemr and not m.group("Mbst_45") + "as " + m.group("Mbst_46") + " e " in TEXT and not m.group("Mbst_45") + "as " + m.group("Mbst_46") + " ou " in TEXT and not m.group("Mbst_45") + "as-" + m.group("Mbst_46") in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_47>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_48>[a-zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_47").lower() in plvrMfoa and m.group("Mbst_48") in plvrMfal and not m.group("Mbst_47") + "as " + m.group("Mbst_48") + "l e " in TEXT and not m.group("Mbst_47") + "as " + m.group("Mbst_48") + "l ou " in TEXT and not m.group("Mbst_47") + "as-" + m.group("Mbst_48") + "l" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_49>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_50>[a-zçáéíóúâêô]+[a])l(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "is"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_49").lower() in plvrMfoa and m.group("Mbst_50") in plvrFemal and not m.group("Mbst_49") + "as " + m.group("Mbst_50") + "l e " in TEXT and not m.group("Mbst_49") + "as " + m.group("Mbst_50") + "l ou " in TEXT and not m.group("Mbst_49") + "as-" + m.group("Mbst_50") + "l" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_51>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_52>[a-zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_51").lower() in plvrMfoa and m.group("Mbst_52") in plvrMfcao and not m.group("Mbst_51") + "as " + m.group("Mbst_52") + "ão e " in TEXT and not m.group("Mbst_51") + "as " + m.group("Mbst_52") + "ão ou " in TEXT and not m.group("Mbst_51") + "as-" + m.group("Mbst_52") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_53>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_54>[a-zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_53").lower() in plvrMfoa and not m.group("Mbst_54") in plvrNfemcao and not m.group("Mbst_53") + "as " + m.group("Mbst_54") + "ão e " in TEXT and not m.group("Mbst_53") + "as " + m.group("Mbst_54") + "ão ou " in TEXT and not m.group("Mbst_53") + "as-" + m.group("Mbst_54") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_55>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_56>[a-zç]+[áéíóú])vel(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "veis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_55").lower() in plvrMfoa and not m.group("Mbst_55") + "as " + m.group("Mbst_56") + "vel e " in TEXT and not m.group("Mbst_55") + "as " + m.group("Mbst_56") + "vel ou " in TEXT and not m.group("Mbst_55") + "as-" + m.group("Mbst_56") + "vel" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_57>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_58>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_57").lower() in plvrMfoa and m.group("Mbst_58").lower() in plvrMfe and not m.group("Mbst_57") + "as " + m.group("Mbst_58") + "e e " in TEXT and not m.group("Mbst_57") + "as " + m.group("Mbst_58") + "e ou " in TEXT and not m.group("Mbst_57") + "as-" + m.group("Mbst_58") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_59>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_60>[a-zçáéíóúâêô]+)e(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "es"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_59").lower() in plvrMfoa and m.group("Mbst_60").lower() in plvrFeme and not m.group("Mbst_59") + "as " + m.group("Mbst_60") + "e e " in TEXT and not m.group("Mbst_59") + "as " + m.group("Mbst_60") + "e ou " in TEXT and not m.group("Mbst_59") + "as-" + m.group("Mbst_60") + "e" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_61>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_62>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_61").lower() in plvrMfoa and m.group("Mbst_62") in plvrMfel and not m.group("Mbst_61") + "as " + m.group("Mbst_62") + "el e " in TEXT and not m.group("Mbst_61") + "as " + m.group("Mbst_62") + "el ou " in TEXT and not m.group("Mbst_61") + "as-" + m.group("Mbst_62") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_63>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_64>[a-z]+)el(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "éis"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_63").lower() in plvrMfoa and m.group("Mbst_64") in plvrFemel and not m.group("Mbst_63") + "as " + m.group("Mbst_64") + "el e " in TEXT and not m.group("Mbst_63") + "as " + m.group("Mbst_64") + "el ou " in TEXT and not m.group("Mbst_63") + "as-" + m.group("Mbst_64") + "el" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_65>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_66>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_65").lower() in plvrMfoa and m.group("Mbst_66") in plvrMfeu and not m.group("Mbst_65") + "as " + m.group("Mbst_66") + "u e " in TEXT and not m.group("Mbst_65") + "as " + m.group("Mbst_66") + "u ou " in TEXT and not m.group("Mbst_65") + "as-" + m.group("Mbst_66") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_67>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_68>[a-zçáéíóúâêô]+)u(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "us"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_67").lower() in plvrMfoa and m.group("Mbst_68") in plvrFemu and not m.group("Mbst_67") + "as " + m.group("Mbst_68") + "u e " in TEXT and not m.group("Mbst_67") + "as " + m.group("Mbst_68") + "u ou " in TEXT and not m.group("Mbst_67") + "as-" + m.group("Mbst_68") + "u" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_69>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_70>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_69").lower() in plvrMfoa and m.group("Mbst_70") in plvrInvaz and not m.group("Mbst_69") + "as " + m.group("Mbst_70") + "z e " in TEXT and not m.group("Mbst_69") + "as " + m.group("Mbst_70") + "z ou " in TEXT and not m.group("Mbst_69") + "as-" + m.group("Mbst_70") + "z" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_71>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_72>[a-z]+)z(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "zes"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_71").lower() in plvrMfoa and m.group("Mbst_72") in plvrFemz and not m.group("Mbst_71") + "as " + m.group("Mbst_72") + "z e " in TEXT and not m.group("Mbst_71") + "as " + m.group("Mbst_72") + "z ou " in TEXT and not m.group("Mbst_71") + "as-" + m.group("Mbst_72") + "z" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_73>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_74>[a-zç]+)([âêíôú])ncia(?![-\\w–\xad])(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "ncias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_73").lower() in plvrMfoa and not m.group("Mbst_73") + "as " + m.group("Mbst_74") + m.group(3) + "ncia e " in TEXT and not m.group("Mbst_73") + "as " + m.group("Mbst_74") + m.group(3) + "ncia ou " in TEXT and not m.group("Mbst_73") + "as-" + m.group("Mbst_74") + m.group(3) + "ncia" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_75>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_76>[a-záâãçéêíóôú]+[gl])ogia(?![-\\w–\xad])(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ogias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_75").lower() in plvrMfoa and not m.group("Mbst_75") + "as " + m.group("Mbst_76") + "ogia e " in TEXT and not m.group("Mbst_75") + "as " + m.group("Mbst_76") + "ogia ou " in TEXT and not m.group("Mbst_75") + "as-" + m.group("Mbst_76") + "ogia" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_77>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_78>[a-záâãçéêíóôú]+)rgia(?![-\\w–\xad])(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "rgias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_77").lower() in plvrMfoa and not m.group("Mbst_77") + "as " + m.group("Mbst_78") + "rgia e " in TEXT and not m.group("Mbst_77") + "as " + m.group("Mbst_78") + "rgia ou " in TEXT and not m.group("Mbst_77") + "as-" + m.group("Mbst_78") + "rgia" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_79>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_80>[a-zç]+)([áéíóú])lia(?![-\\w–\xad])(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "lias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_79").lower() in plvrMfoa and not m.group("Mbst_79") + "as " + m.group("Mbst_80") + m.group(3) + "lia e " in TEXT and not m.group("Mbst_79") + "as " + m.group("Mbst_80") + m.group(3) + "lia ou " in TEXT and not m.group("Mbst_79") + "as-" + m.group("Mbst_80") + m.group(3) + "lia" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_81>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_82>[a-záâãçéêíóôú]+)erapia(?![-\\w–\xad])(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "erapias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_81").lower() in plvrMfoa and not m.group("Mbst_81") + "as " + m.group("Mbst_82") + "erapia e " in TEXT and not m.group("Mbst_81") + "as " + m.group("Mbst_82") + "erapia ou " in TEXT and not m.group("Mbst_81") + "as-" + m.group("Mbst_82") + "erapia" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_83>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_84>[a-zç]+)([áéíóú])ria(?![-\\w–\xad])(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "rias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_83").lower() in plvrMfoa and not m.group("Mbst_83") + "as " + m.group("Mbst_84") + m.group(3) + "ria e " in TEXT and not m.group("Mbst_83") + "as " + m.group("Mbst_84") + m.group(3) + "ria ou " in TEXT and not m.group("Mbst_83") + "as-" + m.group("Mbst_84") + m.group(3) + "ria" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_85>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_86>[a-zç]+)([áéíú])sia(?![-\\w–\xad])(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "sias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_85").lower() in plvrMfoa and not m.group("Mbst_85") + "as " + m.group("Mbst_86") + m.group(3) + "sia e " in TEXT and not m.group("Mbst_85") + "as " + m.group("Mbst_86") + m.group(3) + "sia ou " in TEXT and not m.group("Mbst_85") + "as-" + m.group("Mbst_86") + m.group(3) + "sia" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_87>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_88>[a-zç]+)([áéíóú])rsia(?![-\\w–\xad])(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "rsias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_87").lower() in plvrMfoa and not m.group("Mbst_87") + "as " + m.group("Mbst_88") + m.group(3) + "rsia e " in TEXT and not m.group("Mbst_87") + "as " + m.group("Mbst_88") + m.group(3) + "rsia ou " in TEXT and not m.group("Mbst_87") + "as-" + m.group("Mbst_88") + m.group(3) + "rsia" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_89>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_90>[a-zç]+)([áéíóú])ssia(?![-\\w–\xad])(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "ssias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_89").lower() in plvrMfoa and not m.group("Mbst_89") + "as " + m.group("Mbst_90") + m.group(3) + "ssia e " in TEXT and not m.group("Mbst_89") + "as " + m.group("Mbst_90") + m.group(3) + "ssia ou " in TEXT and not m.group("Mbst_89") + "as-" + m.group("Mbst_90") + m.group(3) + "ssia" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_91>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_92>[a-zç]+)([áéíóú])rnia(?![-\\w–\xad])(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "rnias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_91").lower() in plvrMfoa and not m.group("Mbst_91") + "as " + m.group("Mbst_92") + m.group(3) + "rnia e " in TEXT and not m.group("Mbst_91") + "as " + m.group("Mbst_92") + m.group(3) + "rnia ou " in TEXT and not m.group("Mbst_91") + "as-" + m.group("Mbst_92") + m.group(3) + "rnia" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_93>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_94>[a-zç]+)([âêíôú])nia(?![-\\w–\xad])(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + m.group(3) + "nias"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_93").lower() in plvrMfoa and not m.group("Mbst_93") + "as " + m.group("Mbst_94") + m.group(3) + "nia e " in TEXT and not m.group("Mbst_93") + "as " + m.group("Mbst_94") + m.group(3) + "nia ou " in TEXT and not m.group("Mbst_93") + "as-" + m.group("Mbst_94") + m.group(3) + "nia" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_95>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_96>[a-záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "ões"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_95").lower() in plvrMfoa and not m.group("Mbst_96") in plvrFemao and m.group("Mbst_96") in plvrMfcao and not m.group("Mbst_95") + "as " + m.group("Mbst_96") + "ão e " in TEXT and not m.group("Mbst_95") + "as " + m.group("Mbst_96") + "ão ou " in TEXT and not m.group("Mbst_95") + "as-" + m.group("Mbst_96") + "ão" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_97>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_98>[a-záâãçéêíóôú]+)dade(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "dades"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_97").lower() in plvrMfoa and not m.group("Mbst_97") + "as " + m.group("Mbst_98") + "dade e " in TEXT and not m.group("Mbst_97") + "as " + m.group("Mbst_98") + "dade ou " in TEXT and not m.group("Mbst_97") + "as-" + m.group("Mbst_98") + "dade" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_99>[a-zA-Zçáéíóúâêô]+)as (?P<Mbst_100>[a-zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_99").lower() in plvrMfoa and m.group("Mbst_100").lower() in plvrMfoa and not m.group("Mbst_100").lower() in excMist and not m.group("Mbst_99") + "as " + m.group("Mbst_100") + "a e " in TEXT and not m.group("Mbst_99") + "as " + m.group("Mbst_100") + "a ou " in TEXT and not m.group("Mbst_99") + "as-" + m.group("Mbst_100") + "a" in tCompostops and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_101>[a-zA-Záâãçéêíóôú]+)dade (?P<Mbst_102>[a-zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "dade " + m.group(2) + "a"', 'Não há concordância entre as palavras. Você quis dizer:', 'not " de " + m.group(1) + "dade " in TEXT and m.group("Mbst_102").lower() in plvrMfoa and not m.group("Mbst_102").lower() in excddMfoa and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_103>[a-zA-Záâãçéêíóôú]+)dades (?P<Mbst_104>[a-zçáéíóúâêô]+)o(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_104").lower() in plvrMfoa and not m.group("Mbst_104").lower() in excddMfoa and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_105>[a-zA-Záâãçéêíóôú]+)dades (?P<Mbst_106>[a-zçáéíóúâêô]+)os(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_106").lower() in plvrMfoa and not excplSin.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Mbst_107>[a-zA-Záâãçéêíóôú]+)dades (?P<Mbst_108>[a-zçáéíóúâêô]+)a(?![-\\w–\xad])', '= m.group(1) + "dades " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Mbst_108").lower() in plvrMfoa and not excplSin.search(TEXT)'],
#
 ['(?u)(?<![-\\w–.,\xad])([Bb])ico-de-([Pp])apagaio(?![-\\w–\xad])', '\\1ico de papagaio', 'Para designar a formação óssea, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])icos-de-([Pp])apagaio(?![-\\w–\xad])', '\\1icos de papagaio', 'Para designar a formação óssea, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])ola-de-([Nn])eve(?![-\\w–\xad])', '\\1ola de neve', 'Para designar situação que se agrava progressivamente, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])olas-de-([Nn])eve(?![-\\w–\xad])', '\\1olas de neve', 'Para designar situação que se agrava progressivamente, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])abelo-de-([Aa])njo(?![-\\w–\xad])', '\\1abelo de anjo', 'Para designar massa de fios finos, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])abelos-de-([Aa])njo(?![-\\w–\xad])', '\\1abelos de anjo', 'Para designar massa de fios finos, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])avalo-de-([Bb])atalha(?![-\\w–\xad])', '\\1avalo de batalha', 'Para designar um argumento principal, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])avalos-de-([Bb])atalha(?![-\\w–\xad])', '\\1avalos de batalha', 'Para designar um argumento principal, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])erna-de-([Pp])au(?![-\\w–\xad])', '\\1erna de pa', 'Para designar um jogador de má qualidade, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ernas-de-([Pp])au(?![-\\w–\xad])', '\\1ernas de pa', 'Para designar um jogador de má qualidade, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])omo-de-([Aa])dão(?![-\\w–\xad])', '\\1omo de adão', 'Para designar a cartilagem tireóidea, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])omos-de-([Aa])dão(?![-\\w–\xad])', '\\1omos de adão', 'Para designar a cartilagem tireóidea, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])onta-de-([Ll])ança(?![-\\w–\xad])', '\\1onta de lança', 'Para designar um jogador centroavante, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ontas-de-([Ll])ança(?![-\\w–\xad])', '\\1ontas de lança', 'Para designar um jogador centroavante, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Rr])abo-de-([Gg])alo(?![-\\w–\xad])', '\\1rabo de \\2alo', 'Para designar aguardente, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Rr])abos-de-([Gg])alo(?![-\\w–\xad])', '\\1abos de \\2alo', 'Para designar aguardente, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])au-de-([Aa])rara(?![-\\w–\xad])', '\\1au de \\2rara', 'Para designar caminhão ou suporte de madeira, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])aus-de-([Aal])rara(?![-\\w–\xad])', '\\1aus de \\2rara', 'Para designar caminhão ou suporte de madeira, escreve-se sem hifens. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(O|o|do|Do|no|No|Ao|ao|Pelo|pelo|Deste|deste) poucos(?![-\\w–\xad])', '\\1s poucos', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Algu|algu|Nenhu|nenhu|U|u)m poucos(?![-\\w–\xad])', '\\1ns poucos', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Dia do ([Tt])rabalho(?![-\\w–\xad])', 'Dia do Trabalhador\\nDia Internacional do Trabalhador', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ar(a|as) de ([Pp])aus(?![-\\w–\xad])', '\\1ara de \\3au\\n\\1aras de \\3a', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ntreg(ar|a|as|amos|aremos|ava|avam|am|ávamos) a ([Dd])omicílio(?![-\\w–\xad])', '\\1ntreg\\2 em \\3omicílio', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff]icam|[Ee]stamos|[Ff]icamos|[Ff]iquem|[Ee]stivermos|[Cc]ontas|[Ee]stão|[Ee]starão|[Ff]icarão) quite(?![-\\w–\xad])', '\\1 quites', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee]star|[Ee]stou|[Ff]icar|[Ff]iquei|[Ee]starei|[Ee]stiver|[Ff]ico|[Ee]stava|[Ee]staria|[Ff]icava|[Ff]icarei|[Ff]icaria) quites(?![-\\w–\xad])', '\\1 quite', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])sofr(a|er|erá|eu|erão|eram|am) (alteração|alterações|mudança|mudanças) em função d(e|a|o|as|os)(?![-\\w–\xad])', 'sofr\\1 \\2 em virtude d\\3\\nsofr\\1 \\2 por causa d\\3\\nsofr\\1 \\2 em consequência d\\3\\nsofr\\1 \\2 por conta d\\3', 'Em função de - designa finalidade e não causa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ara maiores (informações|detalhes|esclarecimentos)(?![-\\w–\xad])', '\\1ara mais \\2', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])restar maiores (informações|detalhes|esclarecimentos)(?![-\\w–\xad])', '\\1restar mais \\2', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])tirar a pressão(?![-\\w–\xad])', 'medir a pressão', 'Você quis dizer:', '"ospital" in TEXT or "úde" in TEXT or "rterial" in TEXT or "médic" in TEXT or "nfermeir" in TEXT or "parelho" in TEXT or " sangu" in TEXT or "paciente" in TEXT or "pulso" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])tirou a pressão(?![-\\w–\xad])', 'mediu a pressão', 'Você quis dizer:', '"ospital" in TEXT or "úde" in TEXT or "rterial" in TEXT or "médic" in TEXT or "nfermeir" in TEXT or "parelho" in TEXT or " sangu" in TEXT or "paciente" in TEXT or "pulso" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])tirei a pressão(?![-\\w–\xad])', 'medi a pressão', 'Você quis dizer:', '"ospital" in TEXT or "úde" in TEXT or "rterial" in TEXT or "médic" in TEXT or "nfermeir" in TEXT or "parelho" in TEXT or " sangu" in TEXT or "paciente" in TEXT or "pulso" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])tiraram a pressão(?![-\\w–\xad])', 'mediram a pressão', 'Você quis dizer:', '"ospital" in TEXT or "úde" in TEXT or "rterial" in TEXT or "médic" in TEXT or "nfermeir" in TEXT or "parelho" in TEXT or " sangu" in TEXT or "paciente" in TEXT or "pulso" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])tirar a (minha|sua|nossa) pressão(?![-\\w–\xad])', 'medir a \\1 pressão', 'Você quis dizer:', '"ospital" in TEXT or "úde" in TEXT or "rterial" in TEXT or "médic" in TEXT or "nfermeir" in TEXT or "parelho" in TEXT or " sangu" in TEXT or "paciente" in TEXT or "pulso" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])tirou a (minha|sua|nossa) pressão(?![-\\w–\xad])', 'mediu a \\1 pressão', 'Você quis dizer:', '"ospital" in TEXT or "úde" in TEXT or "rterial" in TEXT or "médic" in TEXT or "nfermeir" in TEXT or "parelho" in TEXT or " sangu" in TEXT or "paciente" in TEXT or "pulso" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])tirei a (minha|sua|nossa) pressão(?![-\\w–\xad])', 'medi a \\1 pressão', 'Você quis dizer:', '"ospital" in TEXT or "úde" in TEXT or "rterial" in TEXT or "médic" in TEXT or "nfermeir" in TEXT or "parelho" in TEXT or " sangu" in TEXT or "paciente" in TEXT or "pulso" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])tiraram a (minha|sua|nossa) pressão(?![-\\w–\xad])', 'mediram a \\1 pressão', 'Você quis dizer:', '"ospital" in TEXT or "úde" in TEXT or "rterial" in TEXT or "médic" in TEXT or "nfermeir" in TEXT or "parelho" in TEXT or " sangu" in TEXT or "paciente" in TEXT or "pulso" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])tirar (minha|sua|nossa) pressão(?![-\\w–\xad])', 'medir \\1 pressão', 'Você quis dizer:', '"ospital" in TEXT or "úde" in TEXT or "rterial" in TEXT or "médic" in TEXT or "nfermeir" in TEXT or "parelho" in TEXT or " sangu" in TEXT or "paciente" in TEXT or "pulso" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])tirou (minha|sua|nossa) pressão(?![-\\w–\xad])', 'mediu \\1 pressão', 'Você quis dizer:', '"ospital" in TEXT or "úde" in TEXT or "rterial" in TEXT or "médic" in TEXT or "nfermeir" in TEXT or "parelho" in TEXT or " sangu" in TEXT or "paciente" in TEXT or "pulso" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])tirei (minha|sua|nossa) pressão(?![-\\w–\xad])', 'medi \\1 pressão', 'Você quis dizer:', '"ospital" in TEXT or "úde" in TEXT or "rterial" in TEXT or "médic" in TEXT or "nfermeir" in TEXT or "parelho" in TEXT or " sangu" in TEXT or "paciente" in TEXT or "pulso" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])tiraram (minha|sua|nossa) pressão(?![-\\w–\xad])', 'mediram \\1 pressão', 'Você quis dizer:', '"ospital" in TEXT or "úde" in TEXT or "rterial" in TEXT or "médic" in TEXT or "nfermeir" in TEXT or "parelho" in TEXT or " sangu" in TEXT or "paciente" in TEXT or "pulso" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Cc])omprimente(?![-\\w–\xad])', '\\1umprimente', 'Comprimente = que comprime, Cumprimente = saudar. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])BEM VINDO(?![-\\w–\xad])', 'BEM-VINDO', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])BEM VINDOS(?![-\\w–\xad])', 'BEM-VINDOS', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss])uspensório(?![-\\w–\xad])', '\\1uspensórios', 'Recomenda-se usar no plural. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])oda(?![-\\w–\xad])', '\\1odas', 'Recomenda-se usar no plural. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])éria(?![-\\w–\xad])', '\\1érias', 'Recomenda-se usar no plural. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo])lheira(?![-\\w–\xad])', '\\1lheiras', 'Recomenda-se usar no plural. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])ondolência(?![-\\w–\xad])', '\\1ondolências', 'Recomenda-se usar no plural. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])êsame(?![-\\w–\xad])', '\\1êsames', 'Recomenda-se usar no plural. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) algema(?![-\\w–\xad])', '\\1s algemas', 'Recomenda-se usar no plural. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])treva(?![-\\w–\xad])', 'trevas', 'Recomenda-se usar no plural. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Jj])ogo de ([Dd])ama(?![-\\w–\xad])', '\\1ogo de \\2amas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Jj])og([a-z]+) ([Dd])ama(?![-\\w–\xad])', '\\1og\\2 \\3amas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])mas porém(?![-\\w–\xad])', 'mas\\nporém', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Mas porém(?![-\\w–\xad])', 'Mas\\nPorém', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])mas, porém(?![-\\w–\xad])', 'mas\\nporém', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Mas, porém(?![-\\w–\xad])', 'Mas\\nPorém', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])mas contudo(?![-\\w–\xad])', 'mas\\ncontudo', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Mas contudo(?![-\\w–\xad])', 'Mas\\nContudo', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])mas, contudo(?![-\\w–\xad])', 'mas\\ncontudo', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Mas, contudo(?![-\\w–\xad])', 'Mas\\nContudo', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])mas no entanto(?![-\\w–\xad])', 'mas\\nno entanto', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Mas no entanto(?![-\\w–\xad])', 'Mas\\nNo entanto', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])mas, no entanto(?![-\\w–\xad])', 'mas\\nno entanto', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Mas, no entanto(?![-\\w–\xad])', 'Mas\\nNo entanto', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])mas entretanto(?![-\\w–\xad])', 'mas\\nentretanto', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Mas entretanto(?![-\\w–\xad])', 'Mas\\nEntretanto', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])mas, entretanto(?![-\\w–\xad])', 'mas\\nentretanto', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Mas, entretanto(?![-\\w–\xad])', 'Mas\\nEntretanto', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])mas todavia(?![-\\w–\xad])', 'mas\\ntodavia', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Mas todavia(?![-\\w–\xad])', 'Mas\\nTodavia', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])mas, todavia(?![-\\w–\xad])', 'mas\\ntodavia', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Mas, todavia(?![-\\w–\xad])', 'Mas\\nTodavia', 'Conjunções redundantes. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])arrasca(?![-\\w–\xad])', '\\1arrasco', 'Para designar aquele que executa a pena de morte usa-se no masculino, Carrasco.', False],
 ['(?u)(?<![-\\w–.,\xad])de grátis(?![-\\w–\xad])', 'grátis\\nde graça', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([a-zA-Záâãçéêíóôõú]+) trás(?![-\\w–\xad])', '\\1 traz', 'Você quis dizer:', 'not m.group(1) in "Para-para-Por-por-Pra-pra-De-de"'],
 ['(?u)(?<![-\\w–.,\xad])(a|e|o) trás(?![-\\w–\xad])', '\\1 traz', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Para|para|Por|por|Pra|pra) traz(?![-\\w–\xad])', '\\1 trás', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])or de tr(az|ás)(?![-\\w–\xad])', '\\1or detrás', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])erante a (Deus|ela|elas|ele|eles|essa|essas|este|estes|isso|isto|meu|meus|mim|nós|seu|seus|ti|todos|um|uma|umas|uns|vós)(?![-\\w–\xad])', '\\1erante \\2', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])erante ao(?![-\\w–\xad])', '\\1erante o', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])erante aos(?![-\\w–\xad])', '\\1erante os', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])erante eu(?![-\\w–\xad])', '\\1erante mim', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])erante tu(?![-\\w–\xad])', '\\1erante ti', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Bb])at(er|eu|ia|emos|eram|i|iam|eriam) na (minha|sua|tua|nossa|vossa) porta(?![-\\w–\xad])', '\\1at\\2 a \\3 porta', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])oso forçado(?![-\\w–\xad])', '\\1ouso forçado', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])fim de(?![-\\w–\xad])', '\\1 fim de', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])heque sem fundo(?![-\\w–\xad])', '\\1heque sem fundos', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])nquanto tempo(?![-\\w–\xad])', '\\1m quanto tempo', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])eio fios(?![-\\w–\xad])', '\\1eios-fios', 'Termo Composto? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])eios fio(?![-\\w–\xad])', '\\1eios-fios', 'Termo Composto? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orco da ([Íí])ndia(?![-\\w–\xad])', '\\1orco-da-índia', 'Termo Composto? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])orcos da ([Íí])ndia(?![-\\w–\xad])', '\\1orcos-da-índia', 'Termo Composto? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Mm])otor ([Bb])ombas(?![-\\w–\xad])', '\\1otores-\\2ombas', 'Termo Composto? Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) pesar de(?![-\\w–\xad])', '\\1pesar de', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])fro descendente(?![-\\w–\xad])', '\\1frodescendente', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])fro descendentes(?![-\\w–\xad])', '\\1frodescendentes', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])fros descendentes(?![-\\w–\xad])', '\\1frodescendentes', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(muito|sempre|meu) gentio(?![-\\w–\xad])', '\\1 gentil', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])seção de cinema(?![-\\w–\xad])', 'sessão de cinema', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Dado os(?![-\\w–\xad])', 'Dados os', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Jj])á é ([23456789]+) horas(?![-\\w–\xad])', '\\1á são \\2 horas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Jj])á é ([1-9][0-9]+) horas(?![-\\w–\xad])', '\\1á são \\2 horas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])ssist(\\w+) o (clipe|novo|episódio|capítulo|sol|filme|desenho|seriado|programa|longa|longametragem|noticiário|Jornal|jornal|jogo|documentário|julgamento)(?![-\\w–\xad])', '\\1ssist\\2 ao \\3', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])ssistir(á|ão) o (clipe|novo|episódio|capítulo|sol|filme|desenho|seriado|programa|longa|longametragem|noticiário|Jornal|jornal|jogo|documentário|julgamento)(?![-\\w–\xad])', '\\1ssist\\2 ao \\3', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])ssist(\\w+) um (clipe|novo|episódio|capítulo|filme|desenho|seriado|programa|longa|longametragem|noticiário|Jornal|jornal|jogo|documentário|julgamento)(?![-\\w–\xad])', '\\1ssist\\2 a um \\3', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])ssistir(á|ão) um (clipe|novo|episódio|capítulo|filme|desenho|seriado|programa|longa|longametragem|noticiário|Jornal|jornal|jogo|documentário|julgamento)(?![-\\w–\xad])', '\\1ssist\\2 a um \\3', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa])luga-se (salas|casas|apartamentos|carros|quartos|imóveis|quitinetes|lojas|sonhos|roupas|vestidos|ternos)(?![-\\w–\xad])', '\\1lugam-se \\2', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])la foi comunicada(?![-\\w–\xad])', '\\1la foi informada\\n\\1la foi avisada\\n\\1la foi cientificada', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])le foi comunicado(?![-\\w–\xad])', '\\1le foi informado\\n\\1le foi avisado\\n\\1le foi cientificado', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])inguém foi comunicado(?![-\\w–\xad])', '\\1inguém foi informado\\n\\1inguém foi avisado\\n\\1inguém foi cientificado', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])las foram comunicadas(?![-\\w–\xad])', '\\1las foram informadas\\n\\1las foram avisadas\\n\\1las foram cientificadas', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])les foram comunicados(?![-\\w–\xad])', '\\1les foram informados\\n\\1les foram avisados\\n\\1les foram cientificados', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])pessoas foram comunicadas(?![-\\w–\xad])', 'pessoas foram informadas\\npessoas foram avisadas\\npessoas foram cientificadas', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])família foi comunicada(?![-\\w–\xad])', 'família foi informada\\nfamília foi avisada\\nfamília foi cientificada', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])famílias foram comunicados(?![-\\w–\xad])', 'famílias foram informadas\\nfamílias foram avisadas\\nfamílias foram cientificadas', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])empregados foram comunicados(?![-\\w–\xad])', 'empregados foram informados\\nempregados foram avisados\\nempregados foram cientificados', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])funcionários foram comunicados(?![-\\w–\xad])', 'funcionários foram informados\\nfuncionários foram avisados\\nfuncionários foram cientificados', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])odos foram comunicados(?![-\\w–\xad])', '\\1odos foram informados\\n\\1odos foram avisados\\n\\1odos foram cientificados', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])la já foi comunicada(?![-\\w–\xad])', '\\1la já foi informada\\n\\1la foi já avisada', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])le já foi comunicado(?![-\\w–\xad])', '\\1le já foi informado\\n\\1le foi já avisado', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])las já foram comunicadas(?![-\\w–\xad])', '\\1las já foram informadas\\n\\1las já foram avisadas', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])les já foram comunicados(?![-\\w–\xad])', '\\1les já foram informados\\n\\1les já foram avisados', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])pessoas já foram comunicadas(?![-\\w–\xad])', 'pessoas já foram informadas\\npessoas já foram avisadas', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])família já foi comunicada(?![-\\w–\xad])', 'família já foi informadas\\nfamília já foi avisadas', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])famílias já foram comunicados(?![-\\w–\xad])', 'famílias já foram informadas\\nfamílias já foram avisadas', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])empregados já foram comunicados(?![-\\w–\xad])', 'empregados já foram informados\\nempregados já foram avisados', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])funcionários já foram comunicados(?![-\\w–\xad])', 'funcionários já foram informados\\nfuncionários já foram avisados', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])la não foi comunicada(?![-\\w–\xad])', '\\1la não foi informada\\n\\1la foi não avisada', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])le não foi comunicado(?![-\\w–\xad])', '\\1le não foi informado\\n\\1le foi não avisado', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])las não foram comunicadas(?![-\\w–\xad])', '\\1las não foram informadas\\n\\1las não foram avisadas', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])les não foram comunicados(?![-\\w–\xad])', '\\1les não foram informados\\n\\1les não foram avisados', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])pessoas não foram comunicadas(?![-\\w–\xad])', 'pessoas não foram informadas\\npessoas não foram avisadas', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])família não foi comunicada(?![-\\w–\xad])', 'família não foi informadas\\nfamília não foi avisadas', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])famílias não foram comunicados(?![-\\w–\xad])', 'famílias não foram informadas\\nfamílias não foram avisadas', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])empregados não foram comunicados(?![-\\w–\xad])', 'empregados não foram informados\\nempregados não foram avisados', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])funcionários não foram comunicados(?![-\\w–\xad])', 'funcionários não foram informados\\nfuncionários não foram avisados', 'Ninguém é comunicado de alguma coisa. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])em haver com(?![-\\w–\xad])', '\\1em a ver com', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])em muito haver com(?![-\\w–\xad])', '\\1em muito a ver com', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])ada haver(?![-\\w–\xad])', '\\1ada a ver', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])udo haver(?![-\\w–\xad])', '\\1udo a ver', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])(icou|ica|icasse|ico|icam|icaram|icaria) haver(?![-\\w–\xad])', '\\1\\2 a ver', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])(em|eve|eria|êm|ive|iveram|enho|emos) haver(?![-\\w–\xad])', '\\1\\2 a ver', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([cs])ero mano(?![-\\w–\xad])', 'ser humano', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([cs])ero manos(?![-\\w–\xad])', 'seres humanos', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([CS])ero mano(?![-\\w–\xad])', 'Ser humano', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([CS])ero manos(?![-\\w–\xad])', 'Seres humanos', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Cer(?![-\\w–\xad])', 'Ser', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])cer(?![-\\w–\xad])', 'ser', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])Ceres(?![-\\w–\xad])', 'Seres', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])ceres(?![-\\w–\xad])', 'seres', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Rr])eso(?![-\\w–\xad])', '\\1ezo', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])ro(?![-\\w–\xad])', '\\1rro', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ee])rro mano(?![-\\w–\xad])', '\\1rro humano', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma grande perca(?![-\\w–\xad])', '\\1ma grande perda', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Uu])ma perca(?![-\\w–\xad])', '\\1ma perda', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])perca de tempo(?![-\\w–\xad])', 'perda de tempo', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])perca de peso(?![-\\w–\xad])', 'perda de peso', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])perca de vagas(?![-\\w–\xad])', 'perda de vagas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])perca de memória(?![-\\w–\xad])', 'perda de memória', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])perca de gordura(?![-\\w–\xad])', 'perda de gordura', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])perca de dados(?![-\\w–\xad])', 'perda de dados', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])perca de safra(?![-\\w–\xad])', 'perda de safra', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])perca de aparelho(?![-\\w–\xad])', 'perda de aparelho', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])percas de aparelho(?![-\\w–\xad])', 'perdas de aparelho', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])percas de aparelhos(?![-\\w–\xad])', 'perdas de aparelhos', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])perca de ([0-9]+)%(?![-\\w–\xad])', 'perda de \\1%', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])percas de ([0-9]+)%(?![-\\w–\xad])', 'perdas de \\1%', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])perca de sinal(?![-\\w–\xad])', 'perda de sinal', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])perca de volume(?![-\\w–\xad])', 'perda de volume', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])perca de mandato(?![-\\w–\xad])', 'perda de mandato', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])perca de potência(?![-\\w–\xad])', 'perda de potência', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])perca de senhas(?![-\\w–\xad])', 'perda de senhas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])perca de conexão(?![-\\w–\xad])', 'perda de conexão', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])a perca de alguém(?![-\\w–\xad])', 'a perda de alguém', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elo o(?![-\\w–\xad])', '\\1elo', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elo a(?![-\\w–\xad])', '\\1ela', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elo os(?![-\\w–\xad])', '\\1elos', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elo as(?![-\\w–\xad])', '\\1elas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elo um(?![-\\w–\xad])', '\\1or um', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elo uma(?![-\\w–\xad])', '\\1or uma', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elo uns(?![-\\w–\xad])', '\\1or uns', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elo umas(?![-\\w–\xad])', '\\1or umas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elo nenhum(?![-\\w–\xad])', '\\1or nenhum', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ela o(?![-\\w–\xad])', '\\1elo', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ela a(?![-\\w–\xad])', '\\1ela', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ela os(?![-\\w–\xad])', '\\1elos', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ela as(?![-\\w–\xad])', '\\1elas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ela um(?![-\\w–\xad])', '\\1or um', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ela uma(?![-\\w–\xad])', '\\1or uma', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ela uns(?![-\\w–\xad])', '\\1or uns', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ela umas(?![-\\w–\xad])', '\\1or umas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])ela nenhum(?![-\\w–\xad])', '\\1or nenhum', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elos o(?![-\\w–\xad])', '\\1elo', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elos a(?![-\\w–\xad])', '\\1ela', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elos os(?![-\\w–\xad])', '\\1elos', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elos as(?![-\\w–\xad])', '\\1elas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elos um(?![-\\w–\xad])', '\\1or um', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elos uma(?![-\\w–\xad])', '\\1or uma', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elos uns(?![-\\w–\xad])', '\\1or uns', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elos umas(?![-\\w–\xad])', '\\1or umas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elos nenhum(?![-\\w–\xad])', '\\1or nenhum', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elas o(?![-\\w–\xad])', '\\1elo', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elas a(?![-\\w–\xad])', '\\1ela', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elas os(?![-\\w–\xad])', '\\1elos', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elas as(?![-\\w–\xad])', '\\1elas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elas um(?![-\\w–\xad])', '\\1or um', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elas uma(?![-\\w–\xad])', '\\1or uma', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elas uns(?![-\\w–\xad])', '\\1or uns', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elas umas(?![-\\w–\xad])', '\\1or umas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])elas nenhum(?![-\\w–\xad])', '\\1or nenhum', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])um um(?![-\\w–\xad])', '\\1um', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])um uns(?![-\\w–\xad])', '\\1uns', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])um uma(?![-\\w–\xad])', '\\1uma', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])um umas(?![-\\w–\xad])', '\\1umas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])um nenhum(?![-\\w–\xad])', '\\1enhum', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])uma um(?![-\\w–\xad])', '\\1um', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])uma uns(?![-\\w–\xad])', '\\1uns', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])uma uma(?![-\\w–\xad])', '\\1uma', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])uma umas(?![-\\w–\xad])', '\\1umas', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Nn])uma nenhum(?![-\\w–\xad])', '\\1enhum', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])vi ela(?![-\\w–\xad])', 'a vi', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])vi ele(?![-\\w–\xad])', 'o vi', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])viram ele(?![-\\w–\xad])', 'o viram', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])viram ela(?![-\\w–\xad])', 'a viram', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])viu ele(?![-\\w–\xad])', 'o vi', 'Você quis dizer:', 'not excviuEle.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])viu ela(?![-\\w–\xad])', 'a vi', 'Você quis dizer:', 'not excviuEle.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])vi elas(?![-\\w–\xad])', 'as vi', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])vi eles(?![-\\w–\xad])', 'os vi', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])viram eles(?![-\\w–\xad])', 'os viram', 'Você quis dizer:', 'not excviuEle.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])viram elas(?![-\\w–\xad])', 'as viram', 'Você quis dizer:', 'not excviuEle.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])viu eles(?![-\\w–\xad])', 'os vi', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])viu elas(?![-\\w–\xad])', 'as vi', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Pp])au [Bb]rasil(?![-\\w–\xad])', '\\1au-brasil', 'Você quis dizer:', False],
 ['(?u)\\b([ ])ou seja(?![-\\w–\xad])', ', ou seja,', '"Ou seja" deve estar entre vírgulas. Você quis dizer:', 'vOusejac.search(TEXT) and not excOuseja.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])ou seja(?![-\\w–\xad])', 'ou seja,', '"Ou seja" deve estar entre vírgulas. Você quis dizer:', 'vOusejae.search(TEXT) and not excOuseja.search(TEXT)'],
 ['(?u)\\b([ ])ou seja(?![-\\w–\xad])', ', ou seja', '"Ou seja" deve estar entre vírgulas. Você quis dizer:', 'vOusejad.search(TEXT) and not excOuseja.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])Ou seja (?P<Puxx_1>[a-zA-Záâçéêíóôúã]+)(?![-\\w–\xad])', 'Ou seja, \\1', 'Faltou a pausa? Você quis dizer:', 'not excOuseja.search(TEXT)'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ccdd_1>[a-zA-Z]+)dade de tempo (?P<Ccdd_2>[a-zA-Z]+[ai])do(?![-\\w–\xad])', '\\1dade de tempo \\2da', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Ccdd_3>[a-zA-Z]+)dades de tempo (?P<Ccdd_4>[a-zA-Z]+[ai])dos(?![-\\w–\xad])', '\\1dades de tempo \\2das', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cfoi_1>[a-zA-Záâçéêíóôúã]+) (?P<Cfoi_2>[a-zA-Z]+)mentos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "mento\\n" + aaVblgspp[m.group(1)] + " " + m.group(2) + "mentos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Cfoi_1").lower() in ccVblgspp'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cfoi_3>[a-zA-Záâçéêíóôúã]+) (?P<Cfoi_4>[a-zA-Z]+)([aií])dos(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "do\\n" + aaVblgspp[m.group(1)] + " " + m.group(2) + m.group(3) + "dos"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Cfoi_3").lower() in ccVblgspp'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cfoi_5>[a-zA-Záâçéêíóôúã]+) (?P<Cfoi_6>[a-zA-Z]+t)os(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "o\\n" + aaVblgspp[m.group(1)] + " " + m.group(2) + "os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Cfoi_5").lower() in ccVblgspp and m.group("Cfoi_6").lower() in ccVbptcto'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cfoi_7>[a-zA-Záâçéêíóôúã]+) (?P<Cfoi_8>[a-zA-Z]+)([aií])das(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + m.group(3) + "da\\n" + aaVblgspp[m.group(1)] + " " + m.group(2) + m.group(3) + "das"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Cfoi_7").lower() in ccVblgspp'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cfoi_9>[a-zA-Záâçéêíóôúã]+) (?P<Cfoi_10>[a-zA-Z]+t)as(?![-\\w–\xad])', '= m.group(1) + " " + m.group(2) + "a\\n" + aaVblgspp[m.group(1)] + " " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Cfoi_9").lower() in ccVblgspp and m.group("Cfoi_10").lower() in ccVbptcto'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cfoi_11>[a-zA-Záâçéêíóôúã]+) (?P<Cfoi_12>[a-zA-Z]+)([aií])do os(?![-\\w–\xad])', '= aaVblgspp[m.group(1)] + " " + m.group(2) + m.group(3) + "dos os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Cfoi_11").lower() in ccVblgspp'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cfoi_13>[a-zA-Záâçéêíóôúã]+) (?P<Cfoi_14>[a-zA-Z]+t)o os(?![-\\w–\xad])', '= aaVblgspp[m.group(1)] + " " + m.group(2) + "os os"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Cfoi_13").lower() in ccVblgspp and m.group("Cfoi_14").lower() in ccVbptcto'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cfoi_15>[a-zA-Záâçéêíóôúã]+) (?P<Cfoi_16>[a-zA-Z]+)([aií])da as(?![-\\w–\xad])', '= aaVblgspp[m.group(1)] + " " + m.group(2) + m.group(3) + "das as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Cfoi_15").lower() in ccVblgspp'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Cfoi_17>[a-zA-Záâçéêíóôúã]+) (?P<Cfoi_18>[a-zA-Z]+t)a as(?![-\\w–\xad])', '= aaVblgspp[m.group(1)] + " " + m.group(2) + "as as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Cfoi_17").lower() in ccVblgspp and m.group("Cfoi_18").lower() in ccVbptcto'],
 ['(?u)(?<![-\\w–.,\xad])(Qu|qu|T|t)antas vezes forem necessários(?![-\\w–\xad])', '\\1antas vezes forem necessárias\\n\\1antas vezes for necessário', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Qu|qu|T|t)antas vezes for necessária(?![-\\w–\xad])', '\\1antas vezes forem necessárias\\n\\1antas vezes for necessário', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Qu|qu|T|t)antas vezes foram necessários(?![-\\w–\xad])', '\\1antas vezes foram necessárias\\n\\1antas vezes foi necessário', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Qu|qu|T|t)antas vezes foi necessária(?![-\\w–\xad])', '\\1antas vezes foram necessárias\\n\\1antas vezes foi necessário', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Qu|qu|T|t)antas vezes sejam necessários(?![-\\w–\xad])', '\\1antas vezes sejam necessárias\\n\\1antas vezes seja necessário', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Qu|qu|T|t)antas vezes seja necessária(?![-\\w–\xad])', '\\1antas vezes sejam necessárias\\n\\1antas vezes seja necessário', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Qu|qu|T|t)antas vezes forem precisos(?![-\\w–\xad])', '\\1antas vezes forem precisas\\n\\1antas vezes for preciso', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Qu|qu|T|t)antas vezes for precisa(?![-\\w–\xad])', '\\1antas vezes forem precisas\\n\\1antas vezes for preciso', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Qu|qu|T|t)antas vezes foram precisos(?![-\\w–\xad])', '\\1antas vezes foram precisas\\n\\1antas vezes foi preciso', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Qu|qu|T|t)antas vezes foi precisa(?![-\\w–\xad])', '\\1antas vezes foram precisas\\n\\1antas vezes foi preciso', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Qu|qu|T|t)antas vezes sejam precisos(?![-\\w–\xad])', '\\1antas vezes sejam precisas\\n\\1antas vezes seja preciso', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(Qu|qu|T|t)antas vezes seja precisa(?![-\\w–\xad])', '\\1antas vezes sejam precisas\\n\\1antas vezes seja preciso', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(do|no|mato|o|O|fogo|punho|ataque|interrogatório|pelo) serrado(?![-\\w–\xad])', '\\1 cerrado', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(do|no|mato|o|O|fogo|punho|ataque|interrogatório|pelo) Serrado(?![-\\w–\xad])', '\\1 Cerrado', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pvir_0>[a-zA-Záâãçéêíóôú]+) vim(?![-\\w–\xad])', '\\1 vir', 'Você quis dizer:', 'm.group("Pvir_0").lower() in plvrVim'],
 ['(?u)(?<![-\\w–.,\xad])([Dd]o|[Hh]á|[Nn]ada|[Nn]ós|[Pp]ara|[Pp]arece|[Pp]arecia|[Tt]em|[Tt]êm|[Tt]enham|[Tt]enho|[Tt]ens|[Tt]er|[Tt]erá|[Tt]erão|[Tt]eria|[Tt]inha|[Tt]ínhamos|[Tt]ive|[Tt]ivesse) que vim(?![-\\w–\xad])', '\\1 que vir', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ss]e|[Qq]uando) (ele|ela|você|alguém|ninguém) vim(?![-\\w–\xad])', '\\1 \\2 vier', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])igual o(?![-\\w–\xad])', 'igual ao', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])rin(a|ar|amento|amentos|ando|ava|avam|ou)(?![-\\w–\xad])', '\\1rein\\2', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ren(ar|amento|amentos|ando|ava|avam|ou|aram|arei|ará|arão)(?![-\\w–\xad])', '\\1rein\\2', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])[ou]i eu que ([a-z]+[bdfhjlmnoprstvxz])ou(?![-\\w–\xad])', '\\1ui eu que \\2ei\\n\\1ui eu quem \\2o', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])[ou]i eu quem ([a-z]+[bdfhjlmnoprstvxz])ei(?![-\\w–\xad])', '\\1ui eu quem \\2ou\\n\\1ui eu que \\2ei', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([a-záâçéêíóôúã]+[s]) a ([lstv])er ([a-z]+[aií]d[ao]s)(?![-\\w–\xad])', '\\1 a \\2erem \\3', 'O adequado é usar o infinitivo flexionado. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Ff])[ou]i eu que ([a-zç]+)cou(?![-\\w–\xad])', '\\1ui eu que \\2quei\\n\\1ui eu quem \\2co', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])[ou]i eu quem ([a-zç]+)quei(?![-\\w–\xad])', '\\1ui eu quem \\2cou\\n\\1ui eu que \\2quei', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])[ou]i eu que ([a-zç]+)gou(?![-\\w–\xad])', '\\1ui eu que \\2guei\\n\\1ui eu quem \\2go', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])[ou]i eu quem ([a-zç]+)guei(?![-\\w–\xad])', '\\1ui eu quem \\2gou\\n\\1ui eu que \\2guei', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])[ou]i eu que ([a-z]+)çou(?![-\\w–\xad])', '\\1ui eu que \\2cei\\n\\1ui eu quem \\2ço', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])[ou]i eu quem ([a-zç]+)cei(?![-\\w–\xad])', '\\1ui eu quem \\2çou\\n\\1ui eu que \\2cei', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])[ou]i eu que ([a-zç]+)eu(?![-\\w–\xad])', '\\1ui eu que \\2i\\n\\1ui eu quem \\2e', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])[ou]i eu quem ([a-zç]+)i(?![-\\w–\xad])', '\\1ui eu quem \\2eu\\n\\1ui eu que \\2i', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])[ou]i eu que ([a-zç]+)ceu(?![-\\w–\xad])', '\\1ui eu que \\2ci\\n\\1ui eu quem \\2ce', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])[ou]i eu quem ([a-zç]+)ci(?![-\\w–\xad])', '\\1ui eu quem \\2ceu\\n\\1ui eu que \\2ci', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(mos|i) nós que ([a-zç]+)ou(?![-\\w–\xad])', '\\1omos nós que \\3amos\\n\\1omos nós quem \\3o', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(mos|i) nós quem ([a-zç]+)amos(?![-\\w–\xad])', '\\1omos nós quem \\3ou\\n\\1omos nós que \\3amos', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(mos|i) nós que ([a-zç]+)cou(?![-\\w–\xad])', '\\1omos nós que \\3camos\\n\\1omos nós quem \\3co', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(mos|i) nós quem ([a-zç]+)camos(?![-\\w–\xad])', '\\1omos nós quem \\3cou\\n\\1omos nós que \\3camos', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(mos|i) nós que ([a-zç]+)gou(?![-\\w–\xad])', '\\1omos nós que \\3gamos\\n\\1omos nós quem \\3go', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(mos|i) nós quem ([a-zç]+)gamos(?![-\\w–\xad])', '\\1omos nós quem \\3gou\\n\\1omos nós que \\3gamos', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(mos|i) nós que ([a-z]+)çou(?![-\\w–\xad])', '\\1omos nós que \\3çamos\\n\\1omos nós quem \\3ço', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(mos|i) nós quem ([a-zç]+)çamos(?![-\\w–\xad])', '\\1omos nós quem \\3çou\\n\\1omos nós que \\3çamos', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(mos|i) nós que ([a-zç]+)eu(?![-\\w–\xad])', '\\1omos nós que \\3emos\\n\\1omos nós quem \\3e', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(mos|i) nós quem ([a-zç]+)emos(?![-\\w–\xad])', '\\1omos nós quem \\3eu\\n\\1omos nós que \\3emos', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(mos|i) nós que ([a-zç]+)ceu(?![-\\w–\xad])', '\\1omos nós que \\3cemos\\n\\1omos nós quem \\3ce', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(mos|i) nós quem ([a-zç]+)cemos(?![-\\w–\xad])', '\\1omos nós quem \\3ceu\\n\\1omos nós que \\3cemos', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(ram|i) (elas|eles|vocês) que ([a-zç]+)ou(?![-\\w–\xad])', '\\1oram \\3 que \\4aram\\n\\1oram \\3 quem \\4o', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(ram|i) (elas|eles|vocês) quem ([a-zç]+)aram(?![-\\w–\xad])', '\\1oram \\3 quem \\4ou\\n\\1oram \\3 que \\4aram', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(ram|i) (elas|eles|vocês) que ([a-zç]+)cou(?![-\\w–\xad])', '\\1oram \\3 que \\4caram\\n\\1oram \\3 quem \\4co', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(ram|i) (elas|eles|vocês) quem ([a-zç]+)caram(?![-\\w–\xad])', '\\1oram \\3 quem \\4cou\\n\\1oram \\3 que \\4caram', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(ram|i) (elas|eles|vocês) que ([a-zç]+)gou(?![-\\w–\xad])', '\\1oram \\3 que \\4garam\\n\\1oram \\3 quem \\4go', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(ram|i) (elas|eles|vocês) quem ([a-zç]+)garam(?![-\\w–\xad])', '\\1oram \\3 quem \\4gou\\n\\1oram \\3 que \\4garam', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(ram|i) (elas|eles|vocês) que ([a-z]+)çou(?![-\\w–\xad])', '\\1oram \\3 que \\4çaram\\n\\1oram \\3 quem \\4ço', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(ram|i) (elas|eles|vocês) quem ([a-zç]+)çaram(?![-\\w–\xad])', '\\1oram \\3 quem \\4çou\\n\\1oram \\3 que \\4çaram', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrCVbrar'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(ram|i) (elas|eles|vocês) que ([a-zç]+)eu(?![-\\w–\xad])', '\\1oram \\3 que \\4eram\\n\\1oram \\3 quem \\4e', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(ram|i) (elas|eles|vocês) quem ([a-zç]+)eram(?![-\\w–\xad])', '\\1oram \\3 quem \\4eu\\n\\1oram \\3 que \\4eram', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrxer'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(ram|i) (elas|eles|vocês) que ([a-zç]+)ceu(?![-\\w–\xad])', '\\1oram \\3 que \\4ceram\\n\\1oram \\3 quem \\4ce', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])([Ff])o(ram|i) (elas|eles|vocês) quem ([a-zç]+)ceram(?![-\\w–\xad])', '\\1oram \\3 quem \\4ceu\\n\\1oram \\3 que \\4ceram', 'Não há concordância verbal. Você quis dizer:', 'm.group(2) in plvrVbrcer'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmatt_8>[A-Za-z]+)s (?P<Msvc_30>[a-zA-Zçáéíóúâêô]+)as (?P<Msvc_31>[a-zA-Záâãçéêíóôú]+) (?P<Msvc_32>[a-zA-Zçáéíóúâêô]+)[ao]s(?![-\\w–\xad])', '= varGenera[m.group(1)] +"s " + m.group(2) + "as " + aaVblgtpp[m.group(3)] + " " + m.group(4) + "as"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvc_30").lower() in plvrMfoa and m.group("Msvc_32").lower() in plvrMfoa and m.group("Msvc_31").lower() in ccVblgstpp and m.group("Pmatt_8") in ajSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmatt_9>[A-Za-z]+) (?P<Msvc_33>[a-zA-Zçáéíóúâêô]+)a (?P<Msvc_34>[a-zA-Záâãçéêíóôú]+) (?P<Msvc_35>[a-zA-Zçáéíóúâêô]+)[ao](?![-\\w–\xad])', '= varGenera[m.group(1)] +" " + m.group(2) + "a " + aaVblgtps[m.group(3)] + " " + m.group(4) + "a"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvc_33").lower() in plvrMfoa and m.group("Msvc_35").lower() in plvrMfoa and m.group("Msvc_34").lower() in ccVblgstps and m.group("Pmatt_9") in ajSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmatt_10>[A-Za-z]+) (?P<Msvc_36>[a-zA-Zçáéíóúâêô]+)a (?P<Msvc_37>[a-zA-Záâãçéêíóôú]+) (?P<Msvc_38>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '= varGenera[m.group(1)] +" " + m.group(2) + "a " + aaVblgtps[m.group(3)] + " " + m.group(4) + "a"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvc_36").lower() in plvrMfoa and m.group("Msvc_38").lower() in plvrMfoa and m.group("Msvc_37").lower() in ccVblgcpt and m.group("Pmatt_10") in ajSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmatt_11>[A-Za-z]+)s (?P<Msvc_39>[a-zA-Zçáéíóúâêô]+)as (?P<Msvc_40>[a-zA-Záâãçéêíóôú]+) (?P<Msvc_41>[a-zA-Záâãçéêíóôú]+)a(?![-\\w–\xad])', '= varGenera[m.group(1)] +"s " + m.group(2) + "as " + aaVblgtpp[m.group(3)] + " " + m.group(4) + "as"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvc_39").lower() in plvrMfoa and m.group("Msvc_41").lower() in plvrMfoa and m.group("Msvc_40").lower() in ccVblgcpt and m.group("Pmatt_11") in ajSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msvc_42>[a-zA-Zçáéíóúâêô]+)a (?P<Msvc_43>[a-záâãçéêíóôú]+)os(?![-\\w–\xad])', '= m.group(1) + "as " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Msvc_42").lower() in plvrMfoa and m.group("Msvc_43").lower() in plvrMfoa and not " e a " + m.group("Msvc_42") in TEXT and not " e " + m.group("Msvc_42") in TEXT and not "s da " + m.group("Msvc_42") in TEXT and not " de " + m.group("Msvc_42") in TEXT'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmatt_13>[a-z]+)s (?P<Msvc_44>[a-zA-Zçáéíóúâêô]+)as (?P<Msvc_45>[a-zA-Záâãçéêíóôú]+) (?P<Msvc_46>[a-zA-Zçáéíóúâêô]+)[ao]s(?![-\\w–\xad])', '= ", "+ varGenera[m.group(1)] +"s " + m.group(2) + "as " + aaVblgtpp[m.group(3)] + " " + m.group(4) + "as"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvc_44").lower() in plvrMfoa and m.group("Msvc_46").lower() in plvrMfoa and m.group("Msvc_45").lower() in ccVblgstpp and m.group("Pmatt_13") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmatt_14>[a-z]+) (?P<Msvc_47>[a-zA-Zçáéíóúâêô]+)a (?P<Msvc_48>[a-zA-Záâãçéêíóôú]+) (?P<Msvc_49>[a-zA-Zçáéíóúâêô]+)[ao](?![-\\w–\xad])', '= ", " + varGenera[m.group(1)] +" " + m.group(2) + "a " + aaVblgtps[m.group(3)] + " " + m.group(4) + "a"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvc_47").lower() in plvrMfoa and m.group("Msvc_49").lower() in plvrMfoa and m.group("Msvc_48").lower() in ccVblgstps and m.group("Pmatt_14") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmatt_15>[a-z]+) (?P<Msvc_50>[a-zA-Zçáéíóúâêô]+)a (?P<Msvc_51>[a-zA-Záâãçéêíóôú]+) (?P<Msvc_52>[a-zA-Záâãçéêíóôú]+)[ao]s(?![-\\w–\xad])', '= ", " + varGenera[m.group(1)] +" " + m.group(2) + "a " + aaVblgtps[m.group(3)] + " " + m.group(4) + "a"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvc_50").lower() in plvrMfoa and m.group("Msvc_52").lower() in plvrMfoa and m.group("Msvc_51").lower() in ccVblgcpt and m.group("Pmatt_15") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmatt_16>[a-z]+)s (?P<Msvc_53>[a-zA-Zçáéíóúâêô]+)as (?P<Msvc_54>[a-zA-Záâãçéêíóôú]+) (?P<Msvc_55>[a-zA-Záâãçéêíóôú]+)a(?![-\\w–\xad])', '= ", "+ varGenera[m.group(1)] +"s " + m.group(2) + "as " + aaVblgtpp[m.group(3)] + " " + m.group(4) + "as"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvc_53").lower() in plvrMfoa and m.group("Msvc_55").lower() in plvrMfoa and m.group("Msvc_54").lower() in ccVblgcpt and m.group("Pmatt_16") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmott_1>[A-Za-z]+) (?P<Mavc_10>[a-zA-Zçáéíóúâêô]+)a (?P<Mavc_11>[a-zA-Záâãçéêíóôú]+) (?P<Mavc_12>[a-zA-Záâãçéêíóôú]+)o(?![-\\w–\xad])', '= varGenera[m.group(1)] +" " + m.group(2) + "a " + aaVblgtps[m.group(3)] + " " + m.group(4) + "a"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mavc_10").lower() in plvrMfoa and m.group("Mavc_12").lower() in plvrMfoa and m.group("Mavc_11").lower() in ccVblgcpt and m.group("Pmott_1") in ajSingular'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmott_2>[a-z]+) (?P<Mavc_13>[a-zA-Zçáéíóúâêô]+)a (?P<Mavc_14>[a-zA-Záâãçéêíóôú]+) (?P<Mavc_15>[a-zA-Záâãçéêíóôú]+)o(?![-\\w–\xad])', '= ", " + varGenera[m.group(1)] +" " + m.group(2) + "a " + aaVblgtps[m.group(3)] + " " + m.group(4) + "a"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Mavc_13").lower() in plvrMfoa and m.group("Mavc_15").lower() in plvrMfoa and m.group("Mavc_14").lower() in ccVblgcpt and m.group("Pmott_2") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmalt_0>[A-Za-z]+)s (?P<Msvd_1>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msvd_2>[a-zA-Záâãçéêíóôú]+) (?P<Msvd_3>[a-zA-Zçáéíóúâêô]+)[ao]s(?![-\\w–\xad])', '= m.group(1) +"s " + m.group(2) + "s " + aaVblgtpp[m.group(3)] + " " + m.group(4) + "as"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvd_1").lower() in plvrFema and m.group("Msvd_3").lower() in plvrMfoa and m.group("Msvd_2").lower() in ccVblgstpp and m.group("Pmalt_0") in ajSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmalt_1>[A-Za-z]+) (?P<Msvd_4>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msvd_5>[a-zA-Záâãçéêíóôú]+) (?P<Msvd_6>[a-zA-Zçáéíóúâêô]+)[ao](?![-\\w–\xad])', '= m.group(1) +" " + m.group(2) + " " + aaVblgtps[m.group(3)] + " " + m.group(4) + "a"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvd_4").lower() in plvrFema and m.group("Msvd_6").lower() in plvrMfoa and m.group("Msvd_5").lower() in ccVblgstps and m.group("Pmalt_1") in ajSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmalt_2>[A-Za-z]+) (?P<Msvd_7>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msvd_8>[a-zA-Záâãçéêíóôú]+) (?P<Msvd_9>[a-zA-Záâãçéêíóôú]+)as(?![-\\w–\xad])', '= m.group(1) +" " + m.group(2) + " " + aaVblgtps[m.group(3)] + " " + m.group(4) + "a"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvd_7").lower() in plvrFema and m.group("Msvd_9").lower() in plvrMfoa and m.group("Msvd_8").lower() in ccVblgcpt and m.group("Pmalt_2") in ajSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Pmalt_3>[A-Za-z]+)s (?P<Msvd_10>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msvd_11>[a-zA-Záâãçéêíóôú]+) (?P<Msvd_12>[a-zA-Záâãçéêíóôú]+)a(?![-\\w–\xad])', '= m.group(1) +"s " + m.group(2) + "s " + aaVblgtpp[m.group(3)] + " " + m.group(4) + "as"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvd_10").lower() in plvrFema and m.group("Msvd_12").lower() in plvrMfoa and m.group("Msvd_11").lower() in ccVblgcpt and m.group("Pmalt_3") in ajSingular'],
 ['(?u)(?<![-\\w–.,\xad])(?P<Msvd_13>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msvd_14>[a-záâãçéêíóôú]+)os(?![-\\w–\xad])', '= m.group(1) + "s " + m.group(2) + "as"', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Msvd_13").lower() in excFeMfoa and m.group("Msvd_13").lower() in plvrFema and m.group("Msvd_14").lower() in plvrMfoa and not " e a " + m.group("Msvd_13") in TEXT and not " e " + m.group("Msvd_13") in TEXT and not " de " + m.group("Msvd_13") in TEXT and not "à"+" " + m.group("Msvd_13") in TEXT'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmalt_4>[a-z]+)s (?P<Msvd_15>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msvd_16>[a-zA-Záâãçéêíóôú]+) (?P<Msvd_17>[a-zA-Zçáéíóúâêô]+)[ao]s(?![-\\w–\xad])', '= ", "+ m.group(1) +"s " + m.group(2) + "s " + aaVblgtpp[m.group(3)] + " " + m.group(4) + "as"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvd_15").lower() in plvrFema and m.group("Msvd_17").lower() in plvrMfoa and m.group("Msvd_16").lower() in ccVblgstpp and m.group("Pmalt_4") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmalt_5>[a-z]+) (?P<Msvd_18>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msvd_19>[a-zA-Záâãçéêíóôú]+) (?P<Msvd_20>[a-zA-Zçáéíóúâêô]+)[ao](?![-\\w–\xad])', '= ", " + m.group(1) +" " + m.group(2) + " " + aaVblgtps[m.group(3)] + " " + m.group(4) + "a"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvd_18").lower() in plvrFema and m.group("Msvd_20").lower() in plvrMfoa and m.group("Msvd_19").lower() in ccVblgstps and m.group("Pmalt_5") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmalt_6>[a-z]+) (?P<Msvd_21>[a-zA-Záâãçéêíóôú]+[a]) (?P<Msvd_22>[a-zA-Záâãçéêíóôú]+) (?P<Msvd_23>[a-zA-Záâãçéêíóôú]+)[ao]s(?![-\\w–\xad])', '= ", " + m.group(1) +" " + m.group(2) + " " + aaVblgtps[m.group(3)] + " " + m.group(4) + "a"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvd_21").lower() in plvrFema and m.group("Msvd_23").lower() in plvrMfoa and m.group("Msvd_22").lower() in ccVblgcpt and m.group("Pmalt_6") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad]), (?P<Pmalt_7>[a-z]+)s (?P<Msvd_24>[a-zA-Záâãçéêíóôú]+[a])s (?P<Msvd_25>[a-zA-Záâãçéêíóôú]+) (?P<Msvd_26>[a-zA-Záâãçéêíóôú]+)a(?![-\\w–\xad])', '= ", " + m.group(1) +"s " + m.group(2) + "s " + aaVblgtpp[m.group(3)] + " " + m.group(4) + "as"', 'Não há concordância verbal. Você quis dizer:', 'm.group("Msvd_24").lower() in plvrFema and m.group("Msvd_26").lower() in plvrMfoa and m.group("Msvd_25").lower() in ccVblgcpt and m.group("Pmalt_7") in acSingular'],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) (o|os)(?![-\\w–\xad])', '\\1\\2', 'Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Oo]|[Dd]a|[Dd]o|[Nn]a|[Nn]o|[Pp]ela|[Pp]elo|[Ss]eu|[Ss]ua) demais(?![-\\w–\xad])', '\\1s demais', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Aa]) demais(?![-\\w–\xad])', '\\1demais\\n\\1s demais', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_1>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '\\1emais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_1").lower() in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_2>[a-zA-Zçáéíóúâêô]+)([ao])(?![-\\w–\xad])', '\\1emais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_2").lower() in plvrMfoa and not "por demais" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_3>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1emais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_3").lower() in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_4>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1emais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_4").lower() in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_5>[a-zA-Z]+ista)(?![-\\w–\xad])', '\\1emais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Dmas_5").lower() in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_6>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '\\1emais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_6") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_7>[a-zA-Zç]+o)(?![-\\w–\xad])', '\\1emais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_7") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_8>[a-zA-Záâãéêíóôú]+)([aeiou])nça(?![-\\w–\xad])', '\\1emais \\2\\3nças', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Dmas_8") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_9>[a-zA-Zç]+)([âêíôú])ncia(?![-\\w–\xad])', '\\1emais \\2\\3ncias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_10>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '\\1emais \\2grafias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_11>[a-zA-Záâãçéêíóôú]+)([gl])ogia(?![-\\w–\xad])', '\\1emais \\2\\3ogias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_12>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '\\1emais \\2rgias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_13>[a-zA-Zç]+)([áéíóú])lia(?![-\\w–\xad])', '\\1emais \\2\\3lias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_14>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '\\1emais \\2erapias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_15>[a-zA-Zç]+)([áéíóú])ria(?![-\\w–\xad])', '\\1emais \\2\\3rias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_16>[a-zA-Zç]+)([áéíú])sia(?![-\\w–\xad])', '\\1emais \\2\\3sias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_17>[a-zA-Zç]+)([áéíóú])rsia(?![-\\w–\xad])', '\\1emais \\2\\3rsias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_18>[a-zA-Zç]+)([áéíóú])ssia(?![-\\w–\xad])', '\\1emais \\2\\3ssias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_19>[a-zA-Zç]+)([áéíóú])rnia(?![-\\w–\xad])', '\\1emais \\2\\3rnias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_20>[a-zA-Zç]+)([âêíôú])nia(?![-\\w–\xad])', '\\1emais \\2\\3nias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_21>[a-zA-Z]+ista)(?![-\\w–\xad])', '\\1emais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Dmas_21") in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_22>[a-zA-Zç]+)(ida|ido)(?![-\\w–\xad])', '\\1emais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Dmas_22") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_23>[a-zA-Zç]+)(osa|oso)(?![-\\w–\xad])', '\\1emais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_24>[a-zA-Zç]+)(iva|ivo)(?![-\\w–\xad])', '\\1emais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_25>[a-zA-Zç]+)mento(?![-\\w–\xad])', '\\1emais \\2mentos', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_26>[a-zA-Zç]+[âêô][mn])(ica|ico)(?![-\\w–\xad])', '\\1emais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_27>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])(ica|ico)(?![-\\w–\xad])', '\\1emais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', 'not "por demais" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_28>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])(ica|ico)(?![-\\w–\xad])', '\\1emais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', 'not "por demais" in TEXT'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_29>[a-zA-Zç]+)(esca|esco)(?![-\\w–\xad])', '\\1emais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_30>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])(ida|ido)(?![-\\w–\xad])', '\\1emais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_31>[a-zA-Zç]+[ó])(loga|logo)(?![-\\w–\xad])', '\\1emais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_32>[a-zA-Zç]+[áéíóúâêô])(ria|rio)(?![-\\w–\xad])', '\\1emais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_33>[a-zA-Zç]+[í])(ssima|ssimo)(?![-\\w–\xad])', '\\1emais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_34>[a-zA-Zç]+[é])(sima|simo)(?![-\\w–\xad])', '\\1emais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_35>[a-zA-Zçáéíóúâêô]+[dst])(ora|ore)(?![-\\w–\xad])', '\\1emais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_36>[a-zA-Záâãçéêíóôú]+[r])e(?![-\\w–\xad])', '\\1emais \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_36") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_37>[a-zA-Záâãçéêíóôú]+[r])e(?![-\\w–\xad])', '\\1emais \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_37") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_38>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '\\1emais \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_38") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_39>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '\\1emais \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_39") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_40>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '\\1emais \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_40") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_41>[a-zA-Zçáéíóúâêô]+[a])i(?![-\\w–\xad])', '\\1emais \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_41") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_42>[a-zA-Záâãçéêíóôú]+[a])i(?![-\\w–\xad])', '\\1emais \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_42") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_43>[a-zA-Záâãçéêíóôú]+[a])i(?![-\\w–\xad])', '\\1emais \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_43") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_44>[a-zA-Z]+)éi(?![-\\w–\xad])', '\\1emais \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_44") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_45>[a-zA-Z]+)éi(?![-\\w–\xad])', '\\1emais \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_45") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_46>[a-zA-Z]+)éi(?![-\\w–\xad])', '\\1emais \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_46") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_47>[a-zA-Záâãçéêíóôú]+[e])i(?![-\\w–\xad])', '\\1emais \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_47") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_48>[a-zA-Zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '\\1emais \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_48") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_49>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '\\1emais \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_49") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_50>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '\\1emais \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_50") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_51>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '\\1emais \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Dmas_51") in plvrFemao and not m.group("Dmas_51") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_52>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '\\1emais \\2dades', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_53>[a-zA-Zç]+[áéíóú])vei(?![-\\w–\xad])', '\\1emais \\2veis', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_54>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '\\1emais \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'not "por demais" in TEXT and m.group("Dmas_54") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_55>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '\\1emais \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'not "por demais" in TEXT and m.group("Dmas_55") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_56>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '\\1emais \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'not "por demais" in TEXT and m.group("Dmas_56") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_57>[a-zA-Z]+)ze(?![-\\w–\xad])', '\\1emais \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_57") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_58>[a-zA-Z]+)ze(?![-\\w–\xad])', '\\1emais \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_58") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_59>[a-zA-Z]+)ze(?![-\\w–\xad])', '\\1emais \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Dmas_59") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_60>[a-zA-Z]+)íze(?![-\\w–\xad])', '\\1emais \\2ízes', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Dd])emais (?P<Dmas_61>[a-zA-Záâãçéêíóôú]+[aeio])n(?![-\\w–\xad])', '\\1emais \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_1>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '\\1uaisquer \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_1").lower() in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_2>[a-zA-Zçáéíóúâêô]+)([ao])s(?![-\\w–\xad])', '\\1uaisquer \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_2").lower() in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_3>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1uaisquer \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_3").lower() in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_4>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1uaisquer \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_4").lower() in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_5>[a-zA-Z]+ista)s(?![-\\w–\xad])', '\\1uaisquer \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Qqer_5").lower() in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_6>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '\\1uaisquer \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_6") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_7>[a-zA-Zç]+o)S(?![-\\w–\xad])', '\\1uaisquer \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_7") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_8>[a-zA-Záâãéêíóôú]+)([aeiou])nças(?![-\\w–\xad])', '\\1uaisquer \\2\\3nças', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Qqer_8") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_9>[a-zA-Zç]+)([âêíôú])ncias(?![-\\w–\xad])', '\\1uaisquer \\2\\3ncias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_10>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '\\1uaisquer \\2grafias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_11>[a-zA-Záâãçéêíóôú]+)([gl])ogias(?![-\\w–\xad])', '\\1uaisquer \\2\\3ogias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_12>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '\\1uaisquer \\2rgias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_13>[a-zA-Zç]+)([áéíóú])lias(?![-\\w–\xad])', '\\1uaisquer \\2\\3lias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_14>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '\\1uaisquer \\2erapias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_15>[a-zA-Zç]+)([áéíóú])rias(?![-\\w–\xad])', '\\1uaisquer \\2\\3rias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_16>[a-zA-Zç]+)([áéíú])sias(?![-\\w–\xad])', '\\1uaisquer \\2\\3sias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_17>[a-zA-Zç]+)([áéíóú])rsias(?![-\\w–\xad])', '\\1uaisquer \\2\\3rsias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_18>[a-zA-Zç]+)([áéíóú])ssias(?![-\\w–\xad])', '\\1uaisquer \\2\\3ssias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_19>[a-zA-Zç]+)([áéíóú])rnias(?![-\\w–\xad])', '\\1uaisquer \\2\\3rnias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_20>[a-zA-Zç]+)([âêíôú])nias(?![-\\w–\xad])', '\\1uaisquer \\2\\3nias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_21>[a-zA-Z]+ista)s(?![-\\w–\xad])', '\\1uaisquer \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Qqer_21") in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_22>[a-zA-Zç]+)(idas|idos)(?![-\\w–\xad])', '\\1uaisquer \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Qqer_22") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_23>[a-zA-Zç]+)(osas|osos)(?![-\\w–\xad])', '\\1uaisquer \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_24>[a-zA-Zç]+)(ivas|ivos)(?![-\\w–\xad])', '\\1uaisquer \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_25>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '\\1uaisquer \\2mentos', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_26>[a-zA-Zç]+[âêô][mn])(icas|icos)(?![-\\w–\xad])', '\\1uaisquer \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_27>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])(icas|icos)(?![-\\w–\xad])', '\\1uaisquer \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_28>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])(icas|icos)(?![-\\w–\xad])', '\\1uaisquer \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_29>[a-zA-Zç]+)(escas|escos)(?![-\\w–\xad])', '\\1uaisquer \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_30>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])(idas|idos)(?![-\\w–\xad])', '\\1uaisquer \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_31>[a-zA-Zç]+[ó])(logas|logos)(?![-\\w–\xad])', '\\1uaisquer \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_32>[a-zA-Zç]+[áéíóúâêô])(rias|rios)(?![-\\w–\xad])', '\\1uaisquer \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_33>[a-zA-Zç]+[í])(ssimas|ssimos)(?![-\\w–\xad])', '\\1uaisquer \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_34>[a-zA-Zç]+[é])(simas|simos)(?![-\\w–\xad])', '\\1uaisquer \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_35>[a-zA-Zçáéíóúâêô]+[dst])(oras|ores)(?![-\\w–\xad])', '\\1uaisquer \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_36>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '\\1uaisquer \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_36") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_37>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '\\1uaisquer \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_37") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_38>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1uaisquer \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_38") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_39>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '\\1uaisquer \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_39") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_40>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '\\1uaisquer \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_40") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_41>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '\\1uaisquer \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_41") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_42>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '\\1uaisquer \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_42") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_43>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '\\1uaisquer \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_43") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_44>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1uaisquer \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_44") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_45>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1uaisquer \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_45") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_46>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1uaisquer \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_46") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_47>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '\\1uaisquer \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_47") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_48>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1uaisquer \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_48") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_49>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '\\1uaisquer \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_49") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_50>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '\\1uaisquer \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_50") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_51>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '\\1uaisquer \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Qqer_51") in plvrFemao and not m.group("Qqer_51") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_52>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '\\1uaisquer \\2dades', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_53>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '\\1uaisquer \\2veis', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_54>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1uaisquer \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_54") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_55>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '\\1uaisquer \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_55") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_56>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '\\1uaisquer \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_56") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_57>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1uaisquer \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_57") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_58>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1uaisquer \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_58") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_59>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1uaisquer \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qqer_59") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_60>[a-zA-Z]+)ízes(?![-\\w–\xad])', '\\1uaisquer \\2ízes', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer (?P<Qqer_61>[a-zA-Záâãçéêíóôú]+[aeio])ns(?![-\\w–\xad])', '\\1uaisquer \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_1>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '\\1uaisquer \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_1").lower() in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_2>[a-zA-Zçáéíóúâêô]+)([ao])(?![-\\w–\xad])', '\\1uaisquer \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_2").lower() in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_3>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1uaisquer \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_3").lower() in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_4>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1uaisquer \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_4").lower() in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_5>[a-zA-Z]+ista)(?![-\\w–\xad])', '\\1uaisquer \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Qisq_5").lower() in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_6>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '\\1uaisquer \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_6") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_7>[a-zA-Zç]+o)(?![-\\w–\xad])', '\\1uaisquer \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_7") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_8>[a-zA-Záâãéêíóôú]+)([aeiou])nça(?![-\\w–\xad])', '\\1uaisquer \\2\\3nças', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Qisq_8") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_9>[a-zA-Zç]+)([âêíôú])ncia(?![-\\w–\xad])', '\\1uaisquer \\2\\3ncias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_10>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '\\1uaisquer \\2grafias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_11>[a-zA-Záâãçéêíóôú]+)([gl])ogia(?![-\\w–\xad])', '\\1uaisquer \\2\\3ogias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_12>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '\\1uaisquer \\2rgias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_13>[a-zA-Zç]+)([áéíóú])lia(?![-\\w–\xad])', '\\1uaisquer \\2\\3lias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_14>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '\\1uaisquer \\2erapias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_15>[a-zA-Zç]+)([áéíóú])ria(?![-\\w–\xad])', '\\1uaisquer \\2\\3rias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_16>[a-zA-Zç]+)([áéíú])sia(?![-\\w–\xad])', '\\1uaisquer \\2\\3sias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_17>[a-zA-Zç]+)([áéíóú])rsia(?![-\\w–\xad])', '\\1uaisquer \\2\\3rsias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_18>[a-zA-Zç]+)([áéíóú])ssia(?![-\\w–\xad])', '\\1uaisquer \\2\\3ssias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_19>[a-zA-Zç]+)([áéíóú])rnia(?![-\\w–\xad])', '\\1uaisquer \\2\\3rnias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_20>[a-zA-Zç]+)([âêíôú])nia(?![-\\w–\xad])', '\\1uaisquer \\2\\3nias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_21>[a-zA-Z]+ista)(?![-\\w–\xad])', '\\1uaisquer \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Qisq_21") in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_22>[a-zA-Zç]+)(ida|ido)(?![-\\w–\xad])', '\\1uaisquer \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Qisq_22") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_23>[a-zA-Zç]+)(osa|oso)(?![-\\w–\xad])', '\\1uaisquer \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_24>[a-zA-Zç]+)(iva|ivo)(?![-\\w–\xad])', '\\1uaisquer \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_25>[a-zA-Zç]+)mento(?![-\\w–\xad])', '\\1uaisquer \\2mentos', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_26>[a-zA-Zç]+[âêô][mn])(ica|ico)(?![-\\w–\xad])', '\\1uaisquer \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_27>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])(ica|ico)(?![-\\w–\xad])', '\\1uaisquer \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_28>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])(ica|ico)(?![-\\w–\xad])', '\\1uaisquer \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_29>[a-zA-Zç]+)(esca|esco)(?![-\\w–\xad])', '\\1uaisquer \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_30>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])(ida|ido)(?![-\\w–\xad])', '\\1uaisquer \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_31>[a-zA-Zç]+[ó])(loga|logo)(?![-\\w–\xad])', '\\1uaisquer \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_32>[a-zA-Zç]+[áéíóúâêô])(ria|rio)(?![-\\w–\xad])', '\\1uaisquer \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_33>[a-zA-Zç]+[í])(ssima|ssimo)(?![-\\w–\xad])', '\\1uaisquer \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_34>[a-zA-Zç]+[é])(sima|simo)(?![-\\w–\xad])', '\\1uaisquer \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_35>[a-zA-Zçáéíóúâêô]+[dst])(ora|ore)(?![-\\w–\xad])', '\\1uaisquer \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_36>[a-zA-Záâãçéêíóôú]+[r])e(?![-\\w–\xad])', '\\1uaisquer \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_36") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_37>[a-zA-Záâãçéêíóôú]+[r])e(?![-\\w–\xad])', '\\1uaisquer \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_37") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_38>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '\\1uaisquer \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_38") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_39>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '\\1uaisquer \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_39") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_40>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '\\1uaisquer \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_40") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_41>[a-zA-Zçáéíóúâêô]+[a])i(?![-\\w–\xad])', '\\1uaisquer \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_41") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_42>[a-zA-Záâãçéêíóôú]+[a])i(?![-\\w–\xad])', '\\1uaisquer \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_42") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_43>[a-zA-Záâãçéêíóôú]+[a])i(?![-\\w–\xad])', '\\1uaisquer \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_43") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_44>[a-zA-Z]+)éi(?![-\\w–\xad])', '\\1uaisquer \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_44") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_45>[a-zA-Z]+)éi(?![-\\w–\xad])', '\\1uaisquer \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_45") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_46>[a-zA-Z]+)éi(?![-\\w–\xad])', '\\1uaisquer \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_46") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_47>[a-zA-Záâãçéêíóôú]+[e])i(?![-\\w–\xad])', '\\1uaisquer \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_47") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_48>[a-zA-Zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '\\1uaisquer \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_48") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_49>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '\\1uaisquer \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_49") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_50>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '\\1uaisquer \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_50") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_51>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '\\1uaisquer \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Qisq_51") in plvrFemao and not m.group("Qisq_51") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_52>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '\\1uaisquer \\2dades', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_53>[a-zA-Zç]+[áéíóú])vei(?![-\\w–\xad])', '\\1uaisquer \\2veis', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_54>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '\\1uaisquer \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_54") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_55>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '\\1uaisquer \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_55") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_56>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '\\1uaisquer \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_56") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_57>[a-zA-Z]+)ze(?![-\\w–\xad])', '\\1uaisquer \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_57") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_58>[a-zA-Z]+)ze(?![-\\w–\xad])', '\\1uaisquer \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_58") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_59>[a-zA-Z]+)ze(?![-\\w–\xad])', '\\1uaisquer \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Qisq_59") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_60>[a-zA-Z]+)íze(?![-\\w–\xad])', '\\1uaisquer \\2ízes', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_61>[a-zA-Záâãçéêíóôú]+[aeio])n(?![-\\w–\xad])', '\\1uaisquer \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer (?P<Qisq_62>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '\\1uaisquer \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Qisq_62") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Qq])ualquer que (seja|fosse)m(?![-\\w–\xad])', '\\1ualquer que \\2\\n\\1uaisquer que \\2m', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Qq])uaisquer que (seja|fosse)(?![-\\w–\xad])', '\\1ualquer que \\2\\n\\1uaisquer que \\2m', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_1>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '\\1ais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_1").lower() in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_2>[a-zA-Zçáéíóúâêô]+)([ao])(?![-\\w–\xad])', '\\1ais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_2").lower() in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_3>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1ais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_3").lower() in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_4>[a-zA-Záâãçéêíóôú]+[a])(?![-\\w–\xad])', '\\1ais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_4").lower() in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_5>[a-zA-Z]+ista)(?![-\\w–\xad])', '\\1ais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Tais_5").lower() in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_6>[a-zA-Záâãçéêíóôú]+[o])(?![-\\w–\xad])', '\\1ais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_6") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_7>[a-zA-Zç]+o)(?![-\\w–\xad])', '\\1ais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_7") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_8>[a-zA-Záâãéêíóôú]+)([aeiou])nça(?![-\\w–\xad])', '\\1ais \\2\\3nças', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Tais_8") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_9>[a-zA-Zç]+)([âêíôú])ncia(?![-\\w–\xad])', '\\1ais \\2\\3ncias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_10>[a-zA-Záâãçéêíóôú]+)grafia(?![-\\w–\xad])', '\\1ais \\2grafias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_11>[a-zA-Záâãçéêíóôú]+)([gl])ogia(?![-\\w–\xad])', '\\1ais \\2\\3ogias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_12>[a-zA-Záâãçéêíóôú]+)rgia(?![-\\w–\xad])', '\\1ais \\2rgias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_13>[a-zA-Zç]+)([áéíóú])lia(?![-\\w–\xad])', '\\1ais \\2\\3lias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_14>[a-zA-Záâãçéêíóôú]+)erapia(?![-\\w–\xad])', '\\1ais \\2erapias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_15>[a-zA-Zç]+)([áéíóú])ria(?![-\\w–\xad])', '\\1ais \\2\\3rias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_16>[a-zA-Zç]+)([áéíú])sia(?![-\\w–\xad])', '\\1ais \\2\\3sias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_17>[a-zA-Zç]+)([áéíóú])rsia(?![-\\w–\xad])', '\\1ais \\2\\3rsias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_18>[a-zA-Zç]+)([áéíóú])ssia(?![-\\w–\xad])', '\\1ais \\2\\3ssias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_19>[a-zA-Zç]+)([áéíóú])rnia(?![-\\w–\xad])', '\\1ais \\2\\3rnias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_20>[a-zA-Zç]+)([âêíôú])nia(?![-\\w–\xad])', '\\1ais \\2\\3nias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_21>[a-zA-Z]+ista)(?![-\\w–\xad])', '\\1ais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Tais_21") in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_22>[a-zA-Zç]+)(ida|ido)(?![-\\w–\xad])', '\\1ais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Tais_22") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_23>[a-zA-Zç]+)(osa|oso)(?![-\\w–\xad])', '\\1ais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_24>[a-zA-Zç]+)(iva|ivo)(?![-\\w–\xad])', '\\1ais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_25>[a-zA-Zç]+)mento(?![-\\w–\xad])', '\\1ais \\2mentos', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_26>[a-zA-Zç]+[âêô][mn])(ica|ico)(?![-\\w–\xad])', '\\1ais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_27>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])(ica|ico)(?![-\\w–\xad])', '\\1ais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_28>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])(ica|ico)(?![-\\w–\xad])', '\\1ais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_29>[a-zA-Zç]+)(esca|esco)(?![-\\w–\xad])', '\\1ais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_30>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])(ida|ido)(?![-\\w–\xad])', '\\1ais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_31>[a-zA-Zç]+[ó])(loga|logo)(?![-\\w–\xad])', '\\1ais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_32>[a-zA-Zç]+[áéíóúâêô])(ria|rio)(?![-\\w–\xad])', '\\1ais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_33>[a-zA-Zç]+[í])(ssima|ssimo)(?![-\\w–\xad])', '\\1ais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_34>[a-zA-Zç]+[é])(sima|simo)(?![-\\w–\xad])', '\\1ais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_35>[a-zA-Zçáéíóúâêô]+[dst])(ora|ore)(?![-\\w–\xad])', '\\1ais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_36>[a-zA-Záâãçéêíóôú]+[r])e(?![-\\w–\xad])', '\\1ais \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_36") in plvrMascr'],['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_37>[a-zA-Záâãçéêíóôú]+[r])e(?![-\\w–\xad])', '\\1ais \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_37") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_38>[a-zA-Zçáéíóúâêô]+)u(?![-\\w–\xad])', '\\1ais \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_38") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_39>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '\\1ais \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_39") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_40>[a-zA-Záâãçéêíóôú]+)u(?![-\\w–\xad])', '\\1ais \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_40") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_41>[a-zA-Zçáéíóúâêô]+[a])i(?![-\\w–\xad])', '\\1ais \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_41") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_42>[a-zA-Záâãçéêíóôú]+[a])i(?![-\\w–\xad])', '\\1ais \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_42") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_43>[a-zA-Záâãçéêíóôú]+[a])i(?![-\\w–\xad])', '\\1ais \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_43") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_44>[a-zA-Z]+)éi(?![-\\w–\xad])', '\\1ais \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_44") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_45>[a-zA-Z]+)éi(?![-\\w–\xad])', '\\1ais \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_45") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_46>[a-zA-Z]+)éi(?![-\\w–\xad])', '\\1ais \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_46") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_47>[a-zA-Záâãçéêíóôú]+[e])i(?![-\\w–\xad])', '\\1ais \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_47") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_48>[a-zA-Zçáéíóúâêô]+[ç])ão(?![-\\w–\xad])', '\\1ais \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_48") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_49>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '\\1ais \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_49") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_50>[a-zA-Záâãçéêíóôú]+[ç])ão(?![-\\w–\xad])', '\\1ais \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_50") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_51>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ão(?![-\\w–\xad])', '\\1ais \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Tais_51") in plvrFemao and not m.group("Tais_51") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_52>[a-zA-Záâãçéêíóôú]+)dade(?![-\\w–\xad])', '\\1ais \\2dades', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_53>[a-zA-Zç]+[áéíóú])vei(?![-\\w–\xad])', '\\1ais \\2veis', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_54>[a-zA-Zçáéíóúâêô]+)e(?![-\\w–\xad])', '\\1ais \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_54") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_55>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '\\1ais \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_55") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_56>[a-zA-Záâãçéêíóôú]+)e(?![-\\w–\xad])', '\\1ais \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_56") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_57>[a-zA-Z]+)ze(?![-\\w–\xad])', '\\1ais \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_57") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_58>[a-zA-Z]+)ze(?![-\\w–\xad])', '\\1ais \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_58") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_59>[a-zA-Z]+)ze(?![-\\w–\xad])', '\\1ais \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Tais_59") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_60>[a-zA-Z]+)íze(?![-\\w–\xad])', '\\1ais \\2ízes', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])ais (?P<Tais_61>[a-zA-Záâãçéêíóôú]+[aeio])n(?![-\\w–\xad])', '\\1ais \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_1>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '\\1ais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_1").lower() in plvrMasco'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_2>[a-zA-Zçáéíóúâêô]+)([ao])s(?![-\\w–\xad])', '\\1ais \\2\\3s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_2").lower() in plvrMfoa'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_3>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1ais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_3").lower() in plvrFema'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_4>[a-zA-Záâãçéêíóôú]+[a])s(?![-\\w–\xad])', '\\1ais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_4").lower() in plvrMasca'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_5>[a-zA-Z]+ista)s(?![-\\w–\xad])', '\\1ais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ttal_5").lower() in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_6>[a-zA-Záâãçéêíóôú]+[o])s(?![-\\w–\xad])', '\\1ais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_6") in plvrMasxo'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_7>[a-zA-Zç]+o)S(?![-\\w–\xad])', '\\1ais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_7") in plvrFemo'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_8>[a-zA-Záâãéêíóôú]+)([aeiou])nças(?![-\\w–\xad])', '\\1ais \\2\\3nças', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ttal_8") in excpLvrnca'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_9>[a-zA-Zç]+)([âêíôú])ncias(?![-\\w–\xad])', '\\1ais \\2\\3ncias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_10>[a-zA-Záâãçéêíóôú]+)grafias(?![-\\w–\xad])', '\\1ais \\2grafias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_11>[a-zA-Záâãçéêíóôú]+)([gl])ogias(?![-\\w–\xad])', '\\1ais \\2\\3ogias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_12>[a-zA-Záâãçéêíóôú]+)rgias(?![-\\w–\xad])', '\\1ais \\2rgias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_13>[a-zA-Zç]+)([áéíóú])lias(?![-\\w–\xad])', '\\1ais \\2\\3lias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_14>[a-zA-Záâãçéêíóôú]+)erapias(?![-\\w–\xad])', '\\1ais \\2erapias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_15>[a-zA-Zç]+)([áéíóú])rias(?![-\\w–\xad])', '\\1ais \\2\\3rias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_16>[a-zA-Zç]+)([áéíú])sias(?![-\\w–\xad])', '\\1ais \\2\\3sias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_17>[a-zA-Zç]+)([áéíóú])rsias(?![-\\w–\xad])', '\\1ais \\2\\3rsias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_18>[a-zA-Zç]+)([áéíóú])ssias(?![-\\w–\xad])', '\\1ais \\2\\3ssias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_19>[a-zA-Zç]+)([áéíóú])rnias(?![-\\w–\xad])', '\\1ais \\2\\3rnias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_20>[a-zA-Zç]+)([âêíôú])nias(?![-\\w–\xad])', '\\1ais \\2\\3nias', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_21>[a-zA-Z]+ista)s(?![-\\w–\xad])', '\\1ais \\2s', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ttal_21") in excIsta'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_22>[a-zA-Zç]+)(idas|idos)(?![-\\w–\xad])', '\\1ais \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ttal_22") in "lib-Lib"'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_23>[a-zA-Zç]+)(osas|osos)(?![-\\w–\xad])', '\\1ais \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_24>[a-zA-Zç]+)(ivas|ivos)(?![-\\w–\xad])', '\\1ais \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_25>[a-zA-Zç]+)mentos(?![-\\w–\xad])', '\\1ais \\2mentos', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_26>[a-zA-Zç]+[âêô][mn])(icas|icos)(?![-\\w–\xad])', '\\1ais \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_27>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])(icas|icos)(?![-\\w–\xad])', '\\1ais \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_28>[a-zA-Zç]+[áéíóúâêô][bcdlmnprstu][bcdfglmnprstvx])(icas|icos)(?![-\\w–\xad])', '\\1ais \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_29>[a-zA-Zç]+)(escas|escos)(?![-\\w–\xad])', '\\1ais \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_30>[a-zA-Zç]+[áéíóúâêô][bcdfglmnprstvx])(idas|idos)(?![-\\w–\xad])', '\\1ais \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_31>[a-zA-Zç]+[ó])(logas|logos)(?![-\\w–\xad])', '\\1ais \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_32>[a-zA-Zç]+[áéíóúâêô])(rias|rios)(?![-\\w–\xad])', '\\1ais \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_33>[a-zA-Zç]+[í])(ssimas|ssimos)(?![-\\w–\xad])', '\\1ais \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_34>[a-zA-Zç]+[é])(simas|simos)(?![-\\w–\xad])', '\\1ais \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_35>[a-zA-Zçáéíóúâêô]+[dst])(oras|ores)(?![-\\w–\xad])', '\\1ais \\2\\3', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_36>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '\\1ais \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_36") in plvrMascr'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_37>[a-zA-Záâãçéêíóôú]+[r])es(?![-\\w–\xad])', '\\1ais \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_37") in plvrFemr'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_38>[a-zA-Zçáéíóúâêô]+)us(?![-\\w–\xad])', '\\1ais \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_38") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_39>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '\\1ais \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_39") in plvrMasc'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_40>[a-zA-Záâãçéêíóôú]+)us(?![-\\w–\xad])', '\\1ais \\2us', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_40") in plvrFem'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_41>[a-zA-Zçáéíóúâêô]+[a])is(?![-\\w–\xad])', '\\1ais \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_41") in plvrMfal'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_42>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '\\1ais \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_42") in plvrMascal'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_43>[a-zA-Záâãçéêíóôú]+[a])is(?![-\\w–\xad])', '\\1ais \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_43") in plvrFemal'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_44>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1ais \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_44") in plvrMfel'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_45>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1ais \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_45") in plvrMascel'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_46>[a-zA-Z]+)éis(?![-\\w–\xad])', '\\1ais \\2éis', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_46") in plvrFemel'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_47>[a-zA-Záâãçéêíóôú]+[e])is(?![-\\w–\xad])', '\\1ais \\2is', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_47") in plvrAmascel'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_48>[a-zA-Zçáéíóúâêô]+[ç])ões(?![-\\w–\xad])', '\\1ais \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_48") in plvrMfcao'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_49>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '\\1ais \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_49") in plvrMascao'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_50>[a-zA-Záâãçéêíóôú]+[ç])ões(?![-\\w–\xad])', '\\1ais \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_50") in plvrNfemcao'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_51>[a-zA-Záâãçéêíóôú]+[abcdefghijlmnopstuvxz])ões(?![-\\w–\xad])', '\\1ais \\2ões', 'Não há concordância entre as palavras. Você quis dizer:', 'not m.group("Ttal_51") in plvrFemao and not m.group("Ttal_51") in excPlvrao'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_52>[a-zA-Záâãçéêíóôú]+)dades(?![-\\w–\xad])', '\\1ais \\2dades', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_53>[a-zA-Zç]+[áéíóú])veis(?![-\\w–\xad])', '\\1ais \\2veis', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_54>[a-zA-Zçáéíóúâêô]+)es(?![-\\w–\xad])', '\\1ais \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_54") in plvrMfe'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_55>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '\\1ais \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_55") in plvrMasce'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_56>[a-zA-Záâãçéêíóôú]+)es(?![-\\w–\xad])', '\\1ais \\2es', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_56") in plvrFeme'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_57>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1ais \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_57") in plvrInvaz'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_58>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1ais \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_58") in plvrMascz'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_59>[a-zA-Z]+)zes(?![-\\w–\xad])', '\\1ais \\2zes', 'Não há concordância entre as palavras. Você quis dizer:', 'm.group("Ttal_59") in plvrFemz'],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_60>[a-zA-Z]+)ízes(?![-\\w–\xad])', '\\1ais \\2ízes', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Tt])al (?P<Ttal_61>[a-zA-Záâãçéêíóôú]+[aeio])ns(?![-\\w–\xad])', '\\1ais \\2ns', 'Não há concordância entre as palavras. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([Cc])oordenador do ([Vv])ero(?![-\\w–\xad])', 'Raimundo Santos Moura', 'VERO, em desenvolvimento desde 2006.\\n http://pt-br.libreoffice.org/projetos/projeto-vero-verificador-ortografico/', False],
 ['(?u)(?<![-\\w–.,\xad])([0-9]+)(ºC|cm|cm2|cm²|cm3|cm³|dam|dm|ºF|g|Gb|h|Hz|J|Kb|kg|kgf|km|km2|km²|l|m|m2|m²|m3|m³|Mb|mg|min|mm|ppm|rpm|s|t|Tb|V|W)(?![-\\w–\xad])', '\\1 \\2', 'Unidade de medida deve estar separada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([0-9]+)o(C|F)(?![-\\w–\xad])', '\\1 º\\2', 'Unidade de medida deve estar separada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([0-9]+)(,)([0-9]+)(ºC|cm|cm2|cm²|cm3|cm³|dam|dm|ºF|g|Gb|h|Hz|J|Kb|kg|kgf|km|km2|km²|l|m|m2|m²|m3|m³|Mb|mg|min|mm|ppm|rpm|s|t|Tb|V|W)(?![-\\w–\xad])', '\\1,\\3 \\4', 'Unidade de medida deve estar separada. Você quis dizer:', False],
 ['(?u)(?<![-\\w–.,\xad])([0-9]+)(,)([0-9]+)o(C|F)(?![-\\w–\xad])', '\\1,\\3 º\\4', 'Unidade de medida deve estar separada. Você quis dizer:', False],
 ['(?u)([,;:?])([.,;:?])', '\\2', 'Sinal de pontuação extra? Você quis dizer:', False],
 ['(?u) ([.?!,:;)\u201d\\]])\\b', '\\1 ', 'Espaço e pontuação invertidos?', False],
 ['(?u) +[.]', '.', 'Espaço extra antes do período?', 'LOCALE.Country == "US"'],
 ['(?u) +[.]', '.', 'Espaço extra antes do ponto final?', 'LOCALE.Country != "US" and not "...." in TEXT'],
 ['(?u) +([?!,:;)\u201d\\]])', '\\1', '= "Intervalo extra antes " + punct[m.group(1)] + "?"', False],
 ['(?u)([([\u201c]) ', '\\1', '= "Intervalo extra depois " + punct[m.group(1)] + "?"', False],
 ['(?u)( -,)(?![-\\w–\xad])', ' –,\\n —,', 'Meio-traço ou travessão:', 'option(LOCALE,"ndash") and option(LOCALE,"mdash")'],
 ['(?u)\\b(- | -)\\b', '-', 'Espaço extra?', 'option(LOCALE,"ndash") and option(LOCALE,"mdash")'],
 ['(?u)\\b(---?| --? )\\b', ' – \\n—', 'Meio-traço ou travessão:', 'option(LOCALE,"ndash") and option(LOCALE,"mdash")'],
 ['(?u)(^)(---?| --? |--? )\\b', ' – \\n—', 'Meio-traço ou travessão:', 'option(LOCALE,"ndash") and option(LOCALE,"mdash")'],
 ['(?u)\\b(---?| --? |—)\\b', ' – ', 'Meio-traço:', 'option(LOCALE,"ndash") and not option(LOCALE,"mdash")'],
 ['(?u)\\b(---?| --? | – )\\b', '—', 'Travessão:', 'option(LOCALE,"mdash") and not option(LOCALE,"ndash")'],
 ['(?u)(?P<Abc_1>[a-zA-Záâãçéêíóôú]+)(?P<pun_1>[?!,:;%‰‱\u02da\u201c\u201d\u2018])(?P<Abc_2>[a-zA-Z]+)', '\\g<Abc_1>\\g<pun_1> \\g<Abc_2>', 'Falta espaço?', False],
 ['(?u)(?P<abc_1>[a-záâãçéêíóôú]+)[.](?P<ABC_1>[A-Z][a-záâçéêíóôú]+)', '\\g<abc_1>. \\g<ABC_1>', 'Falta espaço?', False],
 ['(?u)[)]', '', 'Parêntese de fechamento extra?', 'option(LOCALE,"pair") and not "(" in TEXT and not errosprnt.search(TEXT)'],
 ['(?u)[(]', '', 'Parêntese de abertura extra?', 'option(LOCALE,"pair") and TEXT[-1] in "?!;:\u201d\u2019" and not ")" in TEXT'],
 ['(?u)(?<![0-9])\u201d', '', 'Aspa extra?', 'option(LOCALE,"pair") and not "\u201c" in TEXT'],
 ['(?u)(?<=[0-9])\u201d', '\u2033\\n', 'Aspa dupla ou aspa simples adicional?', 'option(LOCALE,"apostrophe") and not "\u201c" in TEXT'],
 ['(?u)\u201c', '', 'Aspa extra?', 'option(LOCALE,"pair") and TEXT[-1] in "?!;:\u201d\u2019" and not "\u201d" in TEXT'],
 ['(?u)[.]{3}', '\u2026', 'Reticências?', 'not "...." in TEXT and option(LOCALE,"ellipsis")'],
 ['(?u)(\\b|[-–—]|[)\\]]) {2,70}(\\b|$)', '\\1 \\2', ' Espaço extra:', 'option(LOCALE,"spaces")'],
 ['(?u)(^|\\b|(?P<pun_1>[?!,:;%‰‱\u02da\u201c\u201d\u2018])|[.]) {2,3}(\\b|$)', '\\1 ', 'Intervalo extra.', 'option(LOCALE,"spaces2")'],
 ['(?u)(^|\\b|(?P<pun_1>[?!,:;%‰‱\u02da\u201c\u201d\u2018])|[.]) {4,}(\\b|$)', '\\1 \\n\t', 'Alterar espaços múltiplos para um único espaço ou uma tabulação:', 'option(LOCALE,"spaces3")'],
 ['(?u)[\\"\u201c\u201d\u201f\u201e]((?P<abc_1>[a-zA-Záâãçéêíóôú]+)[^\\"\u201c\u201d\u201f\u201e]*)[\\"\u201c\u201f]', '\u201c\\1\u201d', 'Aspas.', 'option(LOCALE,"quotation")'],
 ['(?u)[\\"\u201d\u201f\u201e]((?P<abc_1>[a-zA-Záâãçéêíóôú]+)[^\\"\u201c\u201d\u201f\u201e]*)[\\"\u201c\u201d\u201f]', '\u201c\\1\u201d', 'Aspas.', 'option(LOCALE,"quotation")'],
 [u"(?iu)\'(?P<abc_1>[a-zA-Záâãçéêíóôú]+)\'", '\u2018\\g<abc_1>\u2019', 'Aspa simples.', 'option(LOCALE,"apostrophe")'],
 ['(?u)[\\"\u201d\u201f\u201e]((?P<abc_1>[a-zA-Záâãçéêíóôú]+)[^\\"\u201c\u201d\u201f\u201e]*)[\\"\u201c\u201d\u201f]', '\u201c\\1\u201d', 'Aspas.', 'option(LOCALE,"apostrophe")'],
 [u"(?iu)(?P<Abc_1>[a-zA-Záâãçéêíóôú]+)'(?P<w_1>\\w*)", '\\g<Abc_1>\u2019', 'Substituir caractere do apóstrofo ou aspa:', 'not m.group("Abc_1") in "McDonald" and option(LOCALE,"apostrophe")'],
 [u"(?iu)(?<= )'(?P<Abc_1>[a-zA-Záâãçéêíóôú]+)", '\u2018\\g<Abc_1>\\n\u2019\\g<Abc_1>', 'Substituir caractere da aspa ou apóstrofo:', 'option(LOCALE,"apostrophe")'],
 [u"(?iu)^'(?P<Abc_1>[a-zA-Záâãçéêíóôú]+)", '\u2018\\g<Abc_1>\\n\u2019\\g<Abc_1>', 'Substituir caractere da aspa ou apóstrofo:', 'option(LOCALE,"apostrophe")']]
